%global __spec_install_pre %{___build_pre}

Summary: The Linux kernel

# For a stable, released kernel, released_kernel should be 1. For rawhide
# and/or a kernel built from an rc or git snapshot, released_kernel should
# be 0.
%define released_kernel 1

# Versions of various parts

# Polite request for people who spin their own kernel rpms:
# please modify the "buildid" define in a way that identifies
# that the kernel isn't the stock distribution kernel, for example,
# by setting the define to ".local" or ".bz123456"
#
# % define buildid .local

%define distro_build 431
%define signmodules 1

# if patch fuzzy patch applying will be forbidden
%define with_fuzzy_patches 0

# base_sublevel is the kernel version we're starting with and patching
# on top of -- for example, 2.6.22-rc7-git1 starts with a 2.6.21 base,
# which yields a base_sublevel of 21.
%define base_sublevel 32

## If this is a released kernel ##
%if 0%{?released_kernel}

# Do we have a -stable update to apply?
%define stable_update 0
# Is it a -stable RC?
%define stable_rc 0
# Set rpm version accordingly
%if 0%{?stable_update}
%define stablerev .%{stable_update}
%define stable_base %{stable_update}
%if 0%{?stable_rc}
# stable RCs are incremental patches, so we need the previous stable patch
%define stable_base %(echo $((%{stable_update} - 1)))
%endif
%endif
%define rpmversion 2.6.%{base_sublevel}%{?stablerev}

## The not-released-kernel case ##
%else
# The next upstream release sublevel (base_sublevel+1)
%define upstream_sublevel %(echo $((%{base_sublevel} + 1)))
# The rc snapshot level
%define rcrev 0
# The git snapshot level
%define gitrev 0
# Set rpm version accordingly
%define rpmversion 2.6.%{upstream_sublevel}
%endif
# Nb: The above rcrev and gitrev values automagically define Patch00 and Patch01 below.

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# standard kernel
%define with_up        %{?_without_up:        0} %{?!_without_up:        1}
# kernel-smp (only valid for ppc 32-bit)
%define with_smp       %{?_without_smp:       0} %{?!_without_smp:       1}
# kernel-kdump
%define with_kdump     %{?_without_kdump:     0} %{?!_without_kdump:     1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-doc
%define with_doc       %{?_without_doc:       0} %{?!_without_doc:       1}
# kernel-headers
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
# kernel-firmware
%define with_firmware  %{?_with_firmware:     1} %{?!_with_firmware:     0}
# perf noarch subpkg
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# kernel-bootwrapper (for creating zImages from kernel + initrd)
%define with_bootwrapper %{?_without_bootwrapper: 0} %{?!_without_bootwrapper: 1}
# Want to build a the vsdo directories installed
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}
# Use dracut instead of mkinitrd for initrd image generation
%define with_dracut       %{?_without_dracut:       0} %{?!_without_dracut:       1}
# kernel-abi-whitelists
%define with_kernel_abi_whitelists %{?_with_kernel_abi_whitelists: 0} %{?!_with_kernel_abi_whitelists: 1}

# Build the kernel-doc package, but don't fail the build if it botches.
# Here "true" means "continue" and "false" means "fail the build".
%if 0%{?released_kernel}
%define doc_build_fail false
%else
%define doc_build_fail true
%endif

# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}
# Control whether we perform a compat. check against published ABI.
%define with_fips      %{?_without_fips:      0} %{?!_without_fips:      1}

# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the smp kernel (--with smponly):
%define with_smponly   %{?_with_smponly:      1} %{?!_with_smponly:      0}
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}

# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}

# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}

# Set debugbuildsenabled to 1 for production (build separate debug kernels)
#  and 0 for rawhide (all kernels are debug kernels).
# See also 'make debug' and 'make release'.
%define debugbuildsenabled 1

# pkg_release is what we'll fill in for the rpm Release: field
%if 0%{?released_kernel}

%if 0%{?stable_rc}
%define stable_rctag .rc%{stable_rc}
%endif
%define pkg_release %{distro_build}%{?stable_rctag}%{?dist}%{?buildid}

%else

# non-released_kernel
%if 0%{?rcrev}
%define rctag .rc%rcrev
%else
%define rctag .rc0
%endif
%if 0%{?gitrev}
%define gittag .git%gitrev
%else
%define gittag .git0
%endif
%define pkg_release 0.%{distro_build}%{?rctag}%{?gittag}%{?dist}%{?buildid}

%endif

# The kernel tarball/base version
%define kversion 2.6.32-431.el6

%define make_target bzImage

%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if 0%{!?nopatches:1}
%define nopatches 0
%endif

%if %{nopatches}
%define with_bootwrapper 0
%define variant -vanilla
%else
%define variant_fedora -fedora
%endif

%define using_upstream_branch 0
%if 0%{?upstream_branch:1}
%define stable_update 0
%define using_upstream_branch 1
%define variant -%{upstream_branch}%{?variant_fedora}
%define pkg_release 0.%{distro_build}%{upstream_branch_tag}%{?dist}%{?buildid}
%endif

%define pkg_release %{distro_build}%{?dist}%{?buildid}
%define KVERREL %{rpmversion}-%{pkg_release}.%{_target_cpu}

%if !%{debugbuildsenabled}
%define with_debug 0
%endif

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug

%define with_pae 0

# if requested, only build base kernel
%if %{with_baseonly}
%define with_smp 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build smp kernel
%if %{with_smponly}
%define with_up 0
%define with_kdump 0
%define with_debug 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%if %{debugbuildsenabled}
%define with_up 0
%endif
%define with_smp 0
%define with_pae 0
%define with_xen 0
%define with_kdump 0
%define with_perf 0
%endif

%define all_x86 i386 i686

%if %{with_vdso_install}
# These arches install vdso/ directories.
%define vdso_arches %{all_x86} x86_64 ppc ppc64 s390 s390x
%endif

# Overrides for generic default options

# only ppc and alphav56 need separate smp kernels
%ifnarch ppc alphaev56
%define with_smp 0
%endif

%ifarch s390x
%define with_kdump 1
%else
%define with_kdump 0
%endif

# don't do debug builds on anything but i686 and x86_64
%ifnarch i686 x86_64 s390x ppc64
%define with_debug 0
%endif

# only package docs noarch
%ifnarch noarch
%define with_doc 0
%define with_kernel_abi_whitelists 0
%endif

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define with_perf 0
%define signmodules 0
%define all_arch_configs kernel-%{version}-*.config
%define with_firmware  %{?_without_firmware:  0} %{?!_without_firmware:  1}
%endif

# bootwrapper is only on ppc
%ifnarch ppc ppc64
%define with_bootwrapper 0
%endif

# sparse blows up on ppc64 alpha and sparc64
%ifarch ppc64 ppc alpha sparc64
%define with_sparse 0
%endif

# Per-arch tweaks

%ifarch %{all_x86}
%define asmarch x86
%define hdrarch i386
%define all_arch_configs kernel-%{version}-i?86*.config
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch x86_64
%define asmarch x86
%define all_arch_configs kernel-%{version}-x86_64*.config
%define image_install_path boot
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64
%define asmarch powerpc
%define hdrarch powerpc
%define all_arch_configs kernel-%{version}-ppc64*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%endif

%ifarch s390
%define all_arch_configs kernel-%{kversion}-s390*.config
%define image_install_path boot
%define make_target image
%define kernel_image arch/s390/boot/image
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs kernel-%{version}-s390x*.config
%define image_install_path boot
%define make_target image
%define kernel_image arch/s390/boot/image
%endif

%ifarch sparc
# We only build sparc headers since we dont support sparc32 hardware
%endif

%ifarch sparc64
%define asmarch sparc
%define all_arch_configs kernel-%{version}-sparc64*.config
%define make_target image
%define kernel_image arch/sparc/boot/image
%define image_install_path boot
%define with_perf 0
%endif

%ifarch ppc
%define asmarch powerpc
%define hdrarch powerpc
%define all_arch_configs kernel-%{version}-ppc{-,.}*config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%endif

%ifarch ia64
%define all_arch_configs kernel-%{version}-ia64*.config
%define image_install_path boot/efi/EFI/redhat
%define make_target compressed
%define kernel_image vmlinux.gz
%endif

%ifarch alpha alphaev56
%define all_arch_configs kernel-%{version}-alpha*.config
%define image_install_path boot
%define make_target vmlinux
%define kernel_image vmlinux
%endif

%ifarch %{arm}
%define all_arch_configs kernel-%{version}-arm*.config
%define image_install_path boot
%define hdrarch arm
%define make_target vmlinux
%define kernel_image vmlinux
%endif

%if %{nopatches}
# XXX temporary until last vdso patches are upstream
%define vdso_arches ppc ppc64
%endif

%if %{nopatches}%{using_upstream_branch}
# Ignore unknown options in our config-* files.
# Some options go with patches we're not applying.
%define oldconfig_target loose_nonint_oldconfig
%else
%define oldconfig_target nonint_oldconfig
%endif

# To temporarily exclude an architecture from being built, add it to
# %nobuildarches. Do _NOT_ use the ExclusiveArch: line, because if we
# don't build kernel-headers then the new build system will no longer let
# us use the previous build of that package -- it'll just be completely AWOL.
# Which is a BadThing(tm).

# We don't build a kernel on i386; we only do kernel-headers there,
# and we no longer build for 31bit S390. Same for 32bit sparc and arm.
%define nobuildarches i386 i586 s390 sparc sparc64 ppc ia64 %{arm}

%ifarch %nobuildarches
%define with_up 0
%define with_smp 0
%define with_pae 0
%define with_kdump 0
%define with_debuginfo 0
%define with_perf 0
%define _enable_debug_packages 0
%endif

%define with_pae_debug 0
%if %{with_pae}
%define with_pae_debug %{with_debug}
%endif

#
# Three sets of minimum package version requirements in the form of Conflicts:
# to versions below the minimum
#

#
# First the general kernel 2.6 required versions as per
# Documentation/Changes
#
%define kernel_dot_org_conflicts  ppp < 2.4.3-3, isdn4k-utils < 3.2-32, nfs-utils < 1.0.7-12, e2fsprogs < 1.37-4, util-linux < 2.12, jfsutils < 1.1.7-2, reiserfs-utils < 3.6.19-2, xfsprogs < 2.6.13-4, procps < 3.2.5-6.3, oprofile < 0.9.1-2

#
# Then a series of requirements that are distribution specific, either
# because we add patches for something, or the older versions have
# problems with the newer kernel or lack certain things that make
# integration in the distro harder than needed.
#
%define package_conflicts initscripts < 7.23, udev < 145-11, iptables < 1.3.2-1, ipw2200-firmware < 2.4, iwl4965-firmware < 228.57.2, selinux-policy-targeted < 1.25.3-14, squashfs-tools < 4.0, wireless-tools < 29-3, bfa-firmware < 3.2.21.1-2

#
# The ld.so.conf.d file we install uses syntax older ldconfig's don't grok.
#
%define kernel_xen_conflicts glibc < 2.3.5-1, xen < 3.0.1

%define kernel_PAE_obsoletes kernel-smp < 2.6.17, kernel-xen <= 2.6.27-0.2.rc0.git6.fc10
%define kernel_PAE_provides kernel-xen = %{rpmversion}-%{pkg_release}

%ifarch x86_64
%define kernel_obsoletes kernel-xen <= 2.6.27-0.2.rc0.git6.fc10
%define kernel_provides kernel-xen = %{rpmversion}-%{pkg_release}
%endif

# We moved the drm include files into kernel-headers, make sure there's
# a recent enough libdrm-devel on the system that doesn't have those.
%define kernel_headers_conflicts libdrm-devel < 2.4.0-0.15

#
# Packages that need to be installed before the kernel is, because the %post
# scripts use them.
#
%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, kernel-firmware >= %{rpmversion}-%{pkg_release}, grubby >= 7.0.4-1
%if %{with_dracut}
%define initrd_prereq  dracut-kernel >= 002-18.git413bcf78
%else
%define initrd_prereq  mkinitrd >= 6.0.61-1
%endif

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: kernel = %{rpmversion}-%{pkg_release}\
Provides: kernel-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:.%{1}}\
Provides: kernel-drm = 4.3.0\
Provides: kernel-drm-nouveau = 16\
Provides: kernel-modeset = 1\
Provides: kernel-uname-r = %{KVERREL}%{?1:.%{1}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(post): /sbin/new-kernel-pkg\
Requires(preun): /sbin/new-kernel-pkg\
Conflicts: %{kernel_dot_org_conflicts}\
Conflicts: %{package_conflicts}\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}

Name: kernel%{?variant}
Group: System Environment/Kernel
License: GPLv2
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# DO NOT CHANGE THE 'ExclusiveArch' LINE TO TEMPORARILY EXCLUDE AN ARCHITECTURE BUILD.
# SET %%nobuildarches (ABOVE) INSTEAD
ExclusiveArch: noarch %{all_x86} x86_64 ppc ppc64 ia64 sparc sparc64 s390 s390x alpha alphaev56 %{arm}
ExclusiveOS: Linux

%kernel_reqprovconf
%ifarch x86_64 sparc64
Obsoletes: kernel-smp
%endif


#
# List the packages used during the kernel build
#
BuildRequires: module-init-tools, patch >= 2.5.4, bash >= 2.03, sh-utils, tar
BuildRequires: bzip2, findutils, gzip, m4, perl, make >= 3.78, diffutils, gawk
BuildRequires: gcc >= 3.4.2, binutils >= 2.12, redhat-rpm-config
BuildRequires: net-tools, patchutils, rpm-build >= 4.8.0-7
BuildRequires: xmlto, asciidoc
%if %{with_sparse}
BuildRequires: sparse >= 0.4.1
%endif
%if %{with_perf}
BuildRequires: elfutils-libelf-devel elfutils-devel zlib-devel binutils-devel newt-devel python-devel audit-libs-devel perl(ExtUtils::Embed) bison flex

%endif
%if %{signmodules}
BuildRequires: gnupg
%endif
BuildRequires: python
%if %{with_fips}
BuildRequires: hmaccalc
%endif
%ifarch s390x
# Ensure glibc{,-devel} is installed so zfcpdump can be built
BuildRequires: glibc-static
%endif

BuildConflicts: rhbuildsys(DiskFree) < 7Gb

%if %{with_debuginfo}
# Fancy new debuginfo generation introduced in Fedora 8.
%define debuginfo_args --strict-build-id
%endif

#cross compile make
%if %{with_cross}
%if "%{_target_cpu}" == "i686"
%define cross_opts CROSS_COMPILE=i686-unknown-linux-gnu-
%endif
%if "%{_target_cpu}" == "s390x"
%define cross_opts CROSS_COMPILE=s390x-unknown-linux-gnu-
%endif
%if "%{_target_cpu}" == "ppc64"
%define cross_opts CROSS_COMPILE=powerpc64-unknown-linux-gnu-
%define strip_cmd /opt/crosstool/gcc-glibc/powerpc64-unknown-linux-gnu/bin/powerpc64-unknown-linux-gnu-strip
%endif
%else
%define strip_cmd strip
%endif

Source0: linux-2.6.32-431.el6.tar.bz2

Source1: Makefile.common

%if 0%{?rcrev}
Source2: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/testing/incr/patch-2.6.%{upstream_sublevel}-rc%{rcrev}.bz2
%if 0%{?gitrev}
Source3: ftp://ftp.kernel.org/pub/linux/kernel/v2.6/testing/incr/patch-2.6.%{upstream_sublevel}-rc%{rcrev}-git%{gitrev}.bz2
%endif
%endif

Source11: genkey
Source13: perf-archive
Source14: find-provides
Source15: merge.pl
Source16: perf
Source17: kabitool
Source18: check-kabi
Source19: extrakeys.pub

Source20: Makefile.config

Source30: Module.kabi_i686
Source31: Module.kabi_ppc64
Source32: Module.kabi_s390x
Source33: Module.kabi_x86_64
Source34: Module.kabi_greylist_i686
Source35: Module.kabi_greylist_ppc64
Source36: Module.kabi_greylist_s390x
Source37: Module.kabi_greylist_x86_64
Source38: kernel-abi-whitelists.tar.bz2

Source50: config-x86_64-generic
Source51: config-s390x-rhel
Source52: config-nodebug
Source53: config-powerpc64-debug
Source54: config-generic
Source55: config-ia64-generic-rhel
Source56: config-i686-debug
Source57: config-i686-nodebug
Source58: config-powerpc64
Source59: config-s390x-kdump-rhel
Source60: config-framepointer
Source61: config-powerpc-generic
Source62: config-x86_64-nodebug
Source63: config-generic-rhel
Source64: config-x86-generic-rhel
Source65: config-s390x-kdump
Source66: config-x86_64-generic-rhel
Source67: config-s390x-debug
Source68: config-i686-debug-rhel
Source69: config-x86_64-debug
Source70: config-powerpc64-kdump
Source71: config-x86_64-nodebug-rhel
Source72: config-s390x
Source73: config-i686-nodebug-rhel
Source74: config-powerpc64-rhel
Source75: config-x86_64-debug-rhel
Source76: config-debug-rhel
Source77: config-debug
Source78: config-i686-rhel
Source79: config-i686
Source80: config-powerpc-generic-rhel
Source81: config-x86-generic
Source82: config-nodebug-rhel
Source83: config-powerpc64-kdump-rhel
Source84: config-s390x-generic-rhel
Source85: config-powerpc64-debug-rhel
Source86: config-s390x-debug-rhel

# empty final patch file to facilitate testing of kernel patches
Patch999999: linux-kernel-test.patch

BuildRoot: %{_tmppath}/kernel-%{KVERREL}-root

# Override find_provides to use a script that provides "kernel(symbol) = hash".
# Pass path of the RPM temp dir containing kabideps to find-provides script.
%global _use_internal_dependency_generator 0
%define __find_provides %_sourcedir/find-provides %{_tmppath}
%define __find_requires /usr/lib/rpm/redhat/find-requires kernel

%description
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.


%package doc
Summary: Various documentation bits found in the kernel source
Group: Documentation
%description doc
This package contains documentation files from the kernel
source. Various bits of information about the Linux kernel and the
device drivers shipped with it are documented in these files.

You'll want to install this package if you need a reference to the
options that can be passed to Linux kernel modules at load time.


%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders
Provides: glibc-kernheaders = 3.0-46
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package firmware
Summary: Firmware files used by the Linux kernel
Group: Development/System
# This is... complicated.
# Look at the WHENCE file.
License: GPL+ and GPLv2+ and MIT and Redistributable, no modification permitted
%if "x%{?variant}" != "x"
Provides: kernel-firmware = %{rpmversion}-%{pkg_release}
%endif
%description firmware
Kernel-firmware includes firmware files required for some devices to
operate.

%package bootwrapper
Summary: Boot wrapper files for generating combined kernel + initrd images
Group: Development/System
Requires: gzip
%description bootwrapper
Kernel-bootwrapper contains the wrapper code which makes bootable "zImage"
files combining both kernel and initial ramdisk.

%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Group: Development/System
License: GPLv2
Provides: perl(Perf::Trace::Context) = 0.01
Provides: perl(Perf::Trace::Core) = 0.01
Provides: perl(Perf::Trace::Util) = 0.01
%description -n perf
This package provides the perf tool and the supporting documentation.

%package -n perf-debuginfo
Summary: Debug information for package perf
Group: Development/Debug
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for package perf.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|XXX' -o perf-debuginfo.list}

%package -n python-perf
Summary: Python bindings for apps which will manipulate perf events
Group: Development/Libraries
%description -n python-perf
The python-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%{!?python_sitearch: %global python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

%package -n python-perf-debuginfo
Summary: Debug information for package perf python bindings
Group: Development/Debug
AutoReqProv: no
%description -n python-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '.*%%{python_sitearch}/perf.so(\.debug)?|XXX' -o python-perf-debuginfo.list}

%endif

%package -n kernel-abi-whitelists
Summary: The Red Hat Enterprise Linux kernel ABI symbol whitelists
Group: System Environment/Kernel
AutoReqProv: no
Obsoletes: kabi-whitelists
Provides: kabi-whitelists
%description -n kernel-abi-whitelists
The kABI package contains information pertaining to the Red Hat Enterprise
Linux kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
AutoReqProv: no\
%description -n %{name}%{?1:-%{1}}-debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVERREL}%{?1:\.%{1}}/.*|/.*%%{KVERREL}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: kernel%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: kernel-devel-%{_target_cpu} = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-devel = %{version}-%{release}%{?1:.%{1}}\
Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
AutoReqProv: no\
Requires(pre): /usr/bin/find\
%description -n kernel%{?variant}%{?1:-%{1}}-devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %1\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
%kernel_reqprovconf\
%{expand:%%kernel_devel_package %1 %{!?-n:%1}%{?-n:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %1}\
%{nil}


# First the auxiliary packages of the main kernel package.
%kernel_devel_package
%kernel_debuginfo_package


# Now, each variant package.

%define variant_summary The Linux kernel compiled for SMP machines
%kernel_variant_package -n SMP smp
%description smp
This package includes a SMP version of the Linux kernel. It is
required only on machines with two or more CPUs as well as machines with
hyperthreading technology.

Install the kernel-smp package if your machine uses two or more CPUs.


%define variant_summary The Linux kernel compiled for PAE capable machines
%kernel_variant_package PAE
%description PAE
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.


%define variant_summary The Linux kernel compiled with extra debugging enabled for PAE capable machines
%kernel_variant_package PAEdebug
Obsoletes: kernel-PAE-debug
%description PAEdebug
This package includes a version of the Linux kernel with support for up to
64GB of high memory. It requires a CPU with Physical Address Extensions (PAE).
The non-PAE kernel can only address up to 4GB of memory.
Install the kernel-PAE package if your machine has more than 4GB of memory.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.


%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.


%define variant_summary A minimal Linux kernel compiled for crash dumps
%kernel_variant_package kdump
%description kdump
This package includes a kdump version of the Linux kernel. It is
required only on machines which will use the kexec-based kernel crash dump
mechanism.


%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}%{with_pae}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

%if %{with_smponly}
%if !%{with_smp}
echo "Cannot build --with smponly, smp build is disabled"
exit 1
%endif
%endif

%if %{with_fuzzy_patches}
  patch_command='patch -p1 -s'
%else
  patch_command='patch -p1 -F1 -s'
%endif

ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz) gunzip < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

# we don't want a .config file when building firmware: it just confuses the build system
%define build_firmware \
   mv .config .config.firmware_save \
   make INSTALL_FW_PATH=$RPM_BUILD_ROOT/lib/firmware firmware_install \
   mv .config.firmware_save .config

if [ ! -d kernel-%{kversion}/vanilla-%{kversion}/ ]; then
	rm -f pax_global_header;
%setup -q -n kernel-%{kversion} -c
	mv linux-%{kversion} vanilla-%{kversion};
else
	cd kernel-%{kversion}/;
fi

if [ -d linux-%{KVERREL} ]; then
  # Just in case we ctrl-c'd a prep already
  rm -rf deleteme.%{_target_cpu}
  # Move away the stale away, and delete in background.
  mv linux-%{KVERREL} deleteme.%{_target_cpu}
  rm -rf deleteme.%{_target_cpu} &
fi

cp -rl vanilla-%{kversion} linux-%{KVERREL}

cd linux-%{KVERREL}

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/config-* .
cp %{SOURCE15} %{SOURCE1} %{SOURCE16} %{SOURCE17} %{SOURCE18} .

# Dynamically generate kernel .config files from config-* files
make -f %{SOURCE20} VERSION=%{version} configs

ApplyOptionalPatch linux-kernel-test.patch

# Any further pre-build tree manipulations happen here.

chmod +x scripts/checkpatch.pl

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

mkdir configs

# Remove configs not for the buildarch
for cfg in kernel-%{version}-*.config; do
  if [ `echo %{all_arch_configs} | grep -c $cfg` -eq 0 ]; then
    rm -f $cfg
  fi
done

%if !%{debugbuildsenabled}
rm -f kernel-%{version}-*debug.config
%endif

# now run oldconfig over all the config files
for i in *.config
do
  mv $i .config
  Arch=`head -1 .config | cut -b 3-`
  make ARCH=$Arch %{oldconfig_target} > /dev/null
  echo "# $Arch" > configs/$i
  cat .config >> configs/$i
  rm -f include/generated/kernel.arch
  rm -f include/generated/kernel.cross
done
# end of kernel config
%endif

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

%if %{signmodules}
cp %{SOURCE19} .
cat <<EOF
###
### Now generating a PGP key pair to be used for signing modules.
###
### If this takes a long time, you might wish to run rngd in the background to
### keep the supply of entropy topped up.  It needs to be run as root, and
### should use a hardware random number generator if one is available, eg:
###
###     rngd -r /dev/hwrandom
###
### If one isn't available, the pseudo-random number generator can be used:
###
###     rngd -r /dev/urandom
###
EOF
gpg --homedir . --batch --gen-key %{SOURCE11}
cat <<EOF
###
### Key pair generated.
###
EOF
# if there're external keys to be included
if [ -s %{SOURCE19} ]; then
	gpg --homedir . --no-default-keyring --keyring kernel.pub --import %{SOURCE19}
fi
gpg --homedir . --export --keyring ./kernel.pub Red > extract.pub
gcc -o scripts/bin2c scripts/bin2c.c
scripts/bin2c ksign_def_public_key __initdata <extract.pub >crypto/signature/key.h
%endif

cd ..

###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

%if %{with_debuginfo}
# This override tweaks the kernel makefiles so that we run debugedit on an
# object before embedding it.  When we later run find-debuginfo.sh, it will
# run debugedit again.  The edits it does change the build ID bits embedded
# in the stripped object, but repeating debugedit is a no-op.  We do it
# beforehand to get the proper final build ID bits into the embedded image.
# This affects the vDSO images in vmlinux, and the vmlinux image in bzImage.
export AFTER_LINK=\
'sh -xc "/usr/lib/rpm/debugedit -b $$RPM_BUILD_DIR -d /usr/src/debug -i $@"'
%endif

cp_vmlinux()
{
  %{strip_cmd} -R .note -R .comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$3
    InstallName=${4:-vmlinuz}

    # Pick the right config file for the kernel we're building
    Config=kernel-%{version}-%{_target_cpu}${Flavour:+-${Flavour}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Flavour:+.${Flavour}}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{version}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = %{?stablerev}-%{release}.%{_target_cpu}${Flavour:+.${Flavour}}/" Makefile

    # if pre-rc1 devel kernel, must fix up SUBLEVEL for our versioning scheme
    %if !0%{?rcrev}
    %if 0%{?gitrev}
    perl -p -i -e 's/^SUBLEVEL.*/SUBLEVEL = %{upstream_sublevel}/' Makefile
    %endif
    %endif

    # and now to start the build process

    make -s mrproper
    cp configs/$Config .config

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    if [ "$Arch" == "s390" -a "$Flavour" == "kdump" ]; then
        pushd arch/s390/boot
        gcc -static -o zfcpdump zfcpdump.c
        popd
    fi
    make -s %{?cross_opts} ARCH=$Arch %{oldconfig_target} > /dev/null
    make -s %{?cross_opts} ARCH=$Arch V=1 %{?_smp_mflags} $MakeTarget %{?sparse_mflags}
    if [ "$Arch" != "s390" -o "$Flavour" != "kdump" ]; then
	make -s %{?cross_opts} ARCH=$Arch V=1 %{?_smp_mflags} modules %{?sparse_mflags} || exit 1
    fi

    # Start installing the results
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/boot
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
    install -m 644 System.map $RPM_BUILD_ROOT/%{debuginfodir}/boot/System.map-$KernelVer
%endif
    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
%if %{with_dracut}
    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20
%else
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initrd-$KernelVer.img bs=1M count=5
%endif
    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
    fi
    $CopyKernel $KernelImage \
    		$RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer

%if %{with_fips}
    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    sha512hmac $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer | sed -e "s,$RPM_BUILD_ROOT,," > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
%endif

    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
    # Override $(mod-fw) because we don't want it to install any firmware
    # We'll do that ourselves with 'make firmware_install'
    if [ "$Arch" != "s390" -o "$Flavour" != "kdump" ]; then
      make -s %{?cross_opts} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=

      # check if the modules are being signed
%if %{signmodules}
      if [ -z "$(readelf -n $(find fs/ -name \*.ko | head -n 1) | grep module.sig)" ]; then
          echo "ERROR: modules are NOT signed" >&2;
          exit 1;
      fi
%endif
    else
      mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/{kernel,extra}
    fi

    if [ "$Flavour" == "debug" ]; then
        mkdir -p $RPM_BUILD_ROOT/%{_libexecdir}/$KernelVer/vm;
        install -m 755 Documentation/vm/{page-types,slabinfo} $RPM_BUILD_ROOT/%{_libexecdir}/$KernelVer/vm;
    fi

%ifarch %{vdso_arches}
    make -s %{?cross_opts} ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
    if grep '^CONFIG_XEN=y$' .config >/dev/null; then
      echo > ldconfig-kernel.conf "\
# This directive teaches ldconfig to search in nosegneg subdirectories
# and cache the DSOs there with extra bit 1 set in their hwcap match
# fields.  In Xen guest kernels, the vDSO tells the dynamic linker to
# search in nosegneg subdirectories and to match this extra hwcap bit
# in the ld.so.cache file.
hwcap 1 nosegneg"
    fi
    if [ ! -s ldconfig-kernel.conf ]; then
      echo > ldconfig-kernel.conf "\
# Placeholder file, no vDSO hwcap entries used in this kernel."
    fi
    %{__install} -D -m 444 ldconfig-kernel.conf \
        $RPM_BUILD_ROOT/etc/ld.so.conf.d/kernel-$KernelVer.conf
%endif

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz

%if %{with_kabichk}
    chmod 0755 %_sourcedir/kabitool
    rm -f %{_tmppath}/kernel-$KernelVer-kabideps
    %_sourcedir/kabitool -s Module.symvers -o %{_tmppath}/kernel-$KernelVer-kabideps

    # whitelist checking
    # if this one fails, the build fails
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    whitelist=$RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour
    if [ -e $whitelist ]; then
        $RPM_SOURCE_DIR/check-kabi -k $whitelist -s Module.symvers || exit 1
    else
        echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi

    # greylist checking
    # if this one fails, we go on with warnings in build log
    greylist=$RPM_SOURCE_DIR/Module.kabi_greylist_%{_target_cpu}$Flavour
    if [ -e $greylist ]; then
        echo "**** kABI: greylist checking start ****"
        $RPM_SOURCE_DIR/check-kabi -k $greylist -s Module.symvers
        echo "**** kABI: greylist checking stop  ****"
    fi

%endif
    # Ensure the kabideps file always exists for the RPM ProvReq scripts
    touch %{_tmppath}/kernel-$KernelVer-kabideps

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
%ifarch ppc
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cd include
    cp -a acpi config crypto keys linux math-emu media mtd net pcmcia rdma rxrpc scsi sound trace video drm asm-generic $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    asmdir=$(readlink asm)
    cp -a $asmdir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/
    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    ln -s $asmdir asm
    popd
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/version.h
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/linux/autoconf.h
    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf
    cd ..

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    fgrep /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
      LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking \
			 'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|register_netdevice'
    collect_modules_list block \
			 'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm \
    			 'drm_open|drm_init'
    collect_modules_list modesetting \
    			 'drm_crtc_init'

    # detect missing or incorrect license tags
    rm -f modinfo
    while read i
    do
      echo -n "${i#$RPM_BUILD_ROOT/lib/modules/$KernelVer/} " >> modinfo
      /sbin/modinfo -l $i >> modinfo
    done < modnames

    egrep -v \
    	  'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' \
	  modinfo && exit 1

    rm -f modinfo modnames

    # remove files that will be auto generated by depmod at rpm -i time
    for i in alias alias.bin ccwmap dep dep.bin ieee1394map inputmap isapnpmap ofmap pcimap seriomap symbols symbols.bin usbmap
    do
      rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$i
    done

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir
    ln -sf ../../..$DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot

cd linux-%{KVERREL}

%if %{with_up}
BuildKernel %make_target %kernel_image
%endif

%if %{with_debug}
BuildKernel %make_target %kernel_image debug
%endif

%if %{with_pae_debug}
BuildKernel %make_target %kernel_image PAEdebug
%endif

%if %{with_pae}
BuildKernel %make_target %kernel_image PAE
%endif

%if %{with_smp}
BuildKernel %make_target %kernel_image smp
%endif

%if %{with_kdump}
%ifarch s390x
BuildKernel %make_target %kernel_image kdump
%else
BuildKernel vmlinux vmlinux kdump vmlinux
%endif
%endif

%if %{with_doc}
# Make the HTML and man pages.
make -j1 htmldocs mandocs || %{doc_build_fail}

# sometimes non-world-readable files sneak into the kernel source tree
chmod -R a=rX Documentation
find Documentation -type d | xargs chmod u+w
%endif

%global perf_make \
  make %{?_smp_mflags} -C tools/perf -s V=1 prefix=%{_prefix}
%if %{with_perf}
%{perf_make} all
%{perf_make} man || %{doc_build_fail}
%endif

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%define __debug_install_post \
  /usr/lib/rpm/find-debuginfo.sh %{debuginfo_args} %{_builddir}/%{?buildsubdir}\
%{nil}

%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%defattr(-,root,root)
%endif

%endif

###
### install
###

%install
# for some reason, on RHEL-5 RPM_BUILD_ROOT doesn't get set
if [ -z "$RPM_BUILD_ROOT" ]; then
	export RPM_BUILD_ROOT="%{buildroot}";
fi

cd linux-%{KVERREL}

%if %{with_doc}
docdir=$RPM_BUILD_ROOT%{_datadir}/doc/kernel-doc-%{rpmversion}
man9dir=$RPM_BUILD_ROOT%{_datadir}/man/man9

# copy the source over
mkdir -p $docdir
tar -f - --exclude=man --exclude='.*' -c Documentation | tar xf - -C $docdir

# Install man pages for the kernel API.
mkdir -p $man9dir
find Documentation/DocBook/man -name '*.9.gz' -print0 |
xargs -0 --no-run-if-empty %{__install} -m 444 -t $man9dir $m
ls $man9dir | grep -q '' || > $man9dir/BROKEN
%endif # with_doc

%if %{with_kernel_abi_whitelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
# current kabi release directory
KABI_CURRENT=kabi-rhel65

mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar xjvf %{SOURCE38} -C $INSTALL_KABI_PATH

# add 'kabi-current' link
(cd $INSTALL_KABI_PATH; ln -s $KABI_CURRENT kabi-current)
%endif  # with_kernel_abi_whitelists

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# # perf man pages (note: implicit rpm magic compresses them later)
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-man || %{doc_build_fail}
%endif

%if %{with_headers}
# Install kernel headers
make %{?cross_opts} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

# Do headers_check but don't die if it fails.
make %{?cross_opts} ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_check \
     > hdrwarnings.txt || :
if grep -q exist hdrwarnings.txt; then
   sed s:^$RPM_BUILD_ROOT/usr/include/:: hdrwarnings.txt
   # Temporarily cause a build failure if header inconsistencies.
   # exit 1
fi

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
     	-name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# glibc provides scsi headers for itself, for now
rm -rf $RPM_BUILD_ROOT/usr/include/scsi
rm -f $RPM_BUILD_ROOT/usr/include/asm*/atomic.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/io.h
rm -f $RPM_BUILD_ROOT/usr/include/asm*/irq.h
%endif

%if %{with_firmware}
%{build_firmware}
%endif

%if %{with_bootwrapper}
make %{?cross_opts} ARCH=%{hdrarch} DESTDIR=$RPM_BUILD_ROOT bootwrapper_install WRAPPER_OBJDIR=%{_libdir}/kernel-wrapper WRAPPER_DTSDIR=%{_libdir}/kernel-wrapper/dts
%endif


###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:.%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*.el6*.*/$f $f\
     done)\
fi\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
# grubby might be called during installation when a boot loader configuration
# file is not present, so just drop any error messages. See BZ#610813 for
# more details.
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1}}\
%{expand:\
NEWKERNARGS=""\
(/sbin/grubby --info=`/sbin/grubby --default-kernel`) 2>/dev/null | grep -q crashkernel\
if [ $? -ne 0 ]\
then\
	NEWKERNARGS="--kernel-args=\"crashkernel=auto\""\
fi\
%if %{with_dracut}\
/sbin/new-kernel-pkg --package kernel%{?1:-%{1}} --mkinitrd --dracut --depmod --update %{KVERREL}%{?1:.%{1}} $NEWKERNARGS || exit $?\
%else\
/sbin/new-kernel-pkg --package kernel%{?1:-%{1}} --mkinitrd --depmod --update %{KVERREL}%{?1:.%{1}} $NEWKERNARGS || exit $?\
%endif}\
/sbin/new-kernel-pkg --package kernel%{?1:-%{1}} --rpmposttrans %{KVERREL}%{?1:.%{1}} || exit $?\
if [ -x /sbin/weak-modules ]\
then\
    /sbin/weak-modules --add-kernel %{KVERREL}%{?1:.%{1}} || exit $?\
fi\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*}}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
if grep --silent '^hwcap 0 nosegneg$' /etc/ld.so.conf.d/kernel-*.conf 2> /dev/null; then\
  sed -i '/^hwcap 0 nosegneg$/ s/0/1/' /etc/ld.so.conf.d/kernel-*.conf\
fi\
%{expand:\
/sbin/new-kernel-pkg --package kernel%{?-v:-%{-v*}} --install %{KVERREL}%{?-v:.%{-v*}} || exit $?\
}\
%{nil}

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1}}\
/sbin/new-kernel-pkg --rminitrd --rmmoddep --remove %{KVERREL}%{?1:.%{1}} || exit $?\
if [ -x /sbin/weak-modules ]\
then\
    /sbin/weak-modules --remove-kernel %{KVERREL}%{?1:.%{1}} || exit $?\
fi\
%{nil}

%kernel_variant_preun
%ifarch x86_64
%kernel_variant_post -r (kernel-smp|kernel-xen)
%else
%kernel_variant_post -r kernel-smp
%endif

%kernel_variant_preun smp
%kernel_variant_post -v smp

%kernel_variant_preun PAE
%kernel_variant_post -v PAE -r (kernel|kernel-smp|kernel-xen)

%kernel_variant_preun debug
%kernel_variant_post -v debug

%kernel_variant_post -v PAEdebug -r (kernel|kernel-smp|kernel-xen)
%kernel_variant_preun PAEdebug

%ifarch s390x
%postun kdump
    # Create softlink to latest remaining kdump kernel.
    # If no more kdump kernel is available, remove softlink.
    if [ "$(readlink /boot/zfcpdump)" == "/boot/vmlinuz-%{KVERREL}.kdump" ]
    then
        vmlinuz_next=$(ls /boot/vmlinuz-*.kdump 2> /dev/null | sort | tail -n1)
        if [ $vmlinuz_next ]
        then
            ln -sf $vmlinuz_next /boot/zfcpdump
        else
            rm -f /boot/zfcpdump
        fi
    fi

%post kdump
    ln -sf /boot/vmlinuz-%{KVERREL}.kdump /boot/zfcpdump
%endif

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{with_firmware}
%files firmware
%defattr(-,root,root)
/lib/firmware/*
%doc linux-%{KVERREL}/firmware/WHENCE
%endif

%if %{with_bootwrapper}
%files bootwrapper
%defattr(-,root,root)
/usr/sbin/*
%{_libdir}/kernel-wrapper
%endif

# only some architecture builds need kernel-doc
%if %{with_doc}
%files doc
%defattr(-,root,root)
%{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation/*
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}/Documentation
%dir %{_datadir}/doc/kernel-doc-%{rpmversion}
%{_datadir}/man/man9/*
%endif

%if %{with_kernel_abi_whitelists}
%files -n kernel-abi-whitelists
%defattr(-,root,root,-)
/lib/modules/kabi-*
%endif

%if %{with_perf}
%files -n perf
%defattr(-,root,root)
%{_bindir}/perf
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_mandir}/man[1-8]/*
%doc linux-%{KVERREL}/tools/perf/Documentation/examples.txt
%config(noreplace) %{_sysconfdir}/bash_completion.d/perf

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo
%defattr(-,root,root)

%files -f python-perf-debuginfo.list -n python-perf-debuginfo
%defattr(-,root,root)
%endif

%files -n python-perf
%defattr(-,root,root)
%{python_sitearch}
%endif

# This is %{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{1}\
%{expand:%%files %{?2}}\
%defattr(-,root,root)\
/%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?2:.%{2}}\
%if %{with_fips} \
/%{image_install_path}/.vmlinuz-%{KVERREL}%{?2:.%{2}}.hmac \
%endif \
/boot/System.map-%{KVERREL}%{?2:.%{2}}\
/boot/symvers-%{KVERREL}%{?2:.%{2}}.gz\
#/boot/symvers-%{KVERREL}%{?2:.%{2}}.gz\
/boot/config-%{KVERREL}%{?2:.%{2}}\
%dir /lib/modules/%{KVERREL}%{?2:.%{2}}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/kernel\
/lib/modules/%{KVERREL}%{?2:.%{2}}/extra\
/lib/modules/%{KVERREL}%{?2:.%{2}}/build\
/lib/modules/%{KVERREL}%{?2:.%{2}}/source\
/lib/modules/%{KVERREL}%{?2:.%{2}}/updates\
/lib/modules/%{KVERREL}%{?2:.%{2}}/weak-updates\
%ifarch %{vdso_arches}\
/lib/modules/%{KVERREL}%{?2:.%{2}}/vdso\
/etc/ld.so.conf.d/kernel-%{KVERREL}%{?2:.%{2}}.conf\
%endif\
/lib/modules/%{KVERREL}%{?2:.%{2}}/modules.*\
%if 0%{?3} \
%{_libexecdir}/%{KVERREL}%{?2:.%{2}}/vm/page-types\
%{_libexecdir}/%{KVERREL}%{?2:.%{2}}/vm/slabinfo\
%endif\
%if %{with_dracut}\
%ghost /boot/initramfs-%{KVERREL}%{?2:.%{2}}.img\
%else\
%ghost /boot/initrd-%{KVERREL}%{?2:.%{2}}.img\
%endif\
%{expand:%%files %{?2:%{2}-}devel}\
%defattr(-,root,root)\
%dir /usr/src/kernels\
/usr/src/kernels/%{KVERREL}%{?2:.%{2}}\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?2}.list %{?2:%{2}-}debuginfo}\
%{debuginfodir}/boot/System.map-%{KVERREL}%{?2:.%{2}}\
%defattr(-,root,root)\
%endif\
%endif\
%endif\
%{nil}


%kernel_variant_files %{with_up}
%kernel_variant_files %{with_smp} smp
%kernel_variant_files %{with_debug} debug 1
%kernel_variant_files %{with_pae} PAE
%kernel_variant_files %{with_pae_debug} PAEdebug
%ifarch s390x
%kernel_variant_files %{with_kdump} kdump
%else
%kernel_variant_files -k vmlinux %{with_kdump} kdump
%endif

%changelog
* Sun Nov 10 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-431.el6]
- [md] Disabling of TRIM on RAID5 for RHEL6.5 was too aggressive (Jes Sorensen) [1028426]

* Tue Nov 05 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-430.el6]
- [x86] Revert "efi: be more paranoid about available space when creating variables" (Rafael Aquini) [1012370 1023173]
- [x86] Revert "efivars: firmware bug workarounds should be in platform code" (Rafael Aquini) [1012370 1023173]
- [x86] Revert "efi: Export efi_query_variable_store() for efivars.ko" (Rafael Aquini) [1012370 1023173]
- [x86] Revert "efi: Check max_size only if it is non-zero" (Rafael Aquini) [1012370 1023173]
- [x86] Revert "efi: Distinguish between "remaining space" and actually used space" (Rafael Aquini) [1012370 1023173]
- [x86] Revert "efi: Implement efi_no_storage_paranoia parameter" (Rafael Aquini) [1012370 1023173]
- [x86] Revert "Modify UEFI anti-bricking code" (Rafael Aquini) [1012370 1023173]
- [x86] Revert "efi: Fix dummy variable buffer allocation" (Rafael Aquini) [1012370 1023173]

* Sat Nov 02 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-429.el6]
- [fs] revert xfs: prevent deadlock trying to cover an active log (Eric Sandeen) [1014867]

* Wed Oct 30 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-428.el6]
- [fs] Revert "vfs: allow umount to handle mountpoints without revalidating them" (Rafael Aquini) [1024607]
- [fs] Revert "vfs: massage umount_lookup_last() a bit to reduce nesting" (Rafael Aquini) [1024607]
- [fs] Revert "vfs: rename user_path_umountat() to user_path_mountpoint_at()" (Rafael Aquini) [1024607]
- [fs] Revert "vfs: introduce kern_path_mountpoint()" (Rafael Aquini) [1024607]
- [fs] Revert "autofs4: fix device ioctl mount lookup" (Rafael Aquini) [1024607]

* Mon Oct 28 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-427.el6]
- [tools] perf: Add ref-cycles into array of tested events (Jiri Olsa) [968806]
- [pci] Revert "make SRIOV resources optional" (Myron Stowe) [1022270]
- [pci] Revert "ability to relocate assigned pci-resources" (Myron Stowe) [1022270]
- [pci] Revert "honor child buses add_size in hot plug configuration" (Myron Stowe) [1022270]
- [pci] Revert "make cardbus-bridge resources optional" (Myron Stowe) [1022270]
- [pci] Revert "code and comments cleanup" (Myron Stowe) [1022270]
- [pci] Revert "make re-allocation try harder by reassigning ranges higher in the heirarchy" (Myron Stowe) [1022270]
- [pci] Revert "Calculate right add_size" (Myron Stowe) [1022270]

* Mon Oct 28 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-426.el6]
- [block] loop: unplug_fn only when backing file is attached (Lukas Czerner) [1022997]
- [fs] ext4: Remove warning from ext4_da_update_reserve_space() (Lukas Czerner) [1011876]
- [kernel] async: Revert MAX_THREADS to 256 (Neil Horman) [1021705]
- [net] ipv6: restrict neighbor entry creation to output flow (Jiri Pirko) [997103]
- [net] ipv6: udp packets following an UFO enqueued packet need also be handled by UFO (Jiri Pirko) [1011930] {CVE-2013-4387}
- [net] ipv4: blackhole route should always be recalculated (Herbert Xu) [1010347]
- [net] unix: revert/fix race in stream sockets with SOCK_PASS* flags (Daniel Borkmann) [1019343]
- [net] Loosen constraints for recalculating checksum in skb_segment() (Vlad Yasevich) [1020298]
- [drm] nouveau: fix vblank deadlock (Rob Clark) [1013388]
- [usb] xhci: refactor EHCI/xHCI port switching (Don Zickus) [970715]
- [fs] compat_ioctl: VIDEO_SET_SPU_PALETTE missing error check (Phillip Lougher) [949573] {CVE-2013-1928}
- [fs] vfs: fix d_mountpoint() (Ian Kent) [1011337]
- [fs] autofs4: fix device ioctl mount lookup (Ian Kent) [999708]
- [fs] vfs: introduce kern_path_mountpoint() (Ian Kent) [999708]
- [fs] vfs: rename user_path_umountat() to user_path_mountpoint_at() (Ian Kent) [999708]
- [fs] vfs: massage umount_lookup_last() a bit to reduce nesting (Ian Kent) [999708]
- [fs] vfs: allow umount to handle mountpoints without revalidating them (Ian Kent) [999708]
- [fs] nfs: Remove the 'FIFO' behaviour for nfs41_setup_sequence (Steve Dickson) [1022257]
- [fs] nfs: Record the OPEN create mode used in the nfs4_opendata structure (Steve Dickson) [1019439]
- [fs] nfs: Simulate the change attribute (Steve Dickson) [1018653]
- [scsi] megaraid_sas: Fix synchronization problem between sysPD IO path and AEN path (Tomas Henzl) [1019811]

* Mon Oct 21 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-425.el6]
- [md] dm-snapshot: fix data corruption (Mikulas Patocka) [974481] {CVE-2013-4299}
- [watchdog] iTCO_wdt: add platform driver module alias (Neil Horman) [1019497]
- [hda] alsa: disable 44.1kHz rate for Haswell HDMI/DP audio (Jaroslav Kysela) [831970]
- [x86] Update UV3 hub revision ID (George Beshers) [1018962]
- [fs] xfs: Don't reference the EFI after it is freed (Eric Sandeen) [1018469]
- [security] keys: Fix a race between negating a key and reading the error set (Dave Wysochanski) [890231]
- [fs] nfsv4: Ensure memory ordering between nfs4_ds_connect and nfs4_fl_prepare_ds (Jeff Layton) [1012439]
- [fs] nfsv4: nfs4_fl_prepare_ds - fix bugs when the connect attempt fails (Jeff Layton) [1012439]
- [md] Disable TRIM on RAID5 for RHEL 6.5 (Jes Sorensen) [837097]
- [md] raid5: BIO_RW_SYNCIO is a bit number, not a bitmask (Jes Sorensen) [837097]
- [virt] hyperv: framebuffer pci stub (Gerd Hoffmann) [1013335]
- [netdrv] bnx2x: add missing enum channel_tlvs definitions (Michal Schmidt) [1015137]
- [netdrv] bnx2x: KR2 disablement fix (Michal Schmidt) [1015137]
- [netdrv] bnx2x: Specific Active-DAC is not detected on 57810 (Michal Schmidt) [1015137]
- [netdrv] bnx2x: Generalize KR work-around (Michal Schmidt) [1015137]
- [usb] usbnet: use ethd name for known ethernet devices (Don Zickus) [1014224]
- [usb] cdc_ether: use ethd name for known ethernet devices (Don Zickus) [1014224]
- [mm] Revert "Find_early_table_space based on ranges that are actually being mapped" (Rafael Aquini)
- [mm] Revert "Exclude E820_RESERVED regions and memory holes above 4 GB from direct mapping" (Rafael Aquini)
- [mm] Revert "Group e820 entries together and add map_individual_e820 boot option" (Rafael Aquini)
- [net] bridge: update mdb expiration timer upon reports (Vlad Yasevich) [1013816]
- [net] veth: Remove NETIF_F_HW_VLAN_RX capability (Thomas Graf) [1018158]
- [net] gre/vxlan: handle 802.1Q inner header properly (Thomas Graf) [997632]
- [net] disable the new NAPI weight error message for RHEL 6.5 (Michal Schmidt) [1012090]
- [scsi] sd: Fix parsing of 'temporary ' cache mode prefix (Ewan Milne) [955441]
- [scsi] sd: fix array cache flushing bug causing performance problems (Ewan Milne) [955441]
- [scsi] bfa: firmware update to 3.2.1.1 (Rob Evers) [1002770]
- [netdrv] bna: firmware update to 3.2.1.1 (Ivan Vecera) [1002771]

* Mon Oct 14 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-424.el6]
- [block] loop: fix crash when using unassigned loop device (Mike Snitzer) [989795]
- [fs] xfs: prevent deadlock trying to cover an active log (Dave Chinner) [1014867]
- [x86] microcode: Fix patch level reporting for AMD family 15h (Prarit Bhargava) [1014401]
- [hda] alsa: enable switcheroo code in the snd-hda-intel driver (Jaroslav Kysela) [1013993]
- [x86] reboot: Fix a warning message triggered by stop_other_cpus() (Jerome Marchand) [840710]
- [kernel] async: Bump up the MAX_THREADS count for the async subsystem (Neil Horman) [1010666]
- [pci] Calculate right add_size (Myron Stowe) [997672]
- [netdrv] iwlwifi: pcie: add SKUs for 6000, 6005 and 6235 series (Stanislaw Gruszka) [1013951]
- [netdrv] iwlwifi: pcie: add new SKUs for 7000 & 3160 NIC series (Stanislaw Gruszka) [1013951]
- [netdrv] iwlwifi: enable shadow registers for 7000 (Stanislaw Gruszka) [1013951]
- [netdrv] iwlwifi: add new 7260 and 3160 series device IDs (Stanislaw Gruszka) [1013951]
- [netdrv] be2net: pass if_id for v1 and V2 versions of TX_CREATE cmd (Ivan Vecera) [1014360]
- [netdrv] be2net: call ENABLE_VF cmd for Skyhawk-R too (Ivan Vecera) [1014360]
- [netdrv] be2net: Fix to prevent Tx stall on SH-R when packet size < 32 (Ivan Vecera) [1014360]
- [scsi] pm8001: Queue rotation logic for inbound and outbound queues (Rich Bono) [1013771]
- [scsi] lpfc: Update lpfc version for 8.3.7.21.4p driver release (Rob Evers) [1004841]
- [scsi] lpfc: Fixed spinlock hang (Rob Evers) [1004841]
- [scsi] lpfc: Fixed spinlock inversion problem (Rob Evers) [1004841]
- [scsi] lpfc: Fixed inconsistent spin lock useage (Rob Evers) [1004841]
- [scsi] qla2xxx: Update version number to 8.05.00.03.06.5-k2 (Chad Dupuis) [912652]
- [scsi] qla2xxx: Fix request queue null dereference (Chad Dupuis) [912652]
- [net] tcp: TSQ can use a dynamic limit (Jiri Pirko) [996802]
- [net] tcp: TSO packets automatic sizing (Jiri Pirko) [996802]
- [net] tcp: Apply device TSO segment limit earlier (Jiri Pirko) [996802]
- [net] Allow driver to limit number of GSO segments per skb (Jiri Pirko) [996802]
- [net] cleanups in RX queue allocation (Ivan Vecera) [1012388]
- [net] Update kernel-doc for netif_set_real_num_rx_queues() (Ivan Vecera) [1012388]
- [net] netif_set_real_num_rx_queues may cap num_rx_queues at init time (Ivan Vecera) [1012388]

* Thu Oct 10 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-423.el6]
- [kvm] pmu: add proper support for fixed counter 2 (Gleb Natapov) [1000956]
- [kvm] vmx: do not check bit 12 of EPT violation exit qualification when undefined (Gleb Natapov) [1006139]
- [kvm] vmx: set "blocked by NMI" flag if EPT violation happens during IRET from NMI (Gleb Natapov) [1006139]
- [edac] Fix workqueue-related crashes (Aristeu Rozanski) [831127]
- [edac] amd64_edac: Fix driver module removal (Aristeu Rozanski) [831127]
- [md] raid5: BIO flags adjust (Jes Sorensen) [837097]
- [md] Fix skipping recovery for read-only arrays (Jes Sorensen) [1014102]
- [kernel] audit: fix mq_open and mq_unlink to add the MQ root as a hidden parent audit_names record (Richard Guy Briggs) [1009386]
- [kernel] audit: log the audit_names record type (Richard Guy Briggs) [1009386]
- [kernel] audit: add child record before the create to handle case where create fails (Richard Guy Briggs) [1009386]
- [kernel] audit: format user messages to size of MAX_AUDIT_MESSAGE_LENGTH (Richard Guy Briggs) [1007069]
- [netdrv] tg3: Expand led off fix to include 5720 (Ivan Vecera) [991498]
- [netdrv] tg3: Don't turn off led on 5719 serdes port 0 (Ivan Vecera) [991498]
- [netdrv] tg3: Fix UDP fragments treated as RMCP (Ivan Vecera) [991498]
- [netdrv] tg3: Remove incorrect switch to aux power (Ivan Vecera) [991498]
- [i2c] ismt: initialize DMA buffer (Neil Horman) [1014753]
- [scsi] libfcoe: Make fcoe_sysfs optional / fix fnic NULL exception (Neil Horman) [1014864]
- [fs] gfs2: Fix race in iteration of glocks for unfreeze/umount (Abhijith Das) [999909]
- [fs] gfs2: dirty inode correctly in gfs2_write_end (Benjamin Marzinski) [991596]
- [x86] Mark Intel Atom Avoton processor as supported (Prarit Bhargava) [914842]
- [mm] vmscan: fix zone shrinking exit when scan work is done (David Gibson) [985155]
- [block] free bios when failing blk_execute_rq_nowait calls (Jeff Moyer) [1009312]
- [netdrv] be2net: fix disabling TX in be_close() (Ivan Vecera) [951271]
- [crypto] Fix race condition in larval lookup (Herbert Xu) [916361]

* Mon Oct 07 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-422.el6]
- [fs] fuse: drop dentry on failed revalidate (Brian Foster) [924014]
- [fs] fuse: clean up return in fuse_dentry_revalidate() (Brian Foster) [924014]
- [fs] fuse: use d_materialise_unique() (Brian Foster) [924014]
- [mm] Group e820 entries together and add map_individual_e820 boot option (Larry Woodman) [876275]
- [mm] Exclude E820_RESERVED regions and memory holes above 4 GB from direct mapping (Larry Woodman) [876275]
- [mm] Find_early_table_space based on ranges that are actually being mapped (Larry Woodman) [876275]
- [hid] pantherlord: heap overflow flaw (Radomir Vrbovsky) [1000435] {CVE-2013-2892}
- [virt] hv: Correctly support ws2008R2 and earlier (Jason Wang) [1007341]
- [powerpc] iommu: Use GFP_KERNEL instead of GFP_ATOMIC in iommu_init_table() (Steve Best) [1012666]
- [powerpc] Add isync to copy_and_flush (Steve Best) [1014475]
- [block] rsxx: Kernel Panic caused by mapping Discards (Steve Best) [1013728]
- [kernel] audit: avoid soft lockup due to audit_log_start() incorrect loop termination (Richard Guy Briggs) [990806]
- [fs] nfsv4: Remove the BUG_ON() from nfs4_get_lease_time_prepare() (Steve Dickson) [1012688]
- [netdrv] bnx2x: fix loss of VLAN priority information in received TPA-aggregated packets (Michal Schmidt) [1014694]
- [fs] gfs2: garbage quota usage reported due to uninitialized inode during creation (Abhijith Das) [1008947]
- [fs] nfs: fix filelayout_commit_call_ops (Scott Mayhew) [1012479]
- [netdrv] igb: fix driver reload with VF assigned to guest (Stefan Assmann) [985733]
- [md] Fix bio flags for md raid5 (Jes Sorensen) [837097]
- [md] Fix bio flags for md raid10 (Jes Sorensen) [837097]
- [scsi] qla4xxx: 5.03.00.00.06.05-k3 (Chad Dupuis) [1011476]
- [scsi] qla4xxx: Support setting of local CHAP index for flash target entry (Chad Dupuis) [1011476]
- [scsi] qla4xxx: Correct the check for local CHAP entry type (Chad Dupuis) [1011476]
- [scsi] lpfc: Update lpfc version for 8.3.7.21.3p driver release (Rob Evers) [1012961]
- [scsi] lpfc: Fixed function mode field defined too small for not recognizing dual-chute mode (Rob Evers) [1012961]
- [net] Revert "net: more accurate skb truesize" (Francesco Fusco) [889181]
- [net] fix multiqueue selection (Michal Schmidt) [1011939]

* Mon Sep 30 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-421.el6]
- [scsi] bnx2fc: Bump version from 1.0.14 to 2.4.1 (Tomas Henzl) [1008733]
- [scsi] bnx2fc: hung task timeout warning observed when rmmod bnx2x with active FCoE targets (Tomas Henzl) [1008733]
- [scsi] bnx2fc: Fixed a SCSI CMD cmpl race condition between ABTS and CLEANUP (Tomas Henzl) [1008733]
- [scsi] cnic: Fix crash in, cnic_bnx2x_service_kcq() (Tomas Henzl) [1004554]
- [hid] zeroplus: validate output report details (Frantisek Hrbata) [999906] {CVE-2013-2889}
- [hid] provide a helper for validating hid reports (Frantisek Hrbata) [999906] {CVE-2013-2889}
- [netdrv] sfc: Add SIOCEFX:EFX_MCDI_REQUEST ioctl to workaround MTD limits (Nikolay Aleksandrov) [1008705]
- [netdrv] sfc: deny changing of unsupported flags (Nikolay Aleksandrov) [1010840]
- [kernel] __ptrace_may_access() should not deny sub-threads (Oleg Nesterov) [927360]
- [tools] perf: Make kmem work for non numa machines (Jiri Olsa) [984788]
- [powerpc] Bring all threads online prior to migration/hibernation (Steve Best) [1010528]
- [kvm] introduce guest count uevent (Paolo Bonzini) [1004802]
- [scsi] iscsi_tcp: consider session state in iscsi_sw_sk_state_check (Chris Leech) [840638]
- [crypto] ansi_cprng: Fix off by one error in non-block size request (Neil Horman) [1007694] {CVE-2013-4345}
- [infiniband] cache: don't fill the cache with junk (Doug Ledford) [920306]
- [usb] core: don't try to reset_device() a port that got just disconnected (Don Zickus) [1000944]
- [usb] Fix connected device switch to Inactive state (Don Zickus) [1000944]
- [usb] Don't use EHCI port sempahore for USB 3.0 hubs (Don Zickus) [1000944]
- [netdrv] macvtap: Ignore tap features when VNET_HDR is off (Vlad Yasevich) [987201]
- [netdrv] macvtap: Correctly set tap features when IFF_VNET_HDR is disabled (Vlad Yasevich) [987201]
- [netdrv] macvtap: simplify usage of tap_features (Vlad Yasevich) [987201]
- [infiniband] mlx4: Use default pkey when creating tunnel QPs (Doug Ledford) [993587]
- [infiniband] core: Create QP1 using the pkey index which contains the default pkey (Doug Ledford) [993587]
- [infiniband] ipoib: Make sure child devices use valid/proper pkeys (Doug Ledford) [993587]
- [infiniband] ipoib: Fix pkey change flow for virtualization environments (Doug Ledford) [993587]
- [netdrv] igb: don't deprecate the max_vfs parameter (Stefan Assmann) [1005877]
- [netdrv] igb: Read flow control for i350 from correct EEPROM section (Stefan Assmann) [1005877]
- [netdrv] igb: Add additional get_phy_id call for i354 devices (Stefan Assmann) [1005877]
- [netdrv] igb: Update version number (Stefan Assmann) [1005877]
- [netdrv] igb: Implementation to report advertised/supported link on i354 devices (Stefan Assmann) [1005877]
- [netdrv] igb: Get speed and duplex for 1G non_copper devices (Stefan Assmann) [1005877]
- [netdrv] igb: Support to get 2_5G link status for appropriate media type (Stefan Assmann) [1005877]
- [netdrv] igb: No PHPM support in i354 devices (Stefan Assmann) [1005877]
- [netdrv] igb: M88E1543 PHY downshift implementation (Stefan Assmann) [1005877]
- [netdrv] igb: New PHY_ID for i354 device (Stefan Assmann) [1005877]
- [netdrv] igb: Implementation of 1-sec delay for i210 devices (Stefan Assmann) [1005877]
- [netdrv] igb: Don't look for a PBA in the iNVM when flashless (Stefan Assmann) [1005877]
- [netdrv] igb: Expose RSS indirection table for ethtool (Stefan Assmann) [1005877]
- [netdrv] igb: Add macro for size of RETA indirection table (Stefan Assmann) [1005877]
- [netdrv] igb: Fix get_fw_version function for all parts (Stefan Assmann) [1005877]
- [netdrv] igb: Add device support for flashless SKU of i210 device (Stefan Assmann) [1005877]
- [netdrv] igb: Refactor NVM read functions to accommodate devices with no flash (Stefan Assmann) [1005877]
- [netdrv] igb: Refactor of init_nvm_params (Stefan Assmann) [1005877]
- [netdrv] igb: Update MTU so that it is always at least a standard frame size (Stefan Assmann) [1005877]
- [netdrv] igb: don't allow SR-IOV without MSI-X (Stefan Assmann) [1005877]
- [netdrv] igb: Added rcu_lock to avoid race (Stefan Assmann) [1005877]
- [netdrv] igb: Read register for latch_on without return value (Stefan Assmann) [1005877]
- [netdrv] igb: Reset the link when EEE setting changed (Stefan Assmann) [1005877]
- [netdrv] treewide: relase -> release (Stefan Assmann) [1005877]
- [scsi] iterate over devices individually for /proc/scsi/scsi (David Milburn) [966170]
- [scsi] zfcp: fix lock imbalance by reworking request queue locking (Mikulas Patocka) [803592]
- [kernel] pidns: fix two invalid task_active_pid_ns() usages (Aristeu Rozanski) [984597]
- [netdrv] be2net: implement ethtool set/get_channel hooks (Ivan Vecera) [975885]
- [netdrv] be2net: refactor be_setup() to consolidate queue creation routines (Ivan Vecera) [975885]
- [netdrv] be2net: Fix be_cmd_if_create() to use MBOX if MCCQ is not created (Ivan Vecera) [975885]
- [netdrv] be2net: refactor be_get_resources() code (Ivan Vecera) [975885]
- [netdrv] be2net: don't limit max MAC and VLAN counts (Ivan Vecera) [975885]
- [netdrv] be2net: Fixup profile management routines (Ivan Vecera) [975885]
- [netdrv] be2net: use EQ_CREATEv2 for SH-R (Ivan Vecera) [975885]
- [netdrv] be2net: delete primary MAC address while unloading (Ivan Vecera) [874733]
- [netdrv] be2net: use SET/GET_MAC_LIST for SH-R (Ivan Vecera) [874733]
- [netdrv] be2net: refactor MAC-addr setup code (Ivan Vecera) [874733]
- [netdrv] be2net: fix pmac_id for BE3 VFs (Ivan Vecera) [874733]
- [netdrv] be2net: allow VFs to program MAC and VLAN filters (Ivan Vecera) [874733]
- [netdrv] be2net: fix MAC address modification for VF (Ivan Vecera) [874733]
- [netdrv] be2net: don't use dev_err when AER enabling fails (Ivan Vecera) [986513]
- [netdrv] be2net: Clear any capability flags that driver is not interested in (Ivan Vecera) [998856]
- [net] ethtool: fix RHEL backport of ETHTOOL_RESET (Jiri Benc) [1008678]
- [net] gact: Fix potential panic in tcf_gact() (Jiri Benc) [1003781]
- [net] tcp: fix FIONREAD/SIOCINQ (Francesco Fusco) [1001479]
- [net] vxlan: Avoid creating fdb entry with NULL destination (Amerigo Wang) [923915]
- [net] bridge: sync the definition of struct br_mdb_entry with upstream (Amerigo Wang) [1010251]
- [fs] proc/ns: Fix ABI of proc_inode (Thomas Graf) [1005224]
- [fs] nfs: Fix writeback performance issue on cache invalidation (Scott Mayhew) [1010038]
- [fs] xfs: switch stacks for bmap btree modifications (Dave Chinner) [918359]
- [fs] GFS2: Dont flag consistency error if first mounter is a spectator (Robert S Peterson) [997929]
- [x86] Mark Intel Haswell-EP as supported (Prarit Bhargava) [948339]
- [s390] tx: allow program interruption filtering in user space (Hendrik Brueckner) [1006523]
- [tty] hvc_iucv: Disconnect IUCV connection when lowering DTR (Hendrik Brueckner) [1007570]
- [tty] hvc_console: Add DTR/RTS callback to handle HUPCL control (Hendrik Brueckner) [1007570]
- [netdrv] bonding: fix bond_arp_rcv setting and arp validate desync state (Nikolay Aleksandrov) [1003697]
- [netdrv] bonding: fix store_arp_validate race with mode change (Nikolay Aleksandrov) [1003697]
- [netdrv] bonding: fix set mode race conditions (Nikolay Aleksandrov) [1003697]
- [bluetooth] rfcomm: Fix info leak in RFCOMMGETDEVLIST ioctl() (Radomir Vrbovsky) [922409] {CVE-2012-6545}
- [bluetooth] rfcomm: Fix info leak via getsockname() (Radomir Vrbovsky) [922409] {CVE-2012-6545}
- [mm] mlock: operate on any regions with protection != PROT_NONE (Larry Woodman) [982460]
- [mm] mlock: avoid dirtying pages and triggering writeback (Larry Woodman) [982460]

* Mon Sep 23 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-420.el6]
- [net] ipv6: Don't depend on per socket memory for neighbour discovery messages (Thomas Graf) [963317]
- [netdrv] bnx2x: add missing ethtool ops of virtual functions (Michal Schmidt) [1009492]
- [netdrv] bnx2x: avoid atomic allocations during initialization (Michal Schmidt) [1004645 1007900]
- [netdrv] bnx2x: Fix VF stats sync (Michal Schmidt) [1007900]
- [netdrv] bnx2x: Fix VF memory leak unload (Michal Schmidt) [1007900]
- [netdrv] bnx2x: Fix functionality of configuring vlan list (Michal Schmidt) [1007900]
- [netdrv] bnx2x: Fix move FP memory deallocations (Michal Schmidt) [1007900]
- [netdrv] bnx2x: vf mark stats started (Michal Schmidt) [1007900]
- [netdrv] bnx2x: set VF DMAE when first function has 0 supported VFs (Michal Schmidt) [1007900]
- [netdrv] bnx2x: Protect against VFs' ndos when SR-IOV is disabled (Michal Schmidt) [1007900]
- [netdrv] bnx2x: prevent VF benign attentions (Michal Schmidt) [1007900]
- [netdrv] bnx2x: Consider DCBX remote error (Michal Schmidt) [1007900]
- [netdrv] bnx2x: Change DCB context handling (Michal Schmidt) [1007900]
- [netdrv] bnx2x: dropless flow control not always functional (Michal Schmidt) [1007900]
- [netdrv] bnx2x: fix PTE write access error (Michal Schmidt) [1007900]
- [netdrv] bnx2x: fix memory leak in VF (Michal Schmidt) [1007900]
- [netdrv] bnx2x: update fairness parameters following DCB negotiation (Michal Schmidt) [1007900]
- [netdrv] bnx2x: protect different statistics flows (Michal Schmidt) [1007900]
- [scsi] lpfc: update version for 8.3.7.21.2p driver release (Rob Evers) [1007485]
- [scsi] lpfc: 8.3.42: Fixed issue of task management commands having a fixed timeout (Rob Evers) [1007485]
- [scsi] rdac: Add new IBM product id to the RDAC devlist (Rob Evers) [1006061]
- [block] hpsa: remove unused Smart Array ID (Tomas Henzl) [1002788]
- [block] hpsa: bump driver version to reflect changes (Tomas Henzl) [1002788]
- [block] hpsa: housekeeping patch for device_id and product arrays (Tomas Henzl) [1002788]
- [block] hpsa: add HP Smart Array Gen8 names (Tomas Henzl) [1002788]
- [block] hpsa: add HP Smart Array Gen9 PCI ID's (Tomas Henzl) [1002788]
- [block] hpsa: remove unneeded variable (Tomas Henzl) [893773]
- [block] hpsa: fix a race in cmd_free/scsi_done (Tomas Henzl) [893773]
- [scsi] qla4xxx: 5.03.00.00.06.05-k2 (Chad Dupuis) [982175]
- [scsi] qla4xxx: Export more firmware info in sysfs (Chad Dupuis) [982175]
- [scsi] qla4xxx: Only BIOS boot target entries should be at index 0 and 1 (Chad Dupuis) [982175]
- [scsi] qla4xxx: discovery_parent_idx can be shown without any check (Chad Dupuis) [982175]
- [scsi] qla4xxx: Set IPv6 traffic class if device type is IPv6 (Chad Dupuis) [982175]
- [scsi] qla4xxx: Use discovery_parent_idx instead of discovery_parent_type (Chad Dupuis) [982175]
- [scsi] qla4xxx: Allow removal of failed session using logout (Chad Dupuis) [982175]
- [scsi] libiscsi: Add missing prints for session and connection sysfs attrs (Chad Dupuis) [982175]
- [scsi] megaraid_sas: Add High Availability clustering support using shared Logical Disks (Tomas Henzl) [997004]
- [scsi] megaraid_sas: Version and Changelog update (Tomas Henzl) [997004]
- [net] cnic: Use CHIP_NUM macros from bnx2x.h (Tomas Henzl) [1004554]
- [hid] validate HID report id size (Frantisek Hrbata) [1000453] {CVE-2013-2888}
- [infiniband] cma: Check for GID on listening device first (Doug Ledford) [920306]
- [infiniband] cma: use cached gids (Doug Ledford) [920306]
- [input] wacom: collect device quirks into single function (Aristeu Rozanski) [815589]
- [input] wacom: add device type to device name string (Aristeu Rozanski) [815589]
- [input] wacom: request tablet data for Bamboo Pens (Aristeu Rozanski) [815589]
- [input] wacom: implement missing multitouch wrappers (Aristeu Rozanski) [815589]
- [input] wacom: fix bug in HID parsing introduced by last patchset (Aristeu Rozanski) [815589]
- [fs] nfsv4: Clean up delegation recall error handling (Steve Dickson) [1007556]
- [fs] nfsv4: Clean up nfs4_open_delegation_recall (Steve Dickson) [1007556]
- [fs] nfsv4: Clean up nfs4_lock_delegation_recall (Steve Dickson) [1007556]
- [fs] nfs: It is not safe to dereference lsp->ls_state in release_lockowner (Steve Dickson) [962844]
- [fs] nfs: Ensure that we free the lock stateid on the server (Steve Dickson) [962844]
- [fs] nfs: Don't free the nfs4_lock_state until after the release_lockowner (Steve Dickson) [962844]
- [fs] nfs: Convert nfs41_free_stateid to use an asynchronous RPC call (Steve Dickson) [962844]
- [fs] nfs: Clean up TEST_STATEID and FREE_STATEID error reporting (Steve Dickson) [962844]
- [fs] nfs: Clean up handling of privileged operations (Steve Dickson) [962844]
- [fs] nfs: Clean up nfs41_setup_sequence (Steve Dickson) [962844]
- [fs] nfs: Pass a stateid to test_stateid() and free_stateid() (Steve Dickson) [962844]
- [fs] nfs: added FREE_STATEID call (Steve Dickson) [962844]
- [virt] xen: mask cpu feature avx (Andrew Jones) [1006549]
- [fs] nfsv4: Fix up nfs4_proc_lookup_mountpoint (Jeff Layton) [997133]
- [block] rsxx: Moving pci_map_page to prevent overflow (Steve Best) [1001555]
- [block] rsxx: Handling failed pci_map_page on PowerPC and double free (Steve Best) [1001545]
- [kernel] sched/rt: Add a tuning knob to allow changing SCHED_RR timeslice (Herbert Xu) [919238]
- [kernel] sched: Make initial SCHED_RR timeslace DEF_TIMESLICE (Herbert Xu) [919238]
- [block] nvme: nvme_submit_bio_queue fixup check for DISCARD (David Milburn) [1006051]
- [block] nvme: Update nvme_id_power_state with latest spec (David Milburn) [1006051]
- [block] nvme: Split header file into user-visible and kernel-visible pieces (David Milburn) [1006051]
- [block] nvme: Merge issue on character device bring-up (David Milburn) [1006051]
- [block] nvme: Handle ioremap failure (David Milburn) [1006051]
- [block] nvme: Add pci suspend/resume driver callbacks (David Milburn) [1006051]
- [block] nvme: Use normal shutdown (David Milburn) [1006051]
- [block] nvme: Separate controller init from disk discovery (David Milburn) [1006051]
- [block] nvme: Separate queue alloc/free from create/delete (David Milburn) [1006051]
- [block] nvme: Group pci related actions in functions (David Milburn) [1006051]
- [block] nvme: Disk stats for read/write commands only (David Milburn) [1006051]
- [block] nvme: Bring up cdev on set feature failure (David Milburn) [1006051]
- [block] nvme: Fix checkpatch issues (David Milburn) [1006051]
- [block] nvme: Namespace IDs are unsigned (David Milburn) [1006051]
- [block] nvme: Call nvme_process_cq from submission path (David Milburn) [1006051]
- [block] nvme: Remove "process_cq did something" message (David Milburn) [1006051]
- [block] nvme: Return correct value from interrupt handler (David Milburn) [1006051]
- [block] nvme: Disk IO statistics (David Milburn) [1006051]
- [block] nvme: Restructure MSI / MSI-X setup (David Milburn) [1006051]
- [block] nvme: Use kzalloc instead of kmalloc+memset (David Milburn) [1006051]
- [netdrv] e1000e: Add code to check for failure of pci_disable_link_state call (John Green) [1000548]
- [tools] perf: Fix missing tool parameter (Jiri Olsa) [984785]
- [tools] perf: Remove builtin-inject unused parameter (Jiri Olsa) [984785]
- [mm] pagewalk: walk_page_range should avoid VM_PFNMAP areas (Larry Woodman) [990753]
- [mm] pagemap: set pagemap walk limit to PMD boundary (Motohiro Kosaki) [991260]
- [mm] task_mmu: fix buffer overflow in add_page_map() (Motohiro Kosaki) [991260]
- [mm] proc: copy_to_user() returns unsigned (Motohiro Kosaki) [991260]
- [mm] pagemap: Hold mmap_sem during page walk (Motohiro Kosaki) [991260]
- [netdrv] ixgbe: fix lockdep annotation issue for ptp's work item (Andy Gospodarek) [986967]
- [netdrv] ixgbe: add support for quad-port x520 adapter (Andy Gospodarek) [986967]
- [netdrv] ixgbe: clear semaphore bits on timeouts (Andy Gospodarek) [986967]
- [netdrv] ixgbe: fix semaphore lock for I2C read/writes on 82598 (Andy Gospodarek) [986967]
- [netdrv] ixgbe: add new media type (Andy Gospodarek) [986967]
- [netdrv] ixgbe: bump version number (Andy Gospodarek) [986967]
- [netdrv] ixgbe: fix SFF data dumps of SFP+ modules (Andy Gospodarek) [986967]
- [netdrv] ixgbe: Fix Tx Hang issue with lldpad on 82598EB (Andy Gospodarek) [986967]
- [netdrv] ixgbe: fix fc autoneg ethtool reporting (Andy Gospodarek) [986967]
- [netdrv] ixgbe: Retain VLAN filtering in promiscuous + VT mode (Andy Gospodarek) [986967]
- [netdrv] ixgbe: Use pci_vfs_assigned instead of ixgbe_vfs_are_assigned (Andy Gospodarek) [986967]
- [lib] dma-debug: Fix comparison using wrong pointer variable in dma debug code (Stefan Assmann) [1002992]
- [lib] dma-debug: hash_bucket_find needs to allow for offsets within an entry (Stefan Assmann) [1002992]
- [mm] x86-64: fall back to regular page vmemmap on allocation failure (Johannes Weiner) [854363]
- [mm] x86-64: use vmemmap_populate_basepages() for !pse setups (Johannes Weiner) [854363]
- [mm] x86-64: remove dead debugging code for !pse setups (Johannes Weiner) [854363]
- [mm] sparse-vmemmap: specify vmemmap population range in bytes (Johannes Weiner) [854363]

* Thu Sep 12 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-419.el6]
- [netdrv] bonding: Fix corrupted queue_mapping (Veaceslav Falico) [991799]
- [fs] xfs: fallback to vmalloc for large buffers in xfs_attrlist_by_handle (Eric Sandeen) [905086]
- [fs] nfs: set open access operation call flag in nfs4_init_opendata_res (Jeff Layton) [1002855]
- [kernel] Prevent RT process stall due to missing upstream scheduler bug fix (Larry Woodman) [1002765]

* Tue Sep 10 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-418.el6]
- [netdrv] bnx2x: prevent crash in shutdown flow with CNIC (Michal Schmidt) [1003436]
- [fs] nfs: Minor cleanups for nfs4_handle_exception and nfs4_async_handle_error (Dave Wysochanski) [998752]
- [wireless] iwl4965: fix rfkill set state regression (Stanislaw Gruszka) [992969]
- [wireless] rt2800: fix wrong TX power compensation (Stanislaw Gruszka) [992969]
- [wireless] mac80211: add missing channel context release (Stanislaw Gruszka) [992969]
- [wireless] mac80211: add a flag to indicate CCK support for HT clients (Stanislaw Gruszka) [992969]
- [wireless] ath9k_htc: Restore skb headroom when returning skb to mac80211 (Stanislaw Gruszka) [992969]
- [wireless] ath9k: Enable PLL fix only for AR9340/AR9330 (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: pcie: disable L1 Active after pci_enable_device (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: dvm: fix calling ieee80211_chswitch_done() with NULL (Stanislaw Gruszka) [992969]
- [wireless] Hostap: copying wrong data prism2_ioctl_giwaplist() (Stanislaw Gruszka) [992969]
- [wireless] zd1201: do not use stack as URB transfer_buffer (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: unregister leds when registration failed (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: take the seqno from packet if transmit failed (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: don't set the MCAST queue in STA's queue list (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: properly tell the fw that a STA is awake (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: fix MCAST in AP mode (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: correctly configure MCAST in AP mode (Stanislaw Gruszka) [992969]
- [wireless] mac80211: don't wait for TX status forever (Stanislaw Gruszka) [992969]
- [wireless] nl80211: fix another nl80211_fam.attrbuf race (Stanislaw Gruszka) [992969]
- [wireless] cfg80211: fix P2P GO interface teardown (Stanislaw Gruszka) [992969]
- [wireless] mac80211: continue using disabled channels while connected (Stanislaw Gruszka) [992969]
- [wireless] mac80211: fix infinite loop in ieee80211_determine_chantype (Stanislaw Gruszka) [992969]
- [wireless] mac80211: ignore HT primary channel while connected (Stanislaw Gruszka) [992969]
- [wireless] iwl4965: reset firmware after rfkill off (Stanislaw Gruszka) [992969]
- [wireless] iwl4965: set power mode early (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: dvm: don't send BT_CONFIG on devices w/o Bluetooth (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: set SSID bits for passive channels (Stanislaw Gruszka) [992969]
- [wireless] rt2x00: fix stop queue (Stanislaw Gruszka) [992969]
- [wireless] mac80211: fix monitor interface suspend crash regression (Stanislaw Gruszka) [992969]
- [wireless] mac80211: fix ethtool stats for non-station interfaces (Stanislaw Gruszka) [992969]
- [wireless] mac80211: fix duplicate retransmission detection (Stanislaw Gruszka) [992969]
- [wireless] mac80211/minstrel_ht: fix cck rate sampling (Stanislaw Gruszka) [992969]
- [wireless] mac80211/minstrel: fix NULL pointer dereference issue (Stanislaw Gruszka) [992969]
- [wireless] nl80211: fix mgmt tx status and testmode reporting for netns (Stanislaw Gruszka) [992969]
- [wireless] ath9k_htc: reboot firmware if it was loaded (Stanislaw Gruszka) [992969]
- [wireless] ath9k_htc: do some initial hardware configuration (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: fix flushing not started aggregation sessions (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: add DELL SKU for 5150 HMC (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: refuse connection to APs with BI < 16 (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: fix bug in scan ssid (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: mvm: fix L2P BA ressources leak (Stanislaw Gruszka) [992969]
- [wireless] mac80211: close AP_VLAN interfaces before unregistering all (Stanislaw Gruszka) [992969]
- [wireless] b43: ensue that BCMA is "y" when B43 is "y" (Stanislaw Gruszka) [992969]
- [wireless] ath9k: Do not assign noise for NULL caldata (Stanislaw Gruszka) [992969]
- [wireless] ath9k: Fix noisefloor calibration (Stanislaw Gruszka) [992969]
- [wireless] ath9k_hw: Assign default xlna config for AR9485 (Stanislaw Gruszka) [992969]
- [wireless] rt2x00: rt2800lib: fix default TX power check for RT55xx (Stanislaw Gruszka) [992969]
- [wireless] rt2x00: read 5GHz TX power values from the correct offset (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: pcie: wake the queue if stopped when being unmapped (Stanislaw Gruszka) [992969]
- [wireless] iwlwifi: pcie: fix race in queue unmapping (Stanislaw Gruszka) [992969]
- [fs] ext4: don't let i_reserved_meta_blocks go negative (Lukas Czerner) [916592]
- [fs] ext4: introduce reserved space (Lukas Czerner) [916592]

* Fri Sep 06 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-417.el6]
- [target] Set bi_destructor in iblock_get_bio (Andy Grover) [999490]
- [target] Fix calling bdev_get_queue on a NULL *bio (Andy Grover) [999490]
- [net] ipv6: remove max_addresses check from ipv6_create_tempaddr (Petr Holasek) [999365] {CVE-2013-0343}
- [net] soreuseport: UDP/IPv6 implementation (Thomas Graf) [991600]
- [net] soreuseport: TCP/IPv6 implementation (Thomas Graf) [991600]
- [net] soreuseport: UDP/IPv4 implementation (Thomas Graf) [991600]
- [net] soreuseport: TCP/IPv4 implementation (Thomas Graf) [991600]
- [net] soreuseport: infrastructure (Thomas Graf) [991600]
- [kernel] prevent an older auditd shutdown from orphaning a newer auditd startup (Richard Guy Briggs) [742562]
- [kernel] audit: add an option to control logging of passwords with pam_tty_audit (Richard Guy Briggs) [725100]
- [misc] hpilo: Correct panic when an AUX iLO is detected (Nigel Croxon) [996600]
- [watchdog] hpwdt: Patch to ignore auxilary iLO devices (Nigel Croxon) [996608]
- [netdrv] igb: fix vlan filtering in promisc mode when not in VT mode (Stefan Assmann) [996277]
- [char] random: fix priming of last_data (Jarod Wilson) [997985]
- [char] random: prime last_data value per fips requirements (Jarod Wilson) [997985]
- [char] random: simplify fips mode (Jarod Wilson) [997985]
- [fs] nfs: don't extend writes to cover entire page if pagecache is invalid (Jeff Layton) [1002830]
- [fs] nfs: fix inode reference leak (Steve Dickson) [998694]
- [fs] nfs: Use session max response size for GETDEVICEINFO gdia_maxcount (Steve Dickson) [922810]
- [fs] nfs: Simplify the NFSv4 REMOVE, LINK and RENAME compounds (Steve Dickson) [998697]
- [fs] nfs: Simplify the NFSv4 CREATE compound (Steve Dickson) [998697]
- [fs] nfs: Simplify the NFSv4 OPEN compound (Steve Dickson) [998697]
- [fs] nfs: Simplify the cache invalidation code (Steve Dickson) [998697]
- [fs] nfs: Change attribute updates should set NFS_INO_REVAL_PAGECACHE (Steve Dickson) [998697]
- [fs] nfs: Simplify nfs_fhget() (Steve Dickson) [998697]
- [fs] nfs: Always trust the PageUptodate flag when we have a delegation (Steve Dickson) [998697]
- [fs] nfs: Optimise away nfs_check_inode_attributes() when holding a delegation (Steve Dickson) [998697]
- [fs] nfs: Dont force page cache revalidations when holding a delegation (Steve Dickson) [998697]
- [fs] nfs: Retrieve attributes _before_ calling delegreturn (Steve Dickson) [998697]
- [fs] nfs: Fix a typo in NFS4_enc_link_sz (Steve Dickson) [998697]
- [scsi] Fix bug on some bnx2x devices that don't support iSCSI (Tomas Henzl) [957217]
- [scsi] mpt3sas: Added a driver module parameter max_msix_vectors (Tomas Henzl) [997045]
- [scsi] aacraid: Fix for arrays going offline in the system. System hangs (Rich Bono) [996207]

* Thu Aug 29 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-416.el6]
- [fs] gfs2: dont overrun reserved revokes (Benjamin Marzinski) [996637]
- [s390] qeth: change default standard blkt settings for OSA (Hendrik Brueckner) [997625]
- [s390] kernel: z90crypt module load crash (Hendrik Brueckner) [997621]
- [s390] dasd: fix hanging devices after path events (Hendrik Brueckner) [996185]
- [cpufreq] revert "remove rwsem lock from CPUFREQ_GOV_STOP call -- second call site" (Prarit Bhargava) [869899]
- [perf] Fix regs retrieval for tracepoints events (Jiri Olsa) [1000706]
- [tools] perf: Fix period symbol_conf.field_sep display (Jiri Olsa) [985968]
- [tools] traceevent: Handle dynamic array's element size properly (Jiri Olsa) [664899]
- [tools] perf: Fix perf build make command and BuildRequires (Jiri Olsa) [968186]
- [tools] perf: Add support for wildcard in tracepoint system name (Jiri Olsa) [664899]
- [perf] Add support for PERF_HW_COUNT_REF_CPU_CYCLES (Jiri Olsa) [968806]
- [perf] events: Add Intel x86 mapping for PERF_COUNT_HW_REF_CPU_CYCLES (Jiri Olsa) [968806]
- [perf] events: Add PERF_COUNT_HW_REF_CPU_CYCLES generic PMU event (Jiri Olsa) [968806]
- [perf] events: Enable raw event support for Intel unhalted_reference_cycles event (Jiri Olsa) [968806]
- [net] phonet: some signedness bugs (Francesco Fusco) [1000271]
- [net] phonet: put protocols array under RCU (Francesco Fusco) [1000271]
- [net] openvswitch: Add vxlan tunneling support (Amerigo Wang) [981285]
- [net] vxlan: Add tx-vlan offload support (Amerigo Wang) [981285]
- [net] vxlan: Improve vxlan headroom calculation (Amerigo Wang) [981285]
- [net] vxlan: Factor out vxlan send api (Amerigo Wang) [981285]
- [net] vxlan: Extend vxlan handlers for openvswitch (Amerigo Wang) [981285]
- [net] vxlan: Add vxlan recv demux (Amerigo Wang) [981285]
- [net] vxlan: Restructure vxlan receive (Amerigo Wang) [981285]
- [net] vxlan: Restructure vxlan socket apis (Amerigo Wang) [981285]
- [net] openvswitch: Reset tunnel key between input and output (Amerigo Wang) [981285]
- [net] openvswitch: Use correct type while allocating flex array (Amerigo Wang) [981285]
- [net] openvswitch: Fix bad merge resolution (Amerigo Wang) [981285]
- [net] vxlan: fix a soft lockup in vxlan module removal (Amerigo Wang) [923915]
- [net] vxlan: fix a regression of igmp join (Amerigo Wang) [923915]
- [net] vxlan: fix rcu related warning (Amerigo Wang) [923915]
- [net] vxlan: fdb: replace an existing entry (Amerigo Wang) [923915]
- [kernel] list: introduce list_first_entry_or_null (Amerigo Wang) [923915]
- [net] vxlan: fix igmp races (Amerigo Wang) [923915]
- [net] vxlan: unregister on namespace exit (Amerigo Wang) [923915]
- [net] vxlan: add necessary locking on device removal (Amerigo Wang) [923915]
- [net] vxlan: Fix kernel crash on rmmod (Amerigo Wang) [923915]
- [net] vxlan: fix function name spelling (Amerigo Wang) [923915]
- [net] vxlan: fdb: allow specifying multiple destinations for zero MAC (Amerigo Wang) [923915]
- [net] rtnetlink: allow using zero MAC address in rtnl_fdb_add, rtnl_fdb_del (Amerigo Wang) [923915]
- [net] fix address check in rtnl_fdb_del (Amerigo Wang) [923915]
- [net] vxlan: allow removal of single destination from fdb entry (Amerigo Wang) [923915]
- [net] vxlan: introduce vxlan_fdb_parse (Amerigo Wang) [923915]
- [net] vxlan: introduce vxlan_fdb_find_rdst (Amerigo Wang) [923915]
- [net] vxlan: add implicit fdb entry for default destination (Amerigo Wang) [923915]
- [net] vxlan: Fix sparse warnings (Amerigo Wang) [923915]
- [net] vxlan: cosmetic cleanup's (Amerigo Wang) [923915]
- [net] vxlan: Use initializer for dummy structures (Amerigo Wang) [923915]
- [net] vxlan: port module param should be ushort (Amerigo Wang) [923915]
- [net] vxlan: convert remotes list to list_rcu (Amerigo Wang) [923915]
- [net] vxlan: make vxlan_xmit_one void (Amerigo Wang) [923915]
- [net] vxlan: move cleanup to uninit (Amerigo Wang) [923915]
- [net] vxlan: fix race caused by dropping rtnl_unlock (Amerigo Wang) [923915]
- [net] vxlan: send notification when MAC migrates (Amerigo Wang) [923915]
- [net] vxlan: move IGMP join/leave to work queue (Amerigo Wang) [923915]
- [net] vxlan: fix crash from work pending on module removal (Amerigo Wang) [923915]
- [net] vxlan: fix out of order operation on module removal (Amerigo Wang) [923915]
- [net] vxlan: fix check for migration of static entry (Amerigo Wang) [923915]
- [net] vxlan: handle skb_clone failure (Amerigo Wang) [923915]
- [net] vxlan: only migrate dynamic FDB entries (Amerigo Wang) [923915]
- [net] vxlan: fix race between flush and incoming learning (Amerigo Wang) [923915]
- [net] vxlan: defer vxlan init as late as possible (Amerigo Wang) [923915]
- [net] vxlan: use unsigned int instead of unsigned (Amerigo Wang) [923915]
- [net] vxlan: remove the unused rcu head from struct vxlan_rdst (Amerigo Wang) [923915]
- [net] vxlan: Update vxlan fdb 'used' field after each usage (Amerigo Wang) [923915]
- [net] vxlan: listen on multiple ports (Amerigo Wang) [923915]
- [net] vxlan: do not set SKB_GSO_UDP (Amerigo Wang) [923915]
- [net] vxlan: allow choosing destination port per vxlan (Amerigo Wang) [923915]
- [net] vxlan: compute source port in network byte order (Amerigo Wang) [923915]
- [net] vxlan: source compatiablity with IFLA_VXLAN_GROUP (Amerigo Wang) [923915]
- [net] vxlan: fix byte order issues with NDA_PORT (Amerigo Wang) [923915]
- [net] vxlan: document UDP default port (Amerigo Wang) [923915]
- [net] vxlan: update mail address and copyright date (Amerigo Wang) [923915]
- [net] vxlan: Allow L2 redirection with L3 switching (Amerigo Wang) [923915]
- [net] vxlan: Allow setting destination to unicast address (Amerigo Wang) [923915]
- [net] vxlan: don't bypass encapsulation for multi- and broadcasts (Amerigo Wang) [923915]
- [net] vxlan: use htonl when snooping for loopback address (Amerigo Wang) [923915]
- [net] vxlan: fix some sparse warnings (Amerigo Wang) [923915]
- [net] vxlan: Bypass encapsulation if the destination is local (Amerigo Wang) [923915]
- [net] vxlan: Fix sparse warnings (Amerigo Wang) [923915]
- [net] vxlan: Use IP Tunnels tunnel ENC encap API (Amerigo Wang) [923915]
- [net] vxlan: generalize forwarding tables (Amerigo Wang) [923915]
- [net] vxlan: Add vlan support to static neighbors (Amerigo Wang) [923915]
- [net] vxlan: allow live mac address change (Amerigo Wang) [923915]
- [net] vxlan: add DOVE extensions for VXLAN (Amerigo Wang) [923915]
- [net] vxlan: move SET_ETHTOOL_OPS() to vxlan_newlink() (Amerigo Wang) [923915]
- [net] vxlan: specify fl4.proto before calling ip_route_output_key() (Amerigo Wang) [923915]
- [net] vxlan: Depend on CONFIG_INET (Amerigo Wang) [923915]
- [net] fix invalid usage of netdev->priv_flags (Stanislaw Gruszka) [984373]

* Tue Aug 27 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-415.el6]
- [drm] upstream sync to 3.9.9 (Rob Clark) [818344 902637 962824]
- [uapi] install UAPI headers in the correct path (Rob Clark) [962824]
- [debug] lockdep: provide mutex_lock_nest_lock (Rob Clark) [962824]
- [pci] backport PCIE_SPEED_* (Rob Clark) [962824]
- [pci] Add PCIe Link Capability link speed and width names (Rob Clark) [962824]
- [fs] export get_task_comm() (Rob Clark) [962824]
- [x86] sgi-xp: handle non-fatal traps - headers (George Beshers) [956876]
- [x86] sgi-xp: handle non-fatal traps (George Beshers) [956876]
- [x86] irq: Rename gsi_end gsi_top, and fix off by one errors (Prarit Bhargava) [998602]
- [x86] ioapic: In mpparse use mp_register_ioapic (Prarit Bhargava) [998602]
- [x86] ioapic: Teach mp_register_ioapic to compute a global gsi_end (Prarit Bhargava) [998602]
- [x86] Reinsert "io_apic: initialize nr_ioapic_registers early in mp_register_ioapic()" (Prarit Bhargava) [855057 998602]
- [virt] Add a check to catch KVM emulation of Hyper-V (Jason Wang) [985747]
- [virt] kvm: Switch to use hypervisor_cpuid_base() (Jason Wang) [985747]
- [x86] Introduce hypervisor_cpuid_base() (Jason Wang) [985747]
- [kernel] kexec: add the values related to buddy system for filtering free pages (Nigel Croxon) [960746]
- [virt] hv_balloon: Initialize the transaction ID just before sending the packet (Jason Wang) [993473]
- [virt] hv_balloon: Do not post pressure status if interrupted (Jason Wang) [993473]
- [virt] hv_balloon: Fix a bug in the hot-add code (Jason Wang) [993473]
- [kernel] sysctl: range checking in do_proc_dointvec_ms_jiffies_conv (Francesco Fusco) [972430]
- [net] neigh: prevent overflowing params in /proc/sys/net/ipv4/neigh/ (Francesco Fusco) [972430]
- [net] neigh: fix some compiler warning in net/core/neighbour.c (Francesco Fusco) [972430]
- [net] neigh: prohibit negative value for unres_qlen_bytes parameter (Francesco Fusco) [972430]
- [net] netfilter: don't permit ct creation with random tuple (Thomas Graf) [994393]
- [net] netfilter: fix BUG_ON while removing nf_conntrack with netns (Thomas Graf) [991246]
- [net] gro: Fix kcalloc argument order (Amerigo Wang) [995405]
- [net] gro: fix a race in gro_cell_poll() (Amerigo Wang) [995405]
- [net] ip_tunnel: fix a pointer cast in ip_tunnel_xmit() (Amerigo Wang) [995405]
- [virt] xen: avoid allocation causing potential swap activity on the resume path (Radim Krcmar) [996631]
- [virt] xen: ensure timer tick is resumed even on CPU driving the resume (Radim Krcmar) [996631]
- [infiniband] ipoib: Fix race in deleting ipoib_neigh entries (Doug Ledford) [987174]
- [scsi] libiscsi: Added new boot entries in the session sysfs (Chris Leech) [994743]
- [x86] kvm: use kernel_fpu_begin/end() in kvm_load/put_guest_fpu() (Fam Zheng) [988658]
- [block] do not pass disk names as format strings (Alexander Gordeev) [971372] {CVE-2013-2851}

* Mon Aug 19 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-414.el6]
- [fs] Revert "ext4: dont let i_reserved_meta_blocks go negative" (Rafael Aquini) [916592]
- [fs] Revert "ext4: introduce reserved space" (Rafael Aquini) [916592]
- [netdrv] bnx2x: fill in sane dump flag information (Michal Schmidt) [995475 996988]
- [netdrv] bnx2x: remove zeroing of dump data buffer (Michal Schmidt) [995475 996988]
- [netdrv] bnx2x: fix dump flag handling (Michal Schmidt) [995475 996988]
- [netdrv] bnx2x: fix crash in bnx2x_set_vlan_stripping() (Michal Schmidt) [995475]
- [scsi] lpfc: Update lpfc version for 8.3.7.21.1p driver release (Rob Evers) [947546]
- [scsi] lpfc: Merge with "lpfc 8.3.31: Fixed system panic due to midlayer abort and (Rob Evers) [947546]
- [scsi] lpfc: Removed obsolete fcp_eq_count and fcp_wq_count driver attributes (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Update Copyrights to 2013 for 8.3.38, 8.3.39, and 8.3.40 modifications (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fixed a race condition between SLI host and port failed FCF rediscovery (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fixed issue mailbox wait routine failed to issue dump memory mbox command (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fixed system panic due to unsafe walking and deleting linked list (Rob Evers) [947546]
- [scsi] lpfc: lpfc 8.3.40: Fixed FCoE connection list vlan identifier and add FCF list debug (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Clarified the behavior of the lpfc_max_luns module parameter (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fix to allow OCM to report FEC status (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fixed a missing return code in a logging message (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fixed some logging message fields (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fixed list corruption when lpfc_drain_tx runs (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fix starting reference tag when calculating BG error (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fix inconsistent list removal causes crash (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fixed system panic during handling unsolicited receive buffer error condition (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fix BlockGuard error checking (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fixed crash during FCoE failover testing (Rob Evers) [947546]
- [scsi] lpfc: 8.3.40: Fix lpfc_used_cpu to be more dynamic (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed driver handling of CLEAR_LA with NPIV enabled causing SID=0 frames out (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Reduced tmo value set to FLOGI WQE for quick recovery from FLOGI sequence timeout (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Add log message when completes with clean address bit set to zero (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed driver vector mapping to CPU affinity (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed iocb flags not being reset for scsi commands (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed system panic during EEH recovery due to midlayer acting on outstanding I/O (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed not returning FAILED status when SCSI invoking host reset handler failed (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed bad book keeping in posting els sgls to port (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed BlockGuard to take advantage of rdprotect/wrprotect info when available (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Reduced spinlock contention on SCSI buffer list (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed crash when processing bsg's sg list with high memory pages (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Remove lpfc_fcp_look_ahead module parameter (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fix driver issues with SCSI Host reset (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Doorbell formation information logged in dual-chute mode WQ and RQ setup (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fix driver issues with large s/g lists for BlockGuard (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fix driver issues with large lpfc_sg_seg_cnt values (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed pt2pt and loop discovery problems on topology changes (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Remove driver dependency on HZ (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed BlockGuard error reporting (Rob Evers) [947546]
- [scsi] lpfc: 8.3.39: Fixed VPI allocation issues after firmware dump is performed (Rob Evers) [947546]
- [scsi] lpfc: fix potential NULL pointer dereference in lpfc_sli4_rq_put() (Rob Evers) [947546]
- [scsi] lpfc: 8.3.38: Fixed potential mis-interpretation of READ_TOPOLOGY reserved fields (Rob Evers) [947546]
- [scsi] lpfc: 8.3.38: Fix default value for lpfc_enable_rrq (Rob Evers) [947546]
- [scsi] lpfc: 8.3.38: Fixed circular locking dependency and inconsistent lock state issues (Rob Evers) [947546]
- [scsi] lpfc: 8.3.38: Fixed PT2PT bring up problem for FC SLI4 (Rob Evers) [947546]
- [scsi] lpfc: 8.3.38: Fixed OXID reuse issue (Rob Evers) [947546]
- [scsi] lpfc: 8.3.38: Fixed async FCF modified event to in-use FCF failure to trigger recovery (Rob Evers) [947546]
- [scsi] lpfc: 8.3.38: Fixed deadlock condition in FCF round robin handling (Rob Evers) [947546]
- [scsi] lpfc: 8.3.38: Fixed bsg timeout handling issues that would result in crashes ? applied and checked into RHEL6.5 (Rob Evers) [947546]
- [scsi] lpfc: 8.3.38: Fixed degraded performance after cable pulls (Rob Evers) [947546]
- [scsi] lpfc: 8.3.38: Fixed NMI watch dog panic's when resetting the hba (Rob Evers) [947546]
- [scsi] lpfc: treewide: Fix typos in kernel messages (Rob Evers) [947546]
- [scsi] lpfc: fix lpfc build when wmb() is defined as mb() (Rob Evers) [947546]
- [scsi] lpfc: 8.3.37: Fixed infinite loop in lpfc_sli4_fcf_rr_next_index_get (Rob Evers) [947546]
- [scsi] lpfc: 8.3.37: Fixed crash due to SLI Port invalid resource count (Rob Evers) [947546]
- [scsi] lpfc: 8.3.37: Provide support for FCoE protocol dual-chute (ULP) operation (Rob Evers) [947546]
- [scsi] lpfc: 8.3.37: Fixed stale ndlp state when the node is marked for deferred removal (Rob Evers) [947546]
- [scsi] lpfc: 8.3.37: Fix potential memory corruption bug (Rob Evers) [947546]
- [scsi] lpfc: 8.3.37: Fixed no-context ABTS failed with BA_RJT (Rob Evers) [947546]
- [scsi] lpfc: 8.3.37: Removed use of NOP mailboxes for interrupt verification (Rob Evers) [947546]
- [scsi] lpfc: 8.3.37: Fixed exhausted retry for plogi to nameserver (Rob Evers) [947546]
- [scsi] lpfc: 8.3.37: Fixed ELS_REC received on the unsolicited receive queue (Rob Evers) [947546]
- [scsi] lpfc: 8.3.37: Provide support for change_queue_type (Rob Evers) [947546]
- [scsi] lpfc: 8.3.36: Correct mask error (Rob Evers) [947546]
- [scsi] lpfc: 8.3.36: Correct buffer length overrun (Rob Evers) [947546]
- [scsi] lpfc: 8.3.36: Update DIF support for passthru/strip/insert (Rob Evers) [947546]
- [scsi] lpfc: 8.3.36: Fix bug with Target Resets and FCP2 devices (Rob Evers) [947546]
- [scsi] lpfc: 8.3.35: Fixed not checking solicition in progress bit when verifying FCF record for use (Rob Evers) [947546]
- [scsi] lpfc: 8.3.35: Fixed PRLI not being retried if a LS_RJT with a reason (Rob Evers) [947546]
- [scsi] lpfc: 8.3.35: Expand I/O channel support for large systems (Rob Evers) [947546]
- [scsi] lpfc: 8.3.34: Adjust IO Channels to 1 when INTx (Rob Evers) [947546]
- [scsi] lpfc: 8.3.35: Fix interrupt delay multipler conversion for eq_create (Rob Evers) [947546]
- [scsi] lpfc 8.3.34: Correct typecasts for snprintf messages (Rob Evers) [947546]
- [scsi] lpfc: 8.3.34: Fix number of IO channels to match CPUs (Rob Evers) [947546]
- [scsi] lpfc: 8.3.33: Fixed debugfs queInfo to include queue stats (Rob Evers) [947546]
- [scsi] lpfc: 8.3.33: Add lpfc_fcp_look_ahead module parameter (Rob Evers) [947546]
- [scsi] lpfc: 8.3.33: Make I/O to hw queue distribution algorithm a module parameter (Rob Evers) [947546]
- [scsi] lpfc: 8.3.33: Change Naming convention for SLI4 Interrupt vector (Rob Evers) [947546]
- [scsi] lpfc: 8.3.33: Allow per-hba interrupt rate tuning (Rob Evers) [947546]
- [scsi] lpfc: 8.3.33: Tie parallel I/O queues into separate MSIX vectors (Rob Evers) [947546]
- [scsi] lpfc: 8.3.33: Add Interrupts per second stats via debugfs (Rob Evers) [947546]
- [scsi] lpfc: 8.3.33: Parallelize SLI-4 Q distribution (Rob Evers) [947546]
- [scsi] lpfc: 8.3.33: Formally separate lpfc_sli_ring SLI-3 and SLI-4 variantions (Rob Evers) [947546]
- [scsi] lpfc: 8.3.33: Add debugfs interface to display SLI queue information (Rob Evers) [947546]
- [scsi] lpfc: treewide: fix comment/printk/variable typos (Rob Evers) [947546]
- [netdrv] qlcnic: Update version to 5.2.43 (Chad Dupuis) [927395]
- [netdrv] qlcnic: Enhance virtual NIC logging (Chad Dupuis) [927395]
- [netdrv] qlcnic: qlcnic_get_board_name() function cleanup (Chad Dupuis) [927395]
- [netdrv] qlcnic: Implement GET_LED_STATUS command for 82xx adapter (Chad Dupuis) [927395]
- [netdrv] qlcnic: modify reset recovery path in diag mode (Chad Dupuis) [927395]
- [netdrv] qlcnic: diagnostics routine changes (Chad Dupuis) [927395]
- [netdrv] qlcnic: Convert nested if-else to switch-case (Chad Dupuis) [927395]
- [netdrv] qlcnic: Initialize trans_work and idc_aen_work at VF probe (Chad Dupuis) [927395]
- [netdrv] qlcnic: Remove qlcnic_config_npars module parameter (Chad Dupuis) [927395]
- [netdrv] qlcnic: Update IRQ name for 8200 and 8300 Series adapter (Chad Dupuis) [927395]
- [netdrv] qlcnic: Disable INT-x interrupt for 83xx on driver unload (Chad Dupuis) [927395]
- [netdrv] qlcnic: Support spoof check config (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix LRO bugs while tuning offloads using Q application (Chad Dupuis) [927395]
- [netdrv] qlcnic: Enable LRO if it was disabled by RX checksum (Chad Dupuis) [927395]
- [netdrv] qlcnic: remove netdev->trans_start updates within the driver (Chad Dupuis) [927395]
- [netdrv] qlcnic: Return proper error codes from probe failure paths (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix validation of link event command (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix mailbox response handling (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix bug in diagnostics test reset recovery path (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix reset recovery after transmit timeout (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix ethtool supported port status for 83xx (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix missing bracket in module parameter (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix ethtool strings (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix setting MAC address (Chad Dupuis) [927395]
- [netdrv] qlcnic: Update version to 5.2.42 (Chad Dupuis) [927395]
- [netdrv] qlcnic: Add identifying string for 83xx adapter (Chad Dupuis) [927395]
- [netdrv] qlcnic: Rename the IRQ description (Chad Dupuis) [927395]
- [netdrv] qlcnic: Enable Interrupt Coalescing for 83xx adapter (Chad Dupuis) [927395]
- [netdrv] qlcnic: Add eSwitch statistics support (Chad Dupuis) [927395]
- [netdrv] qlcnic: Take EPORT out of reset sequence before disabling PAUSE (Chad Dupuis) [927395]
- [netdrv] qlcnic: Enhance channel configuration logs (Chad Dupuis) [927395]
- [netdrv] qlcnic: Update version to 5.2.41 (Chad Dupuis) [927395]
- [netdrv] qlcnic: Support polling for mailbox events (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix loopback test for SR-IOV PF (Chad Dupuis) [927395]
- [netdrv] qlcnic: Support VLAN id config (Chad Dupuis) [927395]
- [netdrv] qlcnic: Support MAC address, Tx rate config (Chad Dupuis) [927395]
- [netdrv] qlcnic: VF reset recovery implementation (Chad Dupuis) [927395]
- [netdrv] qlcnic: VF FLR implementation (Chad Dupuis) [927395]
- [netdrv] qlcnic: Change 82xx adapter VLAN id endian type (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix typo in logs (Chad Dupuis) [927395]
- [netdrv] qlcnic: fix TSO race condition (Chad Dupuis) [927395]
- [netdrv] qlcnic: Stop traffic before performing loopback test (Chad Dupuis) [927395]
- [netdrv] qlcnic: fix beaconing test for 82xx adapter (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix set_flags handler for ethtool (Chad Dupuis) [927395]
- [netdrv] qlcnic: Bump up the version to 5.2.40 (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix sparse warnings (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix NULL dereference in error path (Chad Dupuis) [927395]
- [netdrv] qlcnic: Fix potential NULL dereference (Chad Dupuis) [927395]
- [netdrv] qlcnic: Bump up the version to 5.2.39 (Chad Dupuis) [927395]
- [netdrv] qlcnic: Support atomic commands (Chad Dupuis) [927395]
- [netdrv] qlcnic: Support VF-PF communication channel commands (Chad Dupuis) [927395]
- [netdrv] qlcnic: VF-PF communication channel implementation (Chad Dupuis) [927395]
- [netdrv] qlcnic: Use shared interrupt vector for Tx and Rx (Chad Dupuis) [927395]
- [netdrv] qlcnic: SR-IOV VF probe (Chad Dupuis) [927395]
- [netdrv] qlcnic: Support SR-IOV enable and disable (Chad Dupuis) [927395]
- [netdrv] qlcnic: Add QLCNIC_SRIOV to Kconfig (Chad Dupuis) [927395]

* Thu Aug 15 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-413.el6]
- [mm] reinstate mmap -EINVAL return error code when mapping length is zero (Rafael Aquini) [995339]
- [fs] ext4: introduce reserved space (Lukas Czerner) [916592]
- [fs] ext4: dont let i_reserved_meta_blocks go negative (Lukas Czerner) [916592]
- [firmware] efivars: Use correct efi_pstore_info struct when calling pstore_register (Lenny Szubowicz) [867689]
- [s390] zfcp: block queue limits with data router (Hendrik Brueckner) [952734]
- [char] ipmi: eliminate long delay in ipmi_si on SGI UV2 (George Beshers) [876778]
- [net] bridge: fix a conflict in if_bridge.h with glibc headers (Amerigo Wang) [981325]
- [usb] fix endpoint-disabling for failed config changes (Don Zickus) [889391]
- [usb] Free the allocated memory before exiting on error (Don Zickus) [889391]
- [usb] xhci: fix list access before init (Don Zickus) [889391]
- [usb] xhci-mem: init list heads at the beginning of init (Don Zickus) [889391]
- [usb] xhci: override bogus bulk wMaxPacketSize values (Don Zickus) [889391]
- [usb] enclose USB_XHCI_HCD related symbols within a if USB_XHCI_HCD block (Don Zickus) [889391]
- [usb] xhci: clarify compliance mode debug messages (Don Zickus) [889391]
- [usb] xhci: Rename SEGMENT_SIZE and SEGMENT_SHIFT as the former is used in a.out.h (Don Zickus) [889391]
- [usb] xhci: Use ilog2() rather than __ffs() for calculating SEGMENT_SHIFT (Don Zickus) [889391]
- [usb] xhci: Don't warn on empty ring for suspended devices (Don Zickus) [889391]
- [usb] xhci: Fix TRB transfer length macro used for Event TRB (Don Zickus) [889391]
- [usb] xhci: fix build warning (Don Zickus) [889391]
- [usb] xhci: fix bit definitions for IMAN register (Don Zickus) [889391]
- [usb] xhci: correctly enable interrupts (Don Zickus) [889391]
- [usb] xhci: fix memory leak of URB-private data (Don Zickus) [889391]
- [usb] xhci: fix incorrect bit test (Don Zickus) [889391]
- [usb] xhci: Fix TD size for isochronous URBs (Don Zickus) [889391]
- [usb] xhci: Fix isoc TD encoding (Don Zickus) [889391]
- [usb] xhci: remove unused trb var in xhci_irq() (Don Zickus) [889391]
- [usb] xhci: Add Lynx Point LP to list of Intel switchable hosts (Don Zickus) [889391]
- [usb] xhci: move HC_STATE_SUSPENDED check to xhci_suspend() (Don Zickus) [889391]
- [usb] xhci: Stricter conditional for Z1 system models for Compliance Mode Patch (Don Zickus) [889391]
- [usb] xhci: Extend Fresco Logic MSI quirk (Don Zickus) [889391]
- [usb] xhci: fix null-pointer dereference when destroying half-built segment rings (Don Zickus) [889391]
- [usb] xhci: Fix TD Size calculation on 1.0 hosts (Don Zickus) [889391]
- [usb] xhci: Fix conditional check in bandwidth calculation (Don Zickus) [889391]
- [usb] xhci: Avoid global symbol pollution with handshake (Don Zickus) [889391]
- [usb] xhci: Remove assigned but unused ep_ctx (Don Zickus) [889391]
- [usb] xhci: Remove assigned but unused slot_ctx (Don Zickus) [889391]
- [usb] xhci: Fix missing break in xhci_evaluate_context_result (Don Zickus) [889391]
- [usb] xhci: Fix potential NULL ptr deref in command cancellation (Don Zickus) [889391]
- [usb] xhci: Remove __force__ __u16 before assigning DeviceRemovable and assign directly (Don Zickus) [889391]
- [usb] xhci-ring: removes unnecessary semicolon (Don Zickus) [889391]
- [usb] xhci: update a comment regarding the BOS descriptor to reflect the code (Don Zickus) [889391]
- [usb] xhci: sparse fixes (Don Zickus) [889391]
- [usb] Fail a get config when the port is powered off (Don Zickus) [889391]
- [usb] xhci: Handle clear PORT_POWER feature (Don Zickus) [889391]
- [usb] redefine DeviceRemovable and wHubDelay as _le16 (Don Zickus) [889391]
- [usb] xhci: Avoid "dead ports", add roothub port polling (Don Zickus) [894180]
- [usb] Handle warm reset failure on empty port (Don Zickus) [894180]
- [usb] Ignore port state until reset completes (Don Zickus) [894180]
- [usb] Increase reset timeout (Don Zickus) [894180]
- [usb] Allow USB 3.0 ports to be disabled (Don Zickus) [894180]
- [usb] Ignore xHCI Reset Device status (Don Zickus) [894180]
- [usb] Handle auto-transition from hot to warm reset (Don Zickus) [894180]
- [usb] xhci: Handle HS bulk/ctrl endpoints that don't NAK (Don Zickus) [894180]
- [usb] Enable LPM after a failed probe (Don Zickus) [815547]
- [usb] Don't enable LPM if the exit latency is zero (Don Zickus) [815547]
- [usb] Send Set SEL before enablng parent U1/U2 timeout (Don Zickus) [815547]
- [usb] xhci: endianness xhci_calculate_intel_u2_timeout (Don Zickus) [815547]
- [usb] xhci: fix integer overflow (Don Zickus) [815547]
- [usb] Fix LPM disable count mismatch on driver unbind (Don Zickus) [815547]
- [usb] Disable LPM while the device is unconfigured (Don Zickus) [815547]
- [usb] Fix LPM disable/enable during device reset (Don Zickus) [815547]
- [usb] xhci: Fix DIV_ROUND_UP compile error (Don Zickus) [815547]
- [usb] xhci: Fix compile with CONFIG_USB_SUSPEND=n (Don Zickus) [815547]
- [usb] Fix core compile with CONFIG_USB_SUSPEND=n (Don Zickus) [815547]
- [usb] Disable hub-initiated LPM for comms devices (Don Zickus) [815547]
- [usb] xhci: Add Intel U1/U2 timeout policy (Don Zickus) [815547]
- [usb] xhci: Add infrastructure for host-specific LPM policies (Don Zickus) [815547]
- [usb] Add macros for interrupt endpoint types (Don Zickus) [815547]
- [usb] xhci: Reserve one command for USB3 LPM disable (Don Zickus) [815547]
- [usb] xhci: Some Evaluate Context commands must succeed (Don Zickus) [815547]
- [usb] Disable USB 3.0 LPM in critical sections (Don Zickus) [815547]
- [usb] Add support to enable/disable USB3 link states (Don Zickus) [815547]
- [usb] Allow drivers to disable hub-initiated LPM (Don Zickus) [815547]
- [usb] Calculate USB 3.0 exit latencies for LPM (Don Zickus) [815547]
- [usb] Refactor code to set LPM support flag (Don Zickus) [815547]
- [usb] Make sure to fetch the BOS desc for roothubs (Don Zickus) [815547]
- [usb] xhci: Add roothub code to set U1/U2 timeouts (Don Zickus) [815547]
- [scsi] pm8001: Add new driver pmc8001 to RHEL 6.5 (Rich Bono) [922129]
- [scsi] bnx2fc: introduce missing kfree (Jan Vesely) [916004]
- [scsi] bnx2fc: Fix common misspellings (Jan Vesely) [916004]
- [scsi] bnx2fc: Drivers: scsi: remove __dev* attributes (Jan Vesely) [916004]
- [scsi] bnx2fc: Make the fcoe_cltr the SCSI host parent (Jan Vesely) [916004]
- [scsi] bnx2fc: Bumped version to 1.0.14 (Jan Vesely) [916004]
- [scsi] bnx2fc: Update copyright dates (Jan Vesely) [916004]
- [scsi] bnx2fc: Fix race condition between IO completion and abort (Jan Vesely) [916004]
- [scsi] bnx2fc: Include chip number in the symbolic name (Jan Vesely) [916004]
- [scsi] bnx2fc: Enable cached tasks to improve performance (Jan Vesely) [916004]
- [scsi] bnx2fc: adjust duplicate test (Jan Vesely) [916004]
- [scsi] bnx2fc: Bumped version to 1.0.13 (Jan Vesely) [916004]
- [scsi] bnx2fc: Support max IO size to 512KB (Jan Vesely) [916004]
- [scsi] bnx2fc: Tx/Rx byte counts reset to 0 when exceeding 32 bit values (Jan Vesely) [916004]
- [scsi] bnx2fc: Map the doorbell register between offload and enable requests (Jan Vesely) [916004]
- [scsi] bnx2fc: Move offload/upload wait logic into a function (Jan Vesely) [916004]
- [scsi] bnx2fc: support software fcoe target (Jan Vesely) [916004]
- [scsi] bnx2fc: remove useless calls to memset() (Jan Vesely) [916004]
- [scsi] bnx2fc: use fcoe_get_lesb/fcoe_ctlr_get_lesb() directly from libfcoe (Jan Vesely) [916004]
- [scsi] bnx2fc: use fcoe_link_speed_update() from the exported symbol in libfcoe (Jan Vesely) [916004]
- [scsi] bnx2fc: add support to get_netdev for bnx2f_interface (Jan Vesely) [916004]
- [scsi] bnx2fc: Use the fcoe_sysfs control interface (Jan Vesely) [916004]
- [scsi] libfcoe, fcoe, bnx2fc: Add new fcoe control interface (Jan Vesely) [916004]
- [scsi] bnx2fc: treewide: fix typo of "suppport" in various comments (Jan Vesely) [916004]
- [scsi] fix various printk and comment typos (Jan Vesely) [916004]
- [scsi] fcoe, bnx2fc, libfcoe: SW FCoE and bnx2fc use FCoE Syfs (Jan Vesely) [916004]
- [scsi] bnx2fc: Allocate fcoe_ctlr with bnx2fc_interface, not as a member (Jan Vesely) [916004]
- [scsi] bnx2i: Fixed bugs in the handling of unsolicited NOP-Ins (Jan Vesely) [916003]
- [scsi] bnx2i: Update version and copyright year 2013 (Jan Vesely) [916003]
- [scsi] bnx2i: Drivers: scsi: remove __dev* attributes (Jan Vesely) [916003]
- [scsi] bnx2i: Fix typo in printk and comments (Jan Vesely) [916003]
- [scsi] bnx2i: fix the bit manipulation when setting the error mask (Jan Vesely) [916003]
- [scsi] bnx2i: removed the individual PCI DEVICE ID checking (Jan Vesely) [916003]

* Tue Aug 13 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-412.el6]
- [netdrv] ixgbe: fix broken module parameter IntMode (Andy Gospodarek) [958967]
- [netdrv] ixgbe: fix broken module parameter FdirMode (Andy Gospodarek) [958967]
- [fs] fuse: initialize dentry->d_op properly in fuse_direntplus_link() (Brian Foster) [994492]
- [fs] nfs4: Fix infinite loop in nfs4_lookup_root (Scott Mayhew) [987426]
- [tracing] Replace syscall_meta_data struct array with pointer array (Jiri Olsa) [992987]
- [tracing] Replace trace_event struct array with pointer array (Jiri Olsa) [992987]
- [mm] percpu: don't implicitly include slab.h from percpu.h (Baoquan He) [878312]
- [mm] percpu: fix per_cpu_ptr_to_phys() handling of non-page-aligned addresses (Baoquan He) [878312]
- [mm] percpu: explain why per_cpu_ptr_to_phys() is more complicated than necessary (Baoquan He) [878312]
- [mm] percpu: fix chunk range calculation (Baoquan He) [878312]
- [mm] percpu: should use is_vmalloc_addr() (Baoquan He) [878312]
- [mm] percpu: fix pcpu_last_unit_cpu (Baoquan He) [878312]
- [mm] percpu: fix first chunk match in per_cpu_ptr_to_phys() (Baoquan He) [878312]
- [mm] percpu: fix trivial bugs in pcpu_build_alloc_info() (Baoquan He) [878312]
- [mm] percpu: move vmalloc based chunk management into percpu-vm.c (Baoquan He) [878312]
- [mm] percpu: misc preparations for nommu support (Baoquan He) [878312]
- [mm] percpu: reorganize chunk creation and destruction (Baoquan He) [878312]
- [mm] percpu: factor out pcpu_addr_in_first/reserved_chunk() and update per_cpu_ptr_to_phys() (Baoquan He) [878312]
- [mm] percpu: add __percpu sparse annotations to core kernel subsystems (Baoquan He) [878312]
- [mm] percpu: avoid calling __pcpu_ptr_to_addr() (Baoquan He) [878312]
- [mm] percpu: refactor the code in pcpu_depopulate_chunk() (Baoquan He) [878312]
- [mm] percpu: add missing per_cpu_ptr_to_phys() definition for UP (Baoquan He) [878312]
- [mm] percpu: Fix kdump failure if booted with percpu_alloc=page (Baoquan He) [878312]
- [mm] Revert: percpu: fix chunk range calculation (Baoquan He) [878312]
- [mm] Revert: percpu: Fix kdump crash_notes content lost in case i386 debug (Baoquan He) [878312]
- [md] raid5: fix interaction of 'replace' and 'recovery' (Jes Sorensen) [994382]
- [md] raid10: remove use-after-free bug (Jes Sorensen) [994382]
- [md] Remove recent change which allows devices to skip recovery (Jes Sorensen) [994382]
- [md] raid10: fix two problems with RAID10 resync (Jes Sorensen) [994382]
- [infiniband] ocrdma: Fix several stack info leaks (Doug Ledford) [827601]
- [infiniband] ocrdma: Remove unused include (Doug Ledford) [827601]
- [infiniband] hw: import new ocrdma driver from upstream tree (Doug Ledford) [827601]
- [infiniband] cma: Export AF_IB statistics (Michal Schmidt) [908111]
- [infiniband] ucma: Allow user space to specify AF_IB when joining multicast (Michal Schmidt) [908111]
- [infiniband] ucma: Allow user space to pass AF_IB into resolve (Michal Schmidt) [908111]
- [infiniband] ucma: Allow user space to bind to AF_IB (Michal Schmidt) [908111]
- [infiniband] ucma: Name changes to indicate only IP addresses supported (Michal Schmidt) [908111]
- [infiniband] ucma: Add ability to query GID addresses (Michal Schmidt) [908111]
- [infiniband] cma: Export cma_get_service_id() (Michal Schmidt) [908111]
- [infiniband] ucma: Support querying when IB paths are not reversible (Michal Schmidt) [908111]
- [infiniband] sa: Export function to pack a path record into wire format (Michal Schmidt) [908111]
- [infiniband] ucma: Support querying for AF_IB addresses (Michal Schmidt) [908111]
- [infiniband] cma: Only listen on IB devices when using AF_IB (Michal Schmidt) [908111]
- [infiniband] cma: Set qkey for AF_IB (Michal Schmidt) [908111]
- [infiniband] cma: Expose private data when using AF_IB (Michal Schmidt) [908111]
- [infiniband] cma: Merge cma_get/save_net_info (Michal Schmidt) [908111]
- [infiniband] cma: Remove unused SDP related code (Michal Schmidt) [908111]
- [infiniband] cma: Add support for AF_IB to cma_get_service_id() (Michal Schmidt) [908111]
- [infiniband] cma: Add support for AF_IB to rdma_resolve_route() (Michal Schmidt) [908111]
- [infiniband] cma: Add support for AF_IB to rdma_resolve_addr() (Michal Schmidt) [908111]
- [infiniband] cma: Verify that source and dest sa_family are the same (Michal Schmidt) [908111]
- [infiniband] cma: Restrict AF_IB loopback to binding to IB devices only (Michal Schmidt) [908111]
- [infiniband] cma: Add helper functions to return id address information (Michal Schmidt) [908111]
- [infiniband] cma: Do not modify sa_family when setting loopback address (Michal Schmidt) [908111]
- [infiniband] cma: Allow user to specify AF_IB when binding (Michal Schmidt) [908111]
- [infiniband] cma: Update port reservation to support AF_IB (Michal Schmidt) [908111]
- [infiniband] cma: Add AF_IB support to ip_addr_size (Michal Schmidt) [908111]
- [infiniband] cma: Include AF_IB in loopback and any address checks (Michal Schmidt) [908111]
- [infiniband] cma: Allow enabling reuseaddr in any state (Michal Schmidt) [908111]
- [infiniband] rdma: Define native IB address (Michal Schmidt) [908111]
- [netdrv] mlx4: Set link type for RAW PACKET QPs in the QP context (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Disable VLAN stripping for RAW PACKET QPs (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Fetch XRC SRQ in the CQ polling code (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Advertise MW support (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Support memory window binding (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Remove redundant NULL check before kfree (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Fix compiler warning about uninitialized 'vlan' variable (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Convert is_xxx variables in build_mlx_header() to bool (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Remove local invalidate segment unused fields (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Adjust duplicate test (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Fix bug unwinding on error in mlx4_ib_init_sriov() (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Fix build error on platforms where UL is not 64 bits (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: fix unresolved 64bit math in mellanox/mlx4/en_dcb_nl.c (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Can set maxrate only for TC0 (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Set max rate-limit for a TC (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] dcb: Add an optional max rate attribute (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Disable RFS when running in SRIOV mode (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Initialize RFS filters lock and list in init_netdev (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Limit the RFS filter IDs to be < RPS_NO_FILTER (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Add accelerated RFS support (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Add rmap support to mlx4_assign_eq (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: fix small memory leak on error (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Dynamic VST to VST vlan/qos changes (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Fail device init if num_vfs is negative (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Add warning in case of command timeouts (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Replace sscanf() with kstrtoint() (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Add prints when TX timeout occurs (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix a race between napi poll function and RX ring cleanup (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Change log level from error to debug for vlan related messages (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Move register_netdev() to the end of initialization function (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Do not query stats when device port is down (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix resource leak in error flow (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: allow order-0 memory allocations in RX path (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: use one page fragment per incoming frame (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx_en: Timestamping is not supported in slave mode (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Keep VF assigned MAC in the PF admin table (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Handle unassigned VF MAC address correctly (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix adaptive moderation cq update (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Strengthen VLAN tags/priorities enforcement in VST mode (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Add missing report on VST and spoof-checking dev caps (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: fix a build error on 32bit arches (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Add support to get VF config (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Add set VF default vlan ID and priority support (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Add set VF mac address support (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Add structures to keep VF Ethernet ports information (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Add reference counting to MAC registeration (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Disable HW clock overflow check when no HW support (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Disable HW timestamping for VFs (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Expose a few helpers to fill DMFS HW strucutures (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Directly expose fields of DMFS HW rule control segment (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Change a few DMFS fields names to match firmare spec (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Match DMFS promiscuous field names to firmware spec (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Move DMFS HW structs to common header file (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Reduce warning message for SRQ_LIMIT event to debug level (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Add a service task (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Support software timestamping (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Add HW timestamping support (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Read HCA frequency and map internal clock (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Add timestamping device capability (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Implement SRQ object lookup from srqn (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: set correct MTU in SRIOV (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Translate guest B0 steering rules to DMFS (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Add helper function to translate B0 steering rules to DMFS (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Advertize DCB_CAP_DCBX_HOST in getdcbx (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Enable DCB ETS ops only when supported by the firmware (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Added proper description for two device capabilities (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix setting initial MAC address (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Disallow releasing VF QPs which have steering rules (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Always use 64 bit resource ID when doing lookup (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Remove ethtool flow steering rules before releasing QPs (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Fix wrong order of flow steering resources removal (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Fix wrong mask applied on EQ numbers in the wrapper (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Cleanup MAC resources on module unload or port stop (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix race when setting the device MAC address (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Fix endianness bug in set_param_l (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Turn off device-managed FS bit in dev-cap wrapper if DMFS is not enabled (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Disable mlx4_QP_ATTACH calls from guests if the host uses flow steering (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Implement memory windows allocation and deallocation (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Enable memory windows in INIT_HCA and QUERY_HCA (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Disable memory windows for virtual functions (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: fix allocation of device tx_cq (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Propagate MR deregistration failures to caller (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Rename MPT-related functions to have mpt_ prefix (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Add unicast MAC filtering (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Manage hash of MAC addresses per port (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Save previous MAC address of the port so we can replace it later (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Re-arrange ndo_set_rx_mode related code (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Move Ethernet related functionality from mlx4_core to mlx4_en (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Cleanup multiline strings (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Optimize Rx fast path filter checks (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Optimize loopback related checks in data path (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Assigning TX irq per ring (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix compilation error when CONFIG_INET isn't defined (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix error propagation for ethtool helper function (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix transmit timeout when driver restarts port (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Don't reassign port mac address on firmware that supports it (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Use firmware driven flow steering hash mode (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix ethtool rules leftovers after module unloaded (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Block insertion of ethtool steering rules while the interface is down (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix vlan mask for ethtool steering rules (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Validate VLAN IDs provided in ethtool flow steering rules (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix ip/udp steering rules multicast mac when attached via ethtool (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Set correctly allow_loopback flag (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Directly expose fields of HW flow steering rule control segment (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix a race when closing TX queue (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Return proper error code when __mlx4_add_one fails (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Use the correct netif lock on ndo_set_rx_mode (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix traffic loss under promiscuous mode (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Issue the dump eth statistics command under lock (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: remove redundant code (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Add support for destination MAC in steering rules (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Use generic etherdevice.h functions (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Set number of rx/tx channels using ethtool (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix TX moderation info loss after set_ringparam is called (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Adjusting moderation per each ring (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Remove remnants of LRO support (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Unmap UAR also in the case of error flow (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Don't use vlan tag value as an indication for vlan presence (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Perform correct resource cleanup if mlx4_QUERY_ADAPTER() fails (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_core: Remove annoying debug messages from SR-IOV flow (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: fix skb truesize underestimation (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] etherdevice.h: Add ether_addr_equal_64bits (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] ethtool: Add destination MAC address to flow steering API (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fixing TX queue stop/wake flow (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: nullify cq->vector field when closing completion queue (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Checksum counters per ring (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4: Fix vlan table overflow (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Adding 40gb speed report for ethtool (Amir Vadai) [950401 950910 950913 950915]
- [netdrv] mlx4_en: Fix crash upon device initialization error (Amir Vadai) [950401 950910 950913 950915]
- [net] introduce IFF_NO_UNICAST_FLT (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] ipoib: Add more rtnl_link_ops callbacks (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] ipoib: Add rtnl_link_ops support (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] ib_srp: Eliminate state SRP_TARGET_DEAD - minus system_long_wq (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Allow SRP disconnect through sysfs (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp_transport: Simplify attribute initialization code (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp_transport: Fix attribute registration (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp_transport: Document sysfs attributes (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: use __scsi_target_unblock (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] iser: Add Mellanox copyright (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] iser: Fix device removal flow (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] iser: Add support for iser CM REQ additional info (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] iser: Return error to upper layers on EAGAIN registration failures (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] iser: Move informational messages from error to info level (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] iser: Add module version (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] IPoIB: add support for TIPC protocol (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] IPoIB: Fix ipoib_hard_header() return value (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] IPoIB: Fix send lockup due to missed TX completion (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] rds: zero last byte for strncpy (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] rds: simplify a warning message (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] rds: limit the size allocated by rds_message_alloc() (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] IPoIB: Free ipoib neigh on path record failure so path rec queries are retried (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Fail I/O requests if the transport is offline (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Avoid endless SCSI error handling loop (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Avoid sending a task management function needlessly (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Track connection state properly (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] iser: Enable iser when FMRs are not supported (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] iser: Avoid error prints on EAGAIN registration failures (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] iser: Use proper define for the commands per LUN value advertised to SCSI ML (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] IPoIB: Don't attempt to release resources on error flow (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] IPoIB: Add version and firmware info to ethtool reporting (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] IPoIB: Fix ipoib_neigh hashing to use the correct daddr octets (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] IPoIB: Fix crash due to skb double destruct (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] rds: remove depends on CONFIG_EXPERIMENTAL (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] IPoIB: Call skb_dst_drop() once skb is enqueued for sending (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: send disconnect request without waiting for CM timewait exit (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: destroy and recreate QP and CQs when reconnecting (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Introduce the helper function srp_remove_target() (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Suppress superfluous error messages (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Process all error completions (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Introduce srp_handle_qp_err() (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Simplify SCSI error handling (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Keep processing commands during host removal (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Eliminate state SRP_TARGET_CONNECTING (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] srp: Increase block layer timeout (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] iser: Add more RX CQs to scale out processing of SCSI responses (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] core: Don't touch cmid after dropping reference (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] core: Verify that QP handler is valid before dispatching events (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] uverbs: Implement memory windows support in uverbs (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] core: Add "type 2" memory windows support (Doug Ledford) [791284 865301 950918 983117]
- [infiniband] core: Change return value from find_gid_port() (Doug Ledford) [791284 865301 950918 983117]

* Thu Aug 08 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-411.el6]
- [fs] autofs: remove autofs dentry mount check (Ian Kent) [947275]
- [net] bridge: do not call setup_timer() multiple times (Amerigo Wang) [994430]
- [mm] compaction: fixup need_compaction (Andrea Arcangeli) [953225]
- [mm] compaction: add compaction to zone_reclaim_mode (Andrea Arcangeli) [953225]
- [mm] zone_reclaim: after a successful zone_reclaim check the min watermark (Andrea Arcangeli) [953225]
- [mm] compaction: increase the high order pages in the watermarks (Andrea Arcangeli) [953225]
- [mm] compaction: don't require high order pages below min wmark (Andrea Arcangeli) [953225]
- [mm] compaction: reset before initializing the scan cursors (Andrea Arcangeli) [953225]
- [mm] compaction: don't depend on kswapd to invoke reset_isolation_suitable (Andrea Arcangeli) [953225]
- [mm] zone_reclaim: compaction: scan all memory with /proc/sys/vm/compact_memory (Andrea Arcangeli) [953225]
- [mm] zone_reclaim: remove ZONE_RECLAIM_LOCKED (Andrea Arcangeli) [953225]
- [mm] page_alloc: avoid marking zones full prematurely after zone_reclaim() (Andrea Arcangeli) [953225]
- [x86] trace: Add irq_enter/exit() in smp_trace_reschedule_interrupt() (Seiji Aguchi) [738712]
- [x86] trace: Add config option checking to the definitions of mce handlers (Seiji Aguchi) [738712]
- [x86] trace: Do not call local_irq_save() in load_current_idt() (Seiji Aguchi) [738712]
- [x86] trace: Move creation of irq tracepoints from apic.c to irq.c (Seiji Aguchi) [738712]
- [x86] trace: Add irq vector tracepoints (Seiji Aguchi) [738712]
- [x86] trace: Introduce entering/exiting_irq() (Seiji Aguchi) [738712]
- [x86] trace: Add DEFINE_EVENT_FN() macro (Seiji Aguchi) [738712]
- [x86] uv3: Trim MMR register definitions after code changes for SGI UV3 (George Beshers) [988345]
- [x86] uv3: Check current gru hub support for SGI UV3 (George Beshers) [988345]
- [x86] uv3: Update Time Support for SGI UV3 (George Beshers) [988345]
- [x86] uv3: Update x2apic Support for SGI UV3 (George Beshers) [988345]
- [x86] uv3: Update Hub Info for SGI UV3 (George Beshers) [988345]
- [x86] uv3: Update ACPI Check to include SGI UV3 (George Beshers) [988345]
- [x86] uv3: Update MMR register definitions for SGI Ultraviolet System 3 (George Beshers) [988345]
- [kernel] coredump: change wait_for_dump_helpers() to use wait_event_interruptible() (Oleg Nesterov) [773215]
- [kernel] coredump: introduce dump_interrupted() (Oleg Nesterov) [773215]
- [kernel] coredump: Un-inline the core-dump helper functions (Oleg Nesterov) [773215]
- [kernel] coredump: sanitize the setting of signal->group_exit_code (Oleg Nesterov) [773215]
- [kernel] coredump: ensure that SIGKILL always kills the dumping thread (Oleg Nesterov) [773215]
- [kernel] coredump: only SIGKILL should interrupt the coredumping task (Oleg Nesterov) [773215]
- [kernel] coredump: set ->group_exit_code for other CLONE_VM tasks too (Oleg Nesterov) [773215]
- [fs] procfs: allow threads to rename siblings via /proc/pid/tasks/tid/comm (Jerome Marchand) [950840]
- [security] selinux: make security_sb_clone_mnt_opts return an error on context mismatch (Jeff Layton) [800218]
- [netdrv] bna: fix vlan_grp handling (Stefan Assmann) [886420]
- [netdrv] mlx4_en: fix vlgrp handling (Stefan Assmann) [886420]
- [netdrv] qlge: fix vlgrp handling (Stefan Assmann) [886420]
- [netdrv] qlcnic: fix vlgrp handling (Stefan Assmann) [886420]
- [fs] nfs4: end back channel session draining (Steve Dickson) [984118]
- [fs] nfs4: Fix a pNFS session draining deadlock (Steve Dickson) [984118]
- [fs] xfs: Fix delalloc WARN_ON() in xfs_vm_releasepage() (Aaron Tomlin) [991496]
- [fs] nfs: Fix access to suid/sgid executables (Niels de Vos) [988135]
- [fs] nfs4: don't put ACCESS in OPEN compound if O_EXCL (Niels de Vos) [988135]
- [fs] nfs4: Add ACCESS operation to OPEN compound (Niels de Vos) [988135]
- [fs] livelock avoidance in sget() (Eric Sandeen) [916811]
- [fs] ext4: create a new BH_Verified flag to avoid unnecessary metadata validation (Lukas Czerner) [879163]
- [fs] ext4: Fix dirtying of journalled buffers in data=journal mode (Lukas Czerner) [834919]
- [fs] ext4: fix ext_remove_space for punch_hole case (Lukas Czerner) [969307]
- [fs] ext4: punch_hole should wait for DIO writers (Lukas Czerner) [969307]
- [fs] ext4: prevent race while walking extent tree for fiemap (Lukas Czerner) [692063]
- [fs] ext4: Fix possibly very long loop in fiemap (Lukas Czerner) [692063]
- [fs] ext4: make FIEMAP and delayed allocation play well together (Lukas Czerner) [692063]
- [fs] ext4: handle NULL p_ext in ext4_ext_next_allocated_block() (Lukas Czerner) [692063]
- [fs] ext4: drop ec_type from the ext4_ext_cache structure (Lukas Czerner) [692063]
- [fs] lockd: protect nlm_blocked list (David Jeffery) [967095]
- [virt] hv: Populate the guest ID with RHEL info (Jason Wang) [969230]
- [virt] hv: Fix a bug in version negotiation code for util services (Jason Wang) [980554]
- [netdrv] e1000e: disable ASPM L1 on 82583 (Dean Nelson) [991242]
- [pci] Fix bit definitions of PCI_EXP_LNKCAP2 register (Myron Stowe) [989252]
- [virt] storvsc: Increase the value of STORVSC_MAX_IO_REQUESTS (Jason Wang) [969537 969548]
- [virt] storvsc: Support FC devices (Jason Wang) [969537]
- [virt] storvsc: Implement multi-channel support (Jason Wang) [969537]
- [virt] storvsc: Update the storage protocol to win8 level (Jason Wang) [969537]
- [virt] storvsc: Increase the value of scsi timeout for storvsc devices (Jason Wang) [969548]
- [virt] hv: Add the GUID fot synthetic fibre channel device (Jason Wang) [969537]
- [s390] sclp: add parameter to specify number of buffer pages (Hendrik Brueckner) [990853]
- [usb] fix thread-unsafe anchor utiliy routines (Stanislaw Gruszka) [993005]
- [kernel] hung_task: print more info when reporting the problem (Oleg Nesterov) [976899]
- [cpufreq] Convert the cpufreq_driver_lock to a rwlock (Prarit Bhargava) [887045]
- [scsi] fnic: fix sleeping function called from invalid context during probe (Chris Leech) [829506]
- [scsi] fnic: potential dead lock in fnic_is_abts_pending() (Chris Leech) [829506]
- [scsi] fnic: Incremented driver version (Chris Leech) [829506]
- [scsi] fnic: fix kernel panic due to FIP mode misconfiguration (Chris Leech) [829506]
- [scsi] fnic: FIP VLAN Discovery Feature Support (Chris Leech) [829506]
- [scsi] fnic: Fnic Trace Utility (Chris Leech) [829506]
- [scsi] fnic: New debug flags and debug log messages (Chris Leech) [829506]
- [scsi] fnic: fnic driver may hit BUG_ON on device reset (Chris Leech) [829506]
- [scsi] fnic: Fix SGEs limit (Chris Leech) [829506]
- [scsi] fnic: fixing issues in device and firmware reset code (Chris Leech) [829506]
- [scsi] fnic: fix for trusted cos (Chris Leech) [829506]
- [scsi] fnic: fix incorrect use of SLAB_CACHE_DMA flag (Chris Leech) [829506]
- [x86] pmu: prepare for migration support (Paolo Bonzini) [928866]
- [x86] kvm: Add code to track call origin for msr assignment (Paolo Bonzini) [928866]
- [x86] kvm: add kvm_arch_vcpu_postcreate callback, move TSC initialization (Paolo Bonzini) [928866]
- [netdrv] e1000e: fix I217/I218 PHY initialization flow (Dean Nelson) [981032]
- [netdrv] e1000e: enable support for new device IDs (Dean Nelson) [981032]
- [input] wacom: BTN_TOOL_DOUBLETAP is not a valid device_type (Aristeu Rozanski) [815589]
- [input] wacom: use BTN_TOOL_FINGER to indicate touch device type (Aristeu Rozanski) [815589]
- [input] wacom: remove pressure for touch devices (Aristeu Rozanski) [815589]
- [input] wacom: report id 3 returns 4 bytes of data (Aristeu Rozanski) [815589]
- [input] wacom: add support for Lenovo tablet ID 0xE6 (Aristeu Rozanski) [815589]
- [input] wacom: support 2FGT in MT format (Aristeu Rozanski) [815589]
- [input] wacom: support one finger touch the touchscreen way (Aristeu Rozanski) [815589]
- [input] wacom: process pen data in its own routine (Aristeu Rozanski) [815589]
- [input] wacom: share pen info with touch of the same ID (Aristeu Rozanski) [815589]
- [input] wacom: fix runtime PM related deadlock (Aristeu Rozanski) [815589]
- [input] wacom: add support for new LCD tablets (Aristeu Rozanski) [815589]
- [input] wacom: add defines for packet lengths of various devices (Aristeu Rozanski) [815589]
- [input] wacom: fix error path in wacom_probe() (Aristeu Rozanski) [815589]
- [scsi] qla2xxx: Update version number to 8.05.00.03.06.5-k (Chad Dupuis) [927382]
- [scsi] Revert "qla2xxx: Add setting of driver version string for vendor application." (Chad Dupuis) [927382]
- [scsi] qla2xxx: Clear the MBX_INTR_WAIT flag when the mailbox time-out happens (Chad Dupuis) [927382]
- [scsi] qla2xxx: Fix for locking issue between driver ISR and mailbox routines (Chad Dupuis) [927382]
- [scsi] qla2xxx: Add clarifying printk to thermal access fail cases (Chad Dupuis) [927382]
- [scsi] qla2xxx: Wait for IDC complete event to finish loopback operation (Chad Dupuis) [927382]
- [scsi] qla2xxx: Don't process state change aen for reset owner (Chad Dupuis) [927382]
- [scsi] qla2xxx: Don't process RSCNs for a vport on the same physical adapter (Chad Dupuis) [927382]
- [scsi] qla2xxx: Correction of comment in MBC opcode defines (Chad Dupuis) [927382]
- [scsi] qla2xxx: Correct list-iteration bug in Report-ID Acquisition codes (Chad Dupuis) [927382]
- [scsi] qla2xxx: Enhancements to support ISPFx00 (Chad Dupuis) [927382]
- [scsi] qla2xxx: Integrate generic card temperature with mezz card temperature (Chad Dupuis) [927382]
- [scsi] qla2xxx: Add setting of driver version string for vendor application (Chad Dupuis) [927382]
- [scsi] qla2xxx: Update the copyright information (Chad Dupuis) [927382]
- [scsi] qla2xxx: Display the lock owner on lock acquire failure (Chad Dupuis) [927382]
- [scsi] qla2xxx: Move loopback mode reset after chip reset check (Chad Dupuis) [927382]
- [scsi] qla2xxx: Extra loopback error handling for ISP83xx (Chad Dupuis) [927382]
- [scsi] qla2xxx: don't free pool that wasn't allocated (Chad Dupuis) [927382]
- [scsi] qla2xxx: Unload hangs after issuing BSG commands to vport (Chad Dupuis) [927382]
- [scsi] qla2xxx: Do MPI reset only for 81xx (Chad Dupuis) [927382]
- [scsi] qla2xxx: Do link initialization on get loop id failure (Chad Dupuis) [927382]
- [scsi] qla2xxx: Update the FTP site references in the driver sources (Chad Dupuis) [927382]
- [scsi] qla2xxx: Reject loopback request if one is already in progress (Chad Dupuis) [927382]
- [scsi] qla2xxx: Print thermal unsupported message (Chad Dupuis) [927382]
- [scsi] qla2xxx: Avoid null pointer dereference in shutdown routine (Chad Dupuis) [927382]
- [scsi] qla2xxx: Get VPD information from common location for CNA (Chad Dupuis) [927382]
- [scsi] qla2xxx: Correct race in loop_state assignment during reset handling (Chad Dupuis) [927382]
- [scsi] qla2xxx: Display that driver is operating in legacy interrupt mode (Chad Dupuis) [927382]
- [scsi] qla2xxx: Free rsp_data even on error in qla2x00_process_loopback() (Chad Dupuis) [927382]
- [scsi] qla2xxx: Dont clear drv active on iospace config failure (Chad Dupuis) [927382]
- [scsi] qla2xxx: Fix typo in qla2xxx driver (Chad Dupuis) [927382]
- [scsi] qla2xxx: Update ql2xextended_error_logging parameter description with new options (Chad Dupuis) [927382]
- [scsi] qla2xxx: Parameterize the link speed of hba rather than fcport (Chad Dupuis) [927382]
- [scsi] qla2xxx: Add 16Gb/s case to get port speed capability (Chad Dupuis) [927382]
- [scsi] qla2xxx: Move marking fcport online ahead of setting iiDMA speed (Chad Dupuis) [927382]
- [scsi] qla2xxx: Obtain loopback iteration count from bsg request (Chad Dupuis) [927382]
- [scsi] qla2xxx: Add acquiring of risc semaphore before doing ISP reset (Chad Dupuis) [927382]
- [scsi] qla2xxx: Properly set result field of bsg_job reply structure for success and failure (Chad Dupuis) [927382]
- [scsi] qla2xxx: Fix coccinelle warnings in qla2x00_relogin (Chad Dupuis) [927382]
- [scsi] qla2xxx: Ignore driver ack bit if corresponding presence bit is not set (Chad Dupuis) [927382]
- [scsi] qla2xxx: Use correct Request-Q-Out register during bidirectional request processing (Chad Dupuis) [927382]
- [scsi] qla2xxx: Fix typo in qla83xx_fw_dump function (Chad Dupuis) [927382]
- [scsi] qla2xxx: Add Gen3 PCIe speed 8GT/s to the log message (Chad Dupuis) [927382]
- [scsi] qla2xxx: Move noisy Start scsi failed messages to verbose logging level (Chad Dupuis) [927382]
- [scsi] qla2xxx: Honor status value of 2 for report-id acquisition (Chad Dupuis) [927382]
- [scsi] qla2xxx: Fix for warnings reported by sparse (Chad Dupuis) [927382]
- [scsi] qla2xxx: No fcport FC-4 type assignment in GA_NXT response (Chad Dupuis) [927382]
- [scsi] qla2xxx: Change in setting UNLOADING flag and FC vports logout sequence while unloading qla2xxx driver (Chad Dupuis) [927382]
- [scsi] qla2xxx: Clear unsupported 'states' during Get-FW-State queries (Chad Dupuis) [927382]
- [scsi] qla2xxx: Remove spurious taking of ha->vport_slock spinlock (Chad Dupuis) [927382]
- [cciss] Silence noisy per-device cciss messages (Tomas Henzl) [972697]
- [scsi] mpt3sas: Bump driver version to v02.100.00.00-rh1 (Tomas Henzl) [839470]
- [scsi] mpt3sas: when async scanning is enabled then while scanning, devices are removed but their transport layer entries are not removed (Tomas Henzl) [839470]
- [scsi] mpt3sas: MPI2.5 Rev F v2.5.1.1 specification (Tomas Henzl) [839470]
- [scsi] mpt3sas: Infinite loops can occur if MPI2_IOCSTATUS_CONFIG_INVALID_PAGE is not returned (Tomas Henzl) [839470]
- [scsi] mpt3sas: fix for kernel panic when driver loads with HBA conected to non LUN 0 configured expander (Tomas Henzl) [839470]
- [scsi] mpt3sas: Updated the Hardware timing requirements (Tomas Henzl) [839470]
- [scsi] mpt3sas: 2013 source code copyright (Tomas Henzl) [839470]
- [scsi] mpt3sas: don't wank with fasync on ->release() (Tomas Henzl) [839470]
- [scsi] mpt3sas: Fix typos in printk (Tomas Henzl) [839470]
- [scsi] mpt3sas: remove unused variables (Tomas Henzl) [839470]
- [scsi] mpt3sas: Remove unneeded version.h header inclusion (Tomas Henzl) [839470]
- [scsi] mpt3sas: cut and paste bug storing trigger mpi (Tomas Henzl) [839470]
- [scsi] mpt3sas: add new driver supporting 12GB SAS (Tomas Henzl) [839470]
- [scsi] scsi_transport_sas: add 12GB definitions for mpt3sas (Tomas Henzl) [839470]
- [scsi] megaraid_sas: megaraid_sas driver init fails in kdump kernel (Tomas Henzl) [833299]
- [scsi] sd_dif: problem with verify of type 1 protection information (PI) (Ewan Milne) [956402]
- [scsi] sd: Ensure we correctly disable devices with unknown protection type (Ewan Milne) [956402]
- [scsi] sd: Avoid remapping bad reference tags (Ewan Milne) [956402]
- [scsi] sd: Allow protection_type to be overridden (Ewan Milne) [956402]
- [scsi] Disable DIF on Hitachi Ultrastar 15K300 (Ewan Milne) [956402]
- [scsi] Fix printing of variable length commands (Ewan Milne) [956402]
- [scsi] Fix race between starved list and device removal (Ewan Milne) [916994]
- [scsi] Add 'eh_deadline' to limit SCSI EH runtime (Ewan Milne) [923876]
- [scsi] remove check for 'resetting' (Ewan Milne) [923876]
- [scsi] dc395: Move 'last_reset' into internal host structure (Ewan Milne) [923876]
- [scsi] tmscsim: Move 'last_reset' into host structure (Ewan Milne) [923876]
- [scsi] advansys Remove 'last_reset' references (Ewan Milne) [923876]
- [scsi] dpt_i2o: return SCSI_MLQUEUE_HOST_BUSY when in reset (Ewan Milne) [923876]
- [scsi] dpt_i2o: Remove DPTI_STATE_IOCTL (Ewan Milne) [923876]
- [net] ipv6: prevent race between address creation and removal (Jiri Pirko) [953380]
- [net] ipv6: call udp_push_pending_frames when uncorking a socket with AF_INET pending data (Jiri Benc) [987651] {CVE-2013-4162}
- [net] netlabel: improve domain mapping validation (Paul Moore) [963427]
- [net] netlabel: correctly list all the static label mappings (Paul Moore) [918803]
- [x86] Revert "io_apic: initialize nr_ioapic_registers early in mp_register_ioapic()" (Rafael Aquini) [855057]

* Wed Aug 07 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-410.el6]
- [x86] Revert: power: Initialize MSR_IA32_ENERGY_PERF_BIAS due to performance regression (Neil Horman) [968981]
- [mm] mmu_notifier: re-fix freed page still mapped in secondary MMU (George Beshers) [910085]
- [x86] Round the calculated scale factor in set_cyc2ns_scale() (Prarit Bhargava) [975507]
- [x86] sched: Fix overflow in cyc2ns_offset (Prarit Bhargava) [975507]
- [virt] virtio: support unlocked queue poll (Jason Wang) [989411]
- [netdrv] virtio_net: fix race in RX VQ processing (Jason Wang) [989411]
- [watchdog] Use pr_<fmt> and pr_<level> (Don Zickus) [796364]
- [watchdog] cleanup spaces before tabs (Don Zickus) [796364]
- [watchdog] sbc_fitpc2_wdt: fix crash on systems without DMI_BOARD_NAME (Don Zickus) [796364]
- [watchdog] sbc_fitpc2_wdt: fixed "scheduling while atomic" bug (Don Zickus) [796364]
- [watchdog] sbc_fitpc2_wdt: fixed I/O operations order (Don Zickus) [796364]
- [watchdog] watchdog_info constify (Don Zickus) [796364]
- [watchdog] sbc_fitpc2_wdt: fix I/O space access technique (Don Zickus) [796364]
- [block] aoe: adjust ref of head for compound page tails (David Milburn) [976900]
- [block] aoe: update internal version number to v83 (David Milburn) [976900]
- [block] aoe: update copyright date (David Milburn) [976900]
- [block] aoe: perform I/O completions in parallel (David Milburn) [976900]
- [block] aoe: replace kmalloc and then memcpy with kmemdup (David Milburn) [976900]
- [block] aoe: reserve enough headroom on skbs (David Milburn) [976900]
- [block] aoe: get rid of cached bv variable in bufinit() (David Milburn) [976900]
- [block] aoe: fix use after free in aoedev_by_aoeaddr() (David Milburn) [976900]
- [block] aoe: update internal version number to 81 (David Milburn) [976900]
- [block] aoe: identify source of runt AoE packets (David Milburn) [976900]
- [block] aoe: allow comma separator in aoe_iflist value (David Milburn) [976900]
- [block] aoe: allow user to disable target failure timeout (David Milburn) [976900]
- [block] aoe: use dynamic number of remote ports for AoE storage target (David Milburn) [976900]
- [block] aoe: avoid races between device destruction and discovery (David Milburn) [976900]
- [block] aoe: improve handling of misbehaving network paths (David Milburn) [976900]
- [block] aoe: return real minor number for static minors (David Milburn) [976900]
- [block] aoe: initialize sysminor to avoid compiler warning (David Milburn) [976900]
- [block] aoe: make error messages more specific in static minor allocation (David Milburn) [976900]
- [block] aoe: remove call to request handler from I/O completion (David Milburn) [976900]
- [block] aoe: cleanup: correct comment for aoetgt nout (David Milburn) [976900]
- [block] aoe: increase default cap on outstanding AoE commands in the network (David Milburn) [976900]
- [block] aoe: remove vestigial request queue allocation (David Milburn) [976900]
- [block] aoe: copy fallback timing information on destination failover (David Milburn) [976900]
- [block] aoe: update driver-internal version to 64+ (David Milburn) [976900]
- [block] aoe: commands in retransmit queue use new destination on failure (David Milburn) [976900]
- [block] aoe: use high-resolution RTTs with fallback to low-res (David Milburn) [976900]
- [block] aoe: manipulate aoedev network stats under lock (David Milburn) [976900]
- [block] aoe: err device: include MAC addresses for unexpected responses (David Milburn) [976900]
- [block] aoe: improve network congestion handling (David Milburn) [976900]
- [block] aoe: provide ATA identify device content to user on request (David Milburn) [976900]
- [block] aoe: update driver-internal version number to 60 (David Milburn) [976900]
- [block] aoe: whitespace cleanup (David Milburn) [976900]
- [block] aoe: cleanup: remove unused ata_scnt function (David Milburn) [976900]
- [block] aoe: "payload" sysfs file exports per-AoE-command data transfer size (David Milburn) [976900]
- [block] aoe: support larger I/O requests via aoe_maxsectors module param (David Milburn) [976900]
- [block] aoe: update cap on outstanding commands based on config query response (David Milburn) [976900]
- [block] aoe: support the forgetting (flushing) of a user-specified AoE target (David Milburn) [976900]
- [block] aoe: print warning regarding a common reason for dropped transmits (David Milburn) [976900]
- [block] aoe: avoid running request handler on plugged queue (David Milburn) [976900]
- [block] aoe: update aoe-internal version number to 50 (David Milburn) [976900]
- [block] aoe: update documentation to better reflect aoe-plus-udev usage (David Milburn) [976900]
- [block] aoe: remove unused code (David Milburn) [976900]
- [block] aoe: make dynamic block minor numbers the default (David Milburn) [976900]
- [block] aoe: update and specify AoE address guards and error messages (David Milburn) [976900]
- [block] aoe: retain static block device numbers for backwards compatibility (David Milburn) [976900]
- [block] aoe: support more AoE addresses with dynamic block device minor numbers (David Milburn) [976900]
- [block] aoe: update documentation with new URL and VM settings reference (David Milburn) [976900]
- [block] aoe: update copyright year in touched files (David Milburn) [976900]
- [block] aoe: update internal version number to 49 (David Milburn) [976900]
- [block] aoe: remove unused code and add cosmetic improvements (David Milburn) [976900]
- [block] aoe: increase net_device reference count while using it (David Milburn) [976900]
- [block] aoe: associate frames with the AoE storage target (David Milburn) [976900]
- [block] aoe: disallow unsupported AoE minor addresses (David Milburn) [976900]
- [block] aoe: do revalidation steps in order (David Milburn) [976900]
- [block] aoe: failover remote interface based on aoe_deadsecs parameter (David Milburn) [976900]
- [block] aoe: use packets that work with the smallest-MTU local interface (David Milburn) [976900]
- [block] aoe: use a kernel thread for transmissions (David Milburn) [976900]
- [block] aoe: become I/O request queue handler for increased user control (David Milburn) [976900]
- [block] aoe: kernel thread handles I/O completions for simple locking (David Milburn) [976900]
- [block] aoe: for performance support larger packet payloads (David Milburn) [976900]
- [block] aoe: assert AoE packets marked as requiring no checksum (David Milburn) [976900]
- [md] dm-raid: Remember the last sync operation that was performed (Jonathan E Brassow) [985920]
- [md] dm-raid: silence compiler warning on rebuilds_per_group (Jonathan E Brassow) [985920]
- [md] dm-raid: Fix raid_resume not reviving failed devices in all cases (Jonathan E Brassow) [913650]
- [md] dm-raid: Break-up untidy function (Jonathan E Brassow) [913650]
- [md] dm-raid: Add ability to restore transiently failed devices on resume (Jonathan E Brassow) [913650]
- [md] dm-raid: Add message/status support for changing sync action (Jonathan E Brassow) [985920]
- [md] dm-raid: round region_size to power of two (Jonathan E Brassow) [985920]
- [block] nvme: fixup nvme_dev_open for ioctl's (David Milburn) [922973]
- [block] nvme: Return the result from user admin command IOCTL even in case of failure (David Milburn) [922973]
- [block] nvme: Add MSI support (David Milburn) [922973]
- [block] nvme: Use dma_set_mask() correctly (David Milburn) [922973]
- [block] nvme: Do not cancel command multiple times (David Milburn) [922973]
- [block] nvme: fix error return code in nvme_submit_bio_queue() (David Milburn) [922973]
- [block] nvme: check for integer overflow in nvme_map_user_pages() (David Milburn) [922973]
- [block] nvme: update NVM EXPRESS DRIVER file list (David Milburn) [922973]
- [block] nvme: Fix a signedness bug in nvme_trans_modesel_get_mp (David Milburn) [922973]
- [block] nvme: Remove redundant version.h header include (David Milburn) [922973]
- [block] nvme: Use user defined admin ioctl timeout (David Milburn) [922973]
- [block] nvme: Simplify Firmware Activate code slightly (David Milburn) [922973]
- [block] nvme: Only clear the enable bit when disabling controller (David Milburn) [922973]
- [block] nvme: Wait for device to acknowledge shutdown (David Milburn) [922973]
- [block] nvme: Schedule timeout for sync commands (David Milburn) [922973]
- [block] nvme: Meta-data support in NVME_IOCTL_SUBMIT_IO (David Milburn) [922973]
- [block] nvme: Device specific stripe size handling (David Milburn) [922973]
- [block] nvme: Split non-mergeable bio requests (David Milburn) [922973]
- [block] nvme: Remove dead code in nvme_dev_add (David Milburn) [922973]
- [block] nvme: Check for NULL memory in nvme_dev_add (David Milburn) [922973]
- [block] nvme: Fix error clean-up on nvme_alloc_queue (David Milburn) [922973]
- [block] nvme: Free admin queue on request_irq error (David Milburn) [922973]
- [block] nvme: Add scsi unmap to SG_IO (David Milburn) [922973]
- [block] nvme: queue usage fixes in nvme-scsi (David Milburn) [922973]
- [block] nvme: Set TASK_INTERRUPTIBLE before processing queues (David Milburn) [922973]
- [block] nvme: Add a character device for each nvme device (David Milburn) [922973]
- [block] nvme: Fix endian-related problems in user I/O submission path (David Milburn) [922973]
- [block] nvme: Fix I/O cancellation status on big-endian machines (David Milburn) [922973]
- [block] nvme: Fix sparse warnings in scsi emulation (David Milburn) [922973]
- [block] nvme: Don't fail initialisation unnecessarily (David Milburn) [922973]
- [block] nvme: Abstract out sector to block number conversion (David Milburn) [922973]
- [block] nvme: Use round_jiffies_relative() for the periodic, once-per-second timer (David Milburn) [922973]
- [block] nvme: Add nvme-scsi.c (David Milburn) [922973]
- [block] nvme: Add definitions for format command (David Milburn) [922973]
- [block] nvme: Move structures & definitions to header file (David Milburn) [922973]
- [block] nvme: Rename nvme.c to nvme-core.c (David Milburn) [922973]
- [block] nvme: Add discard support for capable devices (David Milburn) [922973]
- [block] nvme: Add namespaces with no LBA range feature (David Milburn) [922973]
- [block] nvme: Add entry for the NVMe driver (David Milburn) [922973]
- [block] nvme: Initialize iod nents to 0 (David Milburn) [922973]
- [block] nvme: Define SMART log (David Milburn) [922973]
- [block] nvme: Add result to nvme_get_features (David Milburn) [922973]
- [block] nvme: Set result from user admin command (David Milburn) [922973]
- [block] nvme: End queued bio requests when freeing queue (David Milburn) [922973]
- [block] nvme: Free cmdid on nvme_submit_bio error (David Milburn) [922973]
- [block] nvme: Cancel outstanding IOs on queue deletion (David Milburn) [922973]
- [block] nvme: Free admin queue memory on initialisation failure (David Milburn) [922973]
- [block] nvme: Use ida for nvme device instance (David Milburn) [922973]
- [block] nvme: Fix whitespace damage in nvme_init (David Milburn) [922973]
- [block] nvme: handle allocation failure in nvme_map_user_pages() (David Milburn) [922973]
- [block] nvme: Fix uninitialized iod compiler warning (David Milburn) [922973]
- [block] nvme: Do not set IO queue depth beyond device max (David Milburn) [922973]
- [block] nvme: Set block queue max sectors (David Milburn) [922973]
- [block] nvme: use namespace id for nvme_get_features (David Milburn) [922973]
- [block] nvme: replace nvme_ns with nvme_dev for user admin (David Milburn) [922973]
- [block] nvme: Fix nvme module init when nvme_major is set (David Milburn) [922973]
- [block] nvme: Set request queue logical block size (David Milburn) [922973]
- [block] nvme: Set number of queues correctly (David Milburn) [922973]
- [block] nvme: Version 0.8 (David Milburn) [922973]
- [block] nvme: Set queue flags correctly (David Milburn) [922973]
- [block] nvme: Simplify nvme_unmap_user_pages (David Milburn) [922973]
- [block] nvme: Mark the end of the sg list (David Milburn) [922973]
- [block] nvme: Fix DMA mapping for admin commands (David Milburn) [922973]
- [block] nvme: Rename IO_TIMEOUT to NVME_IO_TIMEOUT (David Milburn) [922973]
- [block] nvme: Merge the nvme_bio and nvme_prp data structures (David Milburn) [922973]
- [block] nvme: Change nvme_completion_fn to take a dev (David Milburn) [922973]
- [block] nvme: Change get_nvmeq to take a dev instead of a namespace (David Milburn) [922973]
- [block] nvme: Simplify completion handling (David Milburn) [922973]
- [block] nvme: Update Identify Controller data structure (David Milburn) [922973]
- [block] nvme: Implement doorbell stride capability (David Milburn) [922973]
- [block] nvme: Version 0.7 (David Milburn) [922973]
- [block] nvme: Don't probe namespace 0 (David Milburn) [922973]
- [block] nvme: Fix calculation of number of pages in a PRP List (David Milburn) [922973]
- [block] nvme: Create nvme_identify and nvme_get_features functions (David Milburn) [922973]
- [block] nvme: Fix memory leak in nvme_dev_add() (David Milburn) [922973]
- [block] nvme: Fix calls to dma_unmap_sg (David Milburn) [922973]
- [block] nvme: Correct sg list setup in nvme_map_user_pages (David Milburn) [922973]
- [block] nvme: Fix bug in NVME_IOCTL_SUBMIT_IO (David Milburn) [922973]
- [block] nvme: Rework ioctls (David Milburn) [922973]
- [block] nvme: Add the nvme thread to the wait queue before waking it up (David Milburn) [922973]
- [block] nvme: Return real error from nvme_create_queue (David Milburn) [922973]
- [block] nvme: Version 0.6 (David Milburn) [922973]
- [block] nvme: Add a few calling convention notes (David Milburn) [922973]
- [block] nvme: Handle failures from memory allocations in nvme_setup_prps (David Milburn) [922973]
- [block] nvme: Use an IDA to allocate minor numbers (David Milburn) [922973]
- [block] nvme: Add include of delay.h for msleep (David Milburn) [922973]
- [block] nvme: Add support for timing out I/Os (David Milburn) [922973]
- [block] nvme: Rename cancel_cmdid_data to cancel_cmdid (David Milburn) [922973]
- [block] nvme: Fix bug in error handling (David Milburn) [922973]
- [block] nvme: Time out initialisation after a few seconds (David Milburn) [922973]
- [block] nvme: Fix warning in free_irq (David Milburn) [922973]
- [block] nvme: Correct the Controller Configuration settings (David Milburn) [922973]
- [block] nvme: Version 0.5 (David Milburn) [922973]
- [block] nvme: Change the definition of nvme_user_io (David Milburn) [922973]
- [block] nvme: Correct the definitions of two ioctls (David Milburn) [922973]
- [block] nvme: Add compat_ioctl (David Milburn) [922973]
- [block] nvme: Simplify queue lookup (David Milburn) [922973]
- [block] nvme: Remove the kthread from the wait queue (David Milburn) [922973]
- [block] nvme: Fix off-by-one when filling in PRP lists (David Milburn) [922973]
- [block] nvme: Fix interpretation of 'Number of Namespaces' field (David Milburn) [922973]
- [block] nvme: Remove outdated comments (David Milburn) [922973]
- [block] nvme: Fix comment formatting (David Milburn) [922973]
- [block] nvme: Convert comments to kernel-doc notation (David Milburn) [922973]
- [block] nvme: Update admin opcodes to match the 1.0RC spec (David Milburn) [922973]
- [block] nvme: Version 0.4 (David Milburn) [922973]
- [block] nvme: Reduce maximum queue depth by 1 (David Milburn) [922973]
- [block] nvme: Fix discontiguous accesses (David Milburn) [922973]
- [block] nvme: Handle bios that contain non-virtually contiguous addresses (David Milburn) [922973]
- [block] nvme: Implement Flush (David Milburn) [922973]
- [block] nvme: Mark CMD_CTX_CANCELLED as being unlikely (David Milburn) [922973]
- [block] nvme: Correct SQ doorbell semantics (David Milburn) [922973]
- [block] nvme: Let the kthread take care of devices earlier (David Milburn) [922973]
- [block] nvme: Rename nr_queues to nr_io_queues (David Milburn) [922973]
- [block] nvme: Remove setting of 'flags' in rw command (David Milburn) [922973]
- [block] nvme: Release 0.3 (David Milburn) [922973]
- [block] nvme: Add a kthread to handle the congestion list (David Milburn) [922973]
- [block] nvme: Handle failures differently in nvme_submit_bio_queue() (David Milburn) [922973]
- [block] nvme: Update BAR structure to match the current spec (David Milburn) [922973]
- [block] nvme: Handle physical merging of bvec entries (David Milburn) [922973]
- [block] nvme: Check for DMA mapping failure (David Milburn) [922973]
- [block] nvme: Pass the nvme_dev to nvme_free_prps and nvme_setup_prps (David Milburn) [922973]
- [block] nvme: Optimise memory usage for I/Os between 4k and 128k (David Milburn) [922973]
- [block] nvme: Switch to use DMA Pool API (David Milburn) [922973]
- [block] nvme: Rename nvme_req_info to nvme_bio (David Milburn) [922973]
- [block] nvme: Initial PRP List support (David Milburn) [922973]
- [block] nvme: Advance the sg pointer when filling in an sg list (David Milburn) [922973]
- [block] nvme: Renumber the special context values (David Milburn) [922973]
- [block] nvme: Handle the congestion list a little better (David Milburn) [922973]
- [block] nvme: Record the timeout for each command (David Milburn) [922973]
- [block] nvme: Need to lock queue during interrupt handling (David Milburn) [922973]
- [block] nvme: Detect command IDs completing that are out of range (David Milburn) [922973]
- [block] nvme: Detect commands that are completed twice (David Milburn) [922973]
- [block] nvme: Use a symbolic name to represent cancelled commands instead of 0 (David Milburn) [922973]
- [block] nvme: Add a module parameter to use a threaded interrupt (David Milburn) [922973]
- [block] nvme: Call put_nvmeq() before calling nvme_submit_sync_cmd() (David Milburn) [922973]
- [block] nvme: Allow fatal signals to interrupt I/O (David Milburn) [922973]
- [block] nvme: Release 0.2 (David Milburn) [922973]
- [block] nvme: Add download / activate firmware ioctls (David Milburn) [922973]
- [block] nvme: Add remaining status codes (David Milburn) [922973]
- [block] nvme: Move sysfs entries to the right place (David Milburn) [922973]
- [block] nvme: Disable the device before we write the admin queues (David Milburn) [922973]
- [block] nvme: Request I/O regions (David Milburn) [922973]
- [block] nvme: Allow queues to be allocated above 4GB (David Milburn) [922973]
- [block] nvme: Enable device DMA (David Milburn) [922973]
- [block] nvme: Enable and disable the PCI device (David Milburn) [922973]
- [block] nvme: Check returns from nvme_alloc_queue() (David Milburn) [922973]
- [block] nvme: Remove 'node' from nvme_dev (David Milburn) [922973]
- [block] nvme: Read the model, serial & firmware rev from the controller (David Milburn) [922973]
- [block] nvme: Add NVME_IOCTL_SUBMIT_IO (David Milburn) [922973]
- [block] nvme: Create nvme_map_user_pages() and nvme_unmap_user_pages() (David Milburn) [922973]
- [block] nvme: Change NVME_IOCTL_GET_RANGE_TYPE to return all the ranges (David Milburn) [922973]
- [block] nvme: Zero the command before we send it (David Milburn) [922973]
- [block] nvme: Add nvme_setup_prps() (David Milburn) [922973]
- [block] nvme: Make nvme_common_command more featureful (David Milburn) [922973]
- [block] nvme: Use PRP2 for the nvme_identify ioctl (David Milburn) [922973]
- [block] nvme: Fix admin IRQ claim on real hardware (David Milburn) [922973]
- [block] nvme: Rename 'cycle' to 'phase' (David Milburn) [922973]
- [block] nvme: Implement per-CPU queues (David Milburn) [922973]
- [block] nvme: Reduce set_queue_count arguments by one (David Milburn) [922973]
- [block] nvme: Factor out queue_request_irq() (David Milburn) [922973]
- [block] nvme: New driver (David Milburn) [922973]

* Tue Aug 06 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-409.el6]
- [alsa] fix for !CONFIG_SND_DMA_SGBUF after ALSA update from upstream (Jaroslav Kysela) [916264]
- [alsa] hda: Add new GPU codec ID to snd-hda (Jaroslav Kysela) [916264]
- [alsa] hda: pm_runtime backport specific fixes to get things working (Jaroslav Kysela) [916264]
- [alsa] pcm: try to retain kABI compatibility / modversions (Jaroslav Kysela) [916264]
- [alsa] hda: remove unused variable warning (Jaroslav Kysela) [916264]
- [alsa] rawmidi: fix oops (use after free) when unloading a driver module (Jaroslav Kysela) [916264]
- [alsa] rawmidi: fix the get next midi device ioctl (Jaroslav Kysela) [916264]
- [alsa] rawmidi: fix opened substreams count (Jaroslav Kysela) [916264]
- [alsa] core: automatically add .llseek fop (Jaroslav Kysela) [916264]
- [alsa] timer: Add NULL-check for invalid slave timer (Jaroslav Kysela) [916264]
- [alsa] timer: Fix Oops at closing slave timer (Jaroslav Kysela) [916264]
- [alsa] take tu->qlock with irqs disabled (Jaroslav Kysela) [916264]
- [alsa] jack: Add "Line In" input jack constants (Jaroslav Kysela) [916264]
- [alsa] jack: fix one memory leak in sound jack (Jaroslav Kysela) [916264]
- [alsa] vmaster: Fix the regression of missing vmaster hook call (Jaroslav Kysela) [916264]
- [alsa] vmaster: Add snd_ctl_sync_vmaster() helper function (Jaroslav Kysela) [916264]
- [alsa] vmaster: Fix slave change notification (Jaroslav Kysela) [916264]
- [alsa] vmaster: fix core/vmaster.c kernel-doc warning (Jaroslav Kysela) [916264]
- [alsa] vmaster: Free slave-links when freeing the master element (Jaroslav Kysela) [916264]
- [alsa] control: Fix missing VOLATILE flag at creating controls (Jaroslav Kysela) [916264]
- [alsa] control: Fixe a trailing white space error (Jaroslav Kysela) [916264]
- [alsa] core: release the constraint check for replace ops (Jaroslav Kysela) [916264]
- [alsa] core: trivial code style fix (Jaroslav Kysela) [916264]
- [alsa] control: clean up snd_ctl_hole_check() (Jaroslav Kysela) [916264]
- [alsa] control: fix numid conflict check for new controls (Jaroslav Kysela) [916264]
- [alsa] core: Define llseek fops (Jaroslav Kysela) [916264]
- [alsa] pcm: Optimize the call of snd_pcm_update_hw_ptr() in read/write loop (Jaroslav Kysela) [916264]
- [alsa] pcm: fix race condition in wait_for_avail() (Jaroslav Kysela) [916264]
- [alsa] pcm_lib: avoid timing jitter in snd_pcm_read/write() (Jaroslav Kysela) [916264]
- [alsa] pcm: Don't check DMA time-out too shortly (Jaroslav Kysela) [916264]
- [alsa] pcm_lib: fix xrun_log (Jaroslav Kysela) [916264]
- [alsa] pcm_lib: xrun_log log also in_interrupt (Jaroslav Kysela) [916264]
- [alsa] core: Avoid endless sleep after disconnect (Jaroslav Kysela) [916264]
- [alsa] PCM: Fix some races at disconnection (Jaroslav Kysela) [916264]
- [alsa] info: Small refactoring and a sanity check in snd_info_get_line() (Jaroslav Kysela) [916264]
- [alsa] info: Avoid leaking kernel memory (Jaroslav Kysela) [916264]
- [alsa] info: Implement common llseek for binary mode (Jaroslav Kysela) [916264]
- [alsa] info: Remove BKL (Jaroslav Kysela) [916264]
- [alsa] info: Check file position validity in common layer (Jaroslav Kysela) [916264]
- [alsa] core: remove unused variables (Jaroslav Kysela) [916264]
- [alsa] core: Don't use 'default' for default (Jaroslav Kysela) [916264]
- [alsa] Fix yet another race in disconnection (Jaroslav Kysela) [916264]
- [alsa] fix comment/printk typos (Jaroslav Kysela) [916264]
- [alsa] core: Allow card id change to the same string (Jaroslav Kysela) [916264]
- [alsa] hda: add CONFIG_SND_HDA_CODEC_CA0132_DSP define to rhel specific config (Jaroslav Kysela) [916264]
- [alsa] hda: Keep halting ALC5505 DSP (Jaroslav Kysela) [916264]
- [alsa] hda: Fix EAPD vmaster hook for AD1884 & co (Jaroslav Kysela) [916264]
- [alsa] hda: Add Dell SSID to support Headset Mic recording (Jaroslav Kysela) [916264]
- [alsa] hda: relase -> release (Jaroslav Kysela) [916264]
- [alsa] hda: Fix the max length of control name in generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Guess what, it's two more Dell headset mic quirks (Jaroslav Kysela) [916264]
- [alsa] hda: Yet another Dell headset mic quirk (Jaroslav Kysela) [916264]
- [alsa] hda: Add support for ALC5505 DSP power-save mode (Jaroslav Kysela) [916264]
- [alsa] hda: Add missing alc_inv_dmic_sync() call in alc269_resume() (Jaroslav Kysela) [916264]
- [alsa] hda: Remove superfluous stac_resume() (Jaroslav Kysela) [916264]
- [alsa] hda/hdmi: poll eld at resume time (Jaroslav Kysela) [916264]
- [alsa] hda: clean up code to reset hda link (Jaroslav Kysela) [916264]
- [alsa] hda: Add In-driver connection info (Jaroslav Kysela) [916264]
- [alsa] hda: Use auto_mute_via_amp=1 for VT1708 (Jaroslav Kysela) [916264]
- [alsa] hda: Add auto_mute_via_amp flag to generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Remove unused variable (Jaroslav Kysela) [916264]
- [alsa] hda: reset hda link during system/runtime suspend (Jaroslav Kysela) [916264]
- [alsa] hda: Make Thinkpad X220-tablet use generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Fix missing Mic Boost controls for VIA codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Use snd_hda_check_power_state() in patch_hdmi.c (Jaroslav Kysela) [916264]
- [alsa] hda: Avoid choose same converter for unused pins (Jaroslav Kysela) [916264]
- [alsa] hda: Cache the MUX selection for generic HDMI (Jaroslav Kysela) [916264]
- [alsa] hda: Haswell converter power state D0 verify (Jaroslav Kysela) [916264]
- [alsa] hda: Fix return value of snd_hda_check_power_state() (Jaroslav Kysela) [916264]
- [alsa] hda: Don't take unresponsive D3 transition too serious (Jaroslav Kysela) [916264]
- [alsa] hda: Introduce bit flags to snd_hda_codec_read/write() (Jaroslav Kysela) [916264]
- [alsa] hda: Drop hard dependency on CONFIG_SND_DYNAMIC_MINORS (Jaroslav Kysela) [916264]
- [alsa] hda/via: Use standard snd_hda_shutup_pins() (Jaroslav Kysela) [916264]
- [alsa] hda: Add models for Dell headset jacks (Jaroslav Kysela) [916264]
- [alsa] hda: Fix pin configurations for MacBook Air 4,2 (Jaroslav Kysela) [916264]
- [alsa] hda: Headset mic support for three more machines (Jaroslav Kysela) [916264]
- [alsa] hda: add mic fixup for ALC269VB on Ordissimo EVE2 (Jaroslav Kysela) [916264]
- [alsa] hda/via: Clean up duplicated codes (Jaroslav Kysela) [916264]
- [alsa] hda/via: Fix wrongly cleared pins after suspend on VT1802 (Jaroslav Kysela) [916264]
- [alsa] hda: Add keep_eapd_on flag to generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Allow setting automute/automic hooks after parsing (Jaroslav Kysela) [916264]
- [alsa] hda/via: Disable broken dynamic power control (Jaroslav Kysela) [916264]
- [alsa] hda: Add headset quirk for two Dell machines (Jaroslav Kysela) [916264]
- [alsa] hda: add dock support for Thinkpad T431s (Jaroslav Kysela) [916264]
- [alsa] hda: Remove superfluous pci_set_drvdata() at remove (Jaroslav Kysela) [916264]
- [alsa] hda: Enable mic-mute LED on more HP laptops (Jaroslav Kysela) [916264]
- [alsa] hda: add PCI IDs for Intel BayTrail (Jaroslav Kysela) [916264]
- [alsa] Revert: hda: Fix wrong power setup for HP paths of VIA codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Add headset mic support for another Dell machine (Jaroslav Kysela) [916264]
- [alsa] hda: Check the activity of the NID to be powered down (Jaroslav Kysela) [916264]
- [alsa] hda: Fix wrong power setup for HP paths of VIA codecs (Jaroslav Kysela) [916264]
- [alsa] Revert: hda: Don't set up active streams twice (Jaroslav Kysela) [916264]
- [alsa] hda: Apply pin-enablement workaround to all Haswell HDMI codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Fix Oops caused by dereference NULL pointer (Jaroslav Kysela) [916264]
- [alsa] hda: Fix 3.9 regression of EAPD init on Conexant codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Fix system panic when DMA > 40 bits for Nvidia audio controllers (Jaroslav Kysela) [916264]
- [alsa] hda: Move Thinkpad X220 to use auto parser (Jaroslav Kysela) [916264]
- [alsa] hda: Add the support for ALC286 codec (Jaroslav Kysela) [916264]
- [alsa] hda: Limit internal mic boost for a few Asus machines (Jaroslav Kysela) [916264]
- [alsa] hda: Disable the sanity check in snd_hda_add_pincfg() (Jaroslav Kysela) [916264]
- [alsa] hda: fix error return code in patch_alc662() (Jaroslav Kysela) [916264]
- [alsa] hda: Don't call vmaster hook when bus->shutdown is set (Jaroslav Kysela) [916264]
- [alsa] hda: fixup D3 pin and right channel mute on Haswell HDMI audio (Jaroslav Kysela) [916264]
- [alsa] hda: Use the primary DAC for all aamix outputs (Jaroslav Kysela) [916264]
- [alsa] hda: Fix aamix activation with loopback control on VIA codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Fix headset mic support for Asus X101CH (Jaroslav Kysela) [916264]
- [alsa] hda: Implement headset jack functionality for some Dell hw (Jaroslav Kysela) [916264]
- [alsa] hda: Handle Headphone Mic jack more generic (Jaroslav Kysela) [916264]
- [alsa] hda: add some small convenience functions to auto parser (Jaroslav Kysela) [916264]
- [alsa] hda: allow "Headphone Mic" parser flag (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Add a quirk for AC700 Chromebook (Jaroslav Kysela) [916264]
- [alsa] hda/cirrus: Add a quirk for Stumpy ChromeBox (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Update latency based on DSP state (Jaroslav Kysela) [916264]
- [alsa] hda: Introduce get_delay codec PCM ops (Jaroslav Kysela) [916264]
- [alsa] hda: fix uninitialized variable (Jaroslav Kysela) [916264]
- [alsa] hda: Allow power_save_controller option override DCAPS" (Jaroslav Kysela) [916264]
- [alsa] hda: fix typo in proc output (Jaroslav Kysela) [916264]
- [alsa] hda: Enabling Realtek ALC 671 codec (Jaroslav Kysela) [916264]
- [alsa] hda: bug fix on HDMI ELD debug message (Jaroslav Kysela) [916264]
- [alsa] hda: bug fix on return value when getting HDMI ELD info (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Delay HP amp turnon (Jaroslav Kysela) [916264]
- [alsa] hda: VIA prefers side surrounds over HP (Jaroslav Kysela) [916264]
- [alsa] hda: Lower the badness for independent HP penalty (Jaroslav Kysela) [916264]
- [alsa] hda: Allow codec drivers to give own badness tables (Jaroslav Kysela) [916264]
- [alsa] hda: Fix DAC assignment for independent HP (Jaroslav Kysela) [916264]
- [alsa] hda: Enable "Headset Mic" name for some Dell Latitude devices (Jaroslav Kysela) [916264]
- [alsa] hda: Introduce "Headset Mic" name (Jaroslav Kysela) [916264]
- [alsa] hda: Fix abuse of snd_hda_lock_devices() for DSP loader (Jaroslav Kysela) [916264]
- [alsa] hda: Fix typo in checking IEC958 emphasis bit (Jaroslav Kysela) [916264]
- [alsa] hda: Fix yet missing GPIO/EAPD setup in cirrus driver (Jaroslav Kysela) [916264]
- [alsa] hda: Add GPIO-based LED support on HP desktop machines (Jaroslav Kysela) [916264]
- [alsa] hda: Make the resume of digital beep setup proper (Jaroslav Kysela) [916264]
- [alsa] hda: Fix power-saving during playing beep sound (Jaroslav Kysela) [916264]
- [alsa] hda: Move beep attach/detach calls in hda_generic.c (Jaroslav Kysela) [916264]
- [alsa] hda/cirrus: Fix the digital beep registration (Jaroslav Kysela) [916264]
- [alsa] hda: Fix missing beep detach in patch_conexant.c (Jaroslav Kysela) [916264]
- [alsa] hda: Fix missing EAPD/GPIO setup for Cirrus codecs (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Remove extra setting of dsp_state (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Check download state of DSP (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Check if dspload_image succeeded (Jaroslav Kysela) [916264]
- [alsa] hda: Disable IDT eapd_switch if there are no internal speakers (Jaroslav Kysela) [916264]
- [alsa] hda: Don't apply EAPD power filter as default (Jaroslav Kysela) [916264]
- [alsa] hda: Allow unlimited pins and converters in patch_hdmi.c (Jaroslav Kysela) [916264]
- [alsa] hda: Drop explicit memset() by reallocation with __GFP_ZERO (Jaroslav Kysela) [916264]
- [alsa] hda: Fix snd_hda_get_num_raw_conns() to return a correct value (Jaroslav Kysela) [916264]
- [alsa] hda: Don't re-initialize shared hp/mic pinctl (Jaroslav Kysela) [916264]
- [alsa] hda: Avoid automatic pin-ctl update for hp/mic when jack ctl exists (Jaroslav Kysela) [916264]
- [alsa] hda: Consolidate add_in_jack_modes and add_out_jack_modes hints (Jaroslav Kysela) [916264]
- [alsa] hda: Allow to change I/O direction in hp/mic jack mode ctl (Jaroslav Kysela) [916264]
- [alsa] hda: Add some model name strings for ALC260 (Jaroslav Kysela) [916264]
- [alsa] hda: Handle shared hp/mic jack mode (Jaroslav Kysela) [916264]
- [alsa] hda: Add the generic Headphone Mic feature (Jaroslav Kysela) [916264]
- [alsa] hda: Add support of new codec ALC233 (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Avoid division by zero in dspxfr_one_seg() (Jaroslav Kysela) [916264]
- [alsa] hda: check NULL pointer when creating SPDIF PCM switch (Jaroslav Kysela) [916264]
- [alsa] hda: check NULL pointer when creating SPDIF controls (Jaroslav Kysela) [916264]
- [alsa] hda: Enable beep for ASUS EeeBox EBP1501P (Jaroslav Kysela) [916264]
- [alsa] hda/hdmi: Make jacks phantom, if they're not detectable (Jaroslav Kysela) [916264]
- [alsa] hda/hdmi: Notify userspace when ELD control changes (Jaroslav Kysela) [916264]
- [alsa] hda/hdmi: Protect ELD buffer (Jaroslav Kysela) [916264]
- [alsa] hda/hdmi: Refactor hdmi_eld into parsed_hdmi_eld (Jaroslav Kysela) [916264]
- [alsa] hda/hdmi: Do not expose eld data when eld is invalid (Jaroslav Kysela) [916264]
- [alsa] hda/hdmi: ELD shouldn't be valid after unplug (Jaroslav Kysela) [916264]
- [alsa] hda: Fix the silent speaker output on Fujitsu S7020 laptop (Jaroslav Kysela) [916264]
- [alsa] hda: add quirks for mute LED on two HP machines (Jaroslav Kysela) [916264]
- [alsa] hda: Remove speaker clicks on CX20549 (Jaroslav Kysela) [916264]
- [alsa] hda: Disable runtime PM for Intel 5 Series/3400 (Jaroslav Kysela) [916264]
- [alsa] hda: Increase badness for missing multi-io (Jaroslav Kysela) [916264]
- [alsa] hda: Fix broken workaround for HDMI/SPDIF conflicts (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Add missing n to debug prints (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Fix type of INVALID_CHIP_ADDRESS (Jaroslav Kysela) [916264]
- [alsa] hda: update documentation for no-primary-hp fixup (Jaroslav Kysela) [916264]
- [alsa] hda: Workaround for silent output on Sony Vaio VGC-LN51JGB with ALC889 (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Slight optimization for build with DSP (Jaroslav Kysela) [916264]
- [alsa] hda: Fix memory leak and error handling in CA0132 DSP loader (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Improve the DSP transfer timeout calculations (Jaroslav Kysela) [916264]
- [alsa] hda/intel: Add Device IDs for Intel Wellsburg PCH (Jaroslav Kysela) [916264]
- [alsa] hda: Yet another fix for broken HSW HDMI pin connections (Jaroslav Kysela) [916264]
- [alsa] hda: Add fixup for Haswell to enable all pin and convertor widgets (Jaroslav Kysela) [916264]
- [alsa] hda: Support rereading widgets under the function group (Jaroslav Kysela) [916264]
- [alsa] hda: Remove limit of widget connections (Jaroslav Kysela) [916264]
- [alsa] hda: Set non-snoop for Creative HD-audio controllers (Jaroslav Kysela) [916264]
- [alsa] hda: Fix misc compile warnings in patch_ca0132.c (Jaroslav Kysela) [916264]
- [alsa] hda: Use generic array for loopback list management (Jaroslav Kysela) [916264]
- [alsa] hda: Enable loopback accounts for CONFIG_PM=n, too (Jaroslav Kysela) [916264]
- [alsa] hda: Apply mic-mute LED fixup for new HP laptops (Jaroslav Kysela) [916264]
- [alsa] hda: detect jacks on VT1708 even when no streams are active (Jaroslav Kysela) [916264]
- [alsa] hda: Fix phantom jacks on VT1708 (Jaroslav Kysela) [916264]
- [alsa] hda: Add new Kconfig CONFIG_SND_HDA_CODEC_CA0132_DSP (Jaroslav Kysela) [916264]
- [alsa] hda: Release assigned pin/cvt at error path of hdmi_pcm_open() (Jaroslav Kysela) [916264]
- [alsa] hda: New PCI ID for Haswell ULT (Jaroslav Kysela) [916264]
- [alsa] hda: add support for IDT 92HD95 HDA codec (Jaroslav Kysela) [916264]
- [alsa] hda: Fix non-snoop page handling (Jaroslav Kysela) [916264]
- [alsa] hda: Enable LPIB delay count for Poulsbo / Oaktrail (Jaroslav Kysela) [916264]
- [alsa] hda: Fix powermap for external mics on IDT codecs (Jaroslav Kysela) [916264]
- [alsa] hda: fix inverted internal mic on Acer AOA150/ZG5 (Jaroslav Kysela) [916264]
- [alsa] hda: Enable power down of unused widgets for IDT codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Implement path-based power filter to the generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Add snd_hda_check_power_state() helper function (Jaroslav Kysela) [916264]
- [alsa] hda: Synchronize the power state at the end of codec init (Jaroslav Kysela) [916264]
- [alsa] hda: Add power state filtering (Jaroslav Kysela) [916264]
- [alsa] hda/via: Fix wrong checks of power state bits (Jaroslav Kysela) [916264]
- [alsa] hda: Fix wrong arguments for path deactivation checks (Jaroslav Kysela) [916264]
- [alsa] hda: Add auto-mute support to PB desktop (Jaroslav Kysela) [916264]
- [alsa] hda: Add a fixup for Packard-Bell desktop with ALC880 (Jaroslav Kysela) [916264]
- [alsa] hda: Add chained_before flag to the fixup entry (Jaroslav Kysela) [916264]
- [alsa] hda: Small code refactoring about path re-initialization (Jaroslav Kysela) [916264]
- [alsa] hda: Fix missing path between aamix and outputs in AD codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Fix inconsistent pin states after resume (Jaroslav Kysela) [916264]
- [alsa] hda: Fix invalid snd_BUG_ON() in alc271_hp_gate_mic_jack() (Jaroslav Kysela) [916264]
- [alsa] hda: Select auto-parser as default for AD codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Convert some static quirks to fixup codes for AD codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Rearrange for dropping static quirk codes in AD codec driver (Jaroslav Kysela) [916264]
- [alsa] hda: Add SPDIF mux control to AD codec auto-parser (Jaroslav Kysela) [916264]
- [alsa] hda: Combine snd_hda_codec_flush_*_cache() to a single function (Jaroslav Kysela) [916264]
- [alsa] hda: Fix missing call of cmd flush in capture volume put callback (Jaroslav Kysela) [916264]
- [alsa] hda: Add missing exports to helper functions (Jaroslav Kysela) [916264]
- [alsa] hda: Revive SPDIF mux for IDT/STAC codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Disable HP auto-mute during independent HP mode (Jaroslav Kysela) [916264]
- [alsa] hda: Set individual name to secondary analog PCM stream (Jaroslav Kysela) [916264]
- [alsa] hda: Add aamix NID to AD codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Add Conexant CX20755/20756/20757 codec IDs (Jaroslav Kysela) [916264]
- [alsa] hda: Add aamix NID to IDT 92HD codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Remove superfluous header inclusions (Jaroslav Kysela) [916264]
- [alsa] hda: Enable parsing the independent HP mode as default for VIA codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Fix conflicts between Loopback Mixing and Independent HP (Jaroslav Kysela) [916264]
- [alsa] hda: Check aamix-output paths from other DACs, too (Jaroslav Kysela) [916264]
- [alsa] hda: Add missing badness evaluation for unresolved paths (Jaroslav Kysela) [916264]
- [alsa] hda: Set the pin targets after deciding output config (Jaroslav Kysela) [916264]
- [alsa] hda: Improve debug prints for output paths (Jaroslav Kysela) [916264]
- [alsa] hda: Add fixup for Acer AO725 laptop (Jaroslav Kysela) [916264]
- [alsa] hda/conexant: Set mixer NID 0x19 for CX20551 codec (Jaroslav Kysela) [916264]
- [alsa] hda: Correct more array rooms in hda_gen_spec (Jaroslav Kysela) [916264]
- [alsa] hda: Fix the wrong adc_idx for capture source (Jaroslav Kysela) [916264]
- [alsa] hda: Don't add unnecessary indices on HDMI and SPDIF (Jaroslav Kysela) [916264]
- [alsa] hda: don't compare with yourself in fill_input_pin_labels (Jaroslav Kysela) [916264]
- [alsa] hda: make sure there are enough input labels and paths (Jaroslav Kysela) [916264]
- [alsa] hda: Fix speaker pin of FSC Lifebook S7110 laptop (Jaroslav Kysela) [916264]
- [alsa] hda: Add boost to line inputs, too (Jaroslav Kysela) [916264]
- [alsa] hda/sigmatel: Add bass speaker support for HP ENVY Spectre XT (Jaroslav Kysela) [916264]
- [alsa] hda: Consolidate cap_sync_hook and capture_switch_hook (Jaroslav Kysela) [916264]
- [alsa] hda: Fix missing call of capture_switch_hook (Jaroslav Kysela) [916264]
- [alsa] hda: Look for boost controls more deeply (Jaroslav Kysela) [916264]
- [alsa] hda: Fix invalid mute in path activation (Jaroslav Kysela) [916264]
- [alsa] hda: Unify input label creations in generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Keep autocfg.input idx value in imux table (Jaroslav Kysela) [916264]
- [alsa] hda: Fix missing unsol event handler in some codec drivers (Jaroslav Kysela) [916264]
- [alsa] hda: Use generic parser for STAC/IDT codec driver (Jaroslav Kysela) [916264]
- [alsa] hda: Improve naming rule for primary output (Jaroslav Kysela) [916264]
- [alsa] hda: Add PCM capture hook to hda_gen_spec (Jaroslav Kysela) [916264]
- [alsa] hda: Record all detected ADCs in hda_gen_spec (Jaroslav Kysela) [916264]
- [alsa] hda: Move vmaster TLV parsing to snd_hda_gen_parse_auto_config() (Jaroslav Kysela) [916264]
- [alsa] hda: Add input jack mode enum controls to generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Minor cleanup/fixes for patch_sigmatel.c fixup transition (Jaroslav Kysela) [916264]
- [alsa] hda: Give more comments to hda_gen_spec flags (Jaroslav Kysela) [916264]
- [alsa] hda: Add suppress_auto_mute flag to hda_gen_spec (Jaroslav Kysela) [916264]
- [alsa] hda: Record the current speaker / LO mute status in hda_gen_spec (Jaroslav Kysela) [916264]
- [alsa] hda: Properly call automute/switch hooks at init (Jaroslav Kysela) [916264]
- [alsa] hda: Make sure fill_all_dac_nids is called for digital only codecs (Jaroslav Kysela) [916264]
- [alsa] hda: force different capture controls if amp caps differ (Jaroslav Kysela) [916264]
- [alsa] hda: do not add non-existing Mic boost controls (Jaroslav Kysela) [916264]
- [alsa] hda: initialize channel counts correctly (Jaroslav Kysela) [916264]
- [alsa] hda: fix wrong adc_idx in generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Check array bounds in get_input_path (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Make some symbols static (Jaroslav Kysela) [916264]
- [alsa] hda: Add prefer_hp_amp flag to hda_gen_spec (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Fix a wrong comma in snd_printdd() call (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Declare firmware only when really built (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Fix possible invalid DMA channel deallocation (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Fix possible NULL dereference (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Fix another smatch warning (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Fix superfluous unsigned check (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Use snd_hda_set_pin_ctl() helper again (Jaroslav Kysela) [916264]
- [alsa] Revert: hda: Add firmware caching to CA0132 codec (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Fix potential init errors and update module description (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Shuffle to group together related code (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Code shuffle to group similar functions (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Add tuning controls (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Add unsol handler for DSP and jack detection (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Add PCM enhancements (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Add DSP mixer controls and helpers (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Init chip, DSP effects and mixer settings (Jaroslav Kysela) [916264]
- [alsa] hda/ca0132: Add new definitions and structs for DSP (Jaroslav Kysela) [916264]
- [alsa] hda: fix OOPS in hda_mark_cmd_cache_dirty (Jaroslav Kysela) [916264]
- [alsa] hda/sigmatel: Remove superfluous fields from sigmatel_spec (Jaroslav Kysela) [916264]
- [alsa] hda/sigmatel: Move w/a for HP Mini 110 LED to fixup table (Jaroslav Kysela) [916264]
- [alsa] hda/sigmatel: Remove PCI id check in find_mute_led_cfg() (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard fixup table for IDT92HD83xxx (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard fixup table for IDT92HD73xx (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard fixup table for IDT92HD71Bxx (Jaroslav Kysela) [916264]
- [alsa] hda: Check pincap while parsing the configuration (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard fixup table for STAC927x (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard fixup table for STAC922x (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard fixup table for STAC9205 (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard fixup table for STAC9872 (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard fixup table for STAC925x (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard fixup table for STAC9200 (Jaroslav Kysela) [916264]
- [alsa] hda: Add capture_switch_hook to generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Use generic parser for VIA codec driver (Jaroslav Kysela) [916264]
- [alsa] hda: Add generic parser support to Analog Device codec driver (Jaroslav Kysela) [916264]
- [alsa] hda: Rearrange for dropping static quirk codes in Coexant driver (Jaroslav Kysela) [916264]
- [alsa] hda: Use generic parser in Conexant codec driver (Jaroslav Kysela) [916264]
- [alsa] hda: Use generic parser for Cirrus codec driver (Jaroslav Kysela) [916264]
- [alsa] hda: Use generic parser for CA0110 codec (Jaroslav Kysela) [916264]
- [alsa] hda: Use generic codec parser for C-Media codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Allow user to give hints for codec parser behavior (Jaroslav Kysela) [916264]
- [alsa] hda: Add snd_hda_get_int_hint() helper function (Jaroslav Kysela) [916264]
- [alsa] hda: Protect user-defined arrays via mutex (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Generic mute LED implementation for HP laptops (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Fix the timing for some fixups (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Add a fixup for FSC S7020 laptop (Jaroslav Kysela) [916264]
- [alsa] hda: Add output jack mode enum controls (Jaroslav Kysela) [916264]
- [alsa] hda: Update automute / automic upon jack retasking (Jaroslav Kysela) [916264]
- [alsa] hda: Add a new fixup type to override pinctl values (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Read the cached pinctl value in fixups (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Drop aliases for old fixups (Jaroslav Kysela) [916264]
- [alsa] hda: Avoid auto-mute or auto-mic of retasked jacks (Jaroslav Kysela) [916264]
- [alsa] hda: Manage current pinctl values in generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: More strict correction of invalid pinctl bits (Jaroslav Kysela) [916264]
- [alsa] hda: Add helper functions to cache the current pinctl target (Jaroslav Kysela) [916264]
- [alsa] hda: Clear the dropped paths properly (Jaroslav Kysela) [916264]
- [alsa] hda: Allow aamix as a capture source (Jaroslav Kysela) [916264]
- [alsa] hda: Fix inconsistent input_paths after ADC reduction (Jaroslav Kysela) [916264]
- [alsa] hda: Return "Headphone Mic" from hda_get_autocfg_input_label() (Jaroslav Kysela) [916264]
- [alsa] hda: Exclude aamix from capture paths (Jaroslav Kysela) [916264]
- [alsa] hda: Add a flag to suppress mic auto-switch (Jaroslav Kysela) [916264]
- [alsa] hda: Handle BOTH jack port as a fixed output (Jaroslav Kysela) [916264]
- [alsa] hda: Re-define snd_hda_parse_nid_path() (Jaroslav Kysela) [916264]
- [alsa] hda: Manage input paths via path indices (Jaroslav Kysela) [916264]
- [alsa] hda: Fix multi-io channel mode management (Jaroslav Kysela) [916264]
- [alsa] hda: Don't set up active streams twice (Jaroslav Kysela) [916264]
- [alsa] hda: Remove unused dac reference in create_multi_out_ctls() (Jaroslav Kysela) [916264]
- [alsa] hda: Use direct path reference in assign_out_path_ctls() (Jaroslav Kysela) [916264]
- [alsa] hda: Clear path indices properly at each re-evaluation (Jaroslav Kysela) [916264]
- [alsa] hda: Add brief comments to exported snd_hda_gen_*_() functions (Jaroslav Kysela) [916264]
- [alsa] hda: Remove dead HDA_CTL_BIND_VOL and HDA_CTL_BIND_SW codes (Jaroslav Kysela) [916264]
- [alsa] hda: Add snd_hda_gen_free() and snd_hda_gen_check_power_status() (Jaroslav Kysela) [916264]
- [alsa] hda: Allow jack detection when polling is enabled (Jaroslav Kysela) [916264]
- [alsa] hda: Add pcm_playback_hook to hda_gen_spec (Jaroslav Kysela) [916264]
- [alsa] hda: Drop bind-volume workaround (Jaroslav Kysela) [916264]
- [alsa] hda: Drop unneeded pin argument from set_output_and_unmute() (Jaroslav Kysela) [916264]
- [alsa] hda: Add missing slave names for Speaker Surround, etc (Jaroslav Kysela) [916264]
- [alsa] hda: Prefer binding the primary CLFE output (Jaroslav Kysela) [916264]
- [alsa] hda: Fix truncated control names (Jaroslav Kysela) [916264]
- [alsa] hda: Add Loopback Mixing control (Jaroslav Kysela) [916264]
- [alsa] hda: Correct aamix output paths (Jaroslav Kysela) [916264]
- [alsa] hda: Initialize digital-input path properly (Jaroslav Kysela) [916264]
- [alsa] hda: Manage using output/loopback path indices (Jaroslav Kysela) [916264]
- [alsa] hda: Fix multi-io pin assignment in create_multi_out_ctls() (Jaroslav Kysela) [916264]
- [alsa] hda: Simplify the multi-io assignment with multi speakers (Jaroslav Kysela) [916264]
- [alsa] hda: Check the existing path in snd_hda_add_new_path() (Jaroslav Kysela) [916264]
- [alsa] hda: Avoid duplicated path creations (Jaroslav Kysela) [916264]
- [alsa] hda: Initialize output paths with current active states (Jaroslav Kysela) [916264]
- [alsa] hda: Don't skip amp init for activated paths (Jaroslav Kysela) [916264]
- [alsa] hda: Add hooks for HP/line/mic auto switching (Jaroslav Kysela) [916264]
- [alsa] hda: Revive snd_hda_get_conn_list() (Jaroslav Kysela) [916264]
- [alsa] hda: Add codec->inv_jack_detect flag (Jaroslav Kysela) [916264]
- [alsa] hda: Add inv_eapd flag to struct hda_codec (Jaroslav Kysela) [916264]
- [alsa] hda: Implement independent HP control (Jaroslav Kysela) [916264]
- [alsa] hda: Allow aamix in the primary output path (Jaroslav Kysela) [916264]
- [alsa] hda: Define HDA_PARSE_* for snd_hda_parse_nid_path() argument (Jaroslav Kysela) [916264]
- [alsa] hda: Fix typos in debug_show_configs() (Jaroslav Kysela) [916264]
- [alsa] hda: Add more debug prints about new paths (Jaroslav Kysela) [916264]
- [alsa] hda: Drop spec->channel_mode field from hda_gen_spec (Jaroslav Kysela) [916264]
- [alsa] hda: Fix PCM name string for generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Use cached version for changing pins in hda_generic.c (Jaroslav Kysela) [916264]
- [alsa] hda: Dynamically turn on/off EAPD in generic codec driver (Jaroslav Kysela) [916264]
- [alsa] hda: Fix initialization of primary outputs in hda_generic.c (Jaroslav Kysela) [916264]
- [alsa] hda: Refactor init_extra_out() in hda_generic.c (Jaroslav Kysela) [916264]
- [alsa] hda: Clear unsol enable bits on unused pins in generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Add spec->vmaster_mute_enum flag to generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Begin HDA_GEN_* event tag from 1 (Jaroslav Kysela) [916264]
- [alsa] hda: Increase the max depth of widget connections (Jaroslav Kysela) [916264]
- [alsa] hda: Avoid access of amp cache element outside mutex (Jaroslav Kysela) [916264]
- [alsa] hda: Fix wrong dirty check in snd_hda_codec_resume_amp() (Jaroslav Kysela) [916264]
- [alsa] hda: Do sequential writes in snd_hda_gen_init() (Jaroslav Kysela) [916264]
- [alsa] hda: Add / fix comments about capture vol/sw controls in hda_generic.c (Jaroslav Kysela) [916264]
- [alsa] hda: Add missing amp cache flush for bound capture vol/sw ctls (Jaroslav Kysela) [916264]
- [alsa] hda: Add snd_hda_codec_flush_*_cache() aliases (Jaroslav Kysela) [916264]
- [alsa] hda: Flush dirty amp caches before writing inv_dmic fix (Jaroslav Kysela) [916264]
- [alsa] hda: Check CORB overflow (Jaroslav Kysela) [916264]
- [alsa] hda: Clear cached_write flag in snd_hda_codec_resume_*() (Jaroslav Kysela) [916264]
- [alsa] hda: Clear dirty flag upon cache write (Jaroslav Kysela) [916264]
- [alsa] hda: Allow one chance for zero NID in connection list (Jaroslav Kysela) [916264]
- [alsa] hda: Use "Capture Source" for single sources (Jaroslav Kysela) [916264]
- [alsa] hda: Use generic parser codes for Realtek driver (Jaroslav Kysela) [916264]
- [alsa] hda: Export standard jack event handlers for generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Fix NULL dereference in snd_hda_gen_build_controls() (Jaroslav Kysela) [916264]
- [alsa] hda: Move the call of snd_hda_parse_pin_defcfg() from snd_hda_gen_parse_auto_config() (Jaroslav Kysela) [916264]
- [alsa] hda: Export snd_hda_gen_add_kctl() (Jaroslav Kysela) [916264]
- [alsa] hda: Add EAPD control to generic parser (Jaroslav Kysela) [916264]
- [alsa] hda: Merge Realtek parser code to generic parser (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Remove redundant argument from alc_mux_select() (Jaroslav Kysela) [916264]
- [alsa] hda: More generic auto-mic switching for Realtek codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Rearrange INPUT_PIN_ATTR_* (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Fix split stereo dmic code (Jaroslav Kysela) [916264]
- [alsa] hda: Move fixup code into struct hda_codec (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Add conexant-style inverted dmic handling (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Allow multiple individual capture volume/switch controls (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Allow passing name=NULL to alc_kcontrol_new() (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Merge a few split functions (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Assign Master mixer when possible (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Handle vmaster hook in the parser side (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Remove unused fields and macro definitions (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Drop auto_mic_valid_imux flag (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Allow different pins for shared hp/mic vref check (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Parse digital input path (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Rename add_new_out_path() with add_new_nid_path() (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Remove superfluous input amp init (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Clean up some spec fields (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Make input path parser more generic (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Don't change connection at path deactivation (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Initialize loopback paths properly (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Add boost volumes to path list (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Add missing initialization of multi-io routes (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Fix the initialization of pin amp-in (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Rename get_out_path() to get_nid_path() (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Use path-based parser for digital outputs (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Consolidate to a single path list (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Consolidate is_reachable_path() (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Add path active flag (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Remove non-standard automute mode (Jaroslav Kysela) [916264]
- [alsa] hda: Introduce snd_hda_codec_amp_init*() (Jaroslav Kysela) [916264]
- [alsa] hda: Introduce cache & flush cmd / amp writes (Jaroslav Kysela) [916264]
- [alsa] hda: Remove snd_hda_codec_amp_update() call from patch_*.c (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Fix initialization of input amps in output paths (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Check amp capabilities of aa-mixer widget (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Parse analog loopback paths more generically (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Parse input paths (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Make path->idx and path->multi consistent (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Simplify the output volume initialization (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Reduce vol/mute ctl lookups at parsing codec (Jaroslav Kysela) [916264]
- [alsa] hda: Fix mono amp values in proc output (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Manage mixer controls in out_path list (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Add output path parser (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: List up all available DACs (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Simplify alc_auto_is_dac_reachable() (Jaroslav Kysela) [916264]
- [alsa] hda: Add support of new codec ALC284 (Jaroslav Kysela) [916264]
- [alsa] hda: Allow power_save_controller option override DCAPS (Jaroslav Kysela) [916264]
- [alsa] Revert: hda: Shut up pins at power-saving mode with Conexant codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Disable runtime D3 for Intel CPT & co (Jaroslav Kysela) [916264]
- [alsa] hda: print power state for AFG node in proc file (Jaroslav Kysela) [916264]
- [alsa] hda: add mute LED for HP Pavilion 17 (Realtek codec) (Jaroslav Kysela) [916264]
- [alsa] hda: Switch "On" and "Off" for "Mute-LED Mode" kcontrol (Jaroslav Kysela) [916264]
- [alsa] hda: Fix sound resume hang (Jaroslav Kysela) [916264]
- [alsa] hda: bug fix for invalid connection list of Haswell HDMI codec pins (Jaroslav Kysela) [916264]
- [alsa] hda: Fix the wrong pincaps set in ALC861VD dallas/hp fixup (Jaroslav Kysela) [916264]
- [alsa] hda: Set codec->single_adc_amp flag for Realtek codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Remove superfluous zero-clear memset in patch_ca0132.c (Jaroslav Kysela) [916264]
- [alsa] hda: Fix NULL dereference in error path of patch_ca0132.c (Jaroslav Kysela) [916264]
- [alsa] hda: Remove unnecessary struct hda_stream_format from CA0132 (Jaroslav Kysela) [916264]
- [alsa] hda: Update chipio functions and DSP write wait timeout (Jaroslav Kysela) [916264]
- [alsa] hda: Change return value for load_dsp_prepare() to -ENOSYS (Jaroslav Kysela) [916264]
- [alsa] hda: Add comments and descriptions to CA0132 functions (Jaroslav Kysela) [916264]
- [alsa] hda: Add firmware caching to CA0132 codec (Jaroslav Kysela) [916264]
- [alsa] hda: Update CA0132 codec to load DSP firmware binary (Jaroslav Kysela) [916264]
- [alsa] hda: Add DSP firmware enums and defs to CA0132 codec (Jaroslav Kysela) [916264]
- [alsa] hda: Add CA0132 register definitions file (Jaroslav Kysela) [916264]
- [alsa] hda: Add new DSP loader callback routines (Jaroslav Kysela) [916264]
- [alsa] Revert: hda: bug fix for invalid connection list of Haswell HDMI codec pin (Jaroslav Kysela) [916264]
- [alsa] hda: bug fix for invalid connection list of Haswell HDMI codec pin (Jaroslav Kysela) [916264]
- [alsa] hda: Always turn on pins for HDMI/DP (Jaroslav Kysela) [916264]
- [alsa] hda: Fix pin configuration of HP Pavilion dv7 (Jaroslav Kysela) [916264]
- [alsa] hda: Move runtime PM check to runtime_idle callback (Jaroslav Kysela) [916264]
- [alsa] hda: Add stereo-dmic fixup for Acer Aspire One 522 (Jaroslav Kysela) [916264]
- [alsa] hda: Avoid doubly suspend after vga switcheroo (Jaroslav Kysela) [916264]
- [alsa] hda: Check validity of CORB/RIRB WP reads (Jaroslav Kysela) [916264]
- [alsa] hda: use usleep_range in link reset and change timeout check (Jaroslav Kysela) [916264]
- [alsa] hda/via: Add support for codec VT1808 (Jaroslav Kysela) [916264]
- [alsa] hda/via: Add support for codec VT1705CF (Jaroslav Kysela) [916264]
- [alsa] hda: Remove the rest of __devinit* in comments (Jaroslav Kysela) [916264]
- [alsa] hda: Remove superfluous DELAYED_INIT*_MARK (Jaroslav Kysela) [916264]
- [alsa] hda: remove __dev* attributes (Jaroslav Kysela) [916264]
- [alsa] hda: Add PCI device prefix for clarity (Jaroslav Kysela) [916264]
- [alsa] hda: Fix yet another race of vga_switcheroo registration (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Keep the channel count for multiple speakers (Jaroslav Kysela) [916264]
- [alsa] hda: Add a helper function for simple enum kcontrols (Jaroslav Kysela) [916264]
- [alsa] hda: Pass errors properly in alc_auto_check_switches() (Jaroslav Kysela) [916264]
- [alsa] hda: Refactor alc_kcontrol_new() usages (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard sort function in hda_auto_parser.c (Jaroslav Kysela) [916264]
- [alsa] hda: Call snd_array_init() early and only once (Jaroslav Kysela) [916264]
- [alsa] hda: Fix build without CONFIG_PM (Jaroslav Kysela) [916264]
- [alsa] hda: Add a fixup for internal mic on MacBook Pro 8,1 (Jaroslav Kysela) [916264]
- [alsa] hda: Add missing verb applications in patch_cirrus.c (Jaroslav Kysela) [916264]
- [alsa] hda: Move static ADC setup for CS4206 to init verbs (Jaroslav Kysela) [916264]
- [alsa] hda: Don't release firmware when CONFIG_PM is set (Jaroslav Kysela) [916264]
- [alsa] hda: Don't overwrite the pin default configs (Jaroslav Kysela) [916264]
- [alsa] hda: Remove shutup calls in free callbacks (Jaroslav Kysela) [916264]
- [alsa] hda: Use standard helper functions in patch_hdmi.c (Jaroslav Kysela) [916264]
- [alsa] hda/cirrus: Correctly clear line_out_pins when moving to speaker (Jaroslav Kysela) [916264]
- [alsa] hda: Add support for Realtek ALC292 (Jaroslav Kysela) [916264]
- [alsa] hda: Limit runtime PM support only to known Intel chips (Jaroslav Kysela) [916264]
- [alsa] hda: Fix Acer Aspire models with analog mics (Jaroslav Kysela) [916264]
- [alsa] hda: Allow jack state to depend on another jack (Jaroslav Kysela) [916264]
- [alsa] hda: Fix recursive suspend/resume call (Jaroslav Kysela) [916264]
- [alsa] hda: Add a missing quirk entry for iMac 9,1 (Jaroslav Kysela) [916264]
- [alsa] hda: Removed unused non-standard name "C/LFE" (Jaroslav Kysela) [916264]
- [alsa] hda: Give standard "Bass Speaker" mixer for 2.1 speakers (Jaroslav Kysela) [916264]
- [alsa] hda: Add new codec ALC668 and ALC900 (default name ALC1150) (Jaroslav Kysela) [916264]
- [alsa] hda: Improve HP depop when system enter to S3 (Jaroslav Kysela) [916264]
- [alsa] hda: Add pin fixups for ASUS G75 (Jaroslav Kysela) [916264]
- [alsa] hda: Fix invalid connections in VT1802 codec (Jaroslav Kysela) [916264]
- [alsa] hda: Fix empty DAC filling in patch_via.c (Jaroslav Kysela) [916264]
- [alsa] hda: Keep power link on for PantherPoint HDMI (Jaroslav Kysela) [916264]
- [alsa] hda: Force to reset IEC958 status bits for AD codecs (Jaroslav Kysela) [916264]
- [alsa] hda: Mark CS260x immutable structures const (Jaroslav Kysela) [916264]
- [alsa] hda: Fix digital microphone on CS420x (Jaroslav Kysela) [916264]
- [alsa] hda: Cirrus: Fix coefficient index for beep configuration (Jaroslav Kysela) [916264]
- [alsa] hda: stop setup_dig_out_stream() causing clicks (Jaroslav Kysela) [916264]
- [alsa] hda: Add tracepoints to HD-audio controller driver (Jaroslav Kysela) [916264]
- [alsa] hda: remove unused variable in azx_position_ok() (Jaroslav Kysela) [916264]
- [alsa] hda: Don't enable unsol for jacks we're polling (Jaroslav Kysela) [916264]
- [alsa] hda: Add workaround for conflicting IEC958 controls (Jaroslav Kysela) [916264]
- [alsa] hda: Print PCI device name at "spurious message" warnings (Jaroslav Kysela) [916264]
- [alsa] hda: Implement a poll loop for jacks as a module parameter (Jaroslav Kysela) [916264]
- [alsa] hda: Make hda sound card usable for Loongson (Jaroslav Kysela) [916264]
- [alsa] hda: Fix mute-LED setup for HP dv5 laptop (Jaroslav Kysela) [916264]
- [alsa] hda: Fix silent headphone output from Toshiba P200 (Jaroslav Kysela) [916264]
- [alsa] hda: add dock support for Thinkpad T430 (Jaroslav Kysela) [916264]
- [alsa] hda: Always check array bounds in alc_get_line_out_pfx (Jaroslav Kysela) [916264]
- [alsa] hda: Stop LPIB delay counting on broken hardware (Jaroslav Kysela) [916264]
- [alsa] hda: Fix registration race of VGA switcheroo (Jaroslav Kysela) [916264]
- [alsa] hda: Clean up superfluous position_fix list entries (Jaroslav Kysela) [916264]
- [alsa] hda: do not detect jack on internal speakers for Realtek (Jaroslav Kysela) [916264]
- [alsa] hda: Fix missing beep on ASUS X43U notebook (Jaroslav Kysela) [916264]
- [alsa] hda: Remove AZX_DCAPS_POSFIX_COMBO (Jaroslav Kysela) [916264]
- [alsa] hda: Warn an allocation for an uninitialized array (Jaroslav Kysela) [916264]
- [alsa] hda/cirrus: Add missing init/free of hda_gen_spec (Jaroslav Kysela) [916264]
- [alsa] hda: Fix memory leaks at error path in patch_cirrus.c (Jaroslav Kysela) [916264]
- [alsa] hda: Add missing hda_gen_spec to struct via_spec (Jaroslav Kysela) [916264]
- [alsa] hda: remove "Mic Jack Mode" for headset jacks (Latitude Exx30) (Jaroslav Kysela) [916264]
- [alsa] hda: make Cirrus codec use generic unsol event handler (Jaroslav Kysela) [916264]
- [alsa] hda: make VIA codec use generic unsol event handler (Jaroslav Kysela) [916264]
- [alsa] hda: Remove dead GPIO code for VIA codec (Jaroslav Kysela) [916264]
- [alsa] hda: Add new codec ALC283 ALC290 support (Jaroslav Kysela) [916264]
- [alsa] hda: avoid unneccesary indices on "Headphone Jack" controls (Jaroslav Kysela) [916264]
- [alsa] hda: fix indices on boost volume on Conexant (Jaroslav Kysela) [916264]
- [alsa] hda: Fix hang caused by race during suspend (Jaroslav Kysela) [916264]
- [alsa] hda: Clean up redundant FG checks (Jaroslav Kysela) [916264]
- [alsa] hda/realtek: Fix detection of ALC271X codec (Jaroslav Kysela) [916264]
- [alsa] hda: Add inverted internal mic quirk for Lenovo IdeaPad U310 (Jaroslav Kysela) [916264]
- [alsa] hda: make Realtek/Sigmatel/Conexant use the generic unsol event (Jaroslav Kysela) [916264]
- [alsa] hda: make a generic unsol event handler (Jaroslav Kysela) [916264]
- [alsa] hda: add PCI identifier for Intel 5 Series/3400 (Jaroslav Kysela) [916264]
- [alsa] hda: use LPIB for delay estimation (Jaroslav Kysela) [916264]
- [alsa] hda: force use of SSYNC bits (Jaroslav Kysela) [916264]
- [alsa] hda/via: don't report presence on HPs with no presence support (Jaroslav Kysela) [916264]
- [alsa] hda: Add external mic quirk for Asus Zenbook UX31A (Jaroslav Kysela) [916264]
- [alsa] hda: Yet another fix for D3 stop-clock refcounting (Jaroslav Kysela) [916264]
- [alsa] hda: Optimize bitfield usage in struct hda_codec (Jaroslav Kysela) [916264]
- [alsa] hda: Fix D3 clock stop check for codecs with own set_power_state op (Jaroslav Kysela) [916264]
- [alsa] hda: Clean up CONFIG_SND_HDA_POWER_SAVE (Jaroslav Kysela) [916264]
- [alsa] hda: Fix runtime PM leftover refcounts (Jaroslav Kysela) [916264]
- [alsa] hda: bug fix on references without checking CONFIG_SND_HDA_POWER_SAVE (Jaroslav Kysela) [916264]
- [alsa] hda: add runtime PM support (Jaroslav Kysela) [916264]
- [alsa] hda: Fix possible compile warnings regarding CONFIG_PM (Jaroslav Kysela) [916264]
- [alsa] hda: Convert to new pm_ops for PCI drivers (Jaroslav Kysela) [916264]
- [alsa] Revert: hda_intel: Add Device IDs for Intel Wellsburg PCH (Jarod Wilson) [916264]

* Mon Aug 05 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-408.el6]
- [virt] kvm: validate userspace_addr of memslot (Petr  Matousek) [950498] {CVE-2013-1943}
- [x86] edac: Apply patch to support ECC error decoding for Fam16h (Kim Naru) [922941]
- [fs] fuse: readdirplus sanity checks (Niels de Vos) [981741]
- [fs] fuse: readdirplus cleanup (Niels de Vos) [981741]
- [fs] fuse: readdirplus change attributes once (Niels de Vos) [981741]
- [fs] fuse: readdirplus fix instantiate (Niels de Vos) [981741]
- [fs] fuse: fix readdirplus dentry leak (Niels de Vos) [981741]
- [fs] fuse: hold i_mutex in fuse_file_fallocate() (Brian Foster) [979433]
- [fs] cifs: on send failure, readjust server sequence number downward (Sachin Prabhu) [877010]
- [fs] cifs: don't try to unlock pagecache page after releasing it (Sachin Prabhu) [877010]
- [fs] cifs: bugfix for unreclaimed writeback pages in cifs_writev_requeue() (Sachin Prabhu) [877010]
- [fs] cifs: move check for NULL socket into smb_send_rqst (Sachin Prabhu) [877010]
- [fs] cifs: fix writeback race with file that is growing (Sachin Prabhu) [877010]
- [fs] cifs: adjust sequence number downward after signing NT_CANCEL request (Sachin Prabhu) [877010]
- [fs] cifs: remove kmap lock (Sachin Prabhu) [877010]
- [fs] cifs: replace kvec array in readdata with a single kvec (Sachin Prabhu) [877010]
- [fs] cifs: convert async read code to use pages array without kmapping (Sachin Prabhu) [877010]
- [fs] cifs: turn the pages list in cifs_readdata into an array (Sachin Prabhu) [877010]
- [fs] cifs: allocate kvec array for cifs_readdata as a separate allocation (Sachin Prabhu) [877010]
- [fs] cifs: remove the kmap size limit from wsize (Sachin Prabhu) [877010]
- [fs] cifs: convert async write code to pass in data via rq_pages array (Sachin Prabhu) [877010]
- [fs] cifs: change cifs_call_async to use smb_rqst structs (Sachin Prabhu) [877010]
- [fs] cifs: teach signing routines how to deal with arrays of pages in a smb_rqst (Sachin Prabhu) [877010]
- [fs] cifs: teach smb_send_rqst how to handle arrays of pages (Sachin Prabhu) [877010]
- [fs] cifs: cork the socket before a send and uncork it afterward (Sachin Prabhu) [877010]
- [fs] cifs: convert send code to use smb_rqst structs (Sachin Prabhu) [877010]
- [fs] cifs: change signing routines to deal with smb_rqst structs (Sachin Prabhu) [877010]
- [fs] cifs: print error code if smb signature verification fails (Sachin Prabhu) [877010]
- [fs] cifs: rename cifs_sign_smb2 to cifs_sign_smbv (Sachin Prabhu) [877010]
- [fs] cifs: remove bogus reset of smb_buf_length in smb_send routines (Sachin Prabhu) [877010]
- [fs] cifs: convert cifs_iovec_write to use async writes (Sachin Prabhu) [877010]
- [fs] cifs: call cifs_update_eof with i_lock held (Sachin Prabhu) [877010]
- [fs] cifs: fix up get_numpages (Sachin Prabhu) [877010]
- [fs] cifs: fix allocation in cifs_write_allocate_pages (Sachin Prabhu) [877010]
- [fs] cifs: allow caller to specify completion op when allocating writedata (Sachin Prabhu) [877010]
- [fs] cifs: add pid field to cifs_writedata (Sachin Prabhu) [877010]
- [fs] cifs: fix issue mounting of DFS ROOT when redirecting from one domain controller to the next (Sachin Prabhu) [976535]
- [fs] gfs2: go back to try locks if reservation does not fit our needs (Robert S Peterson) [989669]
- [fs] xfs: remove xfs_get_buftarg_list (Eric Sandeen) [973769]
- [fs] xfs: check for stale inode before acquiring iflock on push (Brian Foster) [971441]
- [fs] xfs: fix sgid inheritance for subdirectories inheriting default acls (Carlos Maiolino) [876528]
- [fs] xfs: use XFS_BMAP_BMDR_SPACE vs. XFS_BROOT_SIZE_ADJ (Eric Sandeen) [886566]
- [fs] xfs: check on-disk, not incore, btree root size in dfrag.c (Eric Sandeen) [886566]
- [fs] writeback: avoid extra sync work at enqueue time (Eric Sandeen) [915546]
- [fs] writeback: the kupdate expire timestamp should be a moving target (Eric Sandeen) [915546]
- [fs] fix typo on bio_get_nr_vecs (Carlos Maiolino) [982344]
- [fs] gfs2: Reserve journal space for quota change in do_grow (Robert S Peterson) [976823]
- [fs] nfsd: permit read opens of executable-only files (Niels de Vos) [988120]
- [fs] nfsd: when dentry_open returns an error do not propagate as struct file (Harshula Jayasuriya) [987142]
- [fs] nfs: Make nfs_readdir revalidate less often (Scott Mayhew) [976879]
- [fs] nfs: Make nfs_attribute_cache_expired() non-static (Scott Mayhew) [976879]
- [fs] nfs: set verifier on existing dentries in nfs_prime_dcache (Scott Mayhew) [976879]
- [fs] nfs: fix open() O_RDONLY|O_TRUNC in NFS4.0 (Jeff Layton) [982688]
- [fs] vfs: remove unused __d_splice_alias argument (J. Bruce Fields) [820446]
- [fs] vfs: stop d_splice_alias creating directory aliases (J. Bruce Fields) [820446]
- [fs] nfs: Allow nfs_updatepage to extend a write under additional circumstances (Scott Mayhew) [983288]
- [fs] nfs: add filehandle crc for debug display (Dave Wysochanski) [918580]
- [fs] nfs: add fh_crc to debug output (Dave Wysochanski) [918580]
- [fs] nfs: Add a client-side function to display NFS file handles (Dave Wysochanski) [918580]
- [fs] nfs: include filelayout DS rpc stats in mountstats (Steve Dickson) [963096]
- [fs] nfs: fix a leak at nfs_lookup_revalidate() (Dave Wysochanski) [975211]
- [fs] NFS returns EIO for EDQUOT and others (Scott Mayhew) [888944]
- [fs] nfs: Ensure that NFS file unlock waits for readahead to complete (Dave Wysochanski) [976915]
- [fs] nfs: Add functionality to allow waiting on all outstanding reads to complete (Dave Wysochanski) [976915]
- [fs] nfs: Convert nfs_get_lock_context to return an ERR_PTR on failure (Dave Wysochanski) [976915]
- [netdrv] lseek() does not go to eof - n (Ivan Vecera) [928987]
- [netdrv] bna: Driver and Firmware Updated (Ivan Vecera) [928987]
- [netdrv] bna: Enahncement to Identify Default IOC Function (Ivan Vecera) [928987]
- [netdrv] bna: Fix Ucast Failure Handling (Ivan Vecera) [928987]
- [netdrv] bna: Clear Driver Config Flags When HW Resets (Ivan Vecera) [928987]
- [netdrv] bna: add missing iounmap() on error in bnad_init() (Ivan Vecera) [928987]
- [netdrv] bna: dma_alloc_coherent: use __GFP_ZERO instead of memset() (Ivan Vecera) [928987]
- [netdrv] bna: fix declaration mismatch (Ivan Vecera) [928987]
- [netdrv] bna: Driver Version Updated to 3.1.2.1 (Ivan Vecera) [928987]
- [netdrv] bna: Firmware update (Ivan Vecera) [928987]
- [netdrv] bna: Add RX State (Ivan Vecera) [928987]
- [netdrv] bna: Rx Page Based Allocation (Ivan Vecera) [928987]
- [netdrv] bna: TX Intr Coalescing Fix (Ivan Vecera) [928987]
- [netdrv] bna: Tx and Rx Optimizations (Ivan Vecera) [928987]
- [netdrv] bna: use device model DMA API (Ivan Vecera) [928987]
- [netdrv] bna: Code Cleanup and Enhancements (Ivan Vecera) [928987]
- [netdrv] bna: remove useless calls to memset() (Ivan Vecera) [928987]
- [netdrv] bna: Fix warning false positive (Ivan Vecera) [928987]
- [scsi] bfa: Update the driver version to 3.2.21.1 (Vijay Guvva) [928983]
- [scsi] bfa: dis-associate bfa path_tov with dev_loss_tmo (Vijay Guvva) [928983]
- [scsi] bfa: Support for chinook-quad port card (Vijay Guvva) [928983]
- [scsi] bfa: fix endianess issue for firmware stats (Vijay Guvva) [928983]
- [scsi] bfa: Fix bug_on condition in RPSC rsp handling (Vijay Guvva) [928983]
- [scsi] bfa: Allow rsp queue process during ioc disable (Vijay Guvva) [928983]
- [scsi] bfa: firmware statistics update (Vijay Guvva) [928983]
- [scsi] bfa: fru vpd date update changes (Vijay Guvva) [928983]
- [scsi] bfa: driver compatibility with 32bit libs (Vijay Guvva) [928983]
- [scsi] bfa: kdump fix on 815 and 825 adapters (Vijay Guvva) [928983]
- [scsi] bfa: Fix FDISC timeout handling (Vijay Guvva) [928983]
- [scsi] bfa: Fix 1860 port initialize when ATC is enabled (Vijay Guvva) [928983]
- [scsi] bfa: FDMI enhancements (Vijay Guvva) [928983]
- [scsi] bfa: Fix WARN_ON condition check (Vijay Guvva) [928983]
- [scsi] bfa: Add dynamic diagnostic port support (Vijay Guvva) [928983]
- [scsi] bfa: Forward Error Correction status (Vijay Guvva) [928983]
- [scsi] bfa: Support for FC BB credit recovery (Vijay Guvva) [928983]
- [scsi] bfa: fix for FC Direct Attach LUN discovery failure (Vijay Guvva) [928983]
- [scsi] bfa: fix faulty handling of events in lps sm (Vijay Guvva) [928983]
- [scsi] bfa: fix strncpy() limiter in bfad_start_ops() (Vijay Guvva) [928983]
- [scsi] bfa: Add support to read/update the FRU data (Vijay Guvva) [928983]
- [scsi] bfa: Support Power on Hours display and diag temp sensor fixes (Vijay Guvva) [928983]
- [scsi] bfa: Add support to configure min/max bandwidth for a pcifn (Vijay Guvva) [928983]
- [scsi] bfa: Add support for IO throttling at port level (Vijay Guvva) [928983]
- [scsi] bfa: Add support for user to configure bandwidth on QoS priorities (Vijay Guvva) [928983]
- [scsi] bfa: Fabric Assigned Address implementation fix (Vijay Guvva) [928983]
- [scsi] bfa: Add diagnostic port support (Vijay Guvva) [928983]
- [scsi] bfa: Fix to handle firmware tskim abort request response (Vijay Guvva) [928983]
- [scsi] bfa: Fix few attributes in the RHBA CT passthru command (Vijay Guvva) [928983]
- [scsi] bfa: Add support to have mfg date as part of adapter attributes (Vijay Guvva) [928983]
- [scsi] bfa: Flash Controller PLL initialization fixes (Vijay Guvva) [928983]
- [scsi] bfa: IOCFC state machine enhancements (Vijay Guvva) [928983]
- [scsi] bfa: Add support for FC Arbitrated Loop topology (Vijay Guvva) [928983]
- [scsi] bfa: Add support for max target ports discovery (Vijay Guvva) [928983]
- [scsi] bfa: Add support to register node symbolic name with name server (Vijay Guvva) [928983]
- [scsi] bfa: Fix to process mbox interrupts only if interrupts are enabled in INTx mode (Vijay Guvva) [928983]
- [scsi] bfa: Add PowerPC support and enable PCIE AER handling (Vijay Guvva) [928983]
- [scsi] bfa: Add new hardware model info to sysfs model description routine (Vijay Guvva) [928983]
- [scsi] bfa: Make changes to FCXP resource management (Vijay Guvva) [928983]
- [scsi] bfa: FCS remote port enhancements (Vijay Guvva) [928983]
- [scsi] bfa: Support vport symbolic name change from sysfs (Vijay Guvva) [928983]
- [scsi] bfa: Fix to set correct return error codes and misc cleanup (Vijay Guvva) [928983]
- [scsi] bfa: Fix to defer vport delete handler invocation till firmware logo response (Vijay Guvva) [928983]
- [scsi] fix race in scsi_target_reap (Tomas Henzl) [910203]
- [scsi] iscsi class, qla4xxx: fix sess/conn refcounting when find fns are used (Chad Dupuis) [917577]
- [scsi] qla4xxx: 5.03.00.00.06.05-k1 (Chad Dupuis) [917585]
- [scsi] qla4xxx: Exporting new attrs for iscsi session and connection in sysfs (Chad Dupuis) [917585]
- [scsi] qla4xxx: 5.03.00.00.06.05-k0 (Chad Dupuis) [917585]
- [scsi] qla4xxx: Add missing spaces to error messages (Chad Dupuis) [917585]
- [scsi] qla4xxx: Fix iocb_cnt calculation in qla4xxx_send_mbox_iocb() (Chad Dupuis) [917585]
- [scsi] qla4xxx: Assign values using correct datatype (Chad Dupuis) [917585]
- [scsi] qla4xxx: Fix smatch warnings (Chad Dupuis) [917585]
- [scsi] qla4xxx: Fix sparse warning for qla4xxx_sysfs_ddb_tgt_create (Chad Dupuis) [917585]
- [scsi] qla4xxx: Silence gcc warning (Chad Dupuis) [917585]
- [scsi] qla4xxx: Added print statements to display AENs (Chad Dupuis) [917585]
- [scsi] qla4xxx: Use correct value for max flash node entries (Chad Dupuis) [917585]
- [scsi] qla4xxx: Restrict logout from boot target session using session id (Chad Dupuis) [917585]
- [scsi] qla4xxx: Use correct flash ddb offset for ISP40XX (Chad Dupuis) [917585]
- [scsi] qla4xxx: Replace dev type macros with generic portal type macros (Chad Dupuis) [917585]
- [scsi] qla4xxx: Add flash node mgmt support (Chad Dupuis) [917585]
- [scsi] qla4xxx: Skip retry of initialize_adapter for ISP80XX (Chad Dupuis) [917585]
- [scsi] qla4xxx: Assign correct CHAP table address to FLT (Chad Dupuis) [917585]
- [scsi] qla4xxx: Added missing check for ISP83XX in CHAP related functions (Chad Dupuis) [917585]
- [scsi] qla4xxx: Fixed request queue count manipulation on response path (Chad Dupuis) [917585]
- [scsi] qla4xxx: Fix debug level to avoid floods of same message (Chad Dupuis) [917585]
- [scsi] qla4xxx: Pass correct LUN address to firmware in case of lun_reset (Chad Dupuis) [917585]
- [scsi] qla4xxx: Fix double reset in case of firmware hung for ISP83XX (Chad Dupuis) [917585]
- [scsi] qla4xxx: Set graceful reset bit for ISP83XX (Chad Dupuis) [917585]
- [scsi] qla4xxx: Boot from SAN fix for ISP83XX (Chad Dupuis) [917585]
- [scsi] qla4xxx: Take E-port out of reset before disabling pause frames (Chad Dupuis) [917585]
- [scsi] qla4xxx: remove __dev* attributes (Chad Dupuis) [917585]
- [scsi] qla4xxx: don't free NULL dma pool (Chad Dupuis) [917585]
- [scsi] qla4xxx: Fix return code for qla4xxx_session_get_param (Chad Dupuis) [917585]
- [scsi] qla4xxx: wait for boot target login response during probe (Chad Dupuis) [917585]
- [scsi] qla4xxx: Added support for force firmware dump (Chad Dupuis) [917585]
- [scsi] qla4xxx: Re-register IRQ handler while retrying initialize of adapter (Chad Dupuis) [917585]
- [scsi] qla4xxx: Throttle active IOCBs to firmware limits (Chad Dupuis) [917585]
- [scsi] qla4xxx: Remove unnecessary code from qla4xxx_init_local_data (Chad Dupuis) [917585]
- [scsi] qla4xxx: Quiesce driver activities while loopback (Chad Dupuis) [917585]
- [scsi] qla4xxx: Rename MBOX_ASTS_IDC_NOTIFY to MBOX_ASTS_IDC_REQUEST_NOTIFICATION (Chad Dupuis) [917585]
- [scsi] qla4xxx: Add spurious interrupt messages under debug level 2 (Chad Dupuis) [917585]
- [scsi] qla4xxx: Fix memory corruption issue in qla4xxx_get_ep_fwdb (Chad Dupuis) [917585]
- [scsi] qla4xxx: Allow reset in link down case (Chad Dupuis) [917585]
- [scsi] qla4xxx: Fix MBOX intr switching from polling to intr mode for ISP83XX (Chad Dupuis) [917585]
- [scsi] scsi_transport_iscsi: Exporting new attrs for iscsi session and connection in sysfs (Chad Dupuis) [917577]
- [scsi] libiscsi: Exporting new attrs for iscsi session and connection in sysfs (Chad Dupuis) [917577]
- [scsi] scsi_transport_iscsi: Declare portal type string macros for generic use (Chad Dupuis) [917572]
- [scsi] libiscsi: export function iscsi_switch_str_param (Chad Dupuis) [917572]
- [scsi] scsi_transport_iscsi: Add flash node mgmt support (Chad Dupuis) [917572]
- [scsi] scsi_transport_iscsi: export iscsi class session's target_id in sysfs (Chad Dupuis) [917577]
- [md] dm-flakey: correct ctr alloc failure mesg (Mike Snitzer) [987566]
- [md] dm-mpath: fix ioctl deadlock when no paths (Mike Snitzer) [987566]
- [md] dm: use __GFP_HIGHMEM in __vmalloc (Mike Snitzer) [987566]
- [md] dm-ioctl: set noio flag to avoid __vmalloc deadlock (Mike Snitzer) [987566]
- [md] dm-bufio: avoid a possible __vmalloc deadlock (Mike Snitzer) [987566]
- [md] dm-thin: open dev read only when possible (Mike Snitzer) [987566]
- [md] dm-persistent-data: fix error message typos (Mike Snitzer) [987566]
- [md] dm-snapshot: fix error return code in snapshot_ctr (Mike Snitzer) [987566]

* Fri Aug 02 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-407.el6]
- [x86] mce: Add quirk for instruction recovery on Sandy Bridge processors (Rui Wang) [832367]
- [x86] mce: Avoid reading every machine check bank register twice (Rui Wang) [832367]
- [x86] mce: Fix siginfo_t->si_addr value for non-recoverable memory faults (Rui Wang) [832367]
- [x86] mce: Only restart instruction after machine check recovery if it is safe (Rui Wang) [832367]
- [x86] mce: Add instruction recovery signatures to mce-severity table (Rui Wang) [832367]
- [x86] thermal: Disable power limit notification interrupt (Shyam Iyer) [908990]
- [x86] thermal: Delete power-limit-notification console messages (Shyam Iyer) [908990]
- [virtio] console: prevent use-after-free of port name in port unplug (Amit Shah) [827300]
- [virtio] console: fix locking around send_sigio_to_port() (Amit Shah) [986960]
- [virtio] console: add locking in port unplug path (Amit Shah) [795678 956637]
- [virtio] console: add locks around buffer removal in port unplug path (Amit Shah) [827300]
- [virtio] console: fix raising SIGIO after port unplug (Amit Shah) [986960]
- [virtio] console: return -ENODEV on all read operations after unplug (Amit Shah) [975661]
- [virtio] console: clean up port data immediately at time of unplug (Amit Shah) [795678 796048 827300 947024 956637]
- [virtio] console: fix race in port_fops_open() and port unplug (Amit Shah) [827300]
- [virtio] console: fix race with port unplug and open/close (Amit Shah) [795678 796048 827300 947024 956637]
- [virtio] console: Add pipe_lock/unlock for splice_write (Amit Shah) [987004]
- [virtio] console: Quit from splice_write if pipe->nrbufs is 0 (Amit Shah) [987004]
- [virtio] console: replace EMFILE with EBUSY for already-open port (Amit Shah) [986986]
- [virtio] console: fix error handling in init() function (Amit Shah) [986990]
- [ftrace] syscalls: Fix typo in SYSCALL_DEFINE0 (Jiri Olsa) [989503]
- [ftrace] syscalls: Set event_enter_##sname->data to its metadata (Jiri Olsa) [989503]
- [ftrace] syscalls: Remove unused event_syscall_enter and event_syscall_exit (Jiri Olsa) [989503]
- [x86] efi: Fix dummy variable buffer allocation (Seiji Aguchi) [985577]
- [x86] Modify UEFI anti-bricking code (Seiji Aguchi) [985577]
- [x86] efi: Implement efi_no_storage_paranoia parameter (Seiji Aguchi) [985577]
- [x86] efi: Distinguish between "remaining space" and actually used space (Seiji Aguchi) [985577]
- [x86] efi: Check max_size only if it is non-zero (Seiji Aguchi) [985577]
- [x86] efi: Export efi_query_variable_store() for efivars.ko (Seiji Aguchi) [985577]
- [x86] efivars: firmware bug workarounds should be in platform code (Seiji Aguchi) [985577]
- [x86] efi: be more paranoid about available space when creating variables (Seiji Aguchi) [985577]
- [x86] efivars: Handle duplicate names from get_next_variable() (Seiji Aguchi) [985577]
- [x86] efivars: explicitly calculate length of VariableName (Seiji Aguchi) [985577]
- [x86] efi_pstore: Introducing workqueue updating sysfs (Seiji Aguchi) [985551]
- [x86] efivars: Disable external interrupt while holding efivars->lock (Seiji Aguchi) [985551]
- [x86] efi_pstore: Add a format check for an existing variable name at reading time (Seiji Aguchi) [826190]
- [x86] efi_pstore: Add a format check for an existing variable name at erasing time (Seiji Aguchi) [826190]
- [x86] efi_pstore: Add a sequence counter to a variable name (Seiji Aguchi) [826190]
- [x86] efi_pstore: Add ctime to argument of erase callback (Seiji Aguchi) [826190]
- [x86] efi_pstore: Remove a logic erasing entries from a write callback to hold multiple logs (Seiji Aguchi) [826190]
- [x86] efi_pstore: Add a logic erasing entries to an erase callback (Seiji Aguchi) [826190]
- [x86] efi_pstore: Check remaining space with QueryVariableInfo() before writing data (Seiji Aguchi) [826190]
- [powerpc] perf: Power8 PMU support (Steve Best) [976911]
- [powerpc] perf: Add support for SIER (Steve Best) [976911]
- [powerpc] perf: Add regs_no_sipr() (Steve Best) [976911]
- [powerpc] perf: Add an accessor for regs->result (Steve Best) [976911]
- [powerpc] perf: Convert mmcra_sipr/sihv() to regs_sipr/sihv() (Steve Best) [976911]
- [powerpc] perf: Add an explict flag indicating presence of SLOT field (Steve Best) [976911]
- [scsi] ipr: IOA Status Code IOASC update (Steve Best) [983765]
- [scsi] ipr: qc_fill_rtf() method should not store alternate status register (Steve Best) [983765]
- [scsi] ipr: possible irq lock inversion dependency detected (Steve Best) [983765]
- [cpufreq] intel_pstate: Set timer timeout correctly (Lenny Szubowicz) [956824]
- [cpufreq] intel-pstate: Use #defines instead of hard-coded values (Lenny Szubowicz) [956824]
- [cpufreq] intel_pstate: Fix calculation of current frequency (Lenny Szubowicz) [956824]
- [cpufreq] intel_pstate: Add function to check that all MSRs are valid (Lenny Szubowicz) [956824]
- [cpufreq] intel_pstate: Do not load on VM that does not report max P state (Lenny Szubowicz) [956824]
- [cpufreq] intel_pstate: Fix intel_pstate_init() error path (Lenny Szubowicz) [956824]
- [cpufreq] intel_pstate: Add kernel command line option disable intel_pstate (Lenny Szubowicz) [956824]
- [cpufreq] intel_pstate: Fix 32 bit build (Lenny Szubowicz) [956824]
- [cpufreq] intel_pstate: Fix kobject usage (Lenny Szubowicz) [956824]
- [cpufreq] intel_pstate: Add P-state driver for sandy bridge (Lenny Szubowicz) [956824]
- [cpufreq] Do not track governor name for scaling drivers with internal governors (Lenny Szubowicz) [956824]
- [x86] cpu: Add driver auto probing for x86 features (Lenny Szubowicz) [956824]
- [cpufreq] Unify sysfs attribute definition macros (Lenny Szubowicz) [956824]
- [acpi] efivars: If pstore_register fails, free unneeded pstore buffer (Lenny Szubowicz) [867689]
- [acpi] Eliminate console msg if pstore.backend excludes ERST (Lenny Szubowicz) [867689]
- [acpi] Return unique error if backend registration excluded by kernel param (Lenny Szubowicz) [867689]
- [x86] io_apic: initialize nr_ioapic_registers early in mp_register_ioapic() (Tony Camuso) [855057]
- [mm] tmpfs: distribute interleave better across nodes (George Beshers) [988063]
- [kernel] sched: Bail out of yield_to when source and target runqueue has one task (Rik van Riel) [864233]
- [kvm] Add config to support ple or cpu relax optimzation (Rik van Riel) [864233]
- [kvm] Iterate over only vcpus that are preempted (Rik van Riel) [864233]
- [kvm] Record the preemption status of vcpus using preempt notifiers (Rik van Riel) [864233]
- [kvm] Handle yield_to failure return code for potential undercommit case (Rik van Riel) [864233]
- [kvm] Choose better candidate for directed yield (Rik van Riel) [864233]
- [kvm] s390: Implement the directed yield (diag 9c) hypervisor call for KVM (Rik van Riel) [864233]
- [kvm] Note down when cpu relax intercepted or pause loop exited (Rik van Riel) [864233]
- [netdrv] sfc: Enable RX scatter for flows steered by RFS (Nikolay Aleksandrov) [987200]
- [netdrv] sfc: Fix aRFS UDP flow steering problem (Nikolay Aleksandrov) [984933]
- [md] dm-thin: remove cells from stack (Mike Snitzer) [922212]
- [md] dm-bio-prison: pass cell memory in (Mike Snitzer) [922212]
- [md] persistent-data: add btree_walk (Mike Snitzer) [922212]
- [md] persistent-data: set some btree fn parms const (Mike Snitzer) [922212]
- [md] persistent-data: remove CONFIG_EXPERIMENTAL (Mike Snitzer) [922212]
- [md] dm-bufio: use WRITE_FLUSH instead of REQ_FLUSH (Mike Snitzer) [922212]
- [md] persistent-data: dm-transaction-manager.c: rename HASH_SIZE (Mike Snitzer) [922212]
- [md] dm-thin: fix non power-of-two discard granularity calculation (Mike Snitzer) [922212]
- [md] dm-kcopyd: introduce configurable throttling (Mike Snitzer) [922212]
- [md] dm-ioctl: allow message to return data (Mike Snitzer) [922212]
- [md] dm-ioctl: optimize functions without variable params (Mike Snitzer) [922212]
- [md] dm-ioctl: introduce ioctl_flags (Mike Snitzer) [922212]
- [md] dm-table: remove superfluous variable reset (Mike Snitzer) [922212]
- [md] dm: fix truncated status strings (Mike Snitzer) [922212]
- [usb] host: Fix lockdep warning in AMD PLL quirk (Don Zickus) [854353]
- [usb] ehci: fix obscure race in ehci_endpoint_disable (Don Zickus) [877123]
- [usb] don't read past config->interface if usb_control_msg() fails in usb_reset_configuration() (Don Zickus) [877123]
- [char] tpm: fix regression caused by section type conflict of tpm_dev_release() in ppc builds (Tony Camuso) [732942]
- [char] tpm: fix regression causesd by ppi (Tony Camuso) [732942]
- [char] tpm: declare internal symbols as static (Tony Camuso) [732942]
- [char] tpm: add PPI support in tpm driver (Tony Camuso) [732942]
- [char] tpm: Add securityfs support for event log (Tony Camuso) [732942]
- [char] tpm: Export wait_for_stat for other vendor specific drivers (Tony Camuso) [732942]
- [char] tpm: modularize event log collection (Tony Camuso) [732942]
- [Documentation] ABI: sysfs for Physical Presence Interface (Tony Camuso) [732942]
- [char] tpm: fix memleak when register hardware fails (Tony Camuso) [732942]
- [lib] raid6: cleanup gen_syndrome function selection (Jes Sorensen) [915995]
- [lib] raid6: update test program for recovery functions (Jes Sorensen) [915995]
- [lib] raid6: fix test program build (Jes Sorensen) [915995]
- [x86] add AVX optimized RAID5 checksumming (Jes Sorensen) [915995]
- [crypto] disable preemption while benchmarking RAID5 xor checksumming (Jes Sorensen) [915995]
- [crypto] wait for a full jiffy in do_xor_speed (Jes Sorensen) [915995]
- [x86] Add cpu_has_ssse3 and cpu_has_avx definitions (Jes Sorensen) [915995]
- [md] raid10: fix bug which causes all RAID10 reshapes to move no data (Jes Sorensen) [837097 869622]
- [md] raid5: allow 5-device RAID6 to be reshaped to 4-device (Jes Sorensen) [837097 869622]
- [md] raid10: fix two bugs affecting RAID10 reshape (Jes Sorensen) [837097 869622]
- [md] Remember the last sync operation that was performed (Jes Sorensen) [837097 869622]
- [md] fix buglet in RAID5 -> RAID0 conversion (Jes Sorensen) [837097 869622]
- [md] raid10: check In_sync flag in 'enough()' (Jes Sorensen) [837097 869622]
- [md] raid10: locking changes for 'enough()' (Jes Sorensen) [837097 869622]
- [md] replace strict_strto*() with kstrto*() (Jes Sorensen) [837097 869622]
- [md] Wait for md_check_recovery before attempting device removal (Jes Sorensen) [837097 869622]
- [md] raid1,raid10: use freeze_array in place of raise_barrier in various places (Jes Sorensen) [837097 869622]
- [md] raid1: consider WRITE as successful only if at least one non-Faulty and non-rebuilding drive completed it (Jes Sorensen) [837097 869622]
- [md] md_stop_writes() should always freeze recovery (Jes Sorensen) [837097 869622]
- [md] bad block list should default to disabled (Jes Sorensen) [837097 869622 882413]
- [md] raid1/raid10 md devices leak memory when stopping (Jes Sorensen) [837097 869622 956769]
- [md] Export 'md_reap_sync_thread' function (Jes Sorensen) [837097 869622]
- [md] don't update metadata when stopping a read-only array (Jes Sorensen) [837097 869622]
- [md] Allow devices to be re-added to a read-only array (Jes Sorensen) [837097 869622]
- [md] raid10: Allow skipping recovery when clean arrays are assembled (Jes Sorensen) [837097 869622]
- [md] Fix typos in MD documentation (Jes Sorensen) [837097 869622]
- [md] raid5: avoid an extra write when writing to a known-bad-block (Jes Sorensen) [837097 869622]
- [md] raid5: Change or of some order to improve efficiency (Jes Sorensen) [837097 869622]
- [md] use set_bit_le and clear_bit_le (Jes Sorensen) [837097 869622]
- [md] HOT_DISK_REMOVE shouldn't make a read-auto device active (Jes Sorensen) [837097 869622]
- [md] use common code for all calls to ->hot_remove_disk() (Jes Sorensen) [837097 869622]
- [md] never update metadata when array is read-only (Jes Sorensen) [837097 869622]
- [md] block: Add submit_bio_wait(), remove from md (Jes Sorensen) [837097 869622]
- [md] block: Use bio_sectors() more consistently (Jes Sorensen) [837097 869622]
- [md] remove CONFIG_MULTICORE_RAID456 entirely (Jes Sorensen) [837097 869622]
- [md] raid5: ensure sync and DISCARD don't happen at the same time (Jes Sorensen) [837097 869622]
- [md] Prevent sysfs operations on uninitialized kobjects (Jes Sorensen) [837097 869622]
- [md] raid5: Avoid accessing gendisk or queue structs when not available (Jes Sorensen) [837097 869622]
- [md] raid5: schedule_construction should abort if nothing to do (Jes Sorensen) [837097 869622 882413]
- [md] expedite metadata update when switching read-auto -> active (Jes Sorensen) [837097 869622]
- [md] remove CONFIG_MULTICORE_RAID456 (Jes Sorensen) [837097 869622]
- [md] raid0: improve error message when converting RAID4-with-spares to RAID0 (Jes Sorensen) [837097 869622]
- [md] raid0: fix error return from create_stripe_zones (Jes Sorensen) [837097 869622]
- [md] fix two bugs when attempting to resize RAID0 array (Jes Sorensen) [837097 869622]
- [md] raid10: Improve redundancy for 'far' and 'offset' algorithms II (Jes Sorensen) [837097 869622]
- [md] raid10: Improve redundancy for 'far' and 'offset' algorithms I (Jes Sorensen) [837097 869622]
- [md] raid10: Minor non-functional code changes (Jes Sorensen) [837097 869622]
- [md] protect against crash upon fsync on ro array (Jes Sorensen) [837097 869622]
- [crypto] async_tx: fix checking of dma_wait_for_async_tx() return value (Jes Sorensen) [837097 869622]
- [crypto] async_tx: fix build for async_memset (Jes Sorensen) [837097 869622]
- [crypto] async_tx: add missing DMA unmap to async_memcpy() (Jes Sorensen) [837097 869622]
- [md] raid5: add blktrace calls (Jes Sorensen) [837097 869622]
- [md] raid5: use async_tx_quiesce() instead of open-coding it (Jes Sorensen) [837097 869622]
- [md] Use ->curr_resync as last completed request when cleanly aborting resync (Jes Sorensen) [837097 869622]
- [md] Update checkpoint of resync/recovery based on time (Jes Sorensen) [837097 869622]
- [md] Add place to update ->recovery_cp (Jes Sorensen) [837097 869622]
- [md] re-indent various 'switch' statements (Jes Sorensen) [837097 869622]
- [md] close race between removing and adding a device (Jes Sorensen) [837097 869622]
- [md] removed unused variable in calc_sb_1_csm (Jes Sorensen) [837097 869622]
- [md] raid10: decrement correct pending counter when writing to replacement (Jes Sorensen) [837097 869622]
- [md] raid10: close race that lose writes lost when replacement completes (Jes Sorensen) [837097 869622]
- [md] raid5: Make sure we clear R5_Discard when discard is finished (Jes Sorensen) [837097 869622]
- [md] raid5: move resolving of reconstruct_state earlier in stripe_handle (Jes Sorensen) [837097 869622]
- [md] raid5: round discard alignment up to power of 2 (Jes Sorensen) [837097 869622]
- [md] make sure everything is freed when dm-raid stops an array (Jes Sorensen) [837097 869622]
- [md] Avoid write invalid address if read_seqretry returned true (Jes Sorensen) [837097 869622]
- [md] Reassigned the parameters if read_seqretry returned true in func md_is_badblock (Jes Sorensen) [837097 869622]
- [md] raid10: Fix oops when creating RAID10 arrays via dm-raid.c (Jes Sorensen) [837097 869622]
- [md] raid1: Fix assembling of arrays containing Replacements (Jes Sorensen) [837097 869622]
- [md] Fix typo in drivers/md (Jes Sorensen) [837097 869622]
- [md] refine reporting of resync/reshape delays (Jes Sorensen) [837097 869622]
- [md] raid5: be careful not to resize_stripes too big (Jes Sorensen) [837097 869622]
- [md] make sure manual changes to recovery checkpoint are saved (Jes Sorensen) [837097 869622]
- [md] raid10: use correct limit variable (Jes Sorensen) [837097 869622]
- [md] writing to sync_action should clear the read-auto state (Jes Sorensen) [837097 869622]
- [md] change resync_mismatches to atomic64_t to avoid races (Jes Sorensen) [837097 869622]
- [md] raid5: make sure to_read and to_write never go negative (Jes Sorensen) [837097 869622]
- [md] When RAID5 is dirty, force reconstruct-write instead of read-modify-write (Jes Sorensen) [837097 869622]
- [md] raid5: protect debug message against NULL derefernce (Jes Sorensen) [837097 869622]
- [md] raid5: add some missing locking in handle_failed_stripe (Jes Sorensen) [837097 869622]
- [md] raid5: avoid unnecessary zero page for trim (Jes Sorensen) [837097 869622]
- [md] raid5 trim support (Jes Sorensen) [837097 869622]
- [md] bitmap: Don't use IS_ERR to judge alloc_page() (Jes Sorensen) [837097 869622]
- [md] avoid taking the mutex on some ioctls (Jes Sorensen) [837097 869622]
- [md] change the parameter of md thread (Jes Sorensen) [837097 869622]
- [md] raid 10 supports TRIM (Jes Sorensen) [837097 869622]
- [md] raid 1 supports TRIM (Jes Sorensen) [837097 869622]
- [md] raid 0 supports TRIM (Jes Sorensen) [837097 869622]
- [md] linear supports TRIM (Jes Sorensen) [837097 869622]
- [md] linear: rcu_dereference outside read-lock section (Jes Sorensen) [837097 869622]
- [md] raid10: fix "enough" function for detecting if array is failed (Jes Sorensen) [837097 869622]
- [block] makes bio_split support bio without data (Jes Sorensen) [837097 869622]
- [md] raid5: add missing spin_lock_init (Jes Sorensen) [837097 869622]
- [md] make sure metadata is updated when spares are activated or removed (Jes Sorensen) [837097 869622]
- [md] raid5: fix calculate of 'degraded' when a replacement becomes active (Jes Sorensen) [837097 869622]
- [md] raid10: fix problem with on-stack allocation of r10bio structure (Jes Sorensen) [837097 869622 982360]
- [md] raid5: raid5d handle stripe in batch way (Jes Sorensen) [837097 869622]
- [md] raid1: Add missing case for attempting to repair known bad blocks (Jes Sorensen) [837097 869622]
- [md] remove duplicated test on ->openers when calling do_md_stop() (Jes Sorensen) [837097 869622]
- [md] raid5: Add R5_ReadNoMerge flag which prevent bio from merging at block layer (Jes Sorensen) [837097 869622]
- [md] raid1: prevent merging too large request (Jes Sorensen) [837097 869622]
- [md] md/raid1: read balance chooses idlest disk for SSD (Jes Sorensen) [837097 869622]
- [md] md/raid1: make sequential read detection per disk based (Jes Sorensen) [837097 869622]
- [md] raid5: add a per-stripe lock (Jes Sorensen) [837097 869622]
- [md] raid5: remove unnecessary bitmap write optimization (Jes Sorensen) [837097 869622]
- [md] raid5: lockless access raid5 overrided bi_phys_segments (Jes Sorensen) [837097 869622]
- [md] raid5: reduce chance release_stripe() taking device_lock (Jes Sorensen) [837097 869622]
- [md] raid1: Fix handling of SYNC requests and bio->bi_rw (Jes Sorensen) [837097 869622]
- [md] raid10: Fix handling of SYNC requests and bio->bi_rw (Jes Sorensen) [837097 869622]
- [md] Add missing blank line to avoid conflict in follow-on cherry-pick (Jes Sorensen) [837097 869622]
- [md] Add set_bit_le/clear_bit_le to RHEL6 compat macros (Jes Sorensen) [837097 869622]
- [md] dm-raid: Set recovery flags on resume - include upstream missing bits (Jes Sorensen) [837097 869622]

* Thu Aug 01 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-406.el6]
- [netdrv] eth: Make is_link_local() consistent with other address tests (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Do not forward LLDP type frames (Andy Gospodarek) [923902]
- [netdrv] bridge: Use is_link_local() in store_group_addr() (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: handle link local multicast addresses in SR-IOV mode (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Adjust to handle unassigned MAC address from PF (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: don't release the soft entries (Andy Gospodarek) [923902]
- [netdrv] ixbgevf: Remove dma_alloc_coherent OOM messages (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: use PCI_DEVICE_TABLE macro (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Make next_to_watch a pointer and adjust memory barriers to avoid races (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Make sure link status and speed are fetched (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Fix link speed message to support 100Mbps (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Fix statistics corruption (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Fix link up messages (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Synch out of tree and in tree mailbox interrupt handlers (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: fix up function prototypes after __dev* removals (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: remove __dev* attributes (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Remove unneeded and obsolete comment (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: White space and comments clean up (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Remove mailbox spinlock from the reset function (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Remove checking for mac.ops function pointers (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Remove the ring adapter pointer value (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Fix unnecessary dereference where local var is available (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Streamline the rx buffer allocation (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Reduce size of maximum rx buffer (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Add flag to indicate when rx is in net poll (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: fix possible use of uninitialized variable (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: make sure probe fails on MSI-X enable error (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Update version string (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: fix softirq-safe to unsafe splat on internal mbx_lock (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Check for error on dma_map_single call (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: make netif_napi_add and netif_napi_del symmetric (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Add VF DCB + SR-IOV support (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Limit maximum jumbo frame size to 9.5K to avoid Tx hangs (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Set the netdev number of Tx queues (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Add fix to VF to handle multi-descriptor buffers (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Fix AIM (Adaptive Interrupt Moderation) (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Remove unused parameter in ixgbevf_receive_skb (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Fix code for handling timeout (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: scheduling while atomic in reset hw path (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Add support for VF API negotiation (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Cleanup handling of configuration for jumbo frames (Andy Gospodarek) [923902]
- [netdrv] ixgbevf: Add suspend and resume support to the VF (Andy Gospodarek) [923902]
- [netdrv] ixgbe: Set the SW prio_tc values at initialization to the HW setting (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add mac type to the version in ethtool_regs (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add support for disabling link at boot time on 82599 (Andy Gospodarek) [923901]
- [netdrv] ixgbe: cache AUTOC reads (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix register access during ethtool loopback test (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix EICR write in ixgbe_msix_other (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add WOL support for new subdevice ID (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add SFP+ LX module support (Andy Gospodarek) [923901]
- [netdrv] ixgbe: rename wol_supported to more fitting wol_enabled (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add driver support for x520 OCP adapter (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix possible divide by zero in ixgbe_update_itr (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Remove unnecessary #ifdef CONFIG_DEBUG_FS tests (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Add support for WoL on 82599 SFP+ LOM (Andy Gospodarek) [923901]
- [netdrv] ixgbe: in shutdown, do netif_running() under rtnl_lock (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Fix a bug in setting VF VLAN via PF (Andy Gospodarek) [923901]
- [netdrv] ixgbe: bump version number (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Fix 1G link WoL (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix MNG FW support when adapter not up (Andy Gospodarek) [923901]
- [netdrv] ixgbe: enable devices with internal switch to read pci parent (Andy Gospodarek) [923901]
- [netdrv] ixgbe: create conversion functions from link_status to bus/speed (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Enable support for recognizing PCI-e Gen3 link speed (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Drop check for PAGE_SIZE from ixgbe_xmit_frame_ring (Andy Gospodarek) [923901]
- [netdrv] ixgbe: don't do arithmetic operations on bitmasks (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Mask off check of frag_off as we only want fragment offset (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix registration order of driver and DCA nofitication (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Update DESC_NEEDED define to adjust for changes to MAX_SKB_FRAGS (Andy Gospodarek) [923901]
- [netdrv] ixgbe: implement SFF diagnostic monitoring via ethtool (Andy Gospodarek) [923901]
- [netdrv] ixgbe: cleanup error checking in ixgbe_identify_sfp_module_generic() (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix possible data corruption in read_i2c_byte (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Add support for set_channels ethtool operation (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Add support for displaying the number of Tx/Rx channels (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Make ixgbe_setup_tc usable even when DCB is not enabled (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Define FCoE and Flow director limits much sooner to allow for changes (Andy Gospodarek) [923901]
- [netdrv] ixgbe: refactor initialization of feature flags (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Remove remaining alloc/OOM messages (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Fix SR-IOV MTU warning (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Replace rmb in Tx cleanup with read_barrier_depends (Andy Gospodarek) [923901]
- [netdrv] ixgbe: update date to 2013 (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix return values and memcpy parameters to eliminate Smatch warnings (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix potential null dereference (Andy Gospodarek) [923901]
- [netdrv] ixgbe: allow reading of SFF-8472 data over i2c (Andy Gospodarek) [923901]
- [netdrv] ixgbe: autoneg variable refactoring (Andy Gospodarek) [923901]
- [netdrv] ixgbe: removed unused variable from setup_link_speed (Andy Gospodarek) [923901]
- [netdrv] ixgbe: rename autoneg variables (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Fix device ref count bug (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Reset the NIC if up2tc has changed (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Limit number of reported VFs to device specific value (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Implement PCI SR-IOV sysfs callback operation (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Modularize SR-IOV enablement code (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Make mailbox ops initialization unconditional (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Inline Rx PTP descriptor handling (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add warning when scheduling reset (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Add ptp work item to poll for the Tx timestamp (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Use watchdog check in favor of BPF for detecting latched timestamp (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Update ptp_overflow check comment and jiffies (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add missing supported filters to get_ts_info (Andy Gospodarek) [923901]
- [netdrv] ixgbe: ethtool ixgbe_diag_test cleanup (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Improve performance and reduce size of ixgbe_tx_map (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Update ixgbe Tx flags to improve code efficiency (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Always use context 0, even for FCoE and TSO (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Make TSO check for CHECKSUM_PARTIAL to avoid skb_is_gso check (Andy Gospodarek) [923901]
- [netdrv] ixgbe: SR-IOV: dynamic IEEE DCBx default priority changes (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Fix overwriting of rx_mtrl in ixgbe_ptp_hwtstamp_ioctl (Andy Gospodarek) [923901]
- [netdrv] ixgbe: only compile ixgbe_debugfs.o when enabled (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix up function prototypes after __dev* removals (Andy Gospodarek) [923901]
- [netdrv] ixgbe: check whether thermal sensor is enabled (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Use is_valid_ether_addr (Andy Gospodarek) [923901]
- [netdrv] ixgbe: remove __dev* attributes (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Do not parse past IP header on fragments beyond the first (Andy Gospodarek) [923901]
- [netdrv] ixgbe: bump version number (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Fix incorrect disabling of Tx hang check in case of PFC (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Drop RLPML configuration from x540 RXDCTL register configuration (Andy Gospodarek) [923901]
- [netdrv] ixgbe: ethtool correctly identify autoneg setting (Andy Gospodarek) [923901]
- [netdrv] ixgbe: remove needless queuing for L4 ptp packets (Andy Gospodarek) [923901]
- [netdrv] ixgbe: use ETQF filter name instead of magic number (Andy Gospodarek) [923901]
- [netdrv] ixgbe: convert to use simple_open() (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Reformat output of ixgbe_dump (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Do not use DCA to prefetch the entire packet into the cache (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix default setting of TXDCTL.WTHRESH (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add/update descriptor maps in comments (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Do not decrement budget in ixgbe_clean_rx_irq (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Return success or failure on VF MAC filter set (Andy Gospodarek) [923901]
- [netdrv] ixgbe: clean up the condition for turning on/off the laser (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Fix return value from macvlan filter function (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Add support for pipeline reset (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Fix possible memory leak in ixgbe_set_ringparam (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Add function ixgbe_reset_pipeline_82599 (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Drop unnecessary addition from ixgbe_set_rx_buffer_len (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Correcting small packet padding (Andy Gospodarek) [923901]
- [netdrv] ixgbe: using is_zero_ether_addr() to simplify the code (Andy Gospodarek) [923901]
- [netdrv] ixgbe: (PTP) refactor init, cyclecounter and reset (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add WOL support for new subdevice id (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Enable support for VF API version 1.1 in the PF (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Add support for GET_QUEUES message to get DCB configuration (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Add support for tracking the default user priority to SR-IOV (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Add support for IPv6 and UDP to ixgbe_get_headlen (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Add mailbox API version negotiation support to ixgbe PF (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Move message handling routines into their own functions (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Enable jumbo frames support w/ SR-IOV (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Initialize q_vector cpu and affinity masks correctly (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Limit maximum jumbo frame size to 9.5K to avoid Tx hangs (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add support for X540-AT1 (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix poll loop for FDIRCTRL.INIT_DONE bit (Andy Gospodarek) [923901]
- [netdrv] ixgbe: fix PTP ethtool timestamping function (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Do not read the spoofed packets counter when not in IOV mode (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Improve statistics accuracy for DDP traffic (Andy Gospodarek) [923901]
- [netdrv] ixgbe: added reg_ops file to debugfs (Andy Gospodarek) [923901]
- [netdrv] ixgbe: added netdev_ops file to debugfs (Andy Gospodarek) [923901]
- [netdrv] ixgbe: add debugfs support (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Fix VF rate limiting to correctly account for more queues per VF (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Fix ordering of things so that PF correctly configures its VLANs (Andy Gospodarek) [923901]
- [netdrv] ixgbe: remove old init remnant (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Roll RSC code into non-EOP code (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Make allocating skb and placing data in it a separate function (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Copybreak sooner to avoid get_page/put_page and offset change overhead (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Make pull tail function separate from rest of cleanup_headers (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Have the CPU take ownership of the buffers sooner (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Only use double buffering if page size is less than 8K (Andy Gospodarek) [923901]
- [netdrv] ixgbe: combine ixgbe_add_rx_frag and ixgbe_can_reuse_page (Andy Gospodarek) [923901]
- [netdrv] ixgbe: Remove code that was initializing Rx page offset (Andy Gospodarek) [923901]
- [net] veth: add vlan features (Flavio Leitner) [959817]
- [net] sctp: verify length provided in heartbeat information parameter (Daniel Borkmann) [855383]
- [net] openvswitch: Add Kconfig dependency on GRE-DEMUX (Amerigo Wang) [976810]
- [net] openvswitch: Add gre tunnel support (Amerigo Wang) [976810]
- [net] openvswitch: Optimize flow key match for non tunnel flows (Amerigo Wang) [976810]
- [net] openvswitch: Expand action buffer size (Amerigo Wang) [976810]
- [net] openvswitch: Add tunneling interface (Amerigo Wang) [976810]
- [net] openvswitch: Copy individual actions (Amerigo Wang) [976810]
- [net] openvswitch: Simplify interface ovs_flow_metadata_from_nlattrs() (Amerigo Wang) [976810]
- [net] openvswitch: make skb->csum consistent with rest of networking stack (Amerigo Wang) [976810]
- [net] openvswitch: Fix misspellings in comments and docs (Amerigo Wang) [976810]
- [net] openvswitch: fix variable names in comment (Amerigo Wang) [976810]
- [net] openvswitch: Unify vport error stats handling (Amerigo Wang) [976810]
- [net] openvswitch: Remove unused get_config vport op (Amerigo Wang) [976810]
- [net] openvswitch: Immediately exit on error in ovs_vport_cmd_set() (Amerigo Wang) [976810]
- [net] openvswitch: Remove unneeded ovs_netdev_get_ifindex() (Amerigo Wang) [976810]
- [net] openvswitch: Simplify datapath locking (Amerigo Wang) [976810]
- [net] openvswitch: Use ETH_ALEN to define ethernet addresses (Amerigo Wang) [976810]
- [net] openvswitch: datapath.h: Fix a stale comment (Amerigo Wang) [976810]
- [net] openvswitch: Don't insert empty OVS_VPORT_ATTR_OPTIONS attribute (Amerigo Wang) [976810]
- [net] openvswitch: Move common genl notify code into ovs_notify() (Amerigo Wang) [976810]
- [net] openvswitch: Refine Netlink message size calculation and kill FLOW_BUFSIZE (Amerigo Wang) [976810]
- [net] openvswitch: Use nla_memcpy() to memcpy() data from attributes (Amerigo Wang) [976810]
- [net] openvswitch: Specify the minimal length of OVS_PACKET_ATTR_PACKET in the policy (Amerigo Wang) [976810]
- [net] openvswitch: correct an invalid BUG_ON (Amerigo Wang) [976810]
- [net] openvswitch: Preallocate reply skb in ovs_vport_cmd_set() (Amerigo Wang) [976810]
- [net] ip_gre: fix a soft lockup in ipgre_fini() (Amerigo Wang) [976810]
- [net] gre: Fix MTU sizing check for gretap tunnels (Amerigo Wang) [976810]
- [net] ip_tunnel: Use skb-len to PMTU check (Amerigo Wang) [976810]
- [net] gre: fix a regression in ioctl (Amerigo Wang) [976810]
- [net] ip_tunnel: Add dont fragment flag (Amerigo Wang) [976810]
- [net] ip_tunnel: push generic protocol handling to ip_tunnel module (Amerigo Wang) [976810]
- [net] ip_tunnel: extend iptunnel_xmit() (Amerigo Wang) [976810]
- [net] gre: export gre_handle_offloads() function (Amerigo Wang) [976810]
- [net] gre: export gre_build_header() function (Amerigo Wang) [976810]
- [net] gre: Allow multiple protocol listener for gre protocol (Amerigo Wang) [976810]
- [net] gre: Simplify gre protocol registration locking (Amerigo Wang) [976810]
- [net] ip_tunnel: remove __net_init/exit from exported functions (Amerigo Wang) [976810]
- [net] ip_tunnel: specify protocol outside IP header (Amerigo Wang) [976810]
- [net] ip_tunnel: fix kernel panic with icmp_dest_unreach (Amerigo Wang) [976810]
- [net] ip_gre: fix a possible crash in ipgre_err() (Amerigo Wang) [976810]
- [net] ipv4: typo issue, remove erroneous semicolon (Amerigo Wang) [976810]
- [net] ip_gre: fix a possible crash in parse_gre_header() (Amerigo Wang) [976810]
- [net] ip_gre: don't overwrite iflink during net_dev init (Amerigo Wang) [976810]
- [net] ip_tunnel: Fix off-by-one error in forming dev name (Amerigo Wang) [976810]
- [net] gre: Refactor GRE tunneling code (Amerigo Wang) [976810]
- [net] ip: convert __IPTUNNEL_XMIT() to an inline function (Amerigo Wang) [976810]
- [net] br: fix schedule while atomic issue in br_features_recompute() (Jiri Pirko) [980876]
- [net] ipvs: reduce sync rate with time thresholds (Jesper Brouer) [854454]
- [net] ipvs: Add sysctl_sync_threshold() sysctl_sync_period() (Jesper Brouer) [854454]
- [net] ipvs: wakeup master thread (Jesper Brouer) [854454]
- [net] export sysctl symbols needed by ip_vs_sync (Jesper Brouer) [854454]
- [net] ipvs: always update some of the flags bits in backup (Jesper Brouer) [854454]
- [net] ipvs: fix ip_vs_try_bind_dest to rebind app and transmitter (Jesper Brouer) [854454]
- [net] ipvs: remove check for IP_VS_CONN_F_SYNC from ip_vs_bind_dest (Jesper Brouer) [854454]
- [net] ipvs: ignore IP_VS_CONN_F_NOOUTPUT in backup server (Jesper Brouer) [854454]
- [net] ipvs: try also real server with port 0 in backup server (Jesper Brouer) [854454]
- [net] ipvs: Backup, adding version 0 sending capabilities (Jesper Brouer) [854454]
- [net] ipvs: Backup, Change sending to Version 1 format (Jesper Brouer) [854454]
- [net] ipvs: Backup, Adding Version 1 receive capability (Jesper Brouer) [854454]
- [net] ipvs: Backup, Adding structs for new sync format (Jesper Brouer) [854454]
- [net] ipvs: use pkts for SCTP too (Jesper Brouer) [854454]
- [net] ipvs: skb defrag in L7 helpers (Jesper Brouer) [854454]
- [net] ipvs: Split ports array into src_port and dst_port (Jesper Brouer) [854454]
- [net] ipvs: Backup, Prepare for transferring firewall marks to the backup daemon (Jesper Brouer) [854454]
- [net] ipvs: add static and read_mostly attributes (Jesper Brouer) [854454]
- [net] ipvs: buffer argument to ip_vs_process_message() should not be const (Jesper Brouer) [854454]
- [net] ipvs: Remove useless blocks from ip_vs_process_message() (Jesper Brouer) [854454]
- [net] ipvs: Make the cp argument to ip_vs_sync_conn() static (Jesper Brouer) [854454]
- [net] ipvs: Only match pe_data created by the same pe (Jesper Brouer) [854454]
- [net] ipvs: Add persistence engine to connection entry (Jesper Brouer) [854454]
- [net] ipvs: inherit forwarding method in backup (Jesper Brouer) [854454]
- [net] ipvs: ip_vs_dbg_callid() is only needed for debugging (Jesper Brouer) [854454]
- [net] ipvs: sip persistence engine (Jesper Brouer) [854454]
- [net] ipvs: Fallback if persistence engine fails (Jesper Brouer) [854454]
- [net] ipvs: Allow configuration of persistence engines (Jesper Brouer) [854454]
- [net] ipvs: management of persistence engine modules (Jesper Brouer) [854454]
- [net] ipvs: Add persistence engine data to /proc/net/ip_vs_conn (Jesper Brouer) [854454]
- [net] ipvs: Add struct ip_vs_pe (Jesper Brouer) [854454]
- [net] ipvs: Allow boot time change of hash size (Jesper Brouer) [854454]
- [net] ipvs: ip_vs_bind_scheduler and ip_vs_unbind_scheduler NULL arguments (Jesper Brouer) [854454]
- [net] ipvs: Allow null argument to ip_vs_scheduler_put() (Jesper Brouer) [854454]
- [net] ipvs: fix matching of fwmark templates during scheduling (Jesper Brouer) [854454]
- [net] ipvs: Add struct ip_vs_conn_param (Jesper Brouer) [854454]
- [net] ipvs: compact ip_vs_sched_persist() (Jesper Brouer) [854454]
- [net] ipvs: extend connection flags to 32 bits (Jesper Brouer) [854454]
- [net] nf_conntrack_sip: Add callid parser (Jesper Brouer) [854454]
- [net] nf_conntrack_sip: Allow ct_sip_get_header() to be called with a null ct argument (Jesper Brouer) [854454]
- [net] ipvs: fix synchronization on connection close (Jesper Brouer) [854454]
- [net] ipvs: one-packet scheduling (Jesper Brouer) [854454]

* Wed Jul 31 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-405.el6]
- [char] tty: Fix BUG() on hangup (Aaron Tomlin) [985429]
- [trace] Fix hang in write to sysprof_sample_period (Josh Poimboeuf) [959063]
- [scsi] virtio-scsi: fix LUNs greater than 255 (Laszlo Ersek) [978202]
- [scsi] isci: Fix a race condition in the SSP task management path (David Milburn) [978609]
- [idle] intel_idle: initial C8, C9 and C10 support (Jane Lv) [970729]
- [x86] Fix up numa_node information for AMD CPU family 15h model 0-0fh northbridge functions (Prarit Bhargava) [787034]
- [x86] tsc: add option to output TSC initial value at boot (Prarit Bhargava) [986353]
- [fs] fscache: The retrieval remaining-pages counter needs to be atomic_t (David Howells) [965759]
- [fs] cachefiles: remove unused macro list_to_page() (David Howells) [921178]
- [fs] fscache: Simplify cookie retention for fscache_objects, fixing access problems (David Howells) [928746]
- [fs] fscache: Fix object state machine to have separate work and wait states (David Howells) [921178]
- [kernel] wait: Add wait_on_atomic_t() and wake_up_atomic_t() (David Howells) [921178]
- [fs] fscache: Wrap checks on object state (David Howells) [921178]
- [fs] fscache: Uninline fscache_object_init() (David Howells) [921178]
- [fs] fscache: Don't sleep in page release if __GFP_FS is not set (David Howells) [921178]
- [fs] cachefiles: name i_mutex lock class explicitly (David Howells) [921178]
- [fs] fscache: remove spin_lock() from the condition in while() (David Howells) [921178]
- [fs] fscache: Clear remaining page count on retrieval cancellation (David Howells) [921178]
- [fs] fscache: Mark cancellation of in-progress operation (David Howells) [921178]
- [fs] fscache: Remove unneeded null checks (David Howells) [921178]
- [fs] fscache: One of the write operation paths doesn't set the object state (David Howells) [921178]
- [fs] fscache: Fix signal handling during waits (David Howells) [921178]
- [fs] fscache: Add transition to handle invalidate immediately after lookup (David Howells) [921178 928746]
- [fs] fscache: Exclusive op submission can BUG if there's been an I/O error (David Howells) [921178]
- [fs] fsache: Limit the number of I/O error reports for a cache (David Howells) [921178]
- [fs] fscache: Don't mask off the object event mask when printing it (David Howells) [921178]
- [fs] fscache: Initialise the object event mask with the calculated mask (David Howells) [921178]
- [fs] cachefiles: Add missing retrieval completions (David Howells) [921178]
- [fs] cachefiles: add support for large files in filesystem caching (David Howells) [921178]
- [netdrv] igbvf: Make next_to_watch a pointer and adjust memory barriers to avoid races (Stefan Assmann) [923900]
- [netdrv] igbvf: update version number (Stefan Assmann) [923900]
- [netdrv] igbvf: Check for error on dma_map_single call (Stefan Assmann) [923900]
- [netdrv] enic: release rtnl_lock on error-path (Stefan Assmann) [922984]
- [netdrv] enic: change sprintf() to snprintf() (Stefan Assmann) [922984]
- [netdrv] enic: be less verbose about non-critical firmware errors (Stefan Assmann) [922984]
- [netdrv] enic: fix up function prototypes after __dev* removals (Stefan Assmann) [922984]
- [pci] Remove the obsolete no_pci_devices() check (Myron Stowe) [966887]
- [pci] Use pci_device_id on stack for pci_get_subsys/class() to avoid kmalloc (Myron Stowe) [966887]
- [netdrv] bonding: properly unset current_arp_slave on slave link up (Veaceslav Falico) [988460]
- [firmware] add bnx2x FW 7.8.2, 7.8.17 (Michal Schmidt) [825729 828818 915420 915422 919510]
- [netdrv] bnx2x: ignore unknown ethtool flags (Michal Schmidt) [915517 928435]
- [netdrv] bnx2x: advertise transmit time stamping (Michal Schmidt) [825729 828818 914797 915420 915422 915517 919510]
- [netdrv] bnx2x: add transmit timestamping support (Michal Schmidt) [825729 828818 914797 915420 915422 915517 919510]
- [netdrv] bnx2x: Remove sparse and coccinelle warnings (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix 20G KR2 support claims (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: improve VF timings (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: VF ndo sanity (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix compilation with no IOV support (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Improve PF behaviour toward VF (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: remove redundant D0 power state set (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: replace mechanism to check for next available packet (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix a power state test (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: semi-Semantic changes (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Revise prints (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Semantic removal and beautification (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Revise comments and alignment (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Semantic change of empty lines (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: use XPS if possible for bnx2x_select_queue instead of pure hash (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Change to D3hot only on removal (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Implement PCI shutdown (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Count number of possible FCoE interfaces (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Ack unknown VF messages (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add and correct PCI link speed prints (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Zero VFs starting MACs (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Enable `set_phys_id' for all functions (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Wait for MCP validity during AER (Michal Schmidt) [825729 828818 915420 915422 915517 919510 921799]
- [netdrv] bnx2x: Link-flap avoidance in switch dependent mode (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add Private Flags Support (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix bridged GSO for 57710/57711 chips (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix TCP offload for tunneling ipv4 over ipv6 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix GSO for 57710/57711 chips (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Prevent memory leak when cnic is absent (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: correct reading of speed capabilities (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Prevent NULL pointer dereference in kdump (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Use per port max exchange resources (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Allow recovery from second slot reset (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix memory leak (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Enhance MAC configuration for VFs (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Allow RX/TX pause control in autoneg (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: prevent GRO false checksum claims (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: update version to 1.78.17-0 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: add additional regions for CRC memory test (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: remove non-necessary assignment (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix byte-by-byte nvram write for BE machines (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: refactor nvram read procedure (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Cosmetic changes (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support reading I2C EEPROM SFF8472 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix compilation without CONFIG_BNX2X_SRIOV (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Prevent VF race (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix VF outer vlan removal (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix VF statistics (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: missing ARI should not be lethal (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix AER semaphore release (Michal Schmidt) [825729 828818 915420 915422 915517 919510 921799]
- [netdrv] bnx2x: AER revised (Michal Schmidt) [825729 828818 915420 915422 915517 919510 921799]
- [netdrv] bnx2x: add RSS capability for GRE traffic (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: dma_alloc_coherent: use __GFP_ZERO instead of memset() (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: use list_move instead of list_del/list_add (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Restore FCoE 4-port devices support (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: use FW 7.8.17 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Avoid using zero MAC (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Control SFP+ tap values via nvm config (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add EEE support for BCM84834 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add RJ45 SFP module detection (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Get gso_segs from FW (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Control number of vfs dynamically (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add iproute2 support for vfs (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Prevent "Unknown MF" print in SF mode (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Take chip version from MFW (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Set ethtool ops for vfs (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix vlan-mac memory leak (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: use the default NAPI weight (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix typo in printk and comments (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix status blocks configuration (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Prevent UNDI FW illegal host access (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Prevent null pointer dereference in AFEX mode (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix KR2 rapid link flap (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix assignment of signed expression to unsigned variable (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix occasional statistics off-by-4GB error (Michal Schmidt) [825729 828818 871164 915420 915422 915517 919510]
- [netdrv] bnx2x: add missing napi deletion in error path (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix SFP+ misconfiguration in iSCSI boot scenario (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix intermittent long KR2 link up time (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix KR2 work-around condition (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix KR2 link (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix port identification for the 84834 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix UDP checksum for 57710/57711 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: remove dead code and make local funcs static (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Replace incomming with incoming in all comments and strings (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] cnic: Remove unnecessary alloc/OOM messages, alloc cleanups (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Force link UP when the interface is in LOOPBACK mode (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: SR-IOV version compatibility bugfix (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix compilation with stop-on-error (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add CNIC_DRV_STATE_HANDLES_IRQ to ethdev->drv_state (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: correct memory release scheme (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Remove many sparse warnings (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Modify unload conditions (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Correct memory preparation and release (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add missing VFs reference in macros (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add additional debug information (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: correct usleep_range usage (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: reorganization and beautification (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Semantic renovation (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix GRO parameters (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Introduce 2013 and advance version to 1.78.02 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Added FW GRO bridging support (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] Revert "bnx2x: set gso_type" (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Clean previous IGU status before ack (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: improve stop-on-error (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: add `ethtool -w' support (Michal Schmidt) [825729 828818 915420 915422 915517 919510 921560]
- [netdrv] bnx2x: Added nvram personalities support (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix rare self-test failures (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: use SAN Mac for FCoE (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add an additional fatal hw assertion - BRB_HW_INTERRUPT (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Clear dirty status when booting after UNDI (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Allow management traffic after boot from SAN (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix fastpath structures when memory allocation fails (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: move debugging code before the return (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: align define usage to satisfy static checkers (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: NULL dereference on error in debug code (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Segregate SR-IOV code (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add VF device ids and enable feature (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support PF <-> VF Bulletin Board (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support VF FLR (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support of PF driver of a VF release request (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support of PF driver of a VF close request (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support of PF driver of a VF q_teardown request (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support of PF driver of a VF q_filters request (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support of PF driver of a VF setup_q request (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support statistics collection for VFs by the PF (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support of PF driver of a VF init request (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support of PF driver of a VF acquire request (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Infrastructure for VF <-> PF request on PF side (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Prepare device and initialize VF database (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Allocate VF database in PF when VFs are present (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: VF fastpath (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support ndo_set_rxmode in VF driver (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add teardown_q and close to VF <-> PF channel (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add init, setup_q, set_mac to VF <-> PF channel (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Separate VF and PF logic (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add to VF <-> PF channel the release request (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: VF <-> PF channel 'acquire' at vf probe (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support probing and removing of VF device (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: use ARRAY_SIZE where possible (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: use prandom_bytes() (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix typo of "suport" (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: almost 'use netdev_alloc_frag()' (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix up function prototypes after __dev* removals (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Simplify cnic probing (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: add fw defs for use in cnic (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] cnic, bnx2x, bnx2: Simplify cnic probing (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] cnic: Include bnx2x.h (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2: Add BNX2 prefix to CHIP ID and name macros (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2: Add BNX2 prefix to descriptor structures and macros (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] cnic: Fix rare race condition during iSCSI disconnect (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] cnic: Reset iSCSI EQ during shutdown (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: remove __dev* attributes (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] cnic: remove __dev* attributes (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: recognize fan failure (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Correct PFC disablement (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix 'Ethtool -A' when autoneg (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: prevent DCB if disabled in nvram (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Handle a rarely missed interrupt (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: mask CPL_OF interrupt (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: IGU parse error cause probe failure (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Ext config accessed only on non-E1x (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: nvram enables dropless flow control (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Correct advertised speed/duplex (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Filter packets on FCoE rings (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Management can control PFC/ETS (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: parity recovery flow enhancement (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: revised and corrected SPIO access (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Change duplex setting in EEE function (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add warning message in case of non-10G SFP module (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Cosmetic changes (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Always take PHY lock (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add support for BCM84834 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix SFP+ current leakage (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add support for 20G-KR2 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Remove duplicate inclusion of bnx2x_hsi.h (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Add static declaration to several functions (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Fix typo in bnx2x driver (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix HW initialization using fw 7.8.x (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Support loading cnic resources at run-time (Michal Schmidt) [825729 828818 915420 915422 915517 919510 920624]
- [netdrv] bnx2x: HSI change for 'update' ramrod (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: update version to 1.78.00-0 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x,cnic: use FW 7.8.2 (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: Improve code around bnx2x_tests_str_arr (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [netdrv] bnx2x: fix comment/printk/variable typos (Michal Schmidt) [825729 828818 915420 915422 915517 919510]
- [net] In unregister_netdevice_notifier unregister the netdevices (Michal Schmidt) [987451]
- [net] introduce NAPI_POLL_WEIGHT (Michal Schmidt) [987451]
- [net] Export __netdev_pick_tx so that it can be used in modules (Michal Schmidt) [987451]
- [net] Split core bits of netdev_pick_tx into __netdev_pick_tx (Michal Schmidt) [987451]
- [net] netpoll: call ->ndo_select_queue() in tx path (Michal Schmidt) [987451]
- [lib] introduce prandom_bytes() and prandom_bytes_state() (Michal Schmidt) [987451]

* Tue Jul 30 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-404.el6]
- [pci] pcie: Reset link for devices below Root Port or Downstream Port (Myron Stowe) [966755]
- [acpi] apei: Force fatal AER severity when component has been reset (Myron Stowe) [966755]
- [pci] Remove "extern" from function declarations (Myron Stowe) [966755]
- [pci] pcie: Move AER severity defines to aer.h (Myron Stowe) [966755]
- [pci] pcie: Set dev->__aer_firmware_first only for matching devices (Myron Stowe) [966755]
- [pci] pcie: Factor out HEST device type matching (Myron Stowe) [966755]
- [pci] pcie: Don't parse HEST table for non-PCIe devices (Myron Stowe) [966755]
- [acpi] Move cper_print_aer() call out of interrupt context (Myron Stowe) [967981]
- [pci] pcie: Remove local PCI_BUS() define and use PCI_BUS_NUM() from PCI (Myron Stowe) [967981]
- [pci] Add PCI_BUS_NUM() and PCI_DEVID() interfaces (Myron Stowe) [967981]
- [pci] pcie: pci_get_domain_bus_and_slot() call missing required pci_dev_put() (Myron Stowe) [911740]
- [pci] pcie: Report success only when every device has AER-aware driver (Myron Stowe) [911740]
- [pci] Fix deadlock when unbinding device if parent in D3cold (Myron Stowe) [911740]
- [pci] Make pci_error_handlers const (Myron Stowe) [911740]
- [pci] pcie: Remove the port driver module exit routine (Myron Stowe) [911740]
- [acpi] apei: Add missed ACPI5 support for error trigger table (Myron Stowe) [893388]
- [acpi] apei: fix error status check condition for CPER (Myron Stowe) [825641]
- [edac] add support for error type "Info" (Myron Stowe) [825641]
- [pci] pcie: Cleanup log output for AER (Myron Stowe) [825641]
- [acpi] apei: Enhanced AER logging (Myron Stowe) [825641]
- [trace] Trace Event for PCI Express Advanced Error Reporting (Myron Stowe) [825641]
- [acpi] edac.h: Add generic layers for describing a memory location (Myron Stowe) [825641]
- [acpi] CPER failed to handle generic error records with multiple sections (Myron Stowe) [816520]
- [acpi] APEI build fix (Myron Stowe) [816520]
- [acpi] apei: Fix crash in apei_hest_parse() for acpi=off (Myron Stowe) [816515]
- [acpi] apei: Fixup incorrect 64-bit access width firmware bug (Myron Stowe) [816515]
- [acpi] apei: Fix ERST header length check (Myron Stowe) [816515]
- [acpi] apei: Remove table not found message (Myron Stowe) [816515]
- [pci] Print completion message at KERN_INFO to match starting message (Myron Stowe) [736984]
- [acpi] Add PCIe AER recovery support (Myron Stowe) [736984]
- [pci] pcie: add aer_recover_queue (Myron Stowe) [736984]
- [netdrv] be2net: fix VLAN traffic if no VLAN group is registered (Stefan Assmann) [980772]
- [wireless] brcmsmac: Reduce log spam in heavy tx, make err print in debug (John Green) [960977]
- [watchdog] hpwdt: Increase version string (Linda Knippers) [985144]
- [watchdog] hpwdt: Add check for UEFI bits (Linda Knippers) [985144]
- [netdrv] be2net: Fix to avoid hardware workaround when not needed (Ivan Vecera) [947543]
- [netdrv] be2net: use pci_vfs_assigned()/pci_num_vf() instead of be_find_vfs() (Ivan Vecera) [947543]
- [netdrv] be2net: Fix 32-bit DMA Mask handling (Ivan Vecera) [947543]
- [netdrv] be2net: Implement initiate FW dump feature for Lancer (Ivan Vecera) [947543]
- [netdrv] be2net: Fix crash on 2nd invocation of PCI AER/EEH error_detected hook (Ivan Vecera) [947543]
- [netdrv] be2net: Mark checksum fail for IP fragmented packets (Ivan Vecera) [947543]
- [netdrv] be2net: Trim padded packets for Lancer (Ivan Vecera) [947543]
- [netdrv] be2net: Pad skb to meet min Tx pkt size in lancer (Ivan Vecera) [947543]
- [netdrv] be2net: cleanup be_get_drvinfo() (Ivan Vecera) [947543]
- [netdrv] be2net: refactor HW workarounds in be_xmit() (Ivan Vecera) [947543]
- [netdrv] be2net: bug fix on returning an invalid nic descriptor (Ivan Vecera) [947543]
- [netdrv] be2net: Avoid double insertion of vlan tags (Ivan Vecera) [947543]
- [netdrv] be2net: disable TX in be_close() (Ivan Vecera) [947543]
- [netdrv] be2net: fix EQ from getting full while cleaning RX CQ (Ivan Vecera) [947543]
- [netdrv] be2net: fix payload_len value for GET_MAC_LIST cmd req (Ivan Vecera) [947543]
- [netdrv] be2net: provision VF resources before enabling SR-IOV (Ivan Vecera) [947543]
- [netdrv] be2net: Fix to fail probe if MSI-X enable fails for a VF (Ivan Vecera) [947543]
- [netdrv] be2net: avoid napi_disable() when it has not been enabled (Ivan Vecera) [947543]
- [netdrv] be2net: Fix firmware download for Lancer (Ivan Vecera) [947543]
- [netdrv] be2net: Fix to receive Multicast Packets when Promiscuous mode is enabled on certain devices (Ivan Vecera) [947543]
- [netdrv] be2net: Fix to show tx priority pause counter in ethtool -S (Ivan Vecera) [947543]
- [netdrv] be2net: Fix to use 32-bit stats to report rx_drops_no_fragment (Ivan Vecera) [947543]
- [netdrv] be2net: Fix to use version 2 of cq_create for SkyHawk-R devices (Ivan Vecera) [947543]
- [netdrv] be2net: FLR must be first cmd issued to Lancer FW (Ivan Vecera) [947543]
- [netdrv] be2net: Use GET_FUNCTION_CONFIG V1 cmd (Ivan Vecera) [947543]
- [netdrv] be2net: Fix to show wol disabled/enabled state correctly (Ivan Vecera) [947543]
- [netdrv] be2net: Fixed memory leak (Ivan Vecera) [947543]
- [netdrv] be2net: Avoid diagnostic test in certain versions of firmware to avoid NIC freeze (Ivan Vecera) [947543]
- [netdrv] be2net: Renamed rx_address_mismatch_errors to rx_address_filtered (Ivan Vecera) [947543]
- [netdrv] be2net: Add support for setting and getting rx flow hash options (Ivan Vecera) [947543]
- [netdrv] be2net: Fix PVID tag offload for packets with inline VLAN tag (Ivan Vecera) [947543]
- [netdrv] be2net: fix a Tx stall bug caused by a specific ipv6 packet (Ivan Vecera) [947543]
- [netdrv] be2net: Remove an incorrect pvid check in Tx (Ivan Vecera) [947543]
- [netdrv] be2net: enable IOMMU pass through for be2net (Ivan Vecera) [819453 947543]
- [netdrv] be2net: Use GET_PROFILE_CONFIG V1 cmd for BE3-R (Ivan Vecera) [947543]
- [netdrv] be2net: Avoid flashing BE3 UFI on BE3-R chip (Ivan Vecera) [947543]
- [netdrv] be2net: Don't log "Out of MCCQ wrbs" error (Ivan Vecera) [947543]
- [netdrv] be2net: Use TXQ_CREATE_V2 cmd (Ivan Vecera) [947543]
- [netdrv] be2net: take care of __vlan_put_tag return value (Ivan Vecera) [947543]
- [netdrv] be2net: remove unused variable 'sge' (Ivan Vecera) [947543]
- [netdrv] be2net: dma_alloc_coherent: use __GFP_ZERO instead of memset() (Ivan Vecera) [947543]
- [netdrv] be2net: Remove dma_alloc_coherent OOM messages (Ivan Vecera) [947543]
- [netdrv] be2net: Use new F/W mailbox cmd to manipulate interrupts (Ivan Vecera) [947543]
- [netdrv] be2net: enable interrupts in be_probe() (RoCE and other ULPs need them) (Ivan Vecera) [947543]
- [netdrv] be2net: Update copyright year (Ivan Vecera) [947543]
- [netdrv] be2net: use CSR-BAR SEMAPHORE reg for BE2/BE3 (Ivan Vecera) [947543]
- [netdrv] benet: Wait f/w POST until timeout (Ivan Vecera) [947543]
- [netdrv] be2net: update driver version to 4.6.x (Ivan Vecera) [947543]
- [netdrv] be2net: fix re-loaded PF driver to re-gain control of its VFs (Ivan Vecera) [947543]
- [netdrv] be2net: Updating Module Author string and log message string to "Emulex Corporation" (Ivan Vecera) [947543]
- [netdrv] be2net: fix drvinfo strings set in drivers (Ivan Vecera) [947543]
- [netdrv] be2net: Remove bogus dependencies on INET (Ivan Vecera) [947543]
- [netdrv] be2net: remove adapter->eq_next_idx (Ivan Vecera) [947543]
- [netdrv] be2net: remove roce on lancer (Ivan Vecera) [947543]
- [netdrv] be2net: fix access to SEMAPHORE reg (Ivan Vecera) [947543]
- [netdrv] be2net: re-factor bar mapping code (Ivan Vecera) [947543]
- [netdrv] be2net: do not use sli_family to identify skyhawk-R chip (Ivan Vecera) [947543]
- [netdrv] be2net: fix wrong usage of adapter->generation (Ivan Vecera) [947543]
- [netdrv] be2net: remove LANCER A0 workaround (Ivan Vecera) [947543]
- [netdrv] be2net: Fix smatch warnings in be_main.c (Ivan Vecera) [947543]
- [netdrv] be2net: fix wrong frag_idx reported by RX CQ (Ivan Vecera) [947543]
- [netdrv] benet: convert to set_phys_id (Ivan Vecera) [947543]
- [virt] hv: allocate synic structures before hv_synic_init() (Jason Wang) [927359]
- [virt] hv: check interrupt mask before read_index (Jason Wang) [927359]
- [virt] hv: switch to use mb() instead of smp_mb() (Jason Wang) [927359]
- [virt] hv: vmbus: Implement multi-channel support (Jason Wang) [927359]
- [virt] hv: Fix a bug in get_vp_index() (Jason Wang) [927359]
- [virt] hyperv_fb: Backport to RHEL 6.5 (Jason Wang) [927424]
- [virt] add Hyper-V Synthetic Video Frame Buffer Driver (Jason Wang) [927424]
- [virt] hv: Add a new driver to support host initiated backup (Jason Wang) [927409]
- [netdrv] hyperv: Fix a compiler warning in netvsc_send() (Jason Wang) [927435]
- [netdrv] hyperv: Fix RNDIS send_completion code path (Jason Wang) [927435]
- [netdrv] hyperv: Fix a kernel warning from netvsc_linkstatus_callback() (Jason Wang) [927435]
- [netdrv] hyperv: fix wrong length of mac address (Jason Wang) [927435]
- [netdrv] hyperv: Add an error message to rndis_filter_set_device_mac() (Jason Wang) [927435]
- [netdrv] hyperv: Remove unnecessary comments in rndis_filter_receive_data() (Jason Wang) [927435]
- [netdrv] hyperv: Add buffer for extended info after the RNDIS response message (Jason Wang) [927435]
- [netdrv] hyperv: Report actual status in receive completion packet (Jason Wang) [927435]
- [netdrv] hyperv: Remove extra allocated space for recv_pkt_list elements (Jason Wang) [927435]
- [netdrv] hyperv: Fix page buffer handling in rndis_filter_send_request() (Jason Wang) [927435]
- [netdrv] hyperv: Fix the missing return value in rndis_filter_set_packet_filter() (Jason Wang) [927435]
- [netdrv] hyperv: Fix the max_xfer_size in RNDIS initialization (Jason Wang) [927435]
- [virt] hyperv/hv_balloon: remove old RHEL6 specific code (Jason Wang) [927417]
- [virt] hyperv/balloon: Notify the host of permanent hot-add failures (Jason Wang) [927417]
- [virt] hyperv/balloon: Support 2M page allocations for ballooning (Jason Wang) [927417]
- [mm] page_alloc: export split_page() (Jason Wang) [927417]
- [virt] hyperv/balloon: Permit Linux to specify hot-add alignment requirements (Jason Wang) [927417]
- [virt] hyperv/balloon: make local functions static (Jason Wang) [927417]
- [virt] hyperv/balloon: Implement hot-add functionality (Jason Wang) [927417]
- [mm] memory_hotplug: extend memory hotplug API to allow memory hotplug in virtual machines (Jason Wang) [927417]
- [virt] hyperv/balloon: Make the balloon driver not unloadable (Jason Wang) [927417]
- [virt] hyperv/balloon: Execute hot-add code in a separate context (Jason Wang) [927417]
- [virt] hyperv/balloon: Execute balloon inflation in a separate context (Jason Wang) [927417]
- [virt] hyperv/balloon: Do not request completion notification (Jason Wang) [927417]
- [fcoe] libfc: extend ex_lock to protect all of fc_seq_send (Neil Horman) [829784]
- [fcoe] libfc: Correct check for initiator role (Neil Horman) [829784]
- [fcoe] libfcoe: Fix fcoe_sysfs VN2VN mode (Neil Horman) [829784]
- [fcoe] Split fc_disc_init into fc_disc_init and fc_disc_config (Neil Horman) [829784]
- [fcoe] Always use fcoe_disc_init for discovery layer initialization (Neil Horman) [829784]
- [fcoe] Fix deadlock between create and destroy paths (Neil Horman) [829784]
- [fcoe] libfcoe: Fix Conflicting FCFs issue in the fabric (Neil Horman) [829784]
- [fcoe] Revert "fcoe: fix fcoe enable on link toggle while it is still disabled" (Neil Horman) [829784]
- [fcoe] libfcoe: Check for unusable FCFs before looking for conflicting FCFs (Neil Horman) [829784]
- [fcoe] libfcoe: Handle CVL while waiting to select an FCF (Neil Horman) [829784]
- [fcoe] Fix deadlock while deleting FCoE interface with NPIV ports (Neil Horman) [829784]
- [fcoe] close race on link speed detection in fcoe code (Neil Horman) [829784]
- [fcoe] debris left by "libfcoe: Remove mutex_trylock/restart_syscall checks" (Neil Horman) [829784]
- [fcoe] consolidate the fcoe_ctlr_get_lesb/fcoe_get_lesb (Neil Horman) [829784]
- [fcoe] move fcoe_link_speed_update() to libfcoe and export it (Neil Horman) [829784]
- [fcoe] add support to the get_netdev() for fcoe_interface (Neil Horman) [829784]
- [fcoe] prep work to start consolidate the usage of fcoe_netdev (Neil Horman) [829784]
- [fcoe] Convert debug_logging macros to pr_info (Neil Horman) [829784]
- [fcoe] Use the fcoe_sysfs control interface (Neil Horman) [829784]
- [fcoe] libfcoe: Add new fcoe control interface (Neil Horman) [829784]
- [fcoe] libfcoe: Save some memory and optimize name lookups (Neil Horman) [829784]
- [fcoe] libfcoe: Add fcoe_sysfs debug logging level (Neil Horman) [829784]
- [fcoe] Cleanup locking on fcoe_percpu_receive_thread (Neil Horman) [829784]
- [fcoe] libfcoe: Fix section mismatch (Neil Horman) [829784]
- [fcoe] bnx2fc: cleanup fcoe_dev_stats (Neil Horman) [829784]
- [fcoe] libfcoe: SW FCoE and bnx2fc use FCoE Syfs (Neil Horman) [829784]
- [fcoe] libfcoe: Add fcoe_sysfs (Neil Horman) [829784]
- [powerpc] iommu: Fix multiple issues with IOMMU pools code (Steve Best) [929290]
- [powerpc] iommu: Fix iommu pool initialization (Steve Best) [929290]
- [powerpc] iommu: Implement IOMMU pools to improve multiqueue adapter performance (Steve Best) [929290]
- [powerpc] iommu: Push spinlock into iommu_range_alloc and __iommu_free (Steve Best) [929290]
- [powerpc] iommu: Reduce spinlock coverage in iommu_free (Steve Best) [929290]
- [powerpc] iommu: Reduce spinlock coverage in iommu_alloc and iommu_free (Steve Best) [929290]
- [powerpc] pseries: Disable interrupts around IOMMU percpu data accesses (Steve Best) [929290]
- [block] rsxx: Adding in debugfs entries (Steve Best) [929277]
- [block] rsxx: Fixes incorrect stats calculation (Steve Best) [929277]
- [block] rsxx: Adding EEH check inside cregs timeout (Steve Best) [929277]
- [block] rsxx: Adapter address space sanity check (Steve Best) [929277]
- [block] rsxx: Fixes DLPAR add kernel panic if partition still mounted (Steve Best) [929277]
- [block] rsxx: Changing the adapter name to the official name (Steve Best) [929277]
- [block] rsxx: Adding in sync_start module paramenter (Steve Best) [929277]
- [block] rsxx: Allow block size to be determined by configuration (Steve Best) [929277]
- [block] rsxx: Fixes soft-lockup issues during DMAs (Steve Best) [929277]
- [block] rsxx: Restructured DMA cancel scheme (Steve Best) [929277]
- [block] rsxx: Individual workqueues for interruptible events (Steve Best) [929277]
- [block] rsxx: remove unused variable (Steve Best) [929277]
- [block] rsxx: enable error return of rsxx_eeh_save_issued_dmas() (Steve Best) [929277]
- [block] rsxx: removes dynamic allocation on stack (Steve Best) [929277]
- [block] rsxx: fix missing unlock on error return in rsxx_eeh_remap_dmas() (Steve Best) [929277]
- [block] rsxx: Adding in EEH support to the IBM FlashSystem 70/80 device driver (Steve Best) [929277]
- [block] rsxx: IBM RamSan 70/80 error message bug fix (Steve Best) [929277]
- [block] rsxx: IBM RamSan 70/80 branding changes (Steve Best) [929277]
- [block] rsxx: IBM RamSan 70/80 fixes inconsistent locking (Steve Best) [929277]
- [block] rsxx: IBM RamSan 70/80 trivial changes (Steve Best) [929277]
- [block] rsxx: IBM RamSan 70/80 driver fixes (Steve Best) [929277]
- [block] rsxx: add slab.h include to dma.c (Steve Best) [929277]
- [block] rsxx: IBM RamSan 70/80 device driver (Steve Best) [929277]
- [target] target/file: Fix off-by-one READ_CAPACITY bug for !S_ISBLK export (Andy Grover) [982777]
- [target] Re-instate sess_wait_list for target_wait_for_sess_cmds (Andy Grover) [982777]
- [target] close target_put_sess_cmd() vs. core_tmr_abort_task() race (Andy Grover) [982777]
- [target] iblock: Fix WCE=1 + DPOFUA=1 backend WRITE regression (Andy Grover) [982777]
- [target] Use FD_MAX_SECTORS/FD_BLOCKSIZE for blockdevs using fileio (Andy Grover) [982777]
- [target] tcm_fc: Check for aborted sequence (Andy Grover) [982777]
- [target] Change default sense key of NOT_READY (Andy Grover) [982777]

* Mon Jul 29 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-403.el6]
- [netdrv] qlcnic: Bump up the version to 5.1.38 (Chad Dupuis) [694104]
- [netdrv] qlcnic: Clear link status when interface is down (Chad Dupuis) [694104]
- [netdrv] qlcnic: change mdelay to msleep (Chad Dupuis) [694104]
- [netdrv] qlcnic: Log warning message for 83xx adapter in MSI mode (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix configure mailbox interrupt command for 83xx adapter (Chad Dupuis) [694104]
- [netdrv] qlcnic: Bump up the version to 5.1.37 (Chad Dupuis) [694104]
- [netdrv] qlcnic: Implement flash sysfs callback for 83xx adapter (Chad Dupuis) [694104]
- [netdrv] qlcnic: remove duplicated include from qlcnic_sysfs.c (Chad Dupuis) [694104]
- [netdrv] qlcnic: Bump up the version to 5.1.36 (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix ethtool statistics collection (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix ethtool statistics for 82xx adapter (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix endian issues in 83xx driver (Chad Dupuis) [694104]
- [netdrv] qlcnic: Bump up the version to 5.1.35 (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix configure interrupts for 83xx adapter types (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix internal loopback test for 82xx adapter (Chad Dupuis) [694104]
- [netdrv] qlcnic: Bump up the version to 5.1.34 (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix ping resumption to a VM after a live migration (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix estimation of receive MSS in case of LRO for 83xx adapter (Chad Dupuis) [694104]
- [netdrv] qlcnic: refactor Legacy interrupt handling for 83xx (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix mailbox interrupt (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix unsupported CDRP command error message (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix mailbox response handling (Chad Dupuis) [694104]
- [netdrv] qlcnic: enhance MSIX allocation failure log message (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix async event handling during diagnostic loopback test (Chad Dupuis) [694104]
- [netdrv] qlcnic: refactor 83xx diagnostic IRQ test (Chad Dupuis) [694104]
- [netdrv] qlcnic: refactor 83xx diagnostic loopback test (Chad Dupuis) [694104]
- [netdrv] qlcnic: helper routine to handle async events (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix firmware based IDC participation (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix initialize NIC mailbox command (Chad Dupuis) [694104]
- [netdrv] qlcnic: Updating copyright information (Chad Dupuis) [694104]
- [netdrv] qlcnic: silence false positive overflow warning (Chad Dupuis) [694104]
- [netdrv] qlcnic: Bump up the version to 5.1.33 (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix minidump in NPAR mode (Chad Dupuis) [694104]
- [netdrv] qlcnic: driver LRO bug fix (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix bug in reading HW reset template (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix sparse check endian warnings (Chad Dupuis) [694104]
- [netdrv] qlcnic: Bump up the version to 5.1.32 (Chad Dupuis) [694104]
- [netdrv] qlcnic: sleeping function called from invalid context (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix LED/Beaconing tests to work on all ports of an adapter (Chad Dupuis) [694104]
- [netdrv] qlcnic: avoid mixed mode interrupts for some adapter types (Chad Dupuis) [694104]
- [netdrv] qlcnic: enable RSS for TCP over IPv6 (Chad Dupuis) [694104]
- [netdrv] qlcnic: enable LRO on IPv6 without dest ip check (Chad Dupuis) [694104]
- [netdrv] qlcnic: set driver version in firmware (Chad Dupuis) [694104]
- [netdrv] qlcnic: guard __vlan_find_dev_deep() by rcu_read_lock (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix build error (Chad Dupuis) [694104]
- [netdrv] qlcnic: do not duplicate infrastructure functions (Chad Dupuis) [694104]
- [netdrv] qlcnic: update driver version (Chad Dupuis) [694104]
- [netdrv] qlcnic: remove unused definitions from header file (Chad Dupuis) [694104]
- [netdrv] qlcnic: 83xx ethtool interface routines (Chad Dupuis) [694104]
- [netdrv] qlcnic: 83xx register dump routines (Chad Dupuis) [694104]
- [netdrv] qlcnic: enable 83xx virtual NIC mode (Chad Dupuis) [694104]
- [netdrv] qlcnic: flash template based firmware reset recovery (Chad Dupuis) [694104]
- [netdrv] qlcnic: 83xx CNA inter driver communication mechanism (Chad Dupuis) [694104]
- [netdrv] qlcnic: 83xx adpater flash interface routines (Chad Dupuis) [694104]
- [netdrv] qlcnic: 83xx sysfs routines (Chad Dupuis) [694104]
- [netdrv] qlcnic: 83xx base driver (Chad Dupuis) [694104]
- [netdrv] qlcnic: 83xx data path routines (Chad Dupuis) [694104]
- [netdrv] qlcnic: 83xx memory map and HW access routines (Chad Dupuis) [694104]
- [netdrv] qlcnic: macros for common register access (Chad Dupuis) [694104]
- [netdrv] qlcnic: change driver hardware interface mechanism (Chad Dupuis) [694104]
- [netdrv] qlcnic: update driver version (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix unused variable warnings (Chad Dupuis) [694104]
- [netdrv] qlcnic: rename module params with module_param_named (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix bug in LRO descriptor access macro (Chad Dupuis) [694104]
- [netdrv] qlcnic: update NIC partition interface routines (Chad Dupuis) [694104]
- [netdrv] qlcnic: get board name API (Chad Dupuis) [694104]
- [netdrv] qlcnic: modify PCI and register access routines (Chad Dupuis) [694104]
- [netdrv] qlcnic: move HW specific data to seperate structure (Chad Dupuis) [694104]
- [netdrv] qlcnic: add 82xx adapter specific checks (Chad Dupuis) [694104]
- [netdrv] qlcnic: remove __dev* attributes (Chad Dupuis) [694104]
- [netdrv] qlcnic: remove duplicated include from qlcnic_sysfs.c (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix coding style issues in qlcnic_minidump.c (Chad Dupuis) [694104]
- [netdrv] qlcnic: create file qlcnic_minidump.c for dump utility (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix style issues in qlcnic_sysfs.c file (Chad Dupuis) [694104]
- [netdrv] qlcnic: create file qlcnic_sysfs.c for sysfs routines (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix coding style issues in qlcnic_io.c (Chad Dupuis) [694104]
- [netdrv] qlcnic: create file qlcnic_io.c for datapath routines (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix sparse check endian warnings (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix sparse warnings (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix compiler warnings (Chad Dupuis) [694104]
- [netdrv] qlcnic: fix error return code (Chad Dupuis) [694104]
- [netdrv] qlcnic: Fix scheduling while atomic bug (Chad Dupuis) [694104]
- [virt] kvm: Fix iommu map/unmap to handle memory slot moves (Alex Williamson) [978472]
- [virt] kvm: perform an invalid memslot step for gpa base change (Alex Williamson) [978472]
- [video] vgacon: add cond reschedule points in vgacon_do_font_op (Marcelo Tosatti) [971311]
- [kernel] tracing: Format non-nanosec times from tsc clock without a decimal point (Marcelo Tosatti) [911564]
- [kernel] tracing: Add a TSC trace_clock (Marcelo Tosatti) [911564]
- [perf] kvm: Initialize file_name var to fix segfault (Jiri Olsa) [977969]
- [perf] kvm: Add braces around multi-line statements (Jiri Olsa) [977969]
- [perf] kvm: Total count is a u64, print as so (Jiri Olsa) [977969]
- [perf] kvm: Remove typecast in init_kvm_event_record (Jiri Olsa) [977969]
- [perf] kvm: Only process events for vcpus of interest (Jiri Olsa) [977969]
- [perf] kvm: Fix building perf kvm on non x86 arches (Jiri Olsa) [977969]
- [perf] kvm: Rename perf_kvm to perf_kvm_stat (Jiri Olsa) [977969]
- [perf] kvm: Move global variables into a perf_kvm struct (Jiri Olsa) [977969]
- [perf] kvm: Use perf_evsel__intval (Jiri Olsa) [977969]
- [perf] kvm: Events analysis tool (Jiri Olsa) [977969]
- [perf] Check proper prev_state size for sched_switch tp (Jiri Olsa) [984006]
- [perf] Revert "perf sched: Handle PERF_RECORD_EXIT events" (Jiri Olsa) [984006]
- [perf] Fix breakage introduced by the test_attr infrastructure (Jiri Olsa) [984006]
- [block] mtip32xx: Fix compile warning (David Milburn) [927436]
- [block] mtip32xx: Workaround for unaligned writes (David Milburn) [927436]
- [block] mtip32xx: Disable TRIM support (David Milburn) [927436]
- [block] mtip32xx: fix a smatch warning (David Milburn) [927436]
- [block] mtip32xx: fix two smatch warnings (David Milburn) [927436]
- [block] mtip32xx: Add debugfs entry device_status (David Milburn) [927436]
- [block] mtip32xx: return 0 from pci probe in case of rebuild (David Milburn) [927436]
- [block] mtip32xx: recovery from command timeout (David Milburn) [927436]
- [block] mtip32xx: fix error return code in mtip_pci_probe() (David Milburn) [927436]
- [block] mtip32xx: add missing GENERIC_HARDIRQS dependency (David Milburn) [927436]
- [block] mtip32xx: fix sparse warning, symbol 'mtip_send_trim' was not declared (David Milburn) [927436]
- [block] mtip32xx: add trim support (David Milburn) [927436]
- [block] mtip32xx: fix for crash when the device surprise removed during rebuild (David Milburn) [927436]
- [block] mtip32xx: fix for driver hang after a command timeout (David Milburn) [927436]
- [block] mtip32xx: Fix padding issue (David Milburn) [927436]
- [block] mtip32xx: fix potential NULL pointer dereference in mtip_timeout_function() (David Milburn) [927436]
- [block] mtip32xx: fix shift larger than type warning (David Milburn) [927436]
- [block] mtip32xx: Fix incorrect mask used for erase mode (David Milburn) [927436]
- [block] mtip32xx: Fix to make lba address correct in big-endian systems (David Milburn) [927436]
- [block] mtip32xx: fix potential crash on SEC_ERASE_UNIT (David Milburn) [927436]
- [block] mtip32xx: Added appropriate timeout value for secure erase (David Milburn) [927436]
- [block] mtip32xx: Remove dead code (David Milburn) [927436]
- [block] mtip32xx: Change printk to pr_xxxx (David Milburn) [927436]
- [block] mtip32xx: Proper reporting of write protect status on big-endian (David Milburn) [927436]
- [block] mtip32xx: Increase timeout for standby command (David Milburn) [927436]
- [block] mtip32xx: Handle NCQ commands during the security locked state (David Milburn) [927436]
- [block] mtip32xx: Add support for new devices (David Milburn) [927436]
- [block] mtip32xx: Create debugfs entries for troubleshooting (David Milburn) [927436]
- [block] mtip32xx: Remove version.h header file inclusion (David Milburn) [927436]
- [scsi] ipr: Avoid target_destroy accessing memory after it was freed (Steve Best) [929279]
- [scsi] Handle MLQUEUE busy response in scsi_send_eh_cmnd (Steve Best) [929279]
- [scsi] ipr: SATA DVD probing failed with 64bit adapter (Steve Best) [929279]
- [scsi] ipr: Need to reset adapter after the 6th EEH error (Steve Best) [929279]
- [scsi] ipr: Need to reset adapter after the 6th EEH error (Steve Best) [929279]
- [scsi] ipr: fix addition of abort command to HRRQ free queue (Steve Best) [929279]
- [scsi] ipr: ipr_test_msi() fails when running with msi-x enabled adapter (Steve Best) [929279]
- [scsi] ipr: Fix oops while resetting an ipr adapter (Steve Best) [929279]
- [scsi] ipr: Fix sparse error in ipr driver (Steve Best) [929279]
- [scsi] ipr: Driver version 2.6.0 (Steve Best) [929279]
- [scsi] ipr: Implement block iopoll (Steve Best) [929279]
- [scsi] ipr: Reduce lock contention (Steve Best) [929279]
- [scsi] ipr: Add support for MSI-X and distributed completion (Steve Best) [929279]
- [scsi] ipr: Resource path error logging cleanup (Steve Best) [929279]
- [scsi] ipr: Handler ID memory allocation failure at module load time (Steve Best) [929279]
- [scsi] ipr: Add several new CCIN definitions for new adapters support (Steve Best) [929279]
- [scsi] storvsc: avoid usage of WRITE_SAME (Jason Wang) [969541]
- [scsi] storvsc: Handle dynamic resizing of the device (Jason Wang) [927414]
- [scsi] storvsc: Restructure error handling code on command completion (Jason Wang) [927414]
- [scsi] storvsc: Initialize the sglist (Jason Wang) [969545]
- [input] alps: add "Dolphin V1" touchpad support (Aristeu Rozanski) [837091]
- [input] alps: remove unused argument to alps_enter_command_mode() (Aristeu Rozanski) [837091]
- [input] alps: enable trackstick on Rushmore touchpads (Aristeu Rozanski) [837091]
- [input] alps: add support for "Rushmore" touchpads (Aristeu Rozanski) [837091]
- [input] alps: make the V3 packet field decoder "pluggable" (Aristeu Rozanski) [837091]
- [input] alps: move pixel and bitmap info into alps_data struct (Aristeu Rozanski) [837091]
- [input] alps: fix command mode check (Aristeu Rozanski) [837091]
- [input] alps: rework detection of Pinnacle AGx touchpads (Aristeu Rozanski) [837091]
- [input] alps: move addr_command, nibble_command settings into alps_set_defaults() (Aristeu Rozanski) [837091]
- [input] alps: use function pointers for different protocol handlers (Aristeu Rozanski) [837091]
- [input] alps: rework detection sequence (Aristeu Rozanski) [837091]
- [input] alps: introduce helper function for repeated commands (Aristeu Rozanski) [837091]
- [input] alps: move alps_get_model() down below hw_init code (Aristeu Rozanski) [837091]
- [input] alps: copy "model" info into alps_data struct (Aristeu Rozanski) [837091]
- [input] alps: fix touchpad detection when buttons are pressed (Aristeu Rozanski) [837091]
- [virt] hyperv: Handle Xen emulation of Hyper-V more gracefully (Jason Wang) [927359]
- [virt] hyperv/vmbus: Handle channel rescind message correctly (Jason Wang) [927359]
- [virt] hyperv/vmbus: Fix a bug in hv_need_to_signal() (Jason Wang) [927359]
- [virt] hyperv: remove cast for kmalloc return value (Jason Wang) [927359]
- [virt] hyperv/vmbus: Use the new infrastructure for delivering VMBUS interrupts (Jason Wang) [927359]
- [virt] hyperv: Handle Hyper-V vmbus interrupts as special hypervisor interrupts (Jason Wang) [927359]
- [virt] hyperv/hv_balloon: Prevent the host from ballooning the guest too low (Jason Wang) [927359]
- [virt] hyperv/hv_balloon: Add a parameter to delay pressure reporting (Jason Wang) [927359]
- [virt] hyperv: Execute shutdown in a thread context (Jason Wang) [927359]
- [virt] hyperv/hid-hyperv: Use consolidated GUID definitions (Jason Wang) [927359]
- [virt] hyperv/storvsc: Use the consolidated GUID definition (Jason Wang) [927359]
- [virt] hyperv/netvsc: Use the consolidated GUID definition (Jason Wang) [927359]
- [virt] hyperv: Use consolidated GUID definitions (Jason Wang) [927359]
- [virt] hyperv/vmbus: Consolidate all offer GUID definitions in hyperv.h (Jason Wang) [927359]
- [virt] hyperv: Bind all vmbbus interrupts to the boot CPU (Jason Wang) [927359]
- [virt] hyperv: vmbus_flow_handler() can be static (Jason Wang) [927359]
- [virt] hyperv/hv_balloon: Fix a bug in the definition of struct dm_info_msg (Jason Wang) [927359]
- [virt] hyperv: remove unused variable in vmbus_recvpacket_raw() (Jason Wang) [927359]
- [virt] hyperv: Cleanup and consolidate reporting of build/version info (Jason Wang) [927359]
- [virt] hyperv: Capture the host build information (Jason Wang) [927359]
- [virt] hyperv: Implement flow management on the send side (Jason Wang) [927359]
- [virt] hyperv: Enable protocol negotiation with win8 hosts (Jason Wang) [927359]
- [virt] hyperv: Add a check to deal with spurious interrupts (Jason Wang) [927359]
- [virt] hyperv: Handle vmbus interrupts concurrently on all cpus (Jason Wang) [927359]
- [virt] hyperv: Manage event tasklets on per-cpu basis (Jason Wang) [927359]
- [virt] hyperv: Get rid of unnecessary request for offers (Jason Wang) [927359]
- [virt] hyperv: Get rid of the unused global signaling state (Jason Wang) [927359]
- [virt] hyperv: Add code to distribute channel interrupt load (Jason Wang) [927359]
- [virt] hyperv: Modify the interrupt handling code to support win8 and beyond (Jason Wang) [927359]
- [virt] hyperv: Add state to manage incoming channel interrupt load (Jason Wang) [927359]
- [virt] hyperv: Setup a mapping for Hyper-V's notion cpu ID (Jason Wang) [927359]
- [virt] hyperv: Cleanup vmbus_set_event() to support win7 and beyond (Jason Wang) [927359]
- [virt] hyperv: Manage signaling state on a per-connection basis (Jason Wang) [927359]
- [virt] hyperv: Move vmbus version definitions to hyperv.h (Jason Wang) [927359]
- [virt] hyperv: Change the signature of vmbus_set_event() (Jason Wang) [927359]
- [virt] hyperv: Change the signature for hv_signal_event() (Jason Wang) [927359]
- [virt] hyperv: Save and export negotiated vmbus version (Jason Wang) [927359]
- [virt] hyperv: Extend/modify vmbus_channel_offer_channel for win7 and beyond (Jason Wang) [927359]
- [virt] hyperv: Update the ring buffer structure to match win8 functionality (Jason Wang) [927359]
- [virt] hyperv: Support handling multiple VMBUS versions (Jason Wang) [927359]
- [virt] hyperv: Get rid of hv_get_ringbuffer_interrupt_mask() (Jason Wang) [927359]
- [virt] hyperv: Optimize the signaling on the write path (Jason Wang) [927359]
- [virt] hyperv: Optimize signaling in the read path (Jason Wang) [927359]
- [virt] hyperv: Turn off batched reading for util drivers (Jason Wang) [927359]
- [virt] hyperv: Add state to manage batched reading (Jason Wang) [927359]
- [virt] hyperv: Implement routines for read side signaling optimization (Jason Wang) [927359]
- [virt] hyperv/hv_balloon: remove duplicated include from hv_balloon.c (Jason Wang) [927359]
- [virt] hyperv/hv_balloon: mark a function static (Jason Wang) [927359]
- [virt] hyperv: remove unused variable from channel_mgmt.c (Jason Wang) [927359]
- [usb] make the usbfs memory limit configurable (Gopal) [970457]
- [powerpc] PERF_EVENT_IOC_ENABLE does not reenable event (Steve Best) [986077]
- [trace] sched: Add tracepoint for accounting blocked time (Michal Schmidt) [596098]
- [kernel] kexec: export PG_hwpoison flag into vmcoreinfo (Vivek Goyal) [975267]
- [base] core: Don't remove kobjects in device_shutdown (Mateusz Guzik) [972831]
- [s390] kernel: add support for physical memory > 4TB (Hendrik Brueckner) [913220]
- [kernel] time: enable clocksource watchdog for tsc and kvm guest (Marcelo Tosatti) [873659]
- [acpi] Rework acpi_get_child() to be more efficient (Tony Camuso) [907241]
- [netdrv] pch_gbe: fix ip_summed checksum reporting on rx (Veaceslav Falico) [877556]

* Fri Jul 26 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-402.el6]
- [wireless] iwlwifi: bump required firmware API version for 3160/7260 (Stanislaw Gruszka) [842846 916050]
- [wireless] iwlwifi: adjust firmware D3 configuration API (Stanislaw Gruszka) [842846 916050]
- [wireless] iwlwifi: support BSS only (Stanislaw Gruszka) [842846 916050]
- [wireless] leds: merge net/mac80211/leds-compat.* to drivers/leds (Stanislaw Gruszka) [882300]
- [wireless] Update rndis_wlan driver to compile with new wireless stack (Stanislaw Gruszka) [882300]
- [wireless] Update at76c50x driver to compile with new wireless stack (Stanislaw Gruszka) [882300]
- [wireless] Update adm8211 driver to compile with new wireless stack (Stanislaw Gruszka) [882300]
- [wireless] Update zd1211rw driver to compile with new wireless stack (Stanislaw Gruszka) [882300]
- [wireless] Update brcmsmac driver to compile with new wireless stack (Stanislaw Gruszka) [882300]
- [wireless] Backport ti drivers from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport mwl8k driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport mac80211_hwsim driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport libertas_tf driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport orinoco driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport hostap driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport rtl818x driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport b43legacy driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport b43 driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport p54 driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport rt2x00 driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [firwmare] add htc_7010.fw and htc_9271.fw (Stanislaw Gruszka) [955782]
- [firmware] add carl9170fw (Stanislaw Gruszka) [882300]
- [wireless] Backport carl9170 driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport ath5k/ath9k drivers from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Remove iwmc3200wifi driver (Stanislaw Gruszka) [882300]
- [wireless] Backport iwlegacy driver from linux 3.10 (Stanislaw Gruszka) [882300]
- [firmware] iwlwifi: add firmware for 7260 / 3160 devices (Stanislaw Gruszka) [842847 916051]
- [wireless] Backport iwlwifi driver from linux 3.10 (Stanislaw Gruszka) [842846 882300 916050 954239]
- [net] Backport mac80211 from linux 3.10 (Stanislaw Gruszka) [882300]
- [wireless] Backport wireless core from linux 3.10 (Stanislaw Gruszka) [882300]
- [net] export unregister_netdevice_many symbol (Stanislaw Gruszka) [882300]
- [kernel] driver core: add module_platform_driver (Stanislaw Gruszka) [882300]
- [pcmcia] introduce helper for pcmcia_driver module boilerplate (Stanislaw Gruszka) [882300]
- [net] add GENLMSG_DEFAULT_SIZE to RHEL6 (Stanislaw Gruszka) [882300]
- [fs] procfs: add PDE_DATA (Stanislaw Gruszka) [882300]
- [netdrv] add netdev_continue_rcu (Stanislaw Gruszka) [882300]
- [kernel] driver core: create lock/unlock functions for struct device (Stanislaw Gruszka) [882300]
- [input] add KEY_WPS_BUTTON definition (Stanislaw Gruszka) [882300]
- [pci] add PCI_EXP_LNKCTL_ASPM_L1 and PCI_EXP_LNKCTL_ASPM_L0S (Stanislaw Gruszka) [882300]
- [net] add mac_pton() (Stanislaw Gruszka) [882300]
- [net] etherdevice.h: Add is_unicast_ether_addr function (Stanislaw Gruszka) [882300]
- [net] etherdevice: introduce eth_broadcast_addr (Stanislaw Gruszka) [882300]
- [net] add netdev_features_t (Stanislaw Gruszka) [882300]
- [kconfig] Introduce IS_ENABLED(), IS_BUILTIN() and IS_MODULE() (Stanislaw Gruszka) [882300]
- [net] netlink: advertise incomplete dumps (Stanislaw Gruszka) [882300]
- [net] netlink: add signed types (Stanislaw Gruszka) [882300]
- [net] add ETH_P_802_3_MIN (Stanislaw Gruszka) [882300]
- [kernel] workqueue: add work_busy() (Stanislaw Gruszka) [882300]
- [firmware] Update Broadcom wifi 4313 smac firware to version 610.812 (John Green) [965253]
- [wireless] brcmsmac: request firmware in .start() callback (John Green) [757944]
- [wireless] Revert: brcmsmac: support 4313iPA (John Green) [757944]
- [bcma] init spin lock (John Green) [757944]
- [wireless] brcmsmac: Remove unnecessary memset casts (John Green) [757944]
- [wireless] brcmsmac: Downgrade d11hdrs_mac80211 error messages to warnings (John Green) [757944]
- [wireless] brcmsmac: fix brcms_c_country_valid() (John Green) [757944]
- [wireless] brcmsmac: avoid 512 byte stack variable (John Green) [757944]
- [wireless] brcmsmac: fix u16 overflow warning (John Green) [757944]
- [wireless] brcmsmac: rework of mac80211 .flush() callback operation (John Green) [757944]
- [bcma] unregister gpios before unloading bcma (John Green) [757944]
- [mtd] bcm47xxsflash: add own struct for abstracting bus type (John Green) [757944]
- [bcma] cc: fix (and rename) define of NAND flash type (John Green) [757944]
- [bcma] Xflash: reorder includes to make pr_fmt work (John Green) [757944]
- [bcma] register platform device for parallel flash (John Green) [757944]
- [bcma] fix NAND flash validation (John Green) [757944]
- [wireless] brcmsmac: fix tx status processing (John Green) [757944]
- [bcma] use consistent case for 'hex' constants (John Green) [757944]
- [bcma] add support for 1 and 2 byte extended config space access (John Green) [757944]
- [bcma] don't map/unmap a subset of the PCI config space (John Green) [757944]
- [bcma] jump to 'out' label for invalid 'func' value (John Green) [757944]
- [bcma] update pci configuration for bcm4706/bcm4716 (John Green) [757944]
- [bcma] mips: rename oldirqflag to irqinitmask (John Green) [757944]
- [bcma] mips: remove assigned_irqs from structure (John Green) [757944]
- [bcma] mips: show also disabled IRQs (John Green) [757944]
- [bcma] mips: make some info messages debug messages (John Green) [757944]
- [bcma] mips: explicit assign IRQ numbers (John Green) [757944]
- [bcma] make bcma_find_core_unit() accessible (John Green) [757944]
- [wireless] brcmsmac: remove dead code (John Green) [757944]
- [wireless] brcmsmac: allow user-space setting of interface address (John Green) [757944]
- [wireless] brcmsmac: use perimeter lock in add_interface() callback (John Green) [757944]
- [wireless] brcmsmac: increase timer reference count for new timers only (John Green) [757944]
- [wireless] brcmsmac: initialize morepending in brcms_b_recv() (John Green) [757944]
- [bcma] remove __dev* attributes (John Green) [757944]
- [wireless] brcmsmac: add copyright information for Canonical (John Green) [757944]
- [bcma] correct M25P32 serial flash ID (John Green) [757944]
- [bcma] BCMA_DRIVER_GPIO should depend on GPIOLIB instead of selecting it (John Green) [757944]
- [bcma] mips: fix clearing device IRQ (John Green) [757944]
- [wireless] brcmsmac: add support for BCM43224 with PCI id of 14e4:a8d8 (John Green) [757944]
- [wireless] brcmsmac: do a read after the write of the objmem on broken PCIe controllers (John Green) [757944]
- [bcma] unify naming schema for clock functions (John Green) [757944]
- [wireless] brcmsmac: add support for cores with revision 17 (John Green) [757944]
- [wireless] brcmsmac: fix uninitialized variable warning on arm architecture (John Green) [757944]
- [wireless] brcm80211: remove __dev* attributes (John Green) [757944]
- [bcma] add methods for watchdog driver (John Green) [757944]
- [bcma] set the pmu watchdog if available (John Green) [757944]
- [bcma] add bcma_chipco_alp_clock (John Green) [757944]
- [wireless] brcmsmac: remove duplicated include from debug.c (John Green) [757944]
- [bcma] add common header for watchdog (John Green) [757944]
- [wireless] brcmsmac: Fix possible NULL pointer dereference in _dma_ctrlflags() (John Green) [757944]
- [wireless] brcmsmac: support 4313iPA (John Green) [757944]
- [wireless] brcmsmac: move PHY functions (John Green) [757944]
- [wireless] brcmsmac: hardware info in debugfs (John Green) [757944]
- [wireless] brcmsmac: fix bounds checking in tx/rx (John Green) [757944]
- [wireless] brcmsmac: cleanup in isr code (John Green) [757944]
- [wireless] brcmsmac: handle packet drop during transmit correctly (John Green) [757944]
- [bcma] handle return value of pci_assign_resource (John Green) [757944]
- [bcma] add more package IDs (John Green) [757944]
- [wireless] brcmsmac: Add __printf verification to logging prototypes (John Green) [757944]
- [bcma] export PLL reading function (John Green) [757944]
- [bcma] add GPIO driver (John Green) [757944]
- [bcma] add comment to bcma_chipco_gpio_control (John Green) [757944]
- [bcma] add bcma_chipco_gpio_pullup and bcma_chipco_gpio_pulldown (John Green) [757944]
- [bcma] add locking around GPIO register accesses (John Green) [757944]
- [wireless] brcmsmac: Remove stray argument from debug macro (John Green) [757944]
- [wireless] brcmsmac: Remove unused wlc_prio2prec_map and _BRCMS_PREC_* constants (John Green) [757944]
- [wireless] brcmsmac: Remove some noisy and uninformative debug messages (John Green) [757944]
- [wireless] brcmsmac: Add tracepoint for AMPDU session information (John Green) [757944]
- [wireless] brcmsmac: Add tracepoint for macintstatus (John Green) [757944]
- [wireless] brcmsmac: Improve tx trace and debug support (John Green) [757944]
- [wireless] brcmsmac: Add brcms_dbg_ht() debug macro (John Green) [757944]
- [wireless] brcmsmac: Add brcms_dbg_dma() debug macro (John Green) [757944]
- [wireless] brcmsmac: Add brcms_dbg_int() debug macro (John Green) [757944]
- [wireless] brcmsmac: Add rx and tx debug macros (John Green) [757944]
- [wireless] brcmsmac: Add brcms_dbg_mac80211() debug macro (John Green) [757944]
- [wireless] brcmsmac: Use debug macros for general error and debug statements (John Green) [757944]
- [wireless] brcmsmac: Add support for writing debug messages to the trace buffer (John Green) [757944]
- [wireless] brcmsmac: Add module parameter for setting the debug level (John Green) [757944]
- [wireless] brcm80211: Convert log message levels to debug levels (John Green) [757944]
- [wireless] brcm80211: Allow trace support to be enabled separately from debug (John Green) [757944]
- [wireless] brcmsmac: Reduce number of entries in tx DMA rings (John Green) [757944]
- [wireless] brcmsmac: Use correct descriptor count when calculating next rx descriptor (John Green) [757944]
- [wireless] brcmsmac: Remove internal tx queue (John Green) [757944]
- [wireless] brcmsmac: Use IEEE 802.11 AC levels for pktq precedence levels (John Green) [757944]
- [wireless] brcmsmac: Remove unimplemented flow control functions (John Green) [757944]
- [wireless] brcmsmac: Add helper function for updating txavail count (John Green) [757944]
- [wireless] brcmsmac: Don't weight AMPDU packets in txfifo (John Green) [757944]
- [wireless] brcmsmac: Introduce AMPDU sessions for assembling AMPDUs (John Green) [757944]
- [bcma] suspend/resume callbacks should be conditionally compiled on CONFIG_PM_SLEEP (John Green) [757944]
- [bcma] do not initialize deactivated PCIe cores (John Green) [757944]
- [bcma] add an extra pcie core struct (John Green) [757944]
- [bcma] use fallback sprom if sprom on card was not valid (John Green) [757944]
- [bcma] add some more flash chips for serial flash (John Green) [757944]
- [bcma] extract drv_cc in bcma_core_mips_flash_detect() (John Green) [757944]
- [bcma] mark nflash if it is the boot flash (John Green) [757944]
- [bcma] add and use constants for the flash windows (John Green) [757944]
- [bcma] mark pflash as present when available (John Green) [757944]
- [bcma] init sprom struct earlier (John Green) [757944]
- [bcma] just do the necessary things in early register on SoCs (John Green) [757944]
- [bcma] fix unregistration of cores (John Green) [757944]
- [bcma] Convert #include ... to #include <path/...> in kernel system headers (John Green) [757944]
- [mtd] bcm47xxsflash: basic read-only driver for BCMA serial flash (John Green) [757944]
- [bcma] change delays to follow timers-howto guide (John Green) [757944]
- [bcma] handle BCM43227 (John Green) [757944]
- [wireless] brcm80211: Remove bogus memcpy in ai_detach (John Green) [757944]
- [wireless] brcmsmac: fix mismatch in number of custom regulatory rules (John Green) [757944]
- [bcma] don't leak memory for PCIE, MIPS, GBIT cores (John Green) [757944]
- [wireless] brcm80211: set interface down on reset (John Green) [757944]
- [bcma] detect and register NAND flash device (John Green) [757944]
- [bcma] detect and register serial flash device (John Green) [757944]
- [wireless] brcmsmac: document firmware dependencies (John Green) [757944]
- [bcma] add (mostly) NAND defines (John Green) [757944]
- [bcma] make some functions static (John Green) [757944]
- [wireless] brcmsmac: use ieee80211_channel_to_frequency (John Green) [757944]
- [bcma] BCM43228 support (John Green) [757944]
- [bcma] fix invalid PMU chip control masks (John Green) [757944]
- [bcma] add missing iounmap on error path (John Green) [757944]
- [bcma] fix regression in interrupt assignment on mips (John Green) [757944]
- [bcma] add place for flash memory support (John Green) [757944]
- [bcma] cc: update defines (John Green) [757944]
- [bcma] add new cores at the end of list (John Green) [757944]
- [bcma] add trivial GBIT MAC COMMON driver (John Green) [757944]
- [bcma] fix typo reading number of slave wrappers (John Green) [757944]
- [bcma] support alternative (BCM4706) ChipCommon core id (John Green) [757944]
- [wireless] brcmsmac: restructure info->control.sta handling as it is going to be removed soon (John Green) [757944]
- [bcma] add PMU clock support for BCM4706 (John Green) [757944]
- [bcma] fix CC driver compilation on MIPS (John Green) [757944]
- [wireless] brcmsmac: handle non PCI devices in the phy code (John Green) [757944]
- [wireless] brcmsmac: fix read in write_phy_reg (John Green) [757944]
- [wireless] brcmsmac: extend brcms_c_chipmatch() to also handle non PCIe devices (John Green) [757944]
- [wireless] brcmsmac: fix DMA on SoCs (John Green) [757944]
- [wireless] brcmsmac: extend xmtfifo_sz array (John Green) [757944]
- [wireless] brcmsmac: add some workarounds for other chips again (John Green) [757944]
- [wireless] brcmsmac: add a conditions for core rev 17 again (John Green) [757944]
- [wireless] brcmsmac: remove some unnessessacry casts and void pointer (John Green) [757944]
- [wireless] brcmsmac: use core id constants from bcma (John Green) [757944]
- [wireless] brcmsmac: remove some redundant chip common workarounds (John Green) [757944]
- [wireless] brcmsmac: remove si_pmu_spuravoid_pllupdate() (John Green) [757944]
- [wireless] brcmsmac: remove si_pmu_init() and si_pmu_res_init() (John Green) [757944]
- [wireless] brcmsmac: remove ai_findcore() (John Green) [757944]
- [wireless] brcmsmac: use container_of instead of cast (John Green) [757944]
- [wireless] brcmsmac: remove ai_get_buscoretype() and ai_get_buscorerev() (John Green) [757944]
- [wireless] brcmsmac: remove PCI_FORCEHT() macro (John Green) [757944]
- [wireless] brcmsmac: remove PCIE() macro (John Green) [757944]
- [bcma] use custom printing functions (John Green) [757944]
- [wireless] brcmsmac: fix brcms_c_regd_init() which crashed after 11ad patch (John Green) [757944]
- [bcma] add mdelay bcma_pmu_resources_init() (John Green) [757944]
- [bcma] add bcma_pmu_spuravoid_pllupdate() (John Green) [757944]
- [bcma] remove chip ids doing nothing from PMU initialization (John Green) [757944]
- [bcma] remove bcma_pmu_pll_init() and bcma_pmu_swreg_init() (John Green) [757944]
- [bcma] complete workaround for BCMA43224 and BCM4313 (John Green) [757944]
- [bcma] add PCI ID for BCM43224 (John Green) [757944]
- [bcma] remove fix for 4329b0 bad LPOM is detection (John Green) [757944]
- [bcma] add constants for chip ids (John Green) [757944]
- [bcma] extend workaround for bcm4331 (John Green) [757944]
- [bcma] define some additional cores IDs (John Green) [757944]
- [wireless] brcmsmac: fix NULL pointer crash in brcms_c_regd_init() (John Green) [757944]
- [wireless] brcm80211: use current regulatory domain when checking whether OFDM is allowed (John Green) [757944]
- [wireless] brcm80211: don't validate channels against internal regulatory data (John Green) [757944]
- [wireless] brcm80211: use mac80211 channel data for tx power limits (John Green) [757944]
- [wireless] brcm80211: enable/disable radio on regulatory updates (John Green) [757944]
- [wireless] brcm80211: inform mac80211 of the X2 regulatory domain (John Green) [757944]
- [wireless] brcm80211: clean up channel.c (John Green) [757944]
- [wireless] brcm80211: remove unused code for 40MHz channels (John Green) [757944]
- [wireless] brcm80211: always set channel specified by mac80211 (John Green) [757944]
- [wireless] brcm80211: don't set up tx power limits during initialization (John Green) [757944]
- [wireless] brcmsmac: fix smatch warning found in ampdu.c (John Green) [757944]
- [wireless] brcmsmac: remove brcms_set_hint() function (John Green) [757944]
- [wireless] brcm80211: fixed checkpatch and sparse warnings (John Green) [757944]
- [wireless] brcm80211: Remove casts to same type (John Green) [757944]
- [wireless] brcm80211: brcmu_pkt_buf_free_skb() should handle NULL (John Green) [757944]
- [wireless] brcm80211: remove an unneeded NULL check (John Green) [757944]
- [wireless] brcmsmac: initial backport of brcmsmac wifi driver (John Green) [757944]
- [firmware] Add brcmsmac wireless firmware (John Green) [757944]

* Tue Jul 23 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-401.el6]
- [netdrv] e1000e: Release mutex lock only if it has been initially acquired (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup whitespace (Dean Nelson) [923897]
- [netdrv] e1000e: panic caused by Rx traffic arriving while interface going down (Dean Nelson) [923897]
- [netdrv] e1000e: prevent multiple calls to e1000e_down() and e1000_free_irq() (Dean Nelson) [923897]
- [netdrv] e1000e: fix numeric overflow in phc settime method (Dean Nelson) [923897]
- [netdrv] e1000e: Add missing dma_mapping_error-call in e1000_alloc_jumbo_rx_buffers (Dean Nelson) [923897]
- [netdrv] e1000e: increase driver version number (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup unused defines (Dean Nelson) [923897]
- [netdrv] e1000e: add support for LTR on I217/I218 (Dean Nelson) [923897]
- [netdrv] e1000e: EEE capability advertisement not set/disabled as required (Dean Nelson) [923897]
- [netdrv] e1000e: long access timeouts when I217/I218 MAC and PHY are out of sync (Dean Nelson) [923897]
- [netdrv] e1000e: fix LED blink logic for designs with LEDs driven by cathode (Dean Nelson) [923897]
- [netdrv] e1000e: slow performance between two 82579 connected via 10Mbit hub (Dean Nelson) [923897]
- [netdrv] e1000e: additional error handling on PHY register accesses (Dean Nelson) [923897]
- [netdrv] e1000e: workaround DMA unit hang on I218 (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup - move defines to appropriate header file (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup format of struct e1000_opt_list struct (Dean Nelson) [923897]
- [netdrv] e1000e: fix scheduling while atomic bug (Dean Nelson) [923897]
- [netdrv] e1000e: fix scheduling while atomic bugs (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup USLEEP_RANGE checkpatch checks (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup unnecessary line breaks (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup formatting of static structs (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup unusually placed comments (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup (add/remove) blank lines where appropriate (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup SPACING checkpatch checks (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup LEADING_SPACE checkpatch warnings (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup LONG_LINE checkpatch warnings (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup SPACING checkpatch errors and warnings (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup CODE_INDENT checkpatch errors (Dean Nelson) [923897]
- [netdrv] e1000e: display a warning message when SmartSpeed works (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup checkpatch braces checks (Dean Nelson) [923897]
- [netdrv] e1000e: convert enums of register offsets and move #defines to regs.h (Dean Nelson) [923897]
- [netdrv] e1000e: cosmetic move of #defines and prototypes to the new manage.h (Dean Nelson) [923897]
- [netdrv] e1000e: cosmetic move of #defines and function prototypes to the new nvm.h (Dean Nelson) [923897]
- [netdrv] e1000e: cosmetic move of #defines and function prototypes to the new phy.h (Dean Nelson) [923897]
- [netdrv] e1000e: cosmetic move of function prototypes to the new mac.h (Dean Nelson) [923897]
- [netdrv] e1000e: cosmetic move of #defines and prototypes to the new ich8lan.h (Dean Nelson) [923897]
- [netdrv] e1000e: cosmetic move of #defines to the new 80003es2lan.h (Dean Nelson) [923897]
- [netdrv] e1000e: cosmetic move of #defines and prototypes to the new 82571.h (Dean Nelson) [923897]
- [netdrv] e1000e: use generic IEEE MII definitions (Dean Nelson) [923897]
- [netdrv] e1000e: resolve -Wunused-parameter compile warnings (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup some whitespace and indentation issues (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: group OR'ed bit settings with parens (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup defines.h (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: remove comments which are no longer applicable (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup hw.h (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: remove unused #define (Dean Nelson) [923897]
- [netdrv] e1000e: adjust PM QoS request (Dean Nelson) [923897]
- [netdrv] e1000e: correct maximum frame size on 82579 (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: remove e1000e_commit_phy() (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: remove e1000_get_cable_length() (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: remove e1000_get_phy_cfg_done() (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: rename e1000_get_cfg_done() (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: remove e1000_force_speed_duplex() (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: remove e1000_set_d0_lplu_state() (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: do not assign a variable a value when not necessary (Dean Nelson) [923897]
- [netdrv] e1000e: do not ignore variables which get set a value (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup: remove unnecessary function prototypes (Dean Nelson) [923897]
- [netdrv] e1000e: remove definition of struct which is no longer used (Dean Nelson) [923897]
- [netdrv] e1000e: fix PHY init workarounds for i217/i218 (Dean Nelson) [923897]
- [netdrv] e1000e: correct maximum frame size on i217/i218 (Dean Nelson) [923897]
- [netdrv] e1000e: update copyright date (Dean Nelson) [923897]
- [netdrv] e1000e: remove prototype of non-existent function (Dean Nelson) [923897]
- [netdrv] e1000e: prevent hardware from automatically configuring PHY on I217/I218 (Dean Nelson) [923897]
- [netdrv] e1000e: enable ECC on I217/I218 to catch packet buffer memory errors (Dean Nelson) [923897]
- [netdrv] e1000e: add support for IEEE-1588 PTP (Dean Nelson) [923897]
- [netdrv] e1000e: fix flow-control thresholds for jumbo frames on 82579/I217/I218 (Dean Nelson) [923897]
- [netdrv] e1000e: fix ethtool offline register test for I217 (Dean Nelson) [923897]
- [netdrv] e1000e: add support for hardware timestamping on some devices (Dean Nelson) [923897]
- [netdrv] e1000e: add ethtool .get_eee/.set_eee (Dean Nelson) [923897]
- [netdrv] e1000e: merge multiple conditional statements into one (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup code duplication (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup magic number (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup unnecessary line wrap (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup unusual comment placement (Dean Nelson) [923897]
- [netdrv] e1000e: resolve checkpatch PREFER_PR_LEVEL warning (Dean Nelson) [923897]
- [netdrv] e1000e: add missing bailout on error (Dean Nelson) [923897]
- [netdrv] e1000e: unexpected "Reset adapter" message when cable pulled (Dean Nelson) [923897]
- [netdrv] e1000e: fix enabling of EEE on 82579 and I217 (Dean Nelson) [923897]
- [netdrv] e1000e: 82577: workaround for link drop issue (Dean Nelson) [923897]
- [netdrv] e1000e: helper functions for accessing EMI registers (Dean Nelson) [923897]
- [netdrv] e1000e: Invalid Image CSUM bit changed for I217 (Dean Nelson) [923897]
- [netdrv] e1000e: Acquire/release semaphore when writing each EEPROM page (Dean Nelson) [923897]
- [netdrv] e1000e: SerDes autoneg flow control (Dean Nelson) [923897]
- [netdrv] e1000e: cosmetic cleanup of comments (Dean Nelson) [923897]
- [netdrv] e1000e: Minimum packet size must be 17 bytes (Dean Nelson) [923897]
- [netdrv] e1000e: Change wthresh to 1 to avoid possible Tx stalls (Dean Nelson) [923897]
- [netdrv] e1000e: add transmit timestamping support (Dean Nelson) [923897]
- [netdrv] e1000e: cleanup e1000_set_phys_id (Dean Nelson) [923897]
- [netdrv] e1000e: implement ethtool set_phys_id (Dean Nelson) [923897]
- [bluetooth] L2CAP - Fix info leak via getsockname() (Jacob Tanenbaum) [922418] {CVE-2012-6544}
- [bluetooth] HCI - Fix info leak in getsockopt() (Jacob Tanenbaum) [922418] {CVE-2012-6544}
- [netdrv] igbvf: be sane about random MAC addresses (Stefan Assmann) [870635]
- [net] mii: Remove references to DP83840 PHY in mii.h (Nikolay Aleksandrov) [856764]
- [kernel] err: add a function to cast error-pointers to a return value (Neil Horman) [856764]
- [net] etherdevice: introduce help function eth_zero_addr() (Neil Horman) [856764]
- [net] mii: Convert spaces to tabs in mii.h (Nikolay Aleksandrov) [856764]
- [netdrv] tg3: Wait for boot code to finish after power on (Ivan Vecera) [915516]
- [netdrv] tg3: Add read dma workaround for 5720 (Ivan Vecera) [915516]
- [netdrv] tg3: remove redundant pm init code (Ivan Vecera) [915516]
- [netdrv] tg3: Remove unnecessary lock around tg3_flag_set (Ivan Vecera) [915516]
- [netdrv] tg3: Fix misplaced empty line (Ivan Vecera) [915516]
- [netdrv] tg3: Use descriptive label names in tg3_start (Ivan Vecera) [915516]
- [netdrv] tg3: Make tg3_rings_reset() more concise (Ivan Vecera) [915516]
- [netdrv] tg3: Simplify ring control block setup (Ivan Vecera) [915516]
- [netdrv] tg3: Split APE driver state change out of boot reset signature update (Ivan Vecera) [915516]
- [netdrv] tg3: Update version to 3.132 (Ivan Vecera) [915516]
- [netdrv] tg3: Ensure boot code has completed initialization before accessing hardware (Ivan Vecera) [915516]
- [netdrv] tg3: Use module_pci_driver to register driver (Ivan Vecera) [915516]
- [netdrv] tg3: Implement set/get_eee handlers (Ivan Vecera) [915516]
- [netdrv] tg3: Simplify tg3_phy_eee_config_ok() by reusing tg3_eee_pull_config() (Ivan Vecera) [915516]
- [netdrv] tg3: Add tg3_eee_pull_config() function (Ivan Vecera) [915516]
- [netdrv] tg3: Add ethtool_eee struct and tg3_setup_eee() (Ivan Vecera) [915516]
- [netdrv] tg3: Skip powering down function 0 on certain serdes devices (Ivan Vecera) [915516]
- [netdrv] tg3: Fix data corruption on 5725 with TSO (Ivan Vecera) [915516]
- [netdrv] tg3: fix to append hardware time stamping flags (Ivan Vecera) [915516]
- [netdrv] tg3: shows HW time stamping support only if ptp_capable is present (Ivan Vecera) [915516]
- [netdrv] tg3: Use bool not int (Ivan Vecera) [915516]
- [netdrv] tg3: Update version to 3.131 (Ivan Vecera) [915516]
- [netdrv] tg3: Reset the phy to allow modified EEE settings to take effect (Ivan Vecera) [915516]
- [netdrv] tg3: Pull the phy advertised speed and flow control settings on driver load (Ivan Vecera) [915516]
- [netdrv] tg3: Add support for link flap avoidance (Ivan Vecera) [915516]
- [netdrv] tg3: Add SGMII phy support for 5719/5718 serdes (Ivan Vecera) [915516]
- [netdrv] tg3: Add tg3_clear_mac_status() common function (Ivan Vecera) [915516]
- [netdrv] tg3: Add a warning during link settings change if mgmt enabled (Ivan Vecera) [915516]
- [netdrv] tg3: Remove unnecessary phy reset during ethtool commands (Ivan Vecera) [915516]
- [netdrv] tg3: Fix NVRAM size detection for the STM45PE20 pinstrap on 5762 devices (Ivan Vecera) [915516]
- [netdrv] tg3: Fix flow control settings not propagated to hardware (Ivan Vecera) [915516]
- [netdrv] tg3: fix length overflow in VPD firmware parsing (Ivan Vecera) [915516]
- [netdrv] tg3: dma_alloc_coherent, use __GFP_ZERO instead of memset() (Ivan Vecera) [915516]
- [netdrv] tg3: 5715 does not link up when autoneg off (Ivan Vecera) [915516]
- [netdrv] tg3: Update link_up flag for phylib devices (Ivan Vecera) [915516]
- [netdrv] tg3: Download 57766 EEE service patch firmware (Ivan Vecera) [915516]
- [netdrv] tg3: Enhance firmware download code to support fragmented firmware (Ivan Vecera) [915516]
- [netdrv] tg3: Cleanup firmware parsing code (Ivan Vecera) [915516]
- [netdrv] tg3: Refactor the 2nd type of cpu pause (Ivan Vecera) [915516]
- [netdrv] tg3: Refactor cpu pause/resume code (Ivan Vecera) [915516]
- [netdrv] tg3: Add new FW_TSO flag (Ivan Vecera) [915516]
- [netdrv] tg3: Use different macros for pci_chip_rev_id accesses (Ivan Vecera) [915516]
- [netdrv] tg3: Remove define and single use of GET_CHIP_REV_ID (Ivan Vecera) [915516]
- [netdrv] tg3: Update version to 3.130 (Ivan Vecera) [915516]
- [netdrv] tg3: Set initial carrier state to off (Ivan Vecera) [915516]
- [netdrv] tg3: Fix 5762 NVRAM sizing (Ivan Vecera) [915516]
- [netdrv] tg3: Expand EEE support for all 5717 B0 (Ivan Vecera) [915516]
- [netdrv] tg3: Add 57766 device support (Ivan Vecera) [915516]
- [netdrv] tg3: add support for Ethernet core in bcm4785 (Ivan Vecera) [915516]
- [netdrv] tg3: make it possible to provide phy_id in ioctl (Ivan Vecera) [915516]
- [netdrv] tg3: Remove unnecessary alloc/OOM messages, alloc cleanups (Ivan Vecera) [915516]
- [netdrv] tg3: missing break statement in tg3_get_5720_nvram_info() (Ivan Vecera) [915516]
- [netdrv] tg3: Remove CONFIG_HWMON IS_ENABLED() check (Ivan Vecera) [915516]
- [netdrv] tg3: Improve PCI function number detection (Ivan Vecera) [915516]
- [netdrv] tg3: Add NVRAM support for 5762 (Ivan Vecera) [915516]
- [netdrv] tg3: Add support for new 5762 ASIC (Ivan Vecera) [915516]
- [netdrv] tg3: Fix sparse warning: constant 0x7fffffffffffffff is so big it is long long (Ivan Vecera) [915516]
- [netdrv] tg3: PTP - Enable the timestamping feature in hardware and fill skb tx/rx timestamps (Ivan Vecera) [915516]
- [netdrv] tg3: PTP - Add the hardware timestamp ioctl (Ivan Vecera) [915516]
- [netdrv] tg3: PTP - Implement the ptp api and ethtool functions (Ivan Vecera) [915516]
- [netdrv] tg3: PTP - Add header definitions, initialization and hw access functions (Ivan Vecera) [915516]
- [netdrv] tg3: Fix inconsistent locking for tg3_netif_start() (Ivan Vecera) [915516]
- [netdrv] tg3: Use tp->rxq_cnt when checking RSS tables (Ivan Vecera) [915516]
- [netdrv] tg3: Cleanup hardcoded ethtool test array indexes (Ivan Vecera) [915516]
- [netdrv] tg3: Prevent spurious tx timeout by setting carrier off before tx disable (Ivan Vecera) [915516]
- [netdrv] tg3: Set 10_100_ONLY flag for additional 10/100 Mbps devices (Ivan Vecera) [915516]
- [netdrv] tg3: Call tg3_netif_stop() from tg3_stop() (Ivan Vecera) [915516]
- [netdrv] tg3: Support 5717 C0 (Ivan Vecera) [915516]
- [netdrv] tg3: Fix sparse warnings (Ivan Vecera) [915516]
- [netdrv] tg3: unconditionally select HWMON support when tg3 is enabled (Ivan Vecera) [915516]
- [netdrv] tg3: Disable multiple TX rings by default due to hardware flaw (Ivan Vecera) [915516]
- [netdrv] tg3: Add support for ethtool -L|-l to get/set the number of rings (Ivan Vecera) [915516]
- [netdrv] tg3: Refactor tg3_close() (Ivan Vecera) [915516]
- [netdrv] tg3: Refactor tg3_open() (Ivan Vecera) [915516]
- [netdrv] tg3: Separate coalescing setup for rx and tx (Ivan Vecera) [915516]
- [netdrv] tg3: Allow number of rx and tx rings to be set independently (Ivan Vecera) [915516]
- [netdrv] tg3: Introduce separate functions to allocate/free RX/TX rings (Ivan Vecera) [915516]
- [netdrv] tg3: Fix single-vector MSI-X code (Ivan Vecera) [915516]
- [netdrv] tg3: Make the RSS indir tbl admin configurable (Ivan Vecera) [915516]
- [netdrv] tg3: switch to build_skb() infrastructure (Ivan Vecera) [915516]
- [netdrv] tg3: Fix EEE debounce timer values (Ivan Vecera) [915516]
- [netdrv] tg3: add skb frag size accessors (Ivan Vecera) [915516]
- [netdrv] tg3: use DMA_x_DEVICE and dma_mapping_error with skb_frag_dma_map (Ivan Vecera) [915516]
- [netdrv] tg3: convert to SKB paged frag API (Ivan Vecera) [915516]
- [netdrv] tg3: Reorg tg3_napi members (Ivan Vecera) [915516]
- [netdrv] tg3: Fix MII_TG3_DSP_EXP8 offset (Ivan Vecera) [915516]
- [netdrv] tg3: Remove tg3_config_info definition (Ivan Vecera) [915516]
- [netdrv] tg3: Set real_num_rx_queues for non-multiq devs (Ivan Vecera) [915516]
- [netdrv] tg3: Use netif_set_real_num_rx_queues() and netif_set_real_num_tx_queues() (Ivan Vecera) [915516]
- [netdrv] tg3: use the DMA state API instead of the pci equivalents (Ivan Vecera) [915516]
- [netdrv] tg3: Avoid null pointer dereference in tg3_interrupt in netconsole mode (Ivan Vecera) [887908]
- [netdrv] virtio_net: introduce a new control to set macaddr (Amos Kong) [904924]
- [net] split eth_mac_addr for better error handling (Amos Kong) [904924]
- [netdrv] virtio_net: move virtnet_send_command() above virtnet_set_mac_address() (Amos Kong) [904924]
- [netdrv] virtio_net: use IFF_LIVE_ADDR_CHANGE priv_flag (Amos Kong) [904924]
- [net] eth: reset addr_assign_type if eth_mac_addr() called (Amos Kong) [904924]
- [net] set IFF_LIVE_ADDR_CHANGE to ext_priv_flags (Amos Kong) [904924]
- [net] ipvs: fix CHECKSUM_PARTIAL for TCP, UDP (Thomas Graf) [973122]
- [net] ethtool: allow enable GRO even if RX csum is disabled (Ivan Vecera) [962460]
- [net] bonding: enable gro by default (Ivan Vecera) [962460]
- [net] bridge: fix some kernel warning in multicast timer (Amerigo Wang) [952012]
- [net] sctp: confirm route during forward progress (Daniel Borkmann) [980053]
- [net] bridge: Provide VLAN registration and GRO acceleration for ports (Nikolay Aleksandrov) [858198]

* Fri Jul 19 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-400.el6]
- [netdrv] macvtap: Perform GSO on forwarding path (Vlad Yasevich) [885662]
- [netdrv] macvtap: Let TUNSETOFFLOAD actually controll offload features (Vlad Yasevich) [885662]
- [netdrv] macvtap: Consistently use rcu functions (Vlad Yasevich) [885662]
- [netdrv] macvtap: Convert to using rtnl lock (Vlad Yasevich) [885662]
- [powerpc] power8: Fix oprofile and perf (Steve Best) [929283]
- [powerpc] POWER8 cputable entry (Steve Best) [929283]
- [netdrv] sfc: Fix memory leak when discarding scattered packets (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Remove write permission from phy_type attribute (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix IRQ cleanup in case of a probe failure (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Do not pass non-TCP packets into GRO code (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Define and set RX buffer flag for packets parsed as TCP (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Enable accelerated RFS on vlans (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Report software timestamping capabilities (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Increase size of RX SKB header area (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Enable RX checksum offload for packets not handled by GRO (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix EEH with legacy interrupts (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Store port number in private data, not net_device::dev_id (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Reduce RX scatter buffer size, and reduce alignment if appropriate (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: fix return value check in efx_ptp_probe_channel() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix naming of MTD partitions for FPGA bitfiles (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: make local functions static (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: pass __GFP_ZERO to dma_alloc_coherent() instead of using memset (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: remove duplicated include from efx.c (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: allocate more RX buffers per page (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Replace efx_rx_is_last_buffer() with a flag (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: reuse pages to avoid DMA mapping/unmapping costs (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Enable RX DMA scattering where possible (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Update RX buffer address together with length (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Explicitly prefetch RX hash prefix, not just Ethernet heade (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Replace efx_rx_buf_eh() with simpler efx_rx_buf_va() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Wrap __efx_rx_packet() with efx_rx_flush_packet() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Make RX queue descriptor counts unsigned for consistency (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Properly distinguish RX buffer and DMA lengths (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Document current usage of efx_rx_buffer::len and efx_nic::rx_buffer_len (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Add AER and EEH support for Siena (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Disable RSS when using SR-IOV and only 1 RX queue on the PF (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix replacement detection in efx_filter_insert_filter() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Merge efx_filter_search() into efx_filter_insert() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Don't use efx_filter_ functions for default MAC filters (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Remove redundant parameter to efx_filter_search() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: More sensible semantics for efx_filter_insert_filter() replace flag (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Remove rx_alloc_method SKB (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix Kconfig typo (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Only use TX push if a single descriptor is to be written (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Correct efx_rx_buffer::page_offset when EFX_PAGE_IP_ALIGN != 0 (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Disable soft interrupt handling during efx_device_detach_sync() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Detach net device when stopping queues for reconfiguration (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix efx_rx_buf_offset() in the presence of swiotlb (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Properly sync RX DMA buffer when it is not the last in the page (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Make module parameters really boolean (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix timekeeping in efx_mcdi_poll() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: lock TX queues when calling netif_device_detach() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Work-around flush timeout when flushes have completed (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Reset driver's MAC stats after MC reboot seen (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Do not initialise buffer in efx_alloc_special_buffer() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Correctly initialise reset_method in siena_test_chip() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Remove confusing MMIO functions (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix check for failure of MC_CMD_FLUSH_RX_QUEUES (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Delete redundant page_addr variable from efx_init_rx_buffers_page() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Really disable flow control while flushing (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix byte order warning in self-test (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix byte order warnings for ethtool RX filter interface (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: use standard _bit_le() functions (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix loopback self-test with separate_tx_channels=1 (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix MCDI structure field lookup (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Add parentheses around use of bitfield macro arguments (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Avoid generating over-length MC_CMD_FLUSH_RX_QUEUES request (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Bump version to 3.2 (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Support variable-length response to MCDI GET_BOARD_CFG (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Convert firmware subtypes to native byte order in efx_mcdi_get_board_cfg() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix reporting of IPv4 full filters through ethtool (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Assign efx and efx->type as early as possible in efx_pci_probe() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Remove bogus comment about MTU change and RX buffer overrun (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Remove overly paranoid locking assertions from netdev operations (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix reset vs probe/remove/PM races involving efx_nic::state (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Improve log messages in case we abort probe due to a pending reset (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Never try to stop and start a NIC that is disabled (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Hold RTNL lock only when calling efx_stop_interrupts() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Keep disabled NICs quiescent during suspend/resume (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Hold the RTNL lock for more of the suspend/resume cycle (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Change state names to be clearer, and comment them (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Stash header offsets for TSO in struct tso_state (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Replace tso_state::full_packet_space with ip_base_len (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Simplify TSO header buffer allocation (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Stop TX queues before they fill up (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Refactor struct efx_tx_buffer to use a flags field (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: initialize dynamic sysfs attributes for lockdep (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Correct some comments on enum reset_type (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix interface statistics running backward (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Disable VF queues during register self-test (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Explain why efx_mcdi_exit_assertion() ignores result of efx_mcdi_rpc() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Use dev_kfree_skb() in efx_end_loopback() (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Use strlcpy() to copy ethtool stats names (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Stop changing header offsets on TX (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Remove dead write to tso_state::packet_space (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Use generic DMA API, not PCI-DMA API (Nikolay Aleksandrov) [953929]
- [netdrv] Fix non-kernel-doc comments with kernel-doc start markers (Nikolay Aleksandrov) [953929]
- [netdrv] Fix kernel-doc comments for various functions (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Implement module EEPROM access for SFE4002 and SFN4112F (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Added support for new ethtool APIs for obtaining module eeprom (Nikolay Aleksandrov) [953929]
- [netdrv] sfc: Fix mapping of reset reasons and flags to methods (Nikolay Aleksandrov) [953929]

* Wed Jul 17 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-399.el6]
- [mm] transparent hugepage core changes related to MADV_HUGEPAGE/MADV_NOHUGEPAGE (Larry Woodman) [891857]
- [mm] thp: define MADV_NOHUGEPAGE (Larry Woodman) [891857]
- [mm] thp: define MADV_HUGEPAGE (Larry Woodman) [891857]
- [mm] thp: Add madvise MADV_NOHUGEPAGE (Larry Woodman) [891857]
- [mm] thp: Add madvise MADV_HUGEPAGE (Larry Woodman) [891857]
- [net] tuntap: initialize vlan_features (Vlad Yasevich) [951458]
- [net] netlink_dump: fix locking regression in error path (Daniel Borkmann) [982108]
- [net] ip6_fib: Various cleanups (Jiri Pirko) [958215]
- [net] ip6_fib: return errno pointers consistently for fib6_add_1() (Jiri Pirko) [958215]
- [net] ip6_fib: fix return value check in fib6_add() (Jiri Pirko) [958215]
- [net] ip6_fib/ip6_route: Standardize prefixes for message logging (Jiri Pirko) [958215]
- [net] ip6_fib: Use pr_warn() (Jiri Pirko) [958215]
- [net] ip6_fib: Fix a crash when trying to replace non existing route (Jiri Pirko) [958215]
- [net] ip6_fib: Removing unnecessary NULL checks (Jiri Pirko) [958215]
- [net] ip6_fib: add NLM_F_* flag support for route (Jiri Pirko) [958215]
- [net] ip6_route: Various cleanups (Jiri Pirko) [958215]
- [net] ip6_route: add support for NLM_F_* flags (Jiri Pirko) [958215]
- [net] af_key: fix info leaks in notify messages (Jiri Benc) [981004] {CVE-2013-2234}
- [net] af_key: initialize satype in key_notify_policy_flush() (Thomas Graf) [981227] {CVE-2013-2237}
- [net] ipv4: ipmr_expire_timer causes crash when removing net namespace (Amerigo Wang) [972573]
- [net] ipv6: ip6_sk_dst_check() must not assume ipv6 dst (Jiri Pirko) [981559] {CVE-2013-2232}
- [net] ipv6: remove old token ipv6 address as soon as possible (Daniel Borkmann) [876634]
- [net] ipv6: check return value of ipv6_get_lladdr (Daniel Borkmann) [876634]
- [net] ipv6: don't call addrconf_dst_alloc again when enable lo (Jiri Benc) [744655]
- [net] rps: Ensure that an expired hardware filter can be re-added later (Daniel Borkmann) [893177]
- [crypto] algboss: Hold ref count on larval (Daniel Borkmann) [889992]
- [net] sctp: fix NULL pointer dereference in socket destruction (Daniel Borkmann) [889992]
- [net] Use separate workqueue for linkwatch events (Jan Vesely) [783615]

* Thu Jul 11 2013 Rafael Aquini <aquini@redhat.com> [2.6.32-398.el6]
- [x86] Revert: Allow greater than 1TB of RAM on AMD x86_64 sytems (Larry Woodman) [970735]
- [x86] Revert: Prevent panic in init_memory_mapping() when booting more than 1TB on AMD systems (Larry Woodman) [970735]
- [scsi] megaraid_sas: Changelog and driver version update (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Add support to differentiate between iMR vs MR Firmware (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Add support for Uneven Span PRL11 (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Add support for Extended MSI-x vectors for 12Gb/s controller (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Set IoFlags to enable Fast Path for JBODs for 12 Gb/s controllers (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Add support to display Customer branding details in syslog (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Add support for MegaRAID Fury (device ID-0x005f) 12Gb/s controllers (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Set IO request timeout value provided by OS timeout for Tape devices (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Free event detail memory without device ID check (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Update balance count in driver to be in sync of firmware (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Fix the interrupt mask for Gen2 controller (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Return DID_ERROR for SCSI IO, when controller is in critical h/w error (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Version and Changelog update (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Dont load DevHandle unless FastPath enabled (Tomas Henzl) [949084]
- [scsi] megaraid_sas: Add 4k FastPath DIF support (Tomas Henzl) [949084]
- [scsi] mpt2sas: Bump driver vesion to v15.100.00.00 (Tomas Henzl) [947078]
- [scsi] mpt2sas: fix for unused variable 'event_data' warning (Tomas Henzl) [947078]
- [scsi] mpt2sas: Fix for device scan following host reset could get stuck in a infinite loop (Tomas Henzl) [947078]
- [scsi] mpt2sas: Fix for issue Missing delay not getting set during system bootup (Tomas Henzl) [947078]
- [scsi] mpt2sas: MPI2 Rev W (2.00.15) specification (Tomas Henzl) [947078]
- [scsi] mpt2sas: Calulate the Reply post queue depth calculation as per the MPI spec (Tomas Henzl) [947078]
- [scsi] mpt2sas: fix firmware failure with wrong task attribute (Tomas Henzl) [947078]
- [scsi] mpt2sas: Update the timing requirements for issuing a Hard Reset (Tomas Henzl) [947078]
- [scsi] mpt2sas: update version string to 14.101.00.01 (Tomas Henzl) [947078]
- [scsi] mpt2sas: Add support for OEM specific controller (Tomas Henzl) [947078]
- [scsi] mpt2sas: Add a module parameter that permits overriding protection capabilities (Tomas Henzl) [947078]
- [scsi] mpt2sas: Return the correct sense key for DIF errors (Tomas Henzl) [947078]
- [scsi] mpt2sas: fix double mutex lock in NON_BLOCKING state (Tomas Henzl) [947078]
- [scsi] mpt2sas: Fix for issue - Unable to boot from the drive connected to HBA (Tomas Henzl) [947078]
- [scsi] mpt2sas: Fix for With post diag reset same set of device gets added, removed and then again gets added with new target ids (Tomas Henzl) [947078]
- [scsi] mpt2sas: Fix for staged device discovery functionality of driver not working (Tomas Henzl) [947078]
- [scsi] mpt2sas : MPI 2.0 Rev V(2.0.14) specification (Tomas Henzl) [947078]
- [scsi] mpt2sas: minor fix to follow upstream (Tomas Henzl) [947078]
- [scsi] mpt2sas: Provide sysfs attribute to report Backup Rail Monitor Status (Tomas Henzl) [947078]
- [scsi] mpt2sas: To include more Intel Branding (Tomas Henzl) [947078]
- [scsi] mpt2sas: 2012 source code copyright (Tomas Henzl) [947078]
- [scsi] mpt2sas: Fix for Driver oops, when loading driver with max_queue_depth command line option to a very small value (Tomas Henzl) [947078]
- [scsi] mpt2sas: Fix unsafe using smp_processor_id() in preemptible (Tomas Henzl) [947078]
- [scsi] mpt2sas: move the scsi_host_put to the right place (Tomas Henzl) [947078]

* Wed Jul 10 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-397.el6]
- [ata] ahci: Add Device IDs for Intel Wellsburg PCH RAID mode (John Villalovos) [922969]
- [i2c] i801: Add Device IDs for Intel Wellsburg PCH (John Villalovos) [922969]
- [ata] ahci: Add Device IDs for Intel Wellsburg PCH AHCI mode (John Villalovos) [922969]
- [sound] hda_intel: Add Device IDs for Intel Wellsburg PCH (John Villalovos) [922969]
- [ata] ata_piix: Add Device IDs for Intel Wellsburg PCH (John Villalovos) [922969]
- [usb] uhci: fix for suspend of virtual HP controller (Gopal) [960026]
- [usb] uhci: Remove PCI dependencies from uhci-hub (Gopal) [960026]
- [scsi] st: add MTWEOFI to write filemarks without flushing drive buffer (Jan Vesely) [888903]
- [mm] reinstate the first-fit scheme for arch_get_unmapped_area_topdown() (Rafael Aquini) [980273]
- [netdrv] tg3: Prevent system hang during repeated EEH errors (Ivan Vecera) [973209]
- [netdrv] bnx2x: Change MDIO clock settings (Michal Schmidt) [901747]
- [scsi] aacraid: Dual firmware support (Rich Bono) [924346]
- [scsi] aacraid: 1024 max outstanding command support for Series 7 and above (Rich Bono) [903799 952342]
- [scsi] iscsi_tcp: increase max_lun to ~0, don't care (Jan Vesely) [588679]
- [scsi] st: Take additional queue ref in st_probe (Tomas Henzl) [927988]

* Mon Jul 08 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-396.el6]
- [mm] block: optionally snapshot page contents to provide stable pages during write (Rafael Aquini) [951937]
- [mm] only enforce stable page writes if the backing device requires it (Rafael Aquini) [951937]
- [mm] bdi: allow block devices to say that they require stable page writes (Rafael Aquini) [951937]
- [mm] fix writeback_in_progress() (Rafael Aquini) [951937]
- [mm] ksm: unfolding of ksm_drop_anon_vma and hold_anon_vma functions (Petr Holasek) [947944]
- [mm] ksm: allocate roots when needed (Petr Holasek) [947944]
- [mm] ksm: swapoff might need to copy (Petr Holasek) [947944]
- [mm] ksm: FOLL_MIGRATION do migration_entry_wait (Petr Holasek) [947944]
- [mm] ksm: shrink 32-bit rmap_item back to 32 bytes (Petr Holasek) [947944]
- [mm] ksm: treat unstable nid like in stable tree (Petr Holasek) [947944]
- [mm] ksm: add some comments (Petr Holasek) [947944]
- [mm] ksm: stop hotremove lockdep warning (Petr Holasek) [947944]
- [mm] ksm: enable KSM page migration (Petr Holasek) [947944]
- [mm] ksm: make !merge_across_nodes migration safe (Petr Holasek) [947944]
- [mm] ksm: make KSM page migration possible (Petr Holasek) [947944]
- [mm] ksm: remove old stable nodes more thoroughly (Petr Holasek) [947944]
- [mm] ksm: get_ksm_page locked (Petr Holasek) [947944]
- [mm] ksm: reorganize ksm_check_stable_tree (Petr Holasek) [947944]
- [mm] ksm: trivial tidyups (Petr Holasek) [947944]
- [mm] ksm: add sysfs ABI Documentation (Petr Holasek) [947944]
- [mm] ksm: allow trees per NUMA node (Petr Holasek) [947944]
- [virt] kvm: Add a tracepoint write_tsc_offset (Marcelo Tosatti) [911567]
- [net] ipv4: fix invalid free in ip_cmsg_send() callers (Petr Matousek) [979788] {CVE-2013-2224}

* Tue Jul 02 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-395.el6]
- [x86] Revert: amd: Do not enable ARAT feature on AMD processors below family 0x12 (Prarit Bhargava) [808192 979105]
- [x86] Revert: apic: disable ARAT by default (Prarit Bhargava) [808192 979105]
- [x86] Revert: apic: mark ARAT Support as Tech Preview (Prarit Bhargava) [808192 979105]
- [s390] iucv: fix kernel panic at reboot (Hendrik Brueckner) [967907]
- [kernel] smp: introduce a generic on_each_cpu_mask() function (Hendrik Brueckner) [967907]
- [kernel] audit: wait_for_auditd() should use TASK_UNINTERRUPTIBLE (Oleg Nesterov) [962976]
- [kernel] audit: avoid negative sleep durations (Oleg Nesterov) [962976]
- [s390] dasd: fix hanging device after resume with internal error 13 (Hendrik Brueckner) [974191]
- [s390] cio: suppress 2nd path verification during resume (Hendrik Brueckner) [974191]
- [virt] kvm: Export svm/vmx exit code and vector code to userspace (Andrew Jones) [970607]
- [s390] mm: fix flush_tlb_kernel_range() (Hendrik Brueckner) [974192]
- [powerpc] Add VDSO version of getcpu (Steve Best) [929224]
- [kernel] sched: make weird topologies bootable (Radim Krcmar) [892677]
- [x86] perf: Fix offcore_rsp valid mask for SNB/IVB (Jiri Olsa) [971315] {CVE-2013-2146}
- [scsi] libsas: use right function to alloc smp response (David Milburn) [949887]
- [tools] perf/Documentation: Fix typos (Jiri Olsa) [970529]
- [tools] perf/evsel: Introduce is_group_member method (Jiri Olsa) [970529]
- [tools] perf/ui: Always compile browser setup code (Jiri Olsa) [970529]
- [tools] perf/ui: Add ui_progress__finish() (Jiri Olsa) [970529]
- [tools] perf/ui/gtk: Implement ui_progress functions (Jiri Olsa) [970529]
- [tools] perf/ui: Introduce generic ui_progress helper (Jiri Olsa) [970529]
- [tools] perf/ui/tui: Move progress.c under ui/tui directory (Jiri Olsa) [970529]
- [tools] perf: Add basic event modifier sanity check (Jiri Olsa) [970529]
- [tools] perf: Omit group members from perf_evlist__disable/enable (Jiri Olsa) [970529]
- [tools] perf: Ensure single disable call per event in record comand (Jiri Olsa) [970529]
- [tools] perf: Fix 'disabled' attribute config for record command (Jiri Olsa) [970529]
- [tools] perf: Fix attributes for '{}' defined event groups (Jiri Olsa) [970529]
- [tools] perf: Use sscanf for parsing /proc/pid/maps (Jiri Olsa) [970529]
- [tools] perf: Add gtk.<command> config option for launching GTK browser (Jiri Olsa) [970529]
- [tools] perf: Fix compile error on NO_NEWT=1 build (Jiri Olsa) [970529]
- [tools] perf/hists: Initialize all of he->stat with zeroes (Jiri Olsa) [970529]
- [tools] perf: Stop using 'self' in pstack (Jiri Olsa) [970529]
- [tools] perf/tests: Check for mkstemp return value in dso-data test (Jiri Olsa) [970529]
- [tools] perf/tests: Final cleanup for builtin-test move (Jiri Olsa) [970529]
- [tools] perf/tests: Move pmu tests into separate object (Jiri Olsa) [970529]
- [tools] perf/tests: Move test__syscall_open_tp_fields into separate object (Jiri Olsa) [970529]
- [tools] perf/tests: Move perf_evsel__tp_sched_test into separate object (Jiri Olsa) [970529]
- [tools] perf/tests: Move perf_evsel__roundtrip_name_test into separate object (Jiri Olsa) [970529]
- [tools] perf/tests: Move test__rdpmc into separate object (Jiri Olsa) [970529]
- [tools] perf/tests: Move test__PERF_RECORD into separate object (Jiri Olsa) [970529]
- [tools] perf/tests: Move test__basic_mmap into separate object (Jiri Olsa) [970529]
- [tools] perf/tests: Move test__open_syscall_event_on_all_cpus into separate object (Jiri Olsa) [970529]
- [tools] perf/tests: Move test__open_syscall_event into separate object (Jiri Olsa) [970529]
- [tools] perf/tests: Move test__vmlinux_matches_kallsyms into separate object (Jiri Olsa) [970529]
- [tools] perf/annotate: Merge same lines in summary view (Jiri Olsa) [970529]
- [tools] perf/annotate: Don't try to follow jump target on PLT symbols (Jiri Olsa) [970529]
- [tools] perf/annotate: Whitespace fixups (Jiri Olsa) [970529]
- [tools] perf/test: fix a build error on builtin-test (Jiri Olsa) [970529]
- [tools] perf/machine: Move more methods to machine code (Jiri Olsa) [970529]
- [tools] perf/diff: Use hists__link when not pairing just with baseline (Jiri Olsa) [970529]
- [tools] perf/hists: Introduce hists__link (Jiri Olsa) [970529]
- [tools] perf/diff: Move hists__match to the hists lib (Jiri Olsa) [970529]
- [tools] perf/diff: Start moving to support matching more than two hists (Jiri Olsa) [970529]
- [tools] perf: Don't try to lookup objdump for live mode (Jiri Olsa) [970529]
- [tools] perf: Add arbitary aliases and support names with - (Jiri Olsa) [970529]
- [tools] perf: Add LIBDW_DIR Makefile variable to for alternate libdw (Jiri Olsa) [970529]
- [tools] perf/tests: Move attr.py temp dir cleanup into finally section (Jiri Olsa) [970529]
- [tools] perf/hists: Free branch_info when freeing hist_entry (Jiri Olsa) [970529]
- [tools] perf: Fix detection of stack area (Jiri Olsa) [970529]
- [tools] perf/machine: Set kernel data mapping length (Jiri Olsa) [970529]
- [tools] perf/tests: Removing 'optional' field (Jiri Olsa) [970529]
- [tools] perf/tests: Fix attr watermark field name typo (Jiri Olsa) [970529]
- [tools] perf/tests: Factor attr tests WRITE_ASS macro (Jiri Olsa) [970529]
- [tools] perf/tests: Add missing attr stat basic test (Jiri Olsa) [970529]
- [tools] perf/report: Postpone objdump check until annotation requested (Jiri Olsa) [970529]
- [tools] perf: Introduce struct hist_browser_timer (Jiri Olsa) [970529]
- [tools] perf: Use normalized arch name for searching objdump path (Jiri Olsa) [970529]
- [tools] perf/tests: Add documentation for attr tests (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr stat default test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr stat default test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr stat event syntax group test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr stat group test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr stat no-inherit test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record branch filter tests (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record branch any test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record no delay test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record raw test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record data test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record no-inherit test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record no samples test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record period test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record graph test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record count test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record freq test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record event syntax group test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record group test (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr tests under builtin test command (Jiri Olsa) [970529]
- [tools] perf/tests: Add attr record basic test (Jiri Olsa) [970529]
- [tools] perf/tests: Add framework for automated perf_event_attr tests (Jiri Olsa) [970529]
- [tools] perf/tests: Move test objects into 'tests' directory (Jiri Olsa) [970529]
- [tools] perf/browser: Don't show scripts menu for 'perf top' (Jiri Olsa) [970529]
- [tools] perf: Remove BINDIR define from exec_cmd.o compilation (Jiri Olsa) [970529]
- [tools] perf/annotate: Handle XBEGIN like a jump (Jiri Olsa) [970529]
- [tools] perf: Handle --version string generation on machines without git (Jiri Olsa) [970529]
- [tools] perf: Further speed up the perf build (Jiri Olsa) [970529]
- [tools] perf: Speed up the perf build time by simplifying the perf --version string generation (Jiri Olsa) [970529]
- [tools] perf: Add info about cross compiling for Android ARM (Jiri Olsa) [970529]
- [tools] perf: Warn about missing libelf (Jiri Olsa) [970529]
- [tools] perf/python: Initialize 'page_size' variable (Jiri Olsa) [970529]
- [tools] perf/record: Fix mmap error output condition (Jiri Olsa) [970529]
- [tools] perf/header: Add is_perf_magic() func (Jiri Olsa) [970529]
- [tools] perf/browser: Integrate script browser into main hists browser (Jiri Olsa) [970529]
- [tools] perf/browser: Integrate script browser into annotation browser (Jiri Olsa) [970529]
- [tools] perf/browser: Add a browser for perf script (Jiri Olsa) [970529]
- [tools] perf/script: Add more filter to find_scripts() (Jiri Olsa) [970529]
- [tools] perf: Add a global variable "const char *input_name" (Jiri Olsa) [970529]
- [tools] perf: Move dso_* related functions into dso object (Jiri Olsa) [970529]
- [tools] perf: Move strxfrchar into string object (Jiri Olsa) [970529]
- [tools] perf: Move hex2u64 into util object (Jiri Olsa) [970529]
- [tools] perf: Move BUILD_ID_SIZE into build-id object (Jiri Olsa) [970529]
- [tools] perf: Move build_id__sprintf into build-id object (Jiri Olsa) [970529]
- [tools] perf: Move parse_events error printing to parse_events_options (Jiri Olsa) [970529]
- [tools] perf/stat: Add --pre and --post command (Jiri Olsa) [970529]
- [tools] perf/inject: Mark a dso if it's used (Jiri Olsa) [970529]
- [tools] perf/inject: Merge sched_stat_* and sched_switch events (Jiri Olsa) [970529]
- [tools] perf/inject: Work with files (Jiri Olsa) [970529]
- [tools] perf: Fix LIBELF_MMAP checking (Jiri Olsa) [970529]
- [tools] perf: Always show CHK message when doing try-cc (Jiri Olsa) [970529]
- [tools] perf: Convert invocation of MAKE into SUBDIR (Jiri Olsa) [970529]
- [tools] perf: Cleanup doc related targets (Jiri Olsa) [970529]
- [tools] perf/trace: Compat changes (Jiri Olsa) [970529]
- [tools] perf/trace: Use sched:sched_stat_runtime to provide a thread summary (Jiri Olsa) [970529]
- [tools] perf/trace: Count number of events for each thread and globally (Jiri Olsa) [970529]
- [tools] perf: Don't stop synthesizing threads when one vanishes (Jiri Olsa) [970529]
- [tools] perf: Try to build Documentation when installing (Jiri Olsa) [970529]
- [tools] perf/trace: Print the name of a syscall when failing to read its info (Jiri Olsa) [970529]
- [tools] perf: Pretty print errno for some more functions (Jiri Olsa) [970529]
- [tools] perf/trace: Add duration filter (Jiri Olsa) [970529]
- [tools] perf/trace: Add an event duration column (Jiri Olsa) [970529]
- [tools] perf/trace: Support interrupted syscalls (Jiri Olsa) [970529]
- [tools] perf/test: Align the 'Ok'/'FAILED!' test results (Jiri Olsa) [970529]
- [tools] perf: Give user better message if precise is not supported (Jiri Olsa) [970529]
- [tools] perf: Account the nr_entries in rblist properly (Jiri Olsa) [970529]
- [tools] perf: Try to find cross-built objdump path (Jiri Olsa) [970529]
- [tools] perf: Remove noise in python version feature test (Jiri Olsa) [970529]
- [tools] perf: Diplays more output on features check for make V=1 (Jiri Olsa) [970529]
- [tools] perf/test: Add automated tests for pmu sysfs translated events (Jiri Olsa) [970529]
- [tools] perf: Add support to specify hw event as PMU event term (Jiri Olsa) [970529]
- [tools] perf: Fix PMU object alias initialization (Jiri Olsa) [970529]
- [tools] perf/Documentation: add documentation on compiling for Android (Jiri Olsa) [970529]
- [tools] perf: Update Makefile for Android (Jiri Olsa) [970529]
- [tools] perf: Add on_exit implementation (Jiri Olsa) [970529]
- [tools] perf: Remove duplicated include from trace-event-python.c (Jiri Olsa) [970529]
- [tools] perf/machine: Carve up event processing specific from perf_tool (Jiri Olsa) [970529]
- [tools] perf/sched: Handle PERF_RECORD_EXIT events (Jiri Olsa) [970529]
- [tools] perf/annotate: Handle PERF_RECORD_EXIT events (Jiri Olsa) [970529]
- [tools] perf/event: No need to create a thread when handling PERF_RECORD_EXIT (Jiri Olsa) [970529]
- [tools] perf/machine: Introduce find_thread method (Jiri Olsa) [970529]
- [tools] perf: Have the page size value available for all tools (Jiri Olsa) [970529]
- [tools] perf/diff: Display empty space for non paired samples (Jiri Olsa) [970529]
- [tools] perf/diff: Include samples without symbol in overall stats (Jiri Olsa) [970529]
- [tools] perf/diff: Add -F option to display formula for computation (Jiri Olsa) [970529]
- [tools] perf/diff: Add -p option to display period values for hist entries (Jiri Olsa) [970529]
- [tools] perf/diff: Add weighted diff computation way to compare hist entries (Jiri Olsa) [970529]
- [tools] perf/diff: Add option to sort entries based on diff computation (Jiri Olsa) [970529]
- [tools] perf/diff: Add ratio computation way to compare hist entries (Jiri Olsa) [970529]
- [tools] perf/diff: Add -b option for perf diff to display paired entries only (Jiri Olsa) [970529]
- [tools] perf/trace: Add support for tracing workload given by command line (Jiri Olsa) [970529]
- [tools] perf/trace: Explicitly enable system-wide mode if no option is given (Jiri Olsa) [970529]
- [tools] perf/trace: Validate target task/user/cpu argument (Jiri Olsa) [970529]

* Fri Jun 28 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-394.el6]
- [fs] xfs: don't use speculative prealloc for small files (Brian Foster) [955254]
- [fs] xfs: xfs_iomap_prealloc_size() tracepoint (Brian Foster) [955254]
- [fs] xfs: add quota-driven speculative preallocation throttling (Brian Foster) [955254]
- [fs] xfs: xfs_dquot prealloc throttling watermarks and low free space (Brian Foster) [955254]
- [fs] xfs: pass xfs_dquot to xfs_qm_adjust_dqlimits() instead of xfs_disk_dquot_t (Brian Foster) [955254]
- [fs] xfs: push rounddown_pow_of_two() to after prealloc throttle (Brian Foster) [955254]
- [fs] xfs: reorganize xfs_iomap_prealloc_size to remove indentation (Brian Foster) [955254]
- [fs] xfs: Define a new function xfs_inode_dquot() (Brian Foster) [955254]
- [fs] xfs: Define a new function xfs_this_quota_on() (Brian Foster) [955254]
- [fs] xfs: fix xfs_iomap_eof_prealloc_initial_size type (Brian Foster) [955254]
- [fs] xfs: increase prealloc size to double that of the previous extent (Brian Foster) [955254]
- [fs] xfs: fix potential infinite loop in xfs_iomap_prealloc_size() (Brian Foster) [955254]
- [fs] xfs: limit speculative prealloc size on sparse files (Brian Foster) [955254]
- [fs] xfs: limit speculative prealloc near ENOSPC thresholds (Brian Foster) [955254]
- [fs] xfs: add background scanning to clear eofblocks inodes (Brian Foster) [955254]
- [fs] xfs: add minimum file size filtering to eofblocks scan (Brian Foster) [955254]
- [fs] xfs: support multiple inode id filtering in eofblocks scan (Brian Foster) [955254]
- [fs] xfs: add inode id filtering to eofblocks scan (Brian Foster) [955254]
- [fs] xfs: add XFS_IOC_FREE_EOFBLOCKS ioctl (Brian Foster) [955254]
- [fs] xfs: create function to scan and clear EOFBLOCKS inodes (Brian Foster) [955254]
- [fs] xfs: make xfs_free_eofblocks() non-static, return EAGAIN on trylock failure (Brian Foster) [955254]
- [fs] xfs: create helper to check whether to free eofblocks on inode (Brian Foster) [955254]
- [fs] xfs: support a tag-based inode_ag_iterator (Brian Foster) [955254]
- [fs] xfs: add EOFBLOCKS inode tagging/untagging (Brian Foster) [955254]
- [fs] ext3: Dont call dquot_free_block() if we dont update anything (Eric Sandeen) [790278]
- [fs] ext3: Update ctime in ext3_splice_branch() only when needed (Eric Sandeen) [790278]
- [fs] GFS2: Fall back to vmalloc if kmalloc fails for dir hash tables (Robert S Peterson) [962468]
- [fs] GFS2: Remove inode from i_ordered list in gfs2_clear_inode (Robert S Peterson) [859444]
- [fs] GFS2: fix FITRIM boundary condition errors (Abhijith Das) [891699]
- [fs] jbd[2]: enable CONFIG_JBD[2]_DEBUG on debug kernels (Eric Sandeen) [851269]
- [fs] nfsd4: dont close read-write opens too soon (J. Bruce Fields) [955238]
- [fs] GFS2: Add origin indicator to glock callbacks (Robert S Peterson) [855381]
- [fs] GFS2: Don:t cache iopen glocks (Robert S Peterson) [855381]
- [fs] ext2: update ctime when changing the file:s permission by setfacl (Eric Sandeen) [969323]
- [fs] fuse: fix alignment in short read optimization for async_dio (Brian Foster) [949805]
- [fs] fuse: return -EIOCBQUEUED from fuse_direct_IO() for all async requests (Brian Foster) [949805]
- [fs] fuse: add flag to turn on async direct IO (Brian Foster) [949805]
- [fs] fuse: truncate file if async dio failed (Brian Foster) [949805]
- [fs] fuse: optimize short direct reads (Brian Foster) [949805]
- [fs] fuse: enable asynchronous processing direct IO (Brian Foster) [949805]
- [fs] fuse: make fuse_direct_io() aware about AIO (Brian Foster) [949805]
- [fs] fuse: add support of async IO (Brian Foster) [949805]
- [fs] fuse: move fuse_release_user_pages() up (Brian Foster) [949805]
- [fs] fuse: Do not use RCU for current process credentials (Brian Foster) [949805]
- [fs] fuse: mark pages accessed when written to (Brian Foster) [949805]
- [fs] fuse: cleanup fuse_direct_io() (Brian Foster) [949805]
- [fs] fuse: update inode size and invalidate attributes on fallocate (Brian Foster) [927324]
- [fs] fuse: truncate pagecache range on hole punch (Brian Foster) [927324]
- [fs] fuse: optimize fallocate on permanent failure (Brian Foster) [927324]
- [fs] fuse: convert inode fallocate to file fallocate (Brian Foster) [927324]
- [fs] fuse: add FALLOCATE operation (Brian Foster) [927324]
- [fs] GFS2: Increase i_writecount during gfs2_setattr_size (Robert S Peterson) [968031]
- [fs] NFS4.1 Fix data server connection race (Steve Dickson) [961887]
- [fs] NFSv4: Dont recheck permissions on open in case of recovery cached open (Steve Dickson) [956865]
- [fs] NFSv4.1: Fix the callback highest_used_slotid behaviour (Steve Dickson) [960224]
- [fs] NFS: Cache state owners after files are closed (Steve Dickson) [800677]
- [fs] NFS: Move cl_state_owners and related fields to the nfs_server struct (Steve Dickson) [800677]
- [fs] NFSv4: Fix a readdir regression (Steve Dickson) [963337]
- [fs] xfs: return EOPNOTSUPP for unsupported acl format (Eric Sandeen) [963686]
- [fs] ext2: clear uptodate flag on super block I/O error (Eric Sandeen) [679930]
- [fs] ext4/jbd2: dont wait (forever) for stale tid caused by wraparound (Eric Sandeen) [955807]
- [fs] jbd: dont wait (forever) for stale tid caused by wraparound (Eric Sandeen) [955807]
- [fs] ext4: fix waiting and sending of a barrier in ext4_sync_file() (Eric Sandeen) [955807]
- [fs] jbd2: Add function jbd2_trans_will_send_data_barrier() (Eric Sandeen) [955807]
- [fs] jbd2: fix sending of data flush on journal commit (Eric Sandeen) [955807]
- [fs] ext4: fix fdatasync() for files with only i_size changes (Eric Sandeen) [955807]
- [fs] ext4: Initialize fsync transaction ids in ext4_new_inode() (Eric Sandeen) [955807]
- [fs] ext4: Rewrite __jbd2_log_start_commit logic to match upstream (Eric Sandeen) [955807]
- [net] sctp: Use correct sideffect command in duplicate cookie handling (Daniel Borkmann) [963843] {CVE-2013-2206}
- [net] macvlan: fix checksums error when we are in bridge mode (Vlad Yasevich) [893151]
- [net] bridge: Add const to dummy br_netpoll_send_skb (Flavio Leitner) [924294]
- [net] bridge: send query as soon as leave is received (Amerigo Wang) [952012]
- [net] bridge: only expire the mdb entry when query is received (Amerigo Wang) [952012]
- [net] bridge: Replace mp->mglist hlist with a bool (Amerigo Wang) [952012]
- [net] bond: add support to read speed and duplex via ethtool (Veaceslav Falico) [961131]
- [net] bridge: set fake_rtable's dst to NULL to avoid kernel Oops (Thomas Graf) [924033]
- [net] bonding: fire NETDEV_RELEASE event only on 0 slaves (Veaceslav Falico) [805098]

* Tue Jun 25 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-393.el6]
- [netdrv] igb: Removed unused i2c function (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Implementation of i210/i211 LED support (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix possible panic caused by Rx traffic arrival while interface is down (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix set_ethtool function to call update nvm for entire image (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: SerDes flow control setting (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Support for SFP modules discovery (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Add update to last_rx_timestamp in Rx rings (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Changed LEDs blink mechanism to include designs using cathode (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: limit udelay for phy changes to 10000us (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Bump version of driver (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Remove id's that will not be productized for Linux (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Remove dead code path (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Retain HW VLAN filtering while in promiscuous + VT mode (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: display a warning message when SmartSpeed works (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Use pci_vfs_assigned instead of igb_vfs_are_assigned (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Add SMBI semaphore to I210/I211 (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: SERDES loopback sigdetect bit on i210 devices (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Add support for i354 devices (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Enable EEE LP advertisement (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix code comments and whitespace (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix sparse warnings on function pointers (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Use rx/tx_itr_setting when setting up initial value of itr (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Pull adapter out of main path in igb_xmit_frame_ring (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Mask off check of frag_off as we only want fragment offset (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: random code and comments fix (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Implement support to power sfp cage and turn on I2C (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Support to read and export SFF-8472/8079 data (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Support for 100base-fx SFP (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: fix PHC stopping on max freq (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: make sensor info static (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: fix i350 anti spoofing config (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix for lockdep issue in igb_get_i2c_client (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix link setup for I210 devices (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Refractoring function pointers in igb_get_invariants function (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Intialize MAC function pointers (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Initialize NVM function pointers (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Initialize PHY function pointers (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Update igb to use a path similar to ixgbe to determine when to stop Tx (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Refix sparse warning in igb_get_i2c_client (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix for improper allocation flag in igb_get_i2c_client (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix for improper exit in igb_get_i2c_client (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Remove unnecessary alloc/OOM messages, alloc cleanups (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Copyright string update to year 2013 (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Replace rmb in Tx cleanup with read_barrier_depends (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Use in-kernel PTP_EV_PORT #define (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Free any held skb that should have been timestamped on remove (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Add mechanism for detecting latched hardware Rx timestamp (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Add timeout for PTP Tx work item (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Add support for SW timestamping (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: enable CONFIG_IGB_HWMON (Dean Nelson) [914835 923899 947526]
- [netdrv] igb: Enable hwmon data output for thermal sensors via I2C (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Add support functions to access thermal data (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Add i2c interface to igb (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Update igb version to 4.1.2 (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix SerDes autoneg flow control (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Unset sigdetect for SERDES loopback on 82580 and i350 (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Workaround for global device reset problem on 82580 (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Refactoring of i210 file (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Acquire, release semaphore for writing each EEPROM page (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Updates to read nvm function for i211 device (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Use a 32-bit mask when calculating the flow control watermarks (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Do not parse past IP header on fragments beyond the first (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: No longer rely on APME to determine WoL settings (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Update PTP Rx filters (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Ethtool support to enable and disable EEE (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Improve performance and reduce size of igb_tx_map (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: consolidate creation of Tx buffer info and data descriptor (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: convert to SKB paged frag API (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Update igb Tx flags to improve code efficiency (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Make TSO check for CHECKSUM_PARTIAL to avoid skb_is_gso check (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Support for modifying UDP RSS flow hashing (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Clear Go Link Disconnect for 82580 and later devices (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Enable clock drivers along with associated net/PHY drivers (Dean Nelson) [914835 923899 947526]
- [netdrv] igb: Fix EEPROM writes via ethtool on i210 (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Add function to read i211's invm version (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Remove workaround for EEE configuration on i210/I211 (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix sparse warning in igb_ptp_rx_pktstamp (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Update firmware version info for ethtool output (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Enable auto-crossover during forced operation on 82580 and above (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Update version (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Update get cable length function for i210/i211 (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Split igb_update_dca into separate Tx and Rx functions (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Lock buffer size at 2K even on systems with larger pages (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Move rx_buffer related code in Rx cleanup path into separate function (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Map entire page and sync half instead of mapping and unmapping half pages (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Combine post-processing of skb into a single function (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Do not use header split, instead receive all frames into a single buffer (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Split Rx timestamping into two separate functions (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Correcting and improving small packet check and padding (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Use dma_unmap_addr and dma_unmap_len defines (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Simplify how we populate the RSS key (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Change how we populate the RSS indirection table (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Change Tx cleanup loop to do/while instead of for (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Fix stats output on i210/i211 parts (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Support to enable EEE on all eee_supported devices (Stefan Assmann) [914835 923899 947526]
- [netdrv] igb: Remove artificial restriction on RQDPC stat reading (Stefan Assmann) [914835 923899 947526]
- [netdrv] pci: Add SRIOV helper function to determine if VFs are assigned to guest (Stefan Assmann) [914835 923899 947526]
- [net] phy: fix a bug when verify the EEE support (Nikolay Aleksandrov) [896263]
- [net] mdio: translation of MMD EEE registers to/from ethtool settings (Nikolay Aleksandrov) [896263]
- [net] phy: add the EEE support and the way to access to the MMD registers (Nikolay Aleksandrov) [896263]
- [edac] avoid mce decoding crash after edac driver unloaded (Prarit Bhargava) [787999]
- [x86] mce: Drain mcelog buffer (Prarit Bhargava) [787999]
- [x86] mce: Add wrappers for registering on the decode chain (Prarit Bhargava) [787999]
- [edac] sb_edac: Add it to the building system (Prarit Bhargava) [787999]
- [edac] i7core_edac: Drop the edac_mce facility (Prarit Bhargava) [787999]
- [x86] mce: Use notifier chain only for MCE decoding (Prarit Bhargava) [787999]
- [s390] crash: Fuzzy live dump for System z (Hendrik Brueckner) [929262]
- [s390] mm: allow absolute memory access for /dev/mem (Hendrik Brueckner) [929262]
- [s390] zcrypt: ap bus rescan problem when toggle crypto adapters on/off (Hendrik Brueckner) [929259]
- [s390] zcrypt: Handle AP configuration changes (Hendrik Brueckner) [929259]
- [s390] smp: lost IPIs on cpu hotplug (Hendrik Brueckner) [975179]
- [cdrom] use kzalloc() for failing hardware (Frantisek Hrbata) [973106] {CVE-2013-2164}

* Fri Jun 21 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-392.el6]
- [net] bridge: Set vlan_features to allow offloads on vlans (Vlad Yasevich) [951458]
- [virt] virtio-net: initialize vlan_features (Vlad Yasevich) [951458]
- [net] ipv6: assign rt6_info to inet6_ifaddr in init_loopback (Jiri Benc) [744655]
- [net] ipv6: Fix broken IPv6 routing table after loopback down-up (Jiri Benc) [744655]
- [s390] cio: add channel ID sysfs attribute (Hendrik Brueckner) [929274]
- [s390] cio: make use of newly added format 1 channel-path data (Hendrik Brueckner) [929274]
- [s390] cio: collect format 1 channel-path description data (Hendrik Brueckner) [929274]
- [s390] qeth: Support VEPA mode (Hendrik Brueckner) [929275]
- [s390] ccwgroup: allow drivers to call set_{on, off}line (Hendrik Brueckner) [929275]
- [s390] dasd: add safe offline interface (Hendrik Brueckner) [929264]
- [s390] dasd: add shutdown action (Hendrik Brueckner) [929264]
- [s390] dasd: Correct retry counter for terminated I/O (Hendrik Brueckner) [929264]
- [s390] perf_cpum_cf: fallback to software sampling events (Hendrik Brueckner) [823012]
- [s390] perf_cpum_cf: Add support for counters available with IBM zEC12 (Hendrik Brueckner) [823012]
- [s390] perf_cpum_cf: get rid of compile warnings (Hendrik Brueckner) [823012]
- [s390] perf: add support for s390x CPU counters (Hendrik Brueckner) [823012]
- [ata] libata-sff: port_task is SFF specific (David Milburn) [808672]
- [ata] libata-sff: introduce ata_sff_init/exit() and ata_sff_port_init() (David Milburn) [808672]
- [netdrv] qlge: Update version to 1.00.00.32 (Chad Dupuis) [927891]
- [netdrv] qlge: Fix ethtool autoneg advertising (Chad Dupuis) [927891]
- [netdrv] qlge: Fix receive path to drop error frames (Chad Dupuis) [927891]
- [netdrv] qlge: Fixed a coding style issue (Chad Dupuis) [927891]
- [kernel] sched: Do not account bogus utime (Stanislaw Gruszka) [912662]
- [kernel] sched: Avoid cputime scaling overflow (Stanislaw Gruszka) [912662]
- [acpi] Verify device status after eject (Nigel Croxon) [869134]
- [acpi] Update CPU hotplug error messages (Nigel Croxon) [869134]
- [acpi] Add acpi_handle_<level>() interfaces (Nigel Croxon) [869134]
- [acpi] Export functions for hot-remove (Nigel Croxon) [869134]
- [acpi] Add ACPI CPU hot-remove support (Nigel Croxon) [869134]
- [acpi] Fix stale pointer access to flags.lockable (Nigel Croxon) [869134]
- [acpi] processor_core: prevent cpu from becoming online (Nigel Croxon) [869134]
- [acpi] Set hotplug _OST support bit to _OSC (Nigel Croxon) [869134]
- [acpi] Add _OST support for ACPI container hotplug (Nigel Croxon) [869134]
- [acpi] Add _OST support for ACPI memory hotplug (Nigel Croxon) [869134]
- [acpi] Add _OST support for ACPI CPU hotplug (Nigel Croxon) [869134]
- [acpi] Add _OST support for sysfs eject (Nigel Croxon) [869134]
- [acpi] Add an interface to evaluate _OST (Nigel Croxon) [869134]
- [acpi] scan: return -ENODEV if no device was found (Nigel Croxon) [869134]
- [acpi] processor_core: add missing kfree (Nigel Croxon) [869134]
- [acpi] processor_core: Add CPU hotplug support for processor device objects (Nigel Croxon) [869134]
- [acpi] processor_core: Do not try to set up acpi processor stuff on cores exceeding maxcpus (Nigel Croxon) [869134]
- [idle] intel_idle: Don't register CPU notifier if we are not running (Nigel Croxon) [869134]
- [idle] intel_idle: break dependency between modules (Nigel Croxon) [869134]
- [acpi] processor_core: remove duplicated lines of merging problems with acpi_processor_add (Nigel Croxon) [869134]
- [acpi] processor_core: Delay acpi_processor_start() call for hotplugged cores (Nigel Croxon) [869134]
- [acpi] processor_core: Split up acpi_processor_add (Nigel Croxon) [869134]
- [idle] intel_idle: Split up and provide per CPU initialization func (Nigel Croxon) [869134]
- [acpi] processor_core: Remove unneeded variable passed by acpi_processor_hotadd_init (Nigel Croxon) [869134]
- [s390] scm: process availability (Hendrik Brueckner) [929257]
- [s390] scm_blk: suspend writes (Hendrik Brueckner) [929257]
- [s390] scm_drv: extend notify callback (Hendrik Brueckner) [929257]
- [s390] scm_blk: fix request number accounting (Hendrik Brueckner) [929257]
- [s390] scm: reorder scm_remove (Hendrik Brueckner) [929257]

* Wed Jun 19 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-391.el6]
- [crypto] Revert: unmark gcm(aes) as fips_allowed (Jarod Wilson) [915637]
- [crypto] testmgr: allow aesni-intel and ghash_clmulni-intel in fips mode (Jarod Wilson) [915637]
- [crypto] testmgr: silence warnings about no tests for aesni algorithms (Jarod Wilson) [915637]
- [crypto] Use scatterwalk_crypto_chain (Jarod Wilson) [786972]
- [crypto] scatterwalk: Add scatterwalk_crypto_chain helper (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: fix Kconfig problem with CRYPTO_GLUE_HELPER_X86 (Jarod Wilson) [786968 786972 969522]
- [crypto] gcm: Add RFC4543 wrapper for GCM (Jarod Wilson) [786968 786972 969522]
- [crypto] glue_helper: add more optimized XTS-mode for serpent-avx (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: add more optimized XTS mode for x86-64 (Jarod Wilson) [786968 786972 969522]
- [crypto] glue_helper: use le128 instead of u128 for CTR mode (Jarod Wilson) [786968]
- [crypto] glue_helper: cast6/avx, avoid using temporary stack buffers (Jarod Wilson) [786968 786972 969522]
- [crypto] glue_helper: serpent-sse2, split generic glue code to new helper module (Jarod Wilson) [786968 786972 969522]
- [crypto] ghash-intel: assembler clean-up, use ENDPROC at end of assember functions (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: add ENDPROC statements for assembler functions (Jarod Wilson) [786968 786972 969522]
- [crypto] aes-x86: assembler clean-ups, use ENTRY/ENDPROC, localize jump targets (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: remove rfc3686(ctr(aes)), utilize rfc3686 from ctr-module instead (Jarod Wilson) [786968]
- [crypto] ctr: make rfc3686 asynchronous block cipher (Jarod Wilson) [786968 786972 969522]
- [net] xfrm_algo: probe asynchronous block ciphers instead of synchronous (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: fix XTS mode on x86-32, add wrapper function for asmlinkage aesni_enc() (Jarod Wilson) [786968 786972 969522]
- [crypto] lrw: add interface for parallelized cipher implementions (Jarod Wilson) [786968 786972 969522]
- [crypto] lrw: split gf128mul table initialization from setkey (Jarod Wilson) [786968 786972 969522]
- [crypto] lrw: use blocksize constant (Jarod Wilson) [786968 786972 969522]
- [crypto] crypto: cryptd - disable softirqs in cryptd_queue_worker to prevent data corruption (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: improve lrw and xts performance by utilizing parallel AES-NI hardware pipelines (Jarod Wilson) [786968 786972 969522]
- [crypto] xts: remove dependency on EXPERIMENTAL (Jarod Wilson) [786968 786972 969522]
- [crypto] lrw: remove dependency on EXPERIMENTAL (Jarod Wilson) [786968 786972 969522]
- [crypto] xts: add interface for parallelized cipher implementations (Jarod Wilson) [786968 786972 969522]
- [crypto] xts: use blocksize constant (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: fix wrong kfree pointer (Jarod Wilson) [786972]
- [crypto] aesni-intel: change to use shared ablk_* functions (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: use crypto_{un}register_algs (Jarod Wilson) [786968 786972 969522]
- [crypto] Add bulk algorithm registration interface (Jarod Wilson) [786968 786972 969522]
- [crypto] ablk_helper: move ablk_* functions from serpent-sse2/avx glue code to shared module (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: fix unaligned cbc decrypt for x86-32 (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: move more common code to ablk_init_common (Jarod Wilson) [786968 786972 969522]
- [crypto] aes-x86: quiet sparse noise about symbol not declared (Jarod Wilson) [786968 786972 969522]
- [crypto] cryptd: Use subsys_initcall to prevent races with aesni (Jarod Wilson) [786968 786972 969522]
- [crypto] ghash-intel: Fix set but not used in ghash_async_setkey() (Jarod Wilson) [786972]
- [crypto] aesni-intel: fix aesni build on i386 (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: Merge with fpu.ko (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: fixed problem with packets that are not multiple of 64bytes (Jarod Wilson) [786972]
- [crypto] aesni-intel: Fix remaining leak in rfc4106_set_hash_key (Jarod Wilson) [786972]
- [crypto] aesni-intel: Don't leak memory in rfc4106_set_hash_subkey (Jarod Wilson) [786972]
- [crypto] ghash-intel: ghash-clmulni-intel_glue needs err.h (Jarod Wilson) [786972]
- [crypto] aesni-intel: Fixed build with binutils 2.16 (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: Fixed build error on x86-32 (Jarod Wilson) [786968 969522]
- [crypto] aesni-intel: Ported implementation to x86-32 (Jarod Wilson) [786968 786972 969522]
- [crypto] aesni-intel: RFC4106 AES-GCM Driver Using Intel New Instructions (Jarod Wilson) [786972]
- [crypto] cryptd: Adding the AEAD interface type support to cryptd (Jarod Wilson) [786972]
- [crypto] aesni-intel: Fix another CTR build failure with gas 2.16.1 (Jarod Wilson) [786968]
- [crypto] aesni-intel: Fix CTR optimization build failure with gas 2.16.1 (Jarod Wilson) [786968]
- [crypto] aesni-intel: Add AES-NI accelerated CTR mode (Jarod Wilson) [786968]
- [crypto] ghash-clmulni-intel: Put proper .data section in place (Jarod Wilson) [921642]
- [s390] Revert: kernel: add support for physical memory > 4TB (Jarod Wilson) [913220]
- [kernel] perf: Fix perf_event_for_each() to use sibling (Jiri Olsa) [967933]
- [x86] perf: Add format attributes for p4 (Jiri Olsa) [967933]
- [x86] perf: Adding sysfs group format attribute for pmu device (Jiri Olsa) [967933]
- [x86] perf: Fix local vs remote memory events for NHM/WSM (Jiri Olsa) [967933]
- [tools] perf: Remove deprecated WARN_ON_ONCE() (Jiri Olsa) [967933]
- [tools] perf: Call perf_cgroup_event_time() directly (Jiri Olsa) [967933]
- [tools] perf: Don't call release_callchain_buffers() if allocation fails (Jiri Olsa) [967933]
- [mfd] lpc_ich: Add support for Intel Avoton SoC (Neil Horman) [922965]
- [mfd] lpc_ich: Use devres API to allocate private data (Neil Horman) [922965]
- [mfd] lpc_ich: Add Device IDs for Intel Wellsburg PCH (Neil Horman) [922965]
- [mfd] lpc_ich: Fix gpio base and control offsets (Neil Horman) [922965]
- [mfd] lpc_ich: One uninitialized cell is no error (Neil Horman) [922965]
- [mfd] lpc_ich: Fix resource request for mem 0x00000000 (Neil Horman) [922965]
- [mfd] lpc_ich: Add Device IDs for Intel Lynx Point-LP PCH (Neil Horman) [922965]
- [mfd] lpc_ich: Fix regression for iTCO_wdt driver (Neil Horman) [922965]
- [mfd] Check for mem_base when building IORESOURCE_MEM resources (Neil Horman) [922965]
- [watchdog] iTCO_wdt: Convert iTCO_wdt driver to mfd model (Neil Horman) [922965]
- [watchdog] iTCO_wdt: Use pr_<fmt> and pr_<level> (Neil Horman) [922965]
- [watchdog] iTCO_wdt: fix TCO V1 timeout values and limits (Neil Horman) [922965]
- [mfd] Add LPC driver for Intel ICH chipsets (Neil Horman) [922965]
- [i2c] i801: SMBus patch for Intel Avoton DeviceIDs (Neil Horman) [922965]
- [i2c] iSMT: add Intel Avoton DeviceIDs (Neil Horman) [922965]
- [ata] ata_piix: IDE-mode SATA patch for Intel Avoton DeviceIDs (Neil Horman) [922965]
- [ata] ata_piix: make DVD Drive recognisable on systems with Intel Sandybridge chipsets (Neil Horman) [922965]
- [ata] ahci: AHCI-mode SATA patch for Intel Avoton DeviceIDs (Neil Horman) [922965]
- [usb] xhci: correct comp_mode_recovery_timer on return from hibernate (Tony Camuso) [888974]
- [acpi] Don't let acpi_pad needlessly mark TSC unstable (Lenny Szubowicz) [907545]
- [acpi] acpica: Remove extraneous warning for very large GPE registers (Nigel Croxon) [924873]
- [kernel] async: Make async execution api a little more fair in scheduling (Neil Horman) [871955]
- [md] dm-stripe: fix regression in stripe_width calculation (Mike Snitzer) [960277]
- [block] fix ext_devt_idr handling (Tomas Henzl) [735927]
- [md] dm-crypt: fix mempool deadlock (Mike Snitzer) [831158]
- [scsi] libsas: fix handling vacant phy in sas_set_ex_phy() (David Milburn) [949905]
- [mm] swap: avoid read_swap_cache_async() race to deadlock while waiting on discard I/O completion (Rafael Aquini) [827548]
- [mm] compaction: fix /proc/sys/vm/compact_memory crash (Johannes Weiner) [953680 955525]
- [mm] fadvise: drain all pagevecs if POSIX_FADV_DONTNEED fails to discard all pages (Larry Woodman) [957821]
- [pci] dmar: Remove warning for HPET scope type (Nigel Croxon) [956310]

* Fri Jun 14 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-390.el6]
- [fs] nfs: Fix an NFS client lockdep issue (Jeff Layton) [891937]
- [acpi] acpi_pad: fix power_saving thread deadlock (Lenny Szubowicz) [751123]
- [powerpc] rtas_flash: Fix validate_flash buffer overflow issue (Steve Best) [956385]
- [powerpc] rtas_flash: Fix bad memory access (Steve Best) [956385]
- [powerpc] rtas_flash: New return code to indicate FW entitlement expiry (Steve Best) [956385]
- [powerpc] rtas_flash: Update return token comments (Steve Best) [956385]
- [powerpc] rtas_flash: Free kmem upon module exit (Steve Best) [956385]
- [netdrv] igb: SR-IOV init reordering (Stefan Assmann) [920652]
- [netdrv] igb: Fix null pointer dereference (Stefan Assmann) [920652]
- [netdrv] igb: Enable SR-IOV configuration via PCI sysfs interface (Stefan Assmann) [920652]
- [powerpc] Fix VMX fix for memcpy case (Steve Best) [929280]
- [powerpc] Fix VMX in interrupt check in POWER7 copy loops (Steve Best) [929280]
- [powerpc] POWER7 optimised memcpy using VMX and enhanced prefetch (Steve Best) [929280]
- [powerpc] POWER7 optimised copy_page using VMX and enhanced prefetch (Steve Best) [929280]
- [powerpc] Rename copyuser_power7_vmx.c to vmx-helper.c (Steve Best) [929280]
- [powerpc] Use enhanced touch instructions in POWER7 copy_to_user/copy_from_user (Steve Best) [929280]
- [powerpc] Simplify 4k/64k copy_page logic (Steve Best) [929280]
- [powerpc] Add 64bit csum_and_copy_to_user (Steve Best) [929280]
- [powerpc] Optimise 64bit csum_partial_copy_generic and add csum_and_copy_from_user (Steve Best) [929280]
- [powerpc] Optimise 64bit csum_partial (Steve Best) [929280]
- [kernel] trace: Allow archs to ignore tracing compat syscalls (Josh Poimboeuf) [881038]
- [kernel] trace: Fix perf syscall tracing when syscall_nr == -1 (Josh Poimboeuf) [881038]
- [netdrv] 8139cp: Prevent dev_close/cp_interrupt race on MTU change (John Green) [767885]
- [netdrv] 8139cp: properly support change of MTU values (John Green) [767885]
- [pci] make re-allocation try harder by reassigning ranges higher in the heirarchy (Takahiro MUNEDA) [965006]
- [pci] code and comments cleanup (Takahiro MUNEDA) [965006]
- [pci] make cardbus-bridge resources optional (Takahiro MUNEDA) [965006]
- [pci] honor child buses add_size in hot plug configuration (Takahiro MUNEDA) [965006]
- [pci] ability to relocate assigned pci-resources (Takahiro MUNEDA) [965006]
- [pci] make SRIOV resources optional (Takahiro MUNEDA) [965006]
- [s390] console: fix 3215 console crash (Hendrik Brueckner) [970779]
- [s390] scm_blk: allow more cluster size values (Hendrik Brueckner) [963068]
- [s390] mm: protection exception PSW for aborted transaction (Hendrik Brueckner) [958271]
- [s390] hibernate: Save and restore absolute zero pages (Hendrik Brueckner) [952739]
- [s390] kdump: Add PM notifier for kdump (Hendrik Brueckner) [952738]
- [s390] qeth: fix qeth_wait_for_threads() deadlock for OSN devices (Hendrik Brueckner) [952448]
- [s390] module: Add missing R_390_NONE relocation type (Hendrik Brueckner) [952449]
- [s390] dasd: fix unresponsive device after all channel paths were lost (Hendrik Brueckner) [915731]
- [s390] kernel: add support for physical memory > 4TB (Hendrik Brueckner) [913220]
- [s390] zcore: Add hsa file (Hendrik Brueckner) [915356]
- [s390] ipl: Implement diag308 loop for zfcpdump (Hendrik Brueckner) [915364]
- [s390] eadm_sch: fix driver initialization (Hendrik Brueckner) [912489]
- [s390] zfcp: Do not wakeup while suspended (Hendrik Brueckner) [855129]
- [s390] time: fix sched_clock() overflow (Hendrik Brueckner) [903334]
- [s390] irq: enable irq sum accounting for /proc/stat again (Hendrik Brueckner) [903333]
- [s390] dasd: prevent path verification before resume (Hendrik Brueckner) [903331]
- [s390] dasd: fix unaccessible device after resume (Hendrik Brueckner) [903339]
- [security] selinux: fix parallel compile error (Frantisek Hrbata) [962427]
- [acpi] Evaluate thermal trip points before reading temperature (Tony Camuso) [929293]
- [kernel] time: Fix setting of hardware clock in NTP code (Prarit Bhargava) [912704]
- [x86] quirks: use 'intremap=off' instead of 'nointremap' for consistency (Prarit Bhargava) [960828]
- [fs] proc: fix pagemap_read() error case (Larry Woodman) [918119]
- [base] node: fix off-by-one bug in print_nodes_state() (Prarit Bhargava) [871215]
- [netdrv] sky2: fix scheduling while atomic in sky2_vlan_rx_register (Nikolay Aleksandrov) [920754]
- [netdrv] netxen: write IP address to firmware when using bonding (Nikolay Aleksandrov) [924667]
- [netdrv] be2net: remove BUG_ON() in be_mcc_compl_is_new() (Ivan Vecera) [909488]
- [netdrv] igb: increase timeout for ethtool offline self-test (Stefan Assmann) [906240]
- [netdrv] qlcnic: sleeping function called from invalid context (Amerigo Wang) [907310]
- [netdrv] be2net: ensure all events are ack'ed prior calling be_eq_clean (Ivan Vecera) [884442]
- [pci] Document MPS parameters pci=pcie_bus_safe, pci=pcie_bus_perf, etc (Myron Stowe) [910604]

* Wed Jun 12 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-389.el6]
- [virt] kvm: fix copy to user with irq disabled (Michael S. Tsirkin) [906602] {CVE-2013-1935}
- [netdrv] usb/cdc_ncm: apply usbnet_link_change (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: demote "unexpected notification" to debug level (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: return -ENOMEM if kzalloc fails (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: allow user to prefer NCM for backwards compatibility (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: tag Huawei devices (e.g. E5331) with FLAG_WWAN (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: fix probing of devices with multiple control interface altsettings (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: add another Huawei vendor specific device (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: use IAD provided by the USB core (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: add support FLAG_NOARP for Infineon modem platform (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: fix error path for single interface probing (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: workaround for missing CDC Union (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: fix drvinfo strings set in drivers for ethtool (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: use generic usbnet_manage_power() (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: add Huawei devices (Neil Horman) [815934]
- [usb] add USB_VENDOR_AND_INTERFACE_INFO() macro (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: error path lock fix (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: big endian fix (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: apply introduced usb command APIs (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: do not bind to NCM compatible MBIM devices (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: adding MBIM driver (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: export shared symbols and definitions (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: errata updates for cdc.h (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: fix one more typo (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: add missed constants and structures (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: typo and style fixes (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: ncm constants and structures added (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: refactoring for tx multiplexing (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: splitting rx_fixup for code reuse (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: process chained NDPs (Neil Horman) [815934]
- [netdrv] net/cdc_ncm: refactor bind preparing for MBIM support (Neil Horman) [815934]
- [netdrv] net/cdc_ncm: adding MBIM support to ncm_setup (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: add MBIM constants and structures (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: workaround NTB input size firmware bug (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: tag Ericsson WWAN devices (eg F5521gw) with FLAG_WWAN (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: tag Ericsson WWAN devices (eg F5521gw) with FLAG_WWAN (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: Disable hub-initiated LPM for comms devices (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: avoid discarding datagrams in rx path (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: fix MTU and max_datagram_size handling (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: reduce driver latency in the data path (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: print MAC via printk format specifier (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: make ethtool_ops const (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: Use kzalloc rather than kmalloc followed by memset with 0 (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: convert drivers/net/* to use module_usb_driver() (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: Don't use stack variables for DMA (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: fix endianness problem (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: Remove unneeded version.h includes from drivers/net/ (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: add missing .reset_resume hook (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: release interfaces fix in unbind() (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: Add mising short packet in cdc_ncm driver (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: fix short packet issue on some devices (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: use ethd name for known ethernet devices (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: errata updates for cdc_ncm host driver (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: tx_fixup() race condition fix (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: Don't deref NULL in cdc_ncm_rx_fixup() and don't use uninitialized variable (Neil Horman) [815934]
- [netdrv] usb/cdc_ncm: USB CDC NCM host driver (Neil Horman) [815934]
- [netdrv] usb/serial/sierra: Add support for Sierra Wireless AirCard 320U modem (Neil Horman) [884869]
- [netdrv] sierra_net: keep status interrupt URB active (Neil Horman) [884869]
- [netdrv] sierra_net: apply usbnet_link_change (Neil Horman) [884869]
- [netdrv] sierra_net: Remove unnecessary alloc/OOM messages (Neil Horman) [884869]
- [netdrv] sierra_net: fix ethtool drvinfo strings set in drivers (Neil Horman) [884869]
- [netdrv] sierra_net: shut up sparse restricted type warnings (Neil Horman) [884869]
- [netdrv] usbnet: sierra_net: apply introduced usb command APIs (Neil Horman) [884869]
- [netdrv] sierra_net: Endianess bug fix (Neil Horman) [884869]
- [netdrv] sierra_net: removes unnecessary semicolon (Neil Horman) [884869]
- [netdrv] sierra_net: make private symbols static (Neil Horman) [884869]
- [netdrv] sierra_net: device IDs for Aircard 320U++ (Neil Horman) [884869]
- [netdrv] usbnet: make ethtool_ops const (Neil Horman) [884869]
- [netdrv] sierra_net: convert to use module_usb_driver() (Neil Horman) [884869]
- [netdrv] sierra_net: don't use flush_scheduled_work() (Neil Horman) [884869]
- [netdrv] sierra_net: return operator cleanup (Neil Horman) [884869]
- [netdrv] sierra_net: use __packed annotation (Neil Horman) [884869]
- [netdrv] sierra_net: initiate sync sequence in sierra_net.c driver (Neil Horman) [884869]
- [netdrv] sierra_net: add sierra_net driver (Neil Horman) [884869]
- [netdrv] usbnet: allow status interrupt URB to always be active (Neil Horman) [884869]
- [netdrv] usbnet: handle link change (Neil Horman) [884869]
- [netdrv] usbnet: apply usbnet_link_change (Neil Horman) [884869]
- [netdrv] usbnet: introduce usbnet_link_change API (Neil Horman) [884869]
- [netdrv] usbnet: Remove unnecessary alloc/OOM messages (Neil Horman) [884869]
- [netdrv] usbnet: fix tx_dropped statistics (Neil Horman) [884869]
- [netdrv] usbnet: prevent buggy devices from killing us (Neil Horman) [884869]
- [netdrv] usbnet: fix regression from FLAG_NOARP code (Neil Horman) [884869]
- [netdrv] usbnet: add new flag FLAG_NOARP for usb net devices (Neil Horman) [884869]
- [netdrv] usbnet: generic manage_power() (Neil Horman) [884869]
- [netdrv] usbnet: handle PM failure gracefully (Neil Horman) [884869]
- [netdrv] usbnet: ratelimit kevent may have been dropped warnings (Neil Horman) [884869]
- [netdrv] usbnet: runtime wake up device before calling usbnet_{read|write}_cmd (Neil Horman) [884869]
- [netdrv] usbnet: introduce usbnet_{read|write}_cmd_nopm (Neil Horman) [884869]
- [netdrv] usbnet: Fix memory leak on Tx data path (Neil Horman) [884869]
- [netdrv] usbnet: introduce usbnet 3 command helpers (Neil Horman) [884869]
- [netdrv] usbnet: Support devices reporting idleness (Neil Horman) [884869]
- [netdrv] usbnet: fix softirq storm on suspend (Neil Horman) [884869]
- [netdrv] usbnet: fix deadlock in resume (Neil Horman) [884869]
- [netdrv] usbnet: Use eth_random_addr (Neil Horman) [884869]
- [netdrv] usbnet: handle remote wakeup asap (Neil Horman) [884869]
- [netdrv] usbnet: clear OPEN flag in failure path (Neil Horman) [884869]
- [netdrv] usbnet: sanitise overlong driver information strings (Neil Horman) [884869]
- [netdrv] usbnet: don't initialize transfer buffer before submit status URB (Neil Horman) [884869]
- [netdrv] usbnet: remove declaration for intr_complete (Neil Horman) [884869]
- [netdrv] usbnet: remove usb_get/put_dev in .probe and .disconnect (Neil Horman) [884869]
- [netdrv] usbnet: fix skb traversing races during unlink (Neil Horman) [884869]
- [netdrv] usbnet: fix failure handling in usbnet_probe (Neil Horman) [884869]
- [netdrv] usbnet: fix leak of transfer buffer of dev->interrupt (Neil Horman) [884869]
- [netdrv] usbnet: consider device busy at each recieved packet (Neil Horman) [884869]
- [netdrv] usbnet: don't clear urb->dev in tx_complete (Neil Horman) [884869]
- [netdrv] usbnet: increase URB reference count before usb_unlink_urb (Neil Horman) [884869]
- [netdrv] usbnet: use netif_tx_wake_queue instead of netif_start_queue (Neil Horman) [884869]
- [netdrv] usbnet: reserve headroom on rx skbs (Neil Horman) [884869]
- [netdrv] usbnet: avoid recursive locking in usbnet_stop() (Neil Horman) [884869]
- [netdrv] usbnet: fix oops in usbnet_start_xmit (Neil Horman) [884869]
- [netdrv] usbnet: fix a few typos in comments (Neil Horman) [884869]
- [netdrv] usbnet: fix out of memory during runtime pm (Neil Horman) [884869]
- [netdrv] usbnet: remove flag of EVENT_DEV_WAKING (Neil Horman) [884869]
- [netdrv] usbnet: Resubmit interrupt URB if device is open (Neil Horman) [884869]
- [netdrv] usbnet: Use FIELD_SIZEOF macro in usbnet_init() function (Neil Horman) [884869]
- [netdrv] usbnet: use ethd name for known ethernet devices (Neil Horman) [884869]
- [netdrv] usbnet: Fix up 'FLAG_POINTTOPOINT' and 'FLAG_MULTI_PACKET' overlaps (Neil Horman) [884869]
- [netdrv] usbnet: Ethernet quirks for the LG-VL600 4G modem (Neil Horman) [884869]
- [netdrv] usbnet: Fix leak when usb_autopm_get_interface() returns less than zero in kevent() (Neil Horman) [884869]
- [netdrv] usbnet: don't use flush_scheduled_work() (Neil Horman) [884869]
- [netdrv] usbnet: changes for upcoming cdc_ncm driver (Neil Horman) [884869]
- [netdrv] usbnet: fix usb_autopm_get_interface failure (Neil Horman) [884869]
- [netdrv] usbnet: rx_submit() should return an error code (Neil Horman) [884869]
- [netdrv] usbnet: remove noisy and hardly useful printk (Neil Horman) [884869]
- [netdrv] usbnet: use jiffies in schedule_timeout(), not msecs (Neil Horman) [884869]
- [netdrv] usbnet: use newly introduced hex_to_bin() (Neil Horman) [884869]
- [netdrv] usbnet: Set parent device early for netdev_printk() (Neil Horman) [884869]
- [netdrv] usbnet: Print device statistics as unsigned (Neil Horman) [884869]
- [netdrv] usbnet: Adding URB_ZERO_PACKET flag to usbnet.c (Neil Horman) [884869]
- [netdrv] usbnet: Use netif_<level> logging facilities (Neil Horman) [884869]
- [netdrv] usbnet: Convert dev(dbg|err|warn|info) macros to netdev_<level> (Neil Horman) [884869]
- [netdrv] usbnet: Autosuspend for online devices (Neil Horman) [884869]
- [netdrv] usbnet: Move && and || to end of previous line (Neil Horman) [884869]
- [netdrv] usbnet: Set link down initially for drivers that update link state (Neil Horman) [884869]
- [netdrv] usbnet: Set device type for wlan and wwan devices (Neil Horman) [884869]
- [netdrv] usbnet: Use wwand interface name for mobile broadband devices (Neil Horman) [884869]
- [edac] sb_edac: do not require prescence of IMC_DDRIO device (Mauro Carvalho Chehab) [923451]
- [edac] sb_edac: fix the error about memory type detection on SandyBridge (Mauro Carvalho Chehab) [923451]
- [dma] ioat: Fix excessive CPU utilization (John Feeney) [883575]
- [wireless] b43: stop format string leaking into error msgs (John Linville) [971389] {CVE-2013-2852}

* Tue Jun 11 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-388.el6]
- [powerpc] crypto: Enable the PFO-based encryption device (Steve Best) [929325]
- [crypto] nx: Build files for the nx device driver (Steve Best) [929325]
- [crypto] nx: Fixes for multiple races and issues (Steve Best) [929325]
- [crypto] nx: debugfs routines and docs for the nx device driver on powerpc (Steve Best) [929325]
- [crypto] nx: SHA512 hash routines for nx encryption on powerpc (Steve Best) [929325]
- [crypto] nx: SHA256 hash routines for nx encryption on powerpc (Steve Best) [929325]
- [crypto] nx: AES-XCBC mode routines for nx encryption on powerpc (Steve Best) [929325]
- [crypto] nx: AES-GCM mode routines for nx encryption on powerpc (Steve Best) [929325]
- [crypto] nx: AES-ECB mode routines for nx encryption on powerpc (Steve Best) [929325]
- [crypto] nx: AES-CTR mode routines for nx encryption on powerpc (Steve Best) [929325]
- [crypto] nx: AES-CCM mode routines for nx encryption on powerpc (Steve Best) [929325]
- [crypto] nx: AES-CBC mode routines for nx encryption on powerpc (Steve Best) [929325]
- [crypto] nx: driver code supporting nx encryption on powerpc (Steve Best) [929325]
- [x86] apic: mark ARAT Support as Tech Preview (Prarit Bhargava) [808192]
- [x86] apic: disable ARAT by default (Prarit Bhargava) [808192]
- [x86] amd: Do not enable ARAT feature on AMD processors below family 0x12 (Prarit Bhargava) [808192]
- [tools] perf: Fix SIGALRM and pipe read race for rwtop (Jiri Olsa) [907366]
- [tools] perf: Removing 'nr' field from rw* scripts (Jiri Olsa) [905007]
- [netdrv] bnx2: dma_alloc_coherent, use __GFP_ZERO instead of memset(, 0) (Neil Horman) [917110]
- [netdrv] bnx2: Rename register read and write macros (Neil Horman) [917110]
- [char] n_tty: Remove BUG_ON from n_tty_read() (Stanislaw Gruszka) [848085]
- [base] cpu: emit KOBJ_ADD after 'online' attribute is created (Igor Mammedov) [878749]
- [target] backport LIO from upstream 3.9 (Andy Grover) [903297]
- [scsi] Allow error handling timeout to be specified (Ewan Milne) [826061]
- [pci] make sriov work with hotplug remove (Takahiro MUNEDA) [965002]
- [nfs] sunrpc: Prevent an rpc_task wakeup race (Dave Wysochanski) [840860]
- [nfs] sunrpc: clarify comments on rpc_make_runnable (Dave Wysochanski) [840860]

* Mon Jun 10 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-387.el6]
- [fs] gfs2: Use single-block reservations for directories (Robert S Peterson) [914725]
- [fs] gfs2: Speed up gfs2_rbm_from_block (Robert S Peterson) [914725]
- [fs] gfs2: Remove vestigial parameter ip from function rs_deltree (Robert S Peterson) [914725]
- [fs] ext4: update percpu counters after journal replay (Eric Sandeen) [961930]
- [fs] gfs2: Use ->dirty_inode() (Robert S Peterson) [887341]
- [fs] btrfs: update timestamps on truncate() (Eric Sandeen) [893397]
- [fs] ext4: remove unaligned AIO warning printk (Eric Sandeen) [905397]
- [fs] ext4: limit group search loop for non-extent files (Eric Sandeen) [958939]
- [fs] ext4: fix online resizing for ext3-compat file systems (Eric Sandeen) [958939]
- [fs] nfsd: make symbol nfsd_reply_cache_shrinker static (Jeff Layton) [681606]
- [fs] nfsd: scale up the number of DRC hash buckets with cache size (Jeff Layton) [681606]
- [fs] nfsd: keep stats on worst hash balancing seen so far (Jeff Layton) [681606]
- [fs] nfsd: add new reply_cache_stats file in nfsdfs (Jeff Layton) [681606]
- [fs] nfsd: track memory utilization by the DRC (Jeff Layton) [681606]
- [fs] nfsd: break out comparator into separate function (Jeff Layton) [681606]
- [fs] nfsd: eliminate one of the DRC cache searches (Jeff Layton) [681606]
- [fs] nfsd: only unhash DRC entries that are in the hashtable (Jeff Layton) [681606]
- [fs] nfsd: fix startup order in nfsd_reply_cache_init (Jeff Layton) [681606]
- [fs] nfsd: fix compiler warning about ambiguous types in nfsd_cache_csum (Jeff Layton) [681606]
- [fs] nfsd: fix comments on nfsd_cache_lookup (Jeff Layton) [681606]
- [fs] nfsd: keep a checksum of the first 256 bytes of request (Jeff Layton) [681606]
- [net] sunrpc: trim off trailing checksum before returning decrypted or integrity authenticated buffer (Jeff Layton) [681606]
- [net] sunrpc: fix comment in struct xdr_buf definition (Jeff Layton) [681606]
- [net] sunrpc: copy scope ID in __rpc_copy_addr6 (Jeff Layton) [681606]
- [fs] nfsd: register a shrinker for DRC cache entries (Jeff Layton) [681606]
- [fs] nfsd: add recurring workqueue job to clean the cache (Jeff Layton) [681606]
- [fs] nfsd: when updating an entry with RC_NOCACHE, just free it (Jeff Layton) [681606]
- [fs] nfsd: remove the cache_disabled flag (Jeff Layton) [681606]
- [fs] nfsd: dynamically allocate DRC entries (Jeff Layton) [681606]
- [fs] nfsd: track the number of DRC entries in the cache (Jeff Layton) [681606]
- [fs] nfsd: always move DRC entries to the end of LRU list when updating timestamp (Jeff Layton) [681606]
- [fs] nfsd: break out hashtable search into separate function (Jeff Layton) [681606]
- [fs] nfsd: clean up and clarify the cache expiration code (Jeff Layton) [681606]
- [fs] nfsd: remove redundant test from nfsd_reply_cache_free (Jeff Layton) [681606]
- [fs] nfsd: add alloc and free functions for DRC entries (Jeff Layton) [681606]
- [fs] nfsd: create a dedicated slabcache for DRC entries (Jeff Layton) [681606]
- [fs] nfsd: get rid of RC_INTR (Jeff Layton) [681606]
- [fs] nfsd: remove unneeded spinlock in nfsd_cache_update (Jeff Layton) [681606]
- [fs] nfsd: fix IPv6 address handling in the DRC (Jeff Layton) [681606]
- [fs] nfsd: make op_cacheresult another flag (Jeff Layton) [681606]
- [fs] nfsd: fix v4 reply caching (Jeff Layton) [681606]
- [fs] nfsd: turn on reply cache for NFSv4 (Jeff Layton) [681606]
- [fs] nfsd: introduce OPDESC helper (Jeff Layton) [681606]
- [fs] bio: fix allocation failure due to bio_get_nr_vecs() (Carlos Maiolino) [956947]
- [fs] bio: dont overflow in bio_get_nr_vecs() (Carlos Maiolino) [956947]
- [fs] vfs: fix spurious return of ESTALE errors when cwd on nfs is renamed on server (Jeff Layton) [896580]
- [fs] vfs: revert most of dcache remove d_mounted (Ian Kent) [907512]

* Fri Jun 07 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-386.el6]
- [net] rtnl: fix info leak on RTM_GETLINK request for VF devices (Flavio Leitner) [923659] {CVE-2013-2634 CVE-2013-2635}
- [net] dcbnl: fix various netlink info leaks (Flavio Leitner) [923659] {CVE-2013-2634 CVE-2013-2635}
- [net] tcp: fix tcp_trim_head() to adjust segment count with skb MSS (Daniel Borkmann) [970609]
- [net] af_netlink: force credentials passing (Thomas Graf) [880142]
- [net] af_unix: Only allow recv on connected (Thomas Graf) [880142]
- [net] scm: fix incorrect credentials passing (Thomas Graf) [880142]
- [net] llc: Fix missing msg_namelen update in llc_ui_recvmsg() (Jesper Brouer) [956100] {CVE-2013-3231}
- [net] rps: Update RFS target at poll for tcp/udp (Daniel Borkmann) [893177]
- [net] rps: Fix brokeness causing OOO packets (Daniel Borkmann) [893177]
- [net] rps: enable RFS before first data packet is received (Daniel Borkmann) [893177]
- [net] ipv6: Enable RFS sk_rxhash tracking for ipv6 sockets (Daniel Borkmann) [893177]
- [netdrv] sfc: Implement hardware acceleration of RFS (Daniel Borkmann) [893177]
- [net] rps: Make hardware-accelerated RFS conditional on NETIF_F_NTUPLE (Daniel Borkmann) [893177]
- [net] rps: Enable hardware acceleration of RFS (Daniel Borkmann) [893177]
- [lib] cpu_rmap: avoid flushing all workqueues (Daniel Borkmann) [893177]
- [net] rps: Protect cpu_rmap.h from double inclusion (Daniel Borkmann) [893177]
- [lib] cpu_rmap: CPU affinity reverse-mapping (Daniel Borkmann) [893177]
- [kernel] genirq: Add IRQ affinity notifiers (Daniel Borkmann) [893177]
- [net] bonding: fix enslaving in alb mode when link down (Veaceslav Falico) [965132]
- [net] sch_tbf: segment too big GSO packets (Jiri Pirko) [875750]
- [net] Documentation: add nf_conntrack sysctl api documentation (Jiri Pirko) [747951]

* Fri Jun 07 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-385.el6]
- [x86] perf: Add IvyBridge EP support (Prarit Bhargava) [892531]
- [x86] perf: Fix Intel Ivy Bridge support (Prarit Bhargava) [892531]
- [x86] perf: Add Intel LBR mappings for PERF_SAMPLE_BRANCH filters (Prarit Bhargava) [892531]
- [x86] perf: Add Intel LBR sharing logic (Prarit Bhargava) [892531]
- [x86] perf: Add Intel LBR MSR definitions (Prarit Bhargava) [892531]
- [netdrv] usb/asix: add support for Lenovo X1 Carbon adapter (Dave Airlie) [907174]
- [netdrv] usb/asix: handle packets crossing URB boundaries (Dave Airlie) [907174]
- [x86] amd_iommu: initialize the device table after dma_ops (Don Dutile) [920672]
- [pci] intel-iommu: eliminate warning that may indicate bad BIOS (Don Dutile) [952399]
- [kernel] pidns: Outlaw thread creation after unshare(CLONE_NEWPID) (Aristeu Rozanski) [919065]
- [fs] proc: Usable inode numbers for the namespace file descriptors (Aristeu Rozanski) [919069]
- [fs] proc: Allow proc_free_inum to be called from any context (Aristeu Rozanski) [919069]
- [fs] proc: fix inconsistent lock state (Aristeu Rozanski) [919069]
- [fs] proc: Generalize proc inode allocation (Aristeu Rozanski) [919069]
- [kernel] pidns: Add setns support (Aristeu Rozanski) [919060]
- [kernel] pidns: add reboot_pid_ns() to handle the reboot syscall (Aristeu Rozanski) [919060]
- [fs] vfs: Add setns support for the mount namespace (Aristeu Rozanski) [919067]
- [kernel] pidns: Support unsharing the pid namespace (Aristeu Rozanski) [919065]
- [kernel] pidns: Deny strange cases when creating pid namespaces (Aristeu Rozanski) [919060 919065]
- [kernel] sys_unshare: remove the dead CLONE_THREAD/SIGHAND/VM code (Aristeu Rozanski) [919060 919065]
- [kernel] check_unshare_flags: kill the bogus CLONE_SIGHAND/sig->count check (Aristeu Rozanski) [919060 919065]
- [kernel] pidns: Consolidate initialzation of special init task state (Aristeu Rozanski) [919060 919065]
- [kernel] pidns: Make the pidns proc mount/umount logic obvious (Aristeu Rozanski) [919060 919065]
- [kernel] pid: remove the child_reaper special case in init/main.c (Aristeu Rozanski) [919060 919065]
- [kernel] pid: reduce code size by using a pointer to iterate over array (Aristeu Rozanski) [919060 919065]
- [kernel] pidns: Use task_active_pid_ns where appropriate (Aristeu Rozanski) [919060 919065]
- [kernel] namespaces, pid_ns: fix leakage on fork() failure (Aristeu Rozanski) [919060 919065]
- [kernel] namespaces: make sure that nsproxy_cache is initialized early enough (Aristeu Rozanski) [919060 919065 919067 919069]
- [kernel] pidns: call pid_ns_prepare_proc() from create_pid_namespace() (Aristeu Rozanski) [919060 919065]
- [fs] procfs: setting ->proc_mnt doesnt belong in proc_get_sb() (Aristeu Rozanski) [919069]
- [kernel] signals/send_signal: use si_fromuser() to detect from_ancestor_ns (Aristeu Rozanski) [919060 919065]
- [kernel] signals: SEND_SIG_NOINFO should be considered as SI_FROMUSER() (Aristeu Rozanski) [919060 919065]
- [x86] acpi: Avoid SRAT table checks for Fujitsu Primequest systems (Prarit Bhargava) [966853]
- [kernel] tick: Cleanup NOHZ per cpu data on cpu down (Prarit Bhargava) [950068]

* Thu May 30 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-384.el6]
- [net] tcp: Fix oops from tcp_collapse() when using splice() (Nikola Pajkovsky) [863512] {CVE-2013-2128}
- [net] ipv6: only invalidate previously tokenized addresses (Daniel Borkmann) [876634]
- [net] ipv6: also allow token to be set when device not ready (Daniel Borkmann) [876634]
- [net] ipv6: minor: use in6addr_any in token init (Daniel Borkmann) [876634]
- [net] ipv6: add tokenized interface identifier support (Daniel Borkmann) [876634]
- [net] ipv6: unify logic evaluating inet6_dev's accept_ra property (Daniel Borkmann) [876634]
- [net] ipv6: Send ICMPv6 RSes only when RAs are accepted (Daniel Borkmann) [876634]
- [net] ipv4: kill an RCU warning in inet_fill_link_af() (Daniel Borkmann) [876634]
- [net] rtnetlink: make link af-specific updates atomic (Daniel Borkmann) [876634]
- [net] ipv6: AF_INET6 link address family (Daniel Borkmann) [876634]
- [net] ipv4: AF_INET link address family (Daniel Borkmann) [876634]
- [net] ipv4: Define IPV4_DEVCONF_MAX (Daniel Borkmann) [876634]
- [net] rtnetlink: Link address family API (Daniel Borkmann) [876634]
- [net] ipv6: addrconf.h cleanups (Daniel Borkmann) [876634]
- [net] Revert: openvswitch: Make Open vSwitch use non-accel VLAN tagging (Thomas Graf) [919068]
- [net] offloading: Do not mask out NETIF_F_HW_VLAN_TX for vlan (Thomas Graf) [919068]
- [net] offloading: Support multiple vlan tags in GSO (Thomas Graf) [919068]
- [net] vlan: Enable software emulation for vlan accleration (Thomas Graf) [919068]
- [net] vlan: adjust vlan_set_encap_proto() for its callers (Thomas Graf) [919068]
- [net] veth: extend device features (Thomas Graf) [959780]
- [net] tcp: connect() race with timewait reuse (Jiri Pirko) [947041]
- [net] vxlan: Fix TCPv6 segmentation (Amerigo Wang) [960008]
- [net] gre: Fix GREv4 TCPv6 segmentation (Amerigo Wang) [960008]
- [net] sctp: set association state to established in dupcook_a handler (Michele Baldessari) [916291]
- [net] openvswitch: Use FIELD_SIZEOF() in dp_init() (Thomas Graf) [923212]
- [net] openvswitch: Allow OVS_USERSPACE_ATTR_USERDATA to be variable length (Thomas Graf) [923212]
- [net] openvswitch: Change ENOENT return value to ENODEV in lookup_vport() (Thomas Graf) [923212]
- [net] openvswitch: Make OVSP_LOCAL 32-bit (Thomas Graf) [923212]
- [net] openvswitch: Avoid useless holes in struct vport (Thomas Graf) [923212]
- [net] openvswitch: Use eth_mac_addr() instead of duplicating it (Thomas Graf) [923212]
- [net] introduce new priv_flag indicating iface capable of change mac when running (Thomas Graf) [923212]
- [net] openvswitch: remove some useless comments (Thomas Graf) [923212]
- [net] openvswitch: fix the calculation of checksum for vlan header (Thomas Graf) [923212]
- [net] openvswitch: Fix parsing invalid LLC/SNAP ethertypes (Thomas Graf) [923212]
- [net] openvswitch: Call genlmsg_end in queue_userspace_packet (Thomas Graf) [923212]
- [net] openvswitch: Fix ovs_vport_cmd_new return value on success (Thomas Graf) [923212]
- [net] openvswitch: Fix ovs_vport_cmd_del return value on success (Thomas Graf) [923212]
- [net] openvswitch: Use RCU callback when detaching netdevices (Thomas Graf) [923212]
- [net] openvswitch: add skb mark matching and set action (Thomas Graf) [923212]
- [net] openvswitch: use this_cpu_ptr per-cpu helper (Thomas Graf) [923212]
- [net] openvswitch: add ipv6 'set' action (Thomas Graf) [923212]
- [net] core: add function for incremental IPv6 pseudo header checksum updates (Thomas Graf) [923212]
- [net] ipv6: improve ipv6_find_hdr() to skip empty routing headers (Thomas Graf) [923212]
- [net] ipv6: Move ipv6_find_hdr() out of Netfilter code (Thomas Graf) [923212]
- [net] netfilter: ip6_tables: add flags parameter to ipv6_find_hdr() (Thomas Graf) [923212]
- [net] openvswitch: Process RARP packets with ethertype 0x8035 similar to ARP packets (Thomas Graf) [923212]
- [net] openvswitch: Store flow key len if ARP opcode is not request or reply (Thomas Graf) [923212]
- [net] openvswitch: Print device when warning about over MTU packets (Thomas Graf) [923212]
- [net] openvswitch: Remove unecessary semicolon (Thomas Graf) [923212]
- [net] openvswitch: Increase maximum number of datapath ports (Thomas Graf) [923212]
- [net] openvswitch: using kfree_rcu() to simplify the code (Thomas Graf) [923212]
- [net] openvswitch: Stop using NLA_PUT*() (Thomas Graf) [923212]
- [net] af_unix: dont send SCM_CREDENTIALS by default (Thomas Graf) [880142]
- [net] scm: Capture the full credentials of the scm sender (Thomas Graf) [880142]
- [net] af_unix: Allow connecting to sockets in other network namespaces (Thomas Graf) [880142]
- [net] af_unix: Allow credentials to work across user and pid namespaces (Thomas Graf) [880142]
- [net] scm: Capture the full credentials of the scm sender (Thomas Graf) [880142]
- [net] af_netlink: Add needed scm_destroy after scm_send (Thomas Graf) [880142]
- [net] af_unix: Allow SO_PEERCRED to work across namespaces (Thomas Graf) [880142]
- [net] sock: Introduce cred_to_ucred (Thomas Graf) [880142]
- [kernel] user_ns: Introduce user_nsmap_uid and user_ns_map_gid (Thomas Graf) [880142]
- [net] scm: Reorder scm_cookie (Thomas Graf) [880142]
- [net] rtnetlink: Allow setting the network namespace by fd (Thomas Graf) [880142]
- [net] rtnetlink: Fix ip link add netns oops (Thomas Graf) [880142]
- [net] Support specifying the network namespace upon device creation (Thomas Graf) [880142]
- [net] ns: add a printk to explain a failure (Amerigo Wang) [880142]
- [net] openvswitch: Add support for network namespaces (Amerigo Wang) [880142]
- [netdrv] veth: Enforce minimum size of VETH_INFO_PEER (Amerigo Wang) [880142]
- [netdrv] veth: Fix packet checksumming (Amerigo Wang) [880142]
- [netdrv] veth: Fix the byte counters (Amerigo Wang) [880142]
- [net] fix incorrect getting net device's name (Amerigo Wang) [880142]
- [net] rtnetlink: Add missing manual netlink notification in dev_change_net_namespaces (Amerigo Wang) [880142]
- [net] fix dev_get_valid_name (Amerigo Wang) [880142]
- [net] device name allocation cleanups (Amerigo Wang) [880142]
- [netdrv] dummy: fix rcu_sched self-detected stalls (Amerigo Wang) [880142]
- [net] dev_close() should check IFF_UP (Amerigo Wang) [880142]
- [net] Move rcu_barrier from rollback_registered_many to netdev_run_todo (Amerigo Wang) [880142]
- [net] Fix more stale on-stack list_head objects (Amerigo Wang) [880142]
- [net] deinit automatic LIST_HEAD (Amerigo Wang) [880142]
- [net] factorize sync-rcu call in unregister_netdevice_many (Amerigo Wang) [880142]
- [net] use rcu_barrier() in rollback_registered_many (Amerigo Wang) [880142]
- [net] use list_first_entry macro (Amerigo Wang) [880142]
- [net] Handle NETREG_UNINITIALIZED devices correctly (Amerigo Wang) [880142]
- [net] NETDEV_UNREGISTER_PERNET -> NETDEV_UNREGISTER_BATCH (Amerigo Wang) [880142]
- [net] introduce NETDEV_UNREGISTER_PERNET (Amerigo Wang) [880142]
- [net] Introduce unregister_netdevice_many() (Amerigo Wang) [880142]
- [net] Introduce unregister_netdevice_queue() (Amerigo Wang) [880142]
- [net] rtnetlink: speedup rtnl_dump_ifinfo() (Amerigo Wang) [880142]
- [net] dev_forward_skb() should clear skb_iif (Amerigo Wang) [880142]
- [net] fix mtu check when TSO is enabled (Amerigo Wang) [880142]
- [net] Allow tagged VLAN packets to flow through VETH devices (Amerigo Wang) [880142]
- [net] dev_forward_skb should call nf_reset (Amerigo Wang) [880142]
- [net] ns: keep vlan slaves on master netns move (Amerigo Wang) [880142]
- [fs] proc/ns: Fix the namespace inode permission checks (Amerigo Wang) [880142]
- [fs] improve scalability of pseudo filesystems (Amerigo Wang) [880142]
- [fs] proc/ns: prevent crash when ns_entries is empty (Amerigo Wang) [880142]
- [net] ns: fix net_alloc_generic() (Amerigo Wang) [880142]
- [net] ns: fix proxy ARP entries listing on a netns (Amerigo Wang) [880142]
- [net] ns: get_net_ns_by_fd() oopses if proc_ns_fget() returns an error (Amerigo Wang) [880142]
- [net] ns: fix get_net_ns_by_fd for !CONFIG_NET_NS (Amerigo Wang) [880142]
- [fs] ns proc: Return -ENOENT for a nonexistent /proc/self/ns/ entry (Amerigo Wang) [880142]
- [fs] proc/ns: Fix Oops on stat of /proc/<zombie pid>/ns/net (Amerigo Wang) [880142]
- [net] ns: Allow setting the network namespace by fd (Amerigo Wang) [880142]
- [fs] proc/ns: Add support for the ipc namespace (Amerigo Wang) [880142]
- [fs] proc/ns: Add support for the uts namespace (Amerigo Wang) [880142]
- [fs] proc/ns: Add support for the network namespace (Amerigo Wang) [880142]
- [kernel] ns: Wire up the setns system call (Amerigo Wang) [880142]
- [kernel] ns: Introduce the setns syscall (Amerigo Wang) [880142]
- [fs] proc/ns: proc files for namespace naming policy (Amerigo Wang) [880142]
- [netdrv] mlx4: change TX coalescing defaults (Amerigo Wang) [864597]
- [net] tcp: add LAST_ACK as a valid state for TSQ (Amerigo Wang) [864597]
- [net] tcp: TCP Small Queues (Amerigo Wang) [864597]
- [net] netfilter/ipset: fix crash if IPSET_CMD_NONE command is sent (Thomas Graf) [889048]

* Wed May 29 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-383.el6]
- [x86] efi: Set runtime_version to the EFI spec revision (Lenny Szubowicz) [917193]
- [x86] efi: initialize efi.runtime_version to make query_variable_info/update_capsule workable (Lenny Szubowicz) [917193]
- [x86] efi: Add infrastructure for UEFI 2.0 runtime services (Lenny Szubowicz) [917193]
- [netdrv] sfc: tidy up PTP synchronize function efx_ptp_process_times() (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: PTP changes to support improved UUID filtering mode (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Allow efx_channel_type::receive_skb() to reject a packet (Nikolay Aleksandrov) [862340]
- [netdrv] sfc/ptp: adjust duplicate test (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Select PTP_1588_CLOCK (Nikolay Aleksandrov) [862340]
- [netdrv] ptp: Enable clock drivers along with associated net/PHY drivers (Nikolay Aleksandrov) [862340]
- [netdrv] sfc/ptp: use list_move instead of list_del/list_add (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Fix the reported priorities of different filter types (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Remove EFX_FILTER_FLAG_RX_OVERRIDE_IP (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Fix null function pointer in efx_sriov_channel_type (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Expose FPGA bitfile partition through MTD (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Add support for IEEE-1588 PTP (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Fix maximum array sizes for various MCDI commands (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Allow efx_mcdi_rpc to be called in two parts (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Add channel specific receive_skb handler and post_remove callback (Nikolay Aleksandrov) [862340]
- [netdrv] sfc: Add explicit RX queue flag to channel (Nikolay Aleksandrov) [862340]
- [acpi] apei/ghes: Add hardware memory error recovery support (Dean Nelson) [736982]
- [mm] memory-failure: add memory_failure_queue() (Dean Nelson) [736982]
- [virt] apic: Allow x2apic without IR on VMware platform (Marcelo Tosatti) [905688]
- [virt] apic: Move hypervisor detection of x2apic to hypervisor.h (Marcelo Tosatti) [905688]
- [virt] kvm: Add x86_hyper_kvm to complete detect_hypervisor_platform check (Marcelo Tosatti) [905688]
- [firmware] add kernel parameter to output SMBIOS UUID in proper endian format (Prarit Bhargava) [806134]
- [firmware] dmi_scan: check dmi version when get system uuid (Prarit Bhargava) [806134]
- [firmware] dmi_scan: use pUB to print UUIDs (Prarit Bhargava) [806134]
- [virt] kvm: Use __print_symbolic() for vmexit tracepoints (Stefan Hajnoczi) [891036]
- [virt] kvm: Record instruction set in kvm_exit tracepoint (Stefan Hajnoczi) [891036]
- [fs] hugetlbfs: add thread name and pid to SHM_HUGETLB mlock rlimit warning (Rafael Aquini) [885706]
- [fs] hugetlbfs: lessen the impact of a deprecation warning (Rafael Aquini) [885706]
- [misc] hpilo: ignore auxiliary HP iLO BMCs (Tony Camuso) [826725]
- [misc] hpilo: remove pci_disable_device (Tony Camuso) [826725]
- [misc] hpilo: update module version (Tony Camuso) [826725]
- [powerpc] perf: Fix finding overflowed PMC in interrupt (Steve Best) [905138]
- [powerpc] perf: Fix for PMCs not making progress (Steve Best) [905138]
- [x86] pvpanic: add pvpanic device driver (Andrew Jones) [831178]
- [virt] kvm: limit difference between kvmclock updates (Marcelo Tosatti) [952174]
- [virt] kvm: Fix invalid secondary exec controls in vmx_cpuid_update() (Andrew Jones) [916932]
- [i2c] i2c-i801: Add Device IDs for Intel Lynx Point-LP PCH (John Villalovos) [847118]
- [watchdog] iTCO_wdt: Add Device IDs for Intel Lynx Point-LP PCH (John Villalovos) [847118]
- [ata] ata_piix: Add Device IDs for Intel Lynx Point-LP PCH (John Villalovos) [847118]
- [ata] ahci: Add Device IDs for Intel Lynx Point-LP PCH (John Villalovos) [847118]
- [input] wacom: cleanup feature report for bamboos (Aristeu Rozanski) [949379]
- [kernel] kexec: improve logging when crashkernel=auto can't be satisfied (Steve Best) [929286]
- [usb] uhci: fix IRQ race during initialization (Dave Young) [915834]
- [pci] acpiphp: remove all functions in slot, even without ACPI _EJx (Amos Kong) [890253]
- [x86] oprofile: Fix crash when unloading module in nmi timer mode (Don Zickus) [828936]
- [scsi] cxgb4i: Remove the scsi host device when removing device (Steve Best) [908030]

* Fri May 24 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-382.el6]
- [net] ipvs: sctp: fix checksumming on snat and dnat handlers (Daniel Borkmann) [892256]
- [netdrv] e1000e: enable VLAN RX/TX in PROMISC mode (Stefan Assmann) [886420]
- [netdrv] bnx2x: strip VLAN header in PROMISC mode (Stefan Assmann) [886420]
- [net] vlan: handle packets with empty vlan_group via VLAN code (Stefan Assmann) [886420]
- [net] ptp: remove Tech Preview status (Jiri Benc) [920155]
- [net] ptp: dynamic allocation of PHC char devices (Jiri Benc) [920155]
- [pps] Fix a use-after free bug when unregistering a source (Jiri Benc) [920155]
- [net] ptp: reduce stack usage when measuring the system time offset (Jiri Benc) [920155]
- [net] ptp: reduce stack usage when reading external time stamps (Jiri Benc) [920155]
- [net] ptp: update adjfreq callback description (Jiri Benc) [920155]
- [net] ptp: add an ioctl to compare PHC time with system time (Jiri Benc) [920155]
- [net] ptp: Make PTP_1588_CLOCK select rather than depend on PPS (Jiri Benc) [920155]
- [net] pps, ptp: Remove dependencies on EXPERIMENTAL (Jiri Benc) [920155]
- [net] ptp: clarify the clock_name sysfs attribute (Jiri Benc) [920155]
- [pps] default echo function (Jiri Benc) [920155]
- [net] ptp: validate HWTSTAMP ioctl parameters (Jiri Benc) [920155]
- [net] ptp: introduce ptp one step time stamp mode for sync packets (Jiri Benc) [920155]
- [net] ptp: fix L2 event message recognition (Jiri Benc) [920155]
- [net] correct comment on where to place transmit time stamp hook (Jiri Benc) [920155]
- [net] packet: support for TX time stamps on RAW sockets (Jiri Benc) [920155]
- [net] Documentation: corrected documentation for hardware time stamping (Jiri Benc) [920155]
- [net] bridge: Add multicast_querier toggle and disable queries by default (Flavio Leitner) [905561]
- [net] bridge: Fix fatal typo in setup of multicast_querier_expired (Flavio Leitner) [905561]
- [net] bridge: Restart queries when last querier expires (Flavio Leitner) [905561]
- [net] bridge: Add br_multicast_start_querier (Flavio Leitner) [905561]
- [net] sctp: Validate parameter size for SCTP_GET_ASSOC_STATS (Thomas Graf) [755486]
- [net] sctp: sctp_close: fix release of bindings for deferred call_rcu's (Daniel Borkmann) [903296]
- [net] sctp: refactor sctp_outq_teardown to insure proper re-initalization (Daniel Borkmann) [913170]
- [net] ipv6: TX timestamps for IPv6 UDP packets (Jiri Benc) [904172]
- [net] af_packet: remove BUG statement in tpacket_destruct_skb (Daniel Borkmann) [905335]
- [net] ipv4: prevent setting ttl=0 via IP_TTL (Amerigo Wang) [893306]
- [net] bridge: Correctly encode addresses when dumping mdb entries (Amerigo Wang) [856262]
- [net] bridge: Do not unregister all PF_BRIDGE rtnl operations (Amerigo Wang) [856262]
- [net] bridge: export multicast database via netlink (Amerigo Wang) [856262]
- [net] netfilter: allow NFQUEUE bypass if no listener is available (Daniel Borkmann) [854259]
- [net] netfilter: reduce NF_VERDICT_MASK to 0xff (Daniel Borkmann) [854259]
- [net] netfilter: nfnetlink_queue: do not free skb on error (Daniel Borkmann) [854259]
- [net] netfilter: nfnetlink_queue: return error number to caller (Daniel Borkmann) [854259]
- [net] netfilter: xt_NFQUEUE: consolidate v4/v6 targets into one (Daniel Borkmann) [854259]
- [net] ipv6: Remove IPV6_ADDR_RESERVED (Amerigo Wang) [860764]

* Mon May 20 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-381.el6]
- [fs] xfs: avoid xfs_dir_fsync() to dereference a NULL inode pointer (Carlos Maiolino) [950638]
- [fs] super: fix get_active_super()/umount() race (Carlos Maiolino) [918724]
- [fs] cifs: ensure that we always do cifsFileInfo_get under the spinlock (Sachin Prabhu) [734728]
- [fs] cifs: convert async read callback to slow_work (Sachin Prabhu) [734728]
- [fs] cifs: convert cifs_iovec_read to use async reads (Sachin Prabhu) [734728]
- [fs] cifs: add wrapper for cifs_async_readv to retry opening file (Sachin Prabhu) [734728]
- [fs] cifs: add refcounting to cifs_readdata structures (Sachin Prabhu) [734728]
- [fs] cifs: abstract out function to marshal the iovec for readv receives (Sachin Prabhu) [734728]
- [fs] cifs: make cifs_readdata_alloc take a work_func_t arg (Sachin Prabhu) [734728]
- [fs] cifs: make cifsFileInfo_get return the cifsFileInfo pointer (Sachin Prabhu) [734728]
- [fs] cifs: Change mid_q_entry structure fields (Sachin Prabhu) [734728]
- [fs] cifs: Expand CurrentMid field (Sachin Prabhu) [734728]
- [fs] cifs: Separate protocol-specific code from cifs_readv_receive code (Sachin Prabhu) [734728]
- [fs] cifs: Separate protocol-specific code from demultiplex code (Sachin Prabhu) [734728]
- [fs] cifs: Separate protocol-specific code from transport routines (Sachin Prabhu) [734728]
- [fs] cifs: Delete echo_retries module parm (Sachin Prabhu) [734728]
- [fs] cifs: Prepare credits code for a slot reservation (Sachin Prabhu) [734728]
- [fs] cifs: Make wait_for_free_request killable (Sachin Prabhu) [734728]
- [fs] cifs: Introduce credit-based flow control (Sachin Prabhu) [734728]
- [fs] cifs: Simplify inFlight logic (Sachin Prabhu) [734728]
- [fs] cifs: Respect negotiated MaxMpxCount (Sachin Prabhu) [734728]
- [fs] cifs: better instrumentation for coalesce_t2 (Sachin Prabhu) [734728]
- [fs] cifs: Fix error handling in cifs_readv_complete (Sachin Prabhu) [734728]
- [fs] cifs: Cleanup use of CONFIG_CIFS_STATS2 ifdef to make transport routines more readable (Sachin Prabhu) [734728]
- [fs] cifs: when server doesnt set CAP_LARGE_READ_X, cap default rsize at MaxBufferSize (Sachin Prabhu) [734728]
- [fs] cifs: allow for larger rsize= options and change defaults (Sachin Prabhu) [734728]
- [fs] cifs: convert cifs_readpages to use async reads (Sachin Prabhu) [734728]
- [fs] cifs: add cifs_async_readv (Sachin Prabhu) [734728]
- [fs] cifs: fix protocol definition for READ_RSP (Sachin Prabhu) [734728]
- [fs] cifs: add a callback function to receive the rest of the frame (Sachin Prabhu) [734728]
- [fs] cifs: break out 3rd receive phase into separate function (Sachin Prabhu) [734728]
- [fs] cifs: find mid earlier in receive codepath (Sachin Prabhu) [734728]
- [fs] cifs: move buffer pointers into TCP_Server_Info (Sachin Prabhu) [734728]
- [fs] cifs: eliminate is_multi_rsp parm to find_cifs_mid (Sachin Prabhu) [734728]
- [fs] cifs: move mid finding into separate routine (Sachin Prabhu) [734728]
- [fs] cifs: add a third receive phase to cifs_demultiplex_thread (Sachin Prabhu) [734728]
- [fs] cifs: keep a reusable kvec array for receives (Sachin Prabhu) [734728]
- [fs] cifs: turn read_from_socket into a wrapper around a vectorized version (Sachin Prabhu) [734728]
- [fs] add new module parameter enable_oplocks (Sachin Prabhu) [734728]
- [fs] cifs: clean up check_rfc1002_header (Sachin Prabhu) [734728]
- [fs] cifs: simplify read_from_socket (Sachin Prabhu) [734728]
- [fs] cifs: check for unresponsive server every time we call kernel_recvmsg (Sachin Prabhu) [734728]
- [fs] cifs: make smb_msg local to read_from_socket (Sachin Prabhu) [734728]
- [fs] cifs: remove obsolete comment (Sachin Prabhu) [734728]
- [fs] cifs: consolidate signature generating code (Sachin Prabhu) [734728]
- [fs] cifs: clean up checkSMB (Sachin Prabhu) [734728]
- [fs] cifs: untangle server->maxBuf and CIFSMaxBufSize (Sachin Prabhu) [734728]
- [fs] cifs: use memcpy for magic string in cifs signature generation BSRSPYL (Sachin Prabhu) [734728]
- [fs] cifs: Cleanup demupltiplex thread exiting code (Sachin Prabhu) [734728]
- [fs] cifs: Move mid search to a separate function (Sachin Prabhu) [734728]
- [fs] cifs: Move RFC1002 check to a separate function (Sachin Prabhu) [734728]
- [fs] cifs: Simplify socket reading in demultiplex thread (Sachin Prabhu) [734728]
- [fs] cifs: Move buffer allocation to a separate function (Sachin Prabhu) [734728]
- [fs] cifs: Cleanup: check return codes of crypto api calls (Sachin Prabhu) [734728]
- [fs] cifs: fix the type of cifs_demultiplex_thread() (Sachin Prabhu) [734728]
- [fs] cifs: connect.c remove one to many l's in the word (Sachin Prabhu) [734728]
- [mm] export lru_cache_add_*() to modules (Sachin Prabhu) [734728]
- [fs] ext4: Use single thread to perform DIO unwritten convertion (Carlos Maiolino) [914783]
- [fs] gfs2: Flush work queue before clearing glock hash tables (Robert S Peterson) [952836]
- [fs] cifs: delay super block destruction until all cifsFileInfo objects are gone (Mateusz Guzik) [917890]
- [fs] namei.c: Dont allow to create hardlink for deleted file (Brian Foster) [908158]
- [net] sunrpc: don't use a credential with extra groups (Mateusz Guzik) [955712]
- [fs] xfs: don't free EFIs before the EFDs are committed (Carlos Maiolino) [947582]
- [fs] xfs: pass shutdown method into xfs_trans_ail_delete_bulk (Carlos Maiolino) [805407]
- [fs] gfs2: Reinstate withdraw ack system (Robert S Peterson) [908093]
- [fs] gfs2: Fix unlock of fcntl locks during withdrawn state (Robert S Peterson) [894093]
- [fs] nfs: open a file descriptor for fsync in nfs4 recovery (J. Bruce Fields) [915479]
- [fs] nfs: add more context to state manager error mesgs (Dave Wysochanski) [917711]
- [fs] nfs: Rate limit the state manager for lock reclaim warning messages (Dave Wysochanski) [917711]
- [fs] nfs: Rate limit the state manager warning messages (Dave Wysochanski) [917711]
- [fs] nfs: even if __func__ shown (Dave Wysochanski) [917711]
- [fs] nfs: printks in fs/nfs/ should start with NFS: (Dave Wysochanski) [917711]
- [kernel] audit: destroy filename correctly (Jeff Layton) [678544]
- [fs] vfs: make lremovexattr retry once on ESTALE error (Jeff Layton) [678544]
- [fs] vfs: make removexattr retry once on ESTALE (Jeff Layton) [678544]
- [fs] vfs: make llistxattr retry once on ESTALE error (Jeff Layton) [678544]
- [fs] vfs: make listxattr retry once on ESTALE error (Jeff Layton) [678544]
- [fs] vfs: make getxattr retry once on an ESTALE error (Jeff Layton) [678544]
- [fs] vfs: allow lsetxattr() to retry once on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: allow setxattr to retry once on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: allow utimensat() calls to retry once on an ESTALE error (Jeff Layton) [678544]
- [fs] vfs: fix user_statfs to retry once on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: revert changes to arch/alpha and arch/parisc from statfs cleanup (Jeff Layton) [678544]
- [fs] clean statfs-like syscalls up (Jeff Layton) [678544]
- [fs] vfs: make fchownat retry once on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: Make chown() and lchown() call fchownat() (Jeff Layton) [678544]
- [fs] vfs: make fchmodat retry once on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: have chroot retry once on ESTALE error (Jeff Layton) [678544]
- [fs] vfs: have chdir retry lookup and call once on ESTALE error (Jeff Layton) [678544]
- [fs] vfs: have faccessat retry once on an ESTALE error (Jeff Layton) [678544]
- [fs] vfs: have do_sys_truncate retry once on an ESTALE error (Jeff Layton) [678544]
- [fs] vfs: fix renameat to retry on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: make do_unlinkat retry once on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: make do_rmdir retry once on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: fix linkat to retry once on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: fix symlinkat to retry on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: fix mkdirat to retry once on an ESTALE error (Jeff Layton) [678544]
- [fs] vfs: fix mknodat to retry on ESTALE errors (Jeff Layton) [678544]
- [fs] vfs: add a flags argument to user_path_parent (Jeff Layton) [678544]
- [fs] vfs: fix readlinkat to retry on ESTALE (Jeff Layton) [678544]
- [fs] vfs: make fstatat retry on ESTALE errors from getattr call (Jeff Layton) [678544]
- [fs] namei: include errno.h (Jeff Layton) [678544]
- [fs] vfs: add a retry_estale helper function to handle retries on ESTALE (Jeff Layton) [678544]
- [fs] procfs: don't need a PATH_MAX allocation to hold a string representation of an int (Jeff Layton) [678544]
- [fs] vfs: embed struct filename inside of names_cache allocation if possible (Jeff Layton) [678544]
- [kernel] audit: make audit_inode take struct filename (Jeff Layton) [678544]
- [fs] vfs: make do_filp_open take a struct filename (Jeff Layton) [678544]
- [fs] vfs: make __link_path_walk take a struct filename (Jeff Layton) [678544]
- [kernel] audit: allow audit code to satisfy getname requests from its names_list (Jeff Layton) [678544]
- [mm] swapfile: fix name leak in swapoff (Jeff Layton) [678544]
- [fs] vfs: revert changes from last patch in code that we don't ship (Jeff Layton) [678544]
- [fs] vfs: define struct filename and have getname() return it (Jeff Layton) [678544]
- [fs] vfs: constify dirname argument to do_mount (Jeff Layton) [678544]
- [fs] vfs: paper over lack of const qualifiers in execve code (Jeff Layton) [678544]
- [target] delousing target_core_file a bit (Jeff Layton) [678544]
- [kernel] acct: constify the name arg to acct_on (Jeff Layton) [678544]
- [fs] vfs: allocate page instead of names_cache buffer in mount_block_root (Jeff Layton) [678544]
- [kernel] audit: overhaul __audit_inode_child to accomodate retrying (Jeff Layton) [678544]
- [kernel] audit: optimize audit_compare_dname_path (Jeff Layton) [678544]
- [kernel] audit: make audit_compare_dname_path use parent_len helper (Jeff Layton) [678544]
- [kernel] audit: remove dirlen argument to audit_compare_dname_path (Jeff Layton) [678544]
- [kernel] audit: set the name_len in audit_inode for parent lookups (Jeff Layton) [678544]
- [kernel] audit: add a new "type" field to audit_names struct (Jeff Layton) [678544]
- [kernel] audit: reverse arguments to audit_inode_child (Jeff Layton) [678544]
- [kernel] audit: no need to walk list in audit_inode if name is NULL (Jeff Layton) [678544]
- [kernel] audit: pass in dentry to audit_copy_inode wherever possible (Jeff Layton) [678544]
- [fs] audit: Lose the first argument of audit_inode_child() (Jeff Layton) [678544]
- [fs] audit: __link_path_walk should call audit_inode with original "name" (Jeff Layton) [678544]
- [fs] fuse: fix stat call on 32 bit platforms (Brian Foster) [872629]

* Fri May 17 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-380.el6]
- [net] tcp: sk_add_backlog() is too agressive for TCP (Jiri Benc) [947950]
- [net] add a limit parameter to sk_add_backlog() (Jiri Benc) [947950]
- [net] sctp: fix Kconfig bug in default cookie hmac selection (Daniel Borkmann) [918316]
- [net] sctp: Change defaults on cookie hmac selection (Daniel Borkmann) [918316]
- [net] sctp: Make hmac algorithm selection for cookie generation dynamic (Daniel Borkmann) [918316]
- [net] ipv6: bind() use stronger condition for bind_conflict (Flavio Leitner) [917872]
- [net] tcp: bind() use stronger condition for bind_conflict (Flavio Leitner) [894683]
- [net] vxlan: add ethtool support (Amerigo Wang) [918014]
- [net] vxlan: Use UDP Tunnel segmention (Amerigo Wang) [918014]
- [net] vxlan: fix oops when delete netns containing vxlan (Amerigo Wang) [918014]
- [net] vxlan: reset nf before xmit vxlan encapsulated packet (Amerigo Wang) [918014]
- [net] vxlan: Use tunnel_ip_select_ident() for tunnel IP-Identification (Amerigo Wang) [918014]
- [net] vxlan: Add capability of Rx checksum offload for inner packet (Amerigo Wang) [918014]
- [net] vxlan: capture inner headers during encapsulation (Amerigo Wang) [918014]
- [net] tunneling: Add generic Tunnel segmentation (Amerigo Wang) [918014]
- [net] tunneling: Inherit NETIF_F_SG for hw_enc_features (Amerigo Wang) [918014]
- [net] Kill link between CSUM and SG features (Amerigo Wang) [918014]
- [net] ip_gre: fix the inner header offset for gretap (Amerigo Wang) [918011]
- [net] ip_gre: enable GRO by default (Amerigo Wang) [918011]
- [net] ip_gre: add GRO capability (Amerigo Wang) [918011]
- [net] ip_gre: get rid of ipgre_lock (Amerigo Wang) [918011]
- [net] gro: add gro_cells infrastructure (Amerigo Wang) [918011]
- [net] gro: add checksuming helpers (Amerigo Wang) [918011]
- [net] ipv4: Fix ip-header identification for gso packets (Amerigo Wang) [918011]
- [net] ip_gre: add ethtool support to gre tunnel (Amerigo Wang) [918011]
- [net] ip_gre: Fix GRE_CSUM case (Amerigo Wang) [918011]
- [net] ip_gre: Fix IP-Identification (Amerigo Wang) [918011]
- [net] ip_gre: remove an extra dst_release() (Amerigo Wang) [918011]
- [net] ip_gre: allow CSUM capable devices to handle packets (Amerigo Wang) [918011]
- [net] gre: Add TCP segmentation offload for GRE (Amerigo Wang) [918011]
- [net] gso: factor out skb_mac_gso_segment() from skb_gso_segment() (Amerigo Wang) [918011]
- [net] ipv4: fix warning in xfrm4_mode_tunnel_input (Amerigo Wang) [918011]
- [net] ipv6: fix warning in xfrm6_mode_tunnel_input (Amerigo Wang) [918011]
- [net] Add skb_unclone() helper functions (Amerigo Wang) [918011]
- [net] offloading: Handle encapsulated offloads before fragmentation or handing to lower dev (Amerigo Wang) [918011]
- [net] offloading: Add support for hardware-offloaded encapsulation (Amerigo Wang) [918011]
- [net] ip_gre: When TOS is inherited, use configured TOS value for non-IP packets (Amerigo Wang) [918011]
- [net] ip_gre: Fix kernel panic in IP_GRE with GRE csums (Amerigo Wang) [918011]
- [net] ip_gre: set transport header correctly to gre header (Amerigo Wang) [918011]
- [net] ip_gre: fix possible use after free (Amerigo Wang) [918011]
- [net] gre: add GSO support (Amerigo Wang) [918011]
- [net] ip_gre: Fix ip_gre lockless xmits (Amerigo Wang) [918011]
- [net] ip_gre: lockless xmit (Amerigo Wang) [918011]
- [net] gre: fix improper error handling (Amerigo Wang) [918011]
- [net] gre: PPP over IPv4 (Point-to-Point Tunneling Protocol) (Amerigo Wang) [918011]
- [net] ip_gre: include route header_len in max_headroom calculation (Amerigo Wang) [918011]
- [net] offloading: do not disable sg for packets requiring no checksum (Amerigo Wang) [918011]
- [net] offloading: fix can_checksum_protocol() arguments swap (Amerigo Wang) [918011]
- [net] offloading: Convert checksums to use centrally computed features (Amerigo Wang) [918011]
- [net] offloading: Convert skb_need_linearize() to use precomputed features (Amerigo Wang) [918011]
- [net] offloading: Convert dev_gso_segment() to use precomputed features (Amerigo Wang) [918011]
- [net] offloading: Pass features into netif_needs_gso() (Amerigo Wang) [918011]
- [net] offloading: Generalize netif_get_vlan_features() (Amerigo Wang) [918011]
- [net] Rename skb_has_frags to skb_has_frag_list (Amerigo Wang) [918011]
- [net] fix a wrong assignment in skb_split() (Amerigo Wang) [918011]
- [net] tso: Fix possible wrong checksum generation (Amerigo Wang) [918011]
- [net] gso: fix possible wrong checksum generation (Amerigo Wang) [918011]
- [net] gro: Re-fix different skb headrooms (Amerigo Wang) [918011]
- [net] gro: fix different skb headrooms (Amerigo Wang) [918011]
- [net] Fix skb_copy_expand() handling of ->csum_start (Amerigo Wang) [918011]
- [net] Fix corruption of skb csum field in pskb_expand_head() of net/core/skbuff.c (Amerigo Wang) [918011]
- [net] netlink: drop_monitor/dropwatch friendly (Amerigo Wang) [915552]
- [net] netlink: dont drop packet but consume it (Amerigo Wang) [915552]
- [net] drop_monitor: convert some kfree_skb call sites to consume_skb (Amerigo Wang) [915552]
- [net] more accurate network taps in transmit path (Amerigo Wang) [915552]
- [net] openvswitch: Move LRO check from transmit to received (Amerigo Wang) [904914]
- [net] adjust skb_gso_segment() for calling in rx path (Amerigo Wang) [904914]
- [net] bonding: unset primary slave via sysfs (Veaceslav Falico) [905932]
- [net] netem: fix possible skb leak (Amerigo Wang) [903961]
- [net] WARN if skb_checksum_help() is called on skb requiring segmentation (Amerigo Wang) [903961]

* Fri May 17 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-379.el6]
- [net] macvlan: remove bogus check in macvlan_handle_frame() (Jiri Pirko) [952785]
- [net] macvlan: fix passthru mode race between dev removal and rx path (Jiri Pirko) [952785]
- [kernel] rcu: Replace list_first_entry_rcu() with list_first_or_null_rcu() (Jiri Pirko) [952785]
- [kernel] tick: Don't invoke tick_nohz_stop_sched_tick() if the cpu is offline (Prarit Bhargava) [950068]
- [kernel] tick: Cleanup NOHZ per cpu data on cpu down (Prarit Bhargava) [950068]
- [mm] memory-failure: fix wrong num_poisoned_pages in handling memory error on thp (Naoya Horiguchi) [954045]
- [mm] memory-failure: clean up soft_offline_page() (Naoya Horiguchi) [954045]
- [mm] memory-failure: use num_poisoned_pages instead of mce_bad_pages (Naoya Horiguchi) [954045]
- [mm] memory-failure: do code refactor of soft_offline_page() (Naoya Horiguchi) [954045]
- [mm] memory-failure: fix an error of mce_bad_pages statistics (Naoya Horiguchi) [954045]
- [mm] memory-failure: fix wrong argument of migrate_huge_pages() in soft_offline_huge_page() (Naoya Horiguchi) [954045]
- [mm] memory-failure: let the compiler add the function name (Naoya Horiguchi) [954045]
- [mm] memory-failure: change order of error_states[]'s elements (Naoya Horiguchi) [954045]
- [mm] memory-failure: fix misjudgement of page_action() for errors on mlocked pages (Naoya Horiguchi) [954045]
- [mm] memory-failure: fix action_result() to print out dirty/clean (Naoya Horiguchi) [954045]
- [mm] memory-failure: split thp at the beginning of soft_offline_page() (Naoya Horiguchi) [954045]
- [net] bluetooth/rfcomm: Fix missing msg_namelen update in rfcomm_sock_recvmsg() (Weiping Pan) [955654] {CVE-2013-3225}
- [net] bluetooth: fix possible info leak in bt_sock_recvmsg() (Radomir Vrbovsky) [955604] {CVE-2013-3224}

* Tue May 14 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-378.el6]
- [fs] gfs2: Use ->writepages for ordered writes (Robert S Peterson) [859444]
- [fs] gfs2: Merge gfs2_attach_bufdata() into trans.c (Robert S Peterson) [859444]
- [fs] gfs2: Copy gfs2_trans_add_bh into new data/meta functions (Robert S Peterson) [859444]
- [fs] gfs2: Split gfs2_trans_add_bh() into two (Robert S Peterson) [859444]
- [fs] gfs2: Merge revoke adding functions (Robert S Peterson) [859444]
- [fs] gfs2: Remove bd_list_tr (Robert S Peterson) [859444]
- [fs] gfs2: Clean up gfs2_create (Robert S Peterson) [859444]
- [fs] nfs: Fix another reboot recovery race (Steve Dickson) [923939]
- [fs] nfs: Use CLAIM_DELEG_CUR_FH opens when available (Steve Dickson) [923939]
- [fs] nfs: Enable open-by-filehandle (Steve Dickson) [923939]
- [fs] nfs: Add xdr support for CLAIM_FH and CLAIM_DELEG_CUR_FH opens (Steve Dickson) [923939]
- [fs] nfs: Clean up nfs4_opendata_alloc in preparation for NFSv4.1 open modes (Steve Dickson) [923939]
- [fs] nfs: implement new 4.1 open reclaim types (Steve Dickson) [923939]
- [fs] nfs: Select the "most recent locking state" for read/write/setattr stateids (Steve Dickson) [923939]
- [fs] nfs: Prepare for minorversion-specific nfs_server capabilities (Steve Dickson) [923939]
- [fs] nfs: __nfs_find_lock_context needs to check ctx->lock_context for a match too (Steve Dickson) [923939]
- [fs] nfs: Dont accept more reads/writes if the open context recovery failed (Steve Dickson) [923939]
- [fs] nfs: Fail I/O if the state recovery fails irrevocably (Steve Dickson) [923939]
- [fs] nfs: Resend the READ/WRITE RPC call if a stateid change causes an error (Steve Dickson) [923939]
- [fs] nfs: The stateid must remain the same for replayed RPC calls (Steve Dickson) [923939]
- [fs] nfs: Add a helper for encoding opaque data (Steve Dickson) [923939]
- [fs] nfs: Clean up helper function nfs4_select_rw_stateid() (Steve Dickson) [923939]
- [fs] nfs: Clean up nfs4_select_rw_stateid() (Steve Dickson) [923939]
- [fs] nfs: Rename encode_stateid() to encode_open_stateid() (Steve Dickson) [923939]
- [fs] nfs: Dont copy read delegation stateids in setattr (Steve Dickson) [923939]
- [fs] nfs: Add helpers for basic copying of stateids (Steve Dickson) [923939]
- [fs] nfs: Rename nfs4_copy_stateid() (Steve Dickson) [923939]
- [fs] nfs: Further clean-ups of delegation stateid validation (Steve Dickson) [923939]
- [fs] nfs: Fix matching of the stateids when returning a delegation (Steve Dickson) [923939]
- [fs] gfs2: Clean up inode creation path (Robert S Peterson) [859446]
- [fs] gfs2: dont reference inode:s glock during block allocation trace (Robert S Peterson) [859446]
- [fs] gfs2: Use proper allocation context for new inodes (Robert S Peterson) [859446]
- [fs] gfs2: Move all locking inside the inode creation function (Robert S Peterson) [859446]
- [fs] gfs2: Clean up symlink creation (Robert S Peterson) [859446]
- [fs] gfs2: Clean up mkdir (Robert S Peterson) [859446]
- [fs] gfs2: Make . and .. qstrs constant (Robert S Peterson) [859446]
- [fs] gfs2: Add Orlov allocator (Robert S Peterson) [859446]
- [fs] gfs2: Add "top dir" flag support (Robert S Peterson) [859446]
- [virt] kvm: fix maintenance of guest/host xcr0 state (Paolo Bonzini) [952252]
- [virt] xen-netfront: reduce gso_max_size to account for max TCP header (Andrew Jones) [957231]
- [fs] gfs2: Issue discards in 512b sectors (Robert S Peterson) [922779]
- [fs] nfs: Check for buffer length in __nfs4_get_acl_uncached (Sachin Prabhu) [906056]
- [kernel] tick: Change log level of NOHZ local_softirq_pending message (Radomir Vrbovsky) [907516]
- [x86] vdso: avoid overflow in vgetns() (Prarit Bhargava) [902320]
- [block] propagate proper return codes from blk_get_request callers (Jeff Moyer) [927918]
- [block] Check the return value from blk_get_request (Jeff Moyer) [927918]

* Tue May 14 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-377.el6]
- [kernel] perf: fix perf_swevent_enabled array out-of-bound access (Petr Matousek) [962794] {CVE-2013-2094}
- [tools] perf: Fix strbuf_addf() when the buffer needs to grow (Jiri Olsa) [927866]
- [tools] perf/header: Fix numa topology printing (Jiri Olsa) [927866]
- [tools] perf/test: Fix exclude_guest parse events tests (Jiri Olsa) [927866]
- [tools] perf: do not flush maps on COMM for perf report (Jiri Olsa) [927866]
- [tools] perf/help: Fix --help for builtins (Jiri Olsa) [927866]
- [tools] perf/trace: Check if sample raw_data field is set (Jiri Olsa) [927866]
- [tools] perf/trace: Validate syscall id before growing syscall table (Jiri Olsa) [927866]
- [tools] perf/python: Properly link with libtraceevent (Jiri Olsa) [927866]
- [tools] perf/hists: Add back callchain folding symbol (Jiri Olsa) [927866]
- [tools] perf: Fix build on sparc (Jiri Olsa) [927866]
- [tools] perf/python: Link with libtraceevent (Jiri Olsa) [927866]
- [tools] perf/python: Initialize 'page_size' variable (Jiri Olsa) [927866]
- [tools] traceevent: Fix missed freeing of subargs in free_arg() in filter (Jiri Olsa) [927866]
- [tools] traceevent: Add back pevent assignment in __pevent_parse_format() (Jiri Olsa) [927866]
- [tools] perf/hists: Fix off-by-two bug on the first column (Jiri Olsa) [927866]
- [tools] perf: Remove warnings on JIT samples for srcline sort key (Jiri Olsa) [927866]
- [tools] perf: Fix segfault when using srcline sort key (Jiri Olsa) [927866]
- [tools] perf: Precise mode requires exclude_guest (Jiri Olsa) [927866]
- [tools] perf/hists: Add more helpers for hist entry stat (Jiri Olsa) [927866]
- [tools] perf/hists: Move he->stat.nr_events initialization to a template (Jiri Olsa) [927866]
- [tools] perf/hists: Introduce struct he_stat (Jiri Olsa) [927866]
- [tools] perf/diff: Removing the total_period argument from output code (Jiri Olsa) [927866]
- [tools] perf: Add hpp interface to enable/disable hpp column (Jiri Olsa) [927866]
- [tools] perf: Removing hists pair argument from output path (Jiri Olsa) [927866]
- [tools] perf/hists: Separate overhead and baseline columns (Jiri Olsa) [927866]
- [tools] perf/diff: Refactor diff displacement position info (Jiri Olsa) [927866]
- [tools] perf/hists: Add struct hists pointer to struct hist_entry (Jiri Olsa) [927866]
- [tools] perf: Complete tracepoint event names (Jiri Olsa) [927866]
- [tools] perf/evlist: Remove some unused methods (Jiri Olsa) [927866]
- [tools] perf/evlist: Introduce add_newtp method (Jiri Olsa) [927866]
- [tools] perf: Convert to BACKTRACE_SUPPORT (Jiri Olsa) [927866]
- [tools] perf: Long option completion support for each subcommands (Jiri Olsa) [927866]
- [tools] perf: Complete long option names of perf command (Jiri Olsa) [927866]
- [tools] perf: Check existence of _get_comp_words_by_ref when bash completing (Jiri Olsa) [927866]
- [tools] perf/inject: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/record: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/evlist: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/top: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/probe: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/buildid-list: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/buildid-cache: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/timechart: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/lock: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/kmem: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/help: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/script: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/stat: Don't use globals where not needed to (Jiri Olsa) [927866]
- [tools] perf/sched: Look up thread using tid instead of pid (Jiri Olsa) [927866]
- [tools] perf/inject: Remove static variables (Jiri Olsa) [927866]
- [tools] perf/inject: Remove unused 'input_name' static var (Jiri Olsa) [927866]
- [tools] perf/trace: Use evsel->handler.func (Jiri Olsa) [927866]
- [tools] perf: Convert to HAVE_STRLCPY (Jiri Olsa) [927866]
- [tools] perf: Convert to GTK2_SUPPORT (Jiri Olsa) [927866]
- [tools] perf: Convert to NEWT_SUPPORT (Jiri Olsa) [927866]
- [tools] perf: Convert to LIBAUDIT_SUPPORT (Jiri Olsa) [927866]
- [tools] perf: Convert to LIBUNWIND_SUPPORT (Jiri Olsa) [927866]
- [tools] perf: Convert to LIBELF_SUPPORT (Jiri Olsa) [927866]
- [tools] perf: Remove unused PYRF_OBJS variable on Makefile (Jiri Olsa) [927866]
- [tools] perf: Move libdw availability check before arch Makefile (Jiri Olsa) [927866]
- [tools] perf/trace: Add aliases for some syscalls (Jiri Olsa) [927866]
- [tools] perf/probe: Print an enum type variable in "enum variable-name" format when showing accessible variables (Jiri Olsa) [927866]
- [tools] perf: Check libaudit availability for perf-trace builtin (Jiri Olsa) [927866]
- [tools] perf/hists: Add missing period_* fields when collapsing a hist entry (Jiri Olsa) [927866]
- [tools] perf/trace: New tool (Jiri Olsa) [927866]
- [tools] perf/evsel: Export the event_format constructor (Jiri Olsa) [927866]
- [tools] perf/evsel: Introduce rawptr() method (Jiri Olsa) [927866]
- [tools] perf: Use perf_evsel__newtp in the event parser (Jiri Olsa) [927866]
- [tools] perf/evsel: The tracepoint constructor should store sys:name (Jiri Olsa) [927866]
- [tools] perf/evlist: Introduce set_filter() method (Jiri Olsa) [927866]
- [tools] perf/evlist: Renane set_filters method to apply_filters (Jiri Olsa) [927866]
- [tools] perf/test: Add test to check we correctly parse and match syscall open parms (Jiri Olsa) [927866]
- [tools] perf/evsel: Handle endianity in intval method (Jiri Olsa) [927866]
- [tools] perf/evsel: Know if byte swap is needed (Jiri Olsa) [927866]
- [tools] perf: Allow handling a NULL cpu_map as meaning "all cpus" (Jiri Olsa) [927866]
- [tools] perf/evsel: Improve tracepoint constructor setup (Jiri Olsa) [927866]
- [tools] traceevent: Fix error path on pevent_parse_event (Jiri Olsa) [927866]
- [tools] perf/test: Fix build failure (Jiri Olsa) [927866]
- [tools] traceevent: Handle alloc_arg failure (Jiri Olsa) [927866]
- [tools] perf/test: Add test for the sched tracepoint format fields (Jiri Olsa) [927866]
- [tools] perf/evsel: Provide a new constructor for tracepoints (Jiri Olsa) [927866]
- [tools] traceevent: Carve out events format parsing routine (Jiri Olsa) [927866]
- [tools] traceevent: Remove some die() calls (Jiri Olsa) [927866]
- [tools] traceevent: Fix afterlife gotos (Jiri Olsa) [927866]
- [tools] traceevent: Use calloc were applicable (Jiri Olsa) [927866]
- [tools] traceevent: Use asprintf were applicable (Jiri Olsa) [927866]
- [tools] perf: bfd.h/libbfd detection fails with recent binutils (Jiri Olsa) [927866]
- [tools] traceevent: Free field if an error occurs on process_flags/symbols (Jiri Olsa) [927866]
- [tools] traceevent: Free field if an error occurs on process_fields (Jiri Olsa) [927866]
- [tools] traceevent: Make sure that arg->op.right is set properly (Jiri Olsa) [927866]
- [tools] traceevent: Fix error path on process_array() (Jiri Olsa) [927866]
- [tools] perf: remove sscanf extension as (Jiri Olsa) [927866]
- [tools] perf/header: Remove unused @feat arg from ->process callback (Jiri Olsa) [927866]
- [tools] perf/header: Use pre-processed session env when printing (Jiri Olsa) [927866]
- [tools] perf/header: Add ->process callbacks to most of features (Jiri Olsa) [927866]
- [tools] perf/header: Add struct perf_session_env (Jiri Olsa) [927866]
- [tools] perf/timechart: Use zalloc and fix a couple leaks (Jiri Olsa) [927866]
- [tools] perf/lock: Use perf_evsel__intval and perf_session__set_tracepoints_handlers (Jiri Olsa) [927866]
- [tools] perf/kmem: Use perf_evsel__intval and perf_session__set_tracepoints_handlers (Jiri Olsa) [927866]
- [tools] perf/record: Print event causing perf_event_open() to fail (Jiri Olsa) [927866]
- [tools] perf: Fix a compiling error in util/map.c (Jiri Olsa) [927866]
- [tools] perf: Fix a compiling error in trace-event-perl.c for 32 bits machine (Jiri Olsa) [927866]
- [tools] perf/stat: Check PMU cpumask file (Jiri Olsa) [927866]
- [tools] perf/report: Add missing perf_hpp__init for pipe-mode (Jiri Olsa) [927866]
- [tools] perf/scripts: Export a find_scripts() function (Jiri Olsa) [927866]
- [tools] perf/scripts: Add event_analyzing_sample-record/report (Jiri Olsa) [927866]
- [tools] perf/scripts: Add --symbols option to handle specific symbols (Jiri Olsa) [927866]
- [tools] perf/symbols: Filter samples with unresolved symbol when "--symbols" option is used (Jiri Olsa) [927866]
- [tools] perf/archive: Make 'f' the last parameter for tar (Jiri Olsa) [927866]
- [tools] perf/archive: Remove -f from the rm command (Jiri Olsa) [927866]
- [tools] perf/stat: Move stats related code to util/stat.c (Jiri Olsa) [927866]
- [tools] perf/report: Enable integrated annotation only if possible (Jiri Olsa) [927866]
- [tools] perf: Add sort__has_sym (Jiri Olsa) [927866]
- [tools] perf/hists: Fix first column printing (Jiri Olsa) [927866]
- [tools] perf/hists: Fix output for 100.00 (Jiri Olsa) [927866]
- [tools] traceevent: Define _GNU_SOURCE in Makefile (Jiri Olsa) [927866]
- [tools] perf/sched: Fixup for the die() removal (Jiri Olsa) [927866]
- [tools] perf/probe: Add union member access support (Jiri Olsa) [927866]
- [tools] perf/sched: Don't read all tracepoint variables in advance (Jiri Olsa) [927866]
- [tools] perf/sched: Use perf_evsel__{int, str}val (Jiri Olsa) [927866]
- [tools] perf/evsel: Introduce perf_evsel__{str, int}val methods (Jiri Olsa) [927866]
- [tools] perf/sched: Use perf_tool as ancestor (Jiri Olsa) [927866]
- [tools] perf/sched: Remove unused thread parameter (Jiri Olsa) [927866]
- [tools] perf: Use __maybe_used for unused variables (Jiri Olsa) [927866]
- [tools] perf: Back vdso DSO with real data (Jiri Olsa) [927866]
- [tools] perf/symbols: Make dsos__find function globally available (Jiri Olsa) [927866]
- [tools] perf: Add memdup function (Jiri Olsa) [927866]
- [tools] perf: Do backtrace post unwind only if we regs and stack were captured (Jiri Olsa) [927866]
- [tools] perf: fix ALIGN redefinition in system headers (Jiri Olsa) [927866]
- [tools] perf: include __WORDSIZE definition (Jiri Olsa) [927866]
- [tools] perf: Update types definitions for Android (Jiri Olsa) [927866]
- [tools] perf: Add missing perf_regs.h file to MANIFEST (Jiri Olsa) [927866]
- [tools] perf: include wrapper for magic.h (Jiri Olsa) [927866]
- [tools] perf/kmem: Remove die() calls (Jiri Olsa) [927866]
- [tools] perf/sched: Remove die() calls (Jiri Olsa) [927866]
- [tools] perf/symbols: Remove BIONIC wrapper around libgen.h (Jiri Olsa) [927866]
- [tools] perf/probe: Make a copy of exec path for passing to basename (Jiri Olsa) [927866]
- [tools] perf/annotate: Make a copy of filename for passing to basename (Jiri Olsa) [927866]
- [tools] perf/gtk/browser: Use perf_hpp__format functions (Jiri Olsa) [927866]
- [tools] perf/hists: Use perf_hpp__format functions (Jiri Olsa) [927866]
- [tools] perf/hists: Use perf_hpp__format->width to calculate the column widths (Jiri Olsa) [927866]
- [tools] perf/hists: Handle field separator properly (Jiri Olsa) [927866]
- [tools] perf/hists: Introduce perf_hpp for hist period printing (Jiri Olsa) [927866]
- [tools] perf/bench: fix assert when NDEBUG is defined (Jiri Olsa) [927866]
- [tools] perf: Fix build for another rbtree.c change (Jiri Olsa) [927866]
- [tools] perf: add NO_BACKTRACE for application self-debugging (Jiri Olsa) [927866]
- [tools] traceevent: replace mempcpy with memcpy (Jiri Olsa) [927866]
- [tools] perf: replace mkostemp with mkstemp (Jiri Olsa) [927866]
- [tools] perf: include missing pthread.h header (Jiri Olsa) [927866]
- [tools] perf: fix missing winsize definition (Jiri Olsa) [927866]
- [tools] perf: include basename for non-glibc systems (Jiri Olsa) [927866]
- [tools] perf: Replace sort's standalone field_sep with symbol_conf.field_sep (Jiri Olsa) [927866]
- [tools] perf/diff: Make diff command work with evsel hists (Jiri Olsa) [927866]
- [tools] traceevent: Get rid of die() from pevent_register_print_function (Jiri Olsa) [927866]
- [tools] traceevent: Get rid of die() from pevent_register_event_handler (Jiri Olsa) [927866]
- [tools] traceevent: Get rid of die() from pretty_print() (Jiri Olsa) [927866]
- [tools] perf: Ignore compiled python binaries (Jiri Olsa) [927866]
- [tools] perf: Fix cache event name generation (Jiri Olsa) [927866]
- [tools] perf/test: Add roundtrip test for hardware cache events (Jiri Olsa) [927866]
- [tools] perf/evlist: Add fprintf method (Jiri Olsa) [927866]
- [tools] perf: Remove extraneous newline when parsing hardware cache events (Jiri Olsa) [927866]
- [tools] perf/test: Add round trip test for sw and hw event names (Jiri Olsa) [927866]
- [tools] perf/header: Prepare tracepoint events regardless of name (Jiri Olsa) [927866]
- [tools] perf/header: Fix a typo on evsel (Jiri Olsa) [927866]
- [tools] perf: Clean target should do clean for lib/traceevent too (Jiri Olsa) [927866]
- [tools] perf: Allow user to indicate path to objdump in command line (Jiri Olsa) [927866]
- [tools] perf: Replace mempcpy with memcpy (Jiri Olsa) [927866]
- [tools] perf/header: Swap pmu mapping numbers if needed (Jiri Olsa) [927866]
- [tools] perf/header: Set tracepoint event name only if not set (Jiri Olsa) [927866]
- [tools] perf/header: Use evlist->nr_entries on write_event_desc() (Jiri Olsa) [927866]
- [tools] perf: remove unneeded include of network header files (Jiri Olsa) [927866]
- [tools] perf: Remove the node from rblist in strlist__remove (Jiri Olsa) [927866]
- [tools] perf: Fix intlist node removal (Jiri Olsa) [927866]
- [tools] perf: Fix x86 builds with ARCH specified on the command line (Jiri Olsa) [927866]
- [tools] perf/record: Remove use of die/exit (Jiri Olsa) [927866]
- [tools] perf/script: Remove use of die/exit (Jiri Olsa) [927866]
- [tools] perf/help: Remove use of die and handle errors (Jiri Olsa) [927866]
- [tools] perf/stat: Remove use of die/exit and handle errors (Jiri Olsa) [927866]
- [tools] perf/lock: Remove use of die and handle errors (Jiri Olsa) [927866]
- [tools] perf: handle errors in synthesized event functions (Jiri Olsa) [927866]
- [tools] perf/session: flush_sample_queue needs to handle errors from handlers (Jiri Olsa) [927866]
- [tools] traceevent: Modify header to work in C++ programs (Jiri Olsa) [927866]
- [tools] traceevent: Fix off-by-one bug in pevent_strerror() (Jiri Olsa) [927866]
- [tools] traceevent: Fix strerror_r() use in pevent_strerror (Jiri Olsa) [927866]
- [tools] traceevent: Introduce pevent_strerror (Jiri Olsa) [927866]
- [tools] traceevent: Introduce pevent_errno (Jiri Olsa) [927866]
- [tools] traceevent: Do not link broken field arg for an old ftrace event (Jiri Olsa) [927866]
- [tools] perf: Keep the perf_event_attr on version 3 (Jiri Olsa) [927866]
- [tools] perf: Add pmu mappings to header information (Jiri Olsa) [927866]
- [tools] perf/report: Update event names from header description (Jiri Olsa) [927866]
- [tools] perf: Refactor print_event_desc() (Jiri Olsa) [927866]
- [tools] perf/test: Do not abort tests on error (Jiri Olsa) [927866]
- [tools] perf: Fix 'No libunwind found' make warning message (Jiri Olsa) [927866]
- [tools] perf/hists: Rename and move some functions (Jiri Olsa) [927866]
- [tools] perf/hists: Separate out hist print functions (Jiri Olsa) [927866]
- [tools] perf: Fix include order for bison/flex-generated C files (Jiri Olsa) [927866]
- [tools] perf/symbols: Fix builds with NO_LIBELF set (Jiri Olsa) [927866]
- [tools] perf: silence GTK2 probing errors (Jiri Olsa) [927866]
- [tools] perf/script: Fix libexec scripts path in Documentation (Jiri Olsa) [927866]
- [tools] perf/ui/gtk: Ensure not to call gtk_main_quit() twice (Jiri Olsa) [927866]
- [tools] perf: Rename global variable 'events' in util/header.c (Jiri Olsa) [927866]
- [tools] perf: Rename some variables for better understanding (Jiri Olsa) [927866]
- [tools] perf: Report number of pmu type of unknown events (Jiri Olsa) [927866]
- [tools] perf: Fix type for evsel->ids and add size check for ids (Jiri Olsa) [927866]
- [tools] perf/ui/gtk: Add perf_gtk__show_helpline() for pr_* (Jiri Olsa) [927866]
- [tools] perf/ui/gtk: Use helpline API in browser (Jiri Olsa) [927866]
- [tools] perf/ui/gtk: Implement helpline_fns (Jiri Olsa) [927866]
- [tools] perf/ui: Introduce struct ui_helpline (Jiri Olsa) [927866]
- [tools] perf/evlist: Introduce evsel list accessors (Jiri Olsa) [927866]
- [tools] perf/evlist: Rename __group method to __set_leader (Jiri Olsa) [927866]
- [tools] perf/symbols: Add description of JIT interface (Jiri Olsa) [927866]
- [tools] perf/symbols: Use both runtime and debug images (Jiri Olsa) [927866]
- [tools] perf/symbols: Convert dso__load_syms to take 2 symsrc's (Jiri Olsa) [927866]
- [tools] perf/symbols: Factor want_symtab out of dso__load_sym() (Jiri Olsa) [927866]
- [tools] perf/symbols: Switch dso__synthesize_plt_symbols() to use symsrc (Jiri Olsa) [927866]
- [tools] perf/symbols: Set symtab_type in dso__load_sym (Jiri Olsa) [927866]
- [tools] perf/symbols: Introduce symsrc structure (Jiri Olsa) [927866]
- [tools] perf/symbols: Track symtab_type of vmlinux (Jiri Olsa) [927866]
- [tools] perf/symbols: Avoid segfault in elf_strptr (Jiri Olsa) [927866]
- [tools] perf/symbols: only set vmlinux longname & mark loaded if really loaded (Jiri Olsa) [927866]
- [tools] perf/symbols: Simplify out_fixup in kernel syms loading (Jiri Olsa) [927866]
- [tools] perf/symbols: Remove unused 'end' arg in kallsyms parse cb (Jiri Olsa) [927866]
- [tools] perf/symbols: Correct comment wrt kallsyms loading (Jiri Olsa) [927866]
- [tools] perf/symbols: Remove unneeded call to dso__set_long_name() (Jiri Olsa) [927866]
- [tools] perf/symbols: Don't try to synthesize plt without dynstr (Jiri Olsa) [927866]
- [tools] perf/symbols: Remove unused function map__objdump_2ip (Jiri Olsa) [927866]
- [tools] perf/symbols: Only un-prelink non-zero symbols (Jiri Olsa) [927866]
- [tools] perf/compat: Disable dwarf unwind (Jiri Olsa) [927866]
- [tools] perf: Support for DWARF mode callchain (Jiri Olsa) [927866]
- [tools] perf: Support for DWARF CFI unwinding on post processing (Jiri Olsa) [927866]
- [tools] perf: Support user regs and stack in sample parsing (Jiri Olsa) [927866]
- [tools] perf: Add libunwind dependency for DWARF CFI unwinding (Jiri Olsa) [927866]
- [tools] perf: Add interface to arch registers sets (Jiri Olsa) [927866]
- [tools] perf/compat: Force PERF_ATTR_SIZE_VER0 perf event abi (Jiri Olsa) [927866]
- [tools] perf: Adding PERF_ATTR_SIZE_VER2 to the header swap check (Jiri Olsa) [927866]
- [tools] perf/symbols: Implement poor man's ELF parser (Jiri Olsa) [927866]
- [tools] perf/symbols: Support minimal build without libelf (Jiri Olsa) [927866]
- [tools] perf/symbols: Split out util/symbol-elf.c (Jiri Olsa) [927866]
- [tools] perf/symbols: Introduce symbol__elf_init() (Jiri Olsa) [927866]
- [tools] perf: Fix /etc config related installation (Jiri Olsa) [927866]
- [tools] perf: Support for events bash completion (Jiri Olsa) [927866]
- [tools] perf: Initial bash completion support (Jiri Olsa) [927866]
- [tools] perf/lock: improve message when tracepoints are not enabled (Jiri Olsa) [927866]
- [tools] perf/scripts: Correct handler check and spelling errors (Jiri Olsa) [927866]
- [tools] perf/scripts: Add event_analyzing_sample.py as a sample for general event handling (Jiri Olsa) [927866]
- [tools] perf/scripts: Add a python library EventClass.py (Jiri Olsa) [927866]
- [tools] perf/scripts: Pass event/thread/dso name and symbol info to event handler in python (Jiri Olsa) [927866]
- [tools] perf/script: Replace struct thread with struct addr_location as a parameter for process_event (Jiri Olsa) [927866]
- [tools] perf/script: Add general python handler to process non-tracepoint events (Jiri Olsa) [927866]
- [tools] perf/list: Document precise event sampling for AMD IBS (Jiri Olsa) [927866]
- [tools] perf/list: Update documentation about raw event setup (Jiri Olsa) [927866]
- [tools] traceevent: Fix cast from pointer to integer for 32 bit (Jiri Olsa) [927866]
- [tools] perf: Fix parsing of 64 bit raw config value for 32 bit (Jiri Olsa) [927866]
- [tools] perf: Fix lib/traceevent build dir with OUTPUT variable set (Jiri Olsa) [927866]
- [tools] perf: Fix version file for perf documentation with OUTPUT variable set (Jiri Olsa) [927866]
- [tools] perf/script: Stop using pevent directly (Jiri Olsa) [927866]
- [tools] perf/sched: Use perf_sample (Jiri Olsa) [927866]
- [tools] perf/lock: Use evsel->tp_format and perf_sample (Jiri Olsa) [927866]
- [tools] perf/kmem: Use evsel->tp_format and perf_sample (Jiri Olsa) [927866]
- [tools] perf/evsel: Cache associated event_format (Jiri Olsa) [927866]
- [tools] perf/header: Set the tracepoint names on PERF_RECORD_HEADER_TRACING_DATA (Jiri Olsa) [927866]
- [tools] perf: Add dump_stack function (Jiri Olsa) [927866]
- [tools] perf/hists: Add verbose mode hotkey (Jiri Olsa) [927866]
- [tools] perf: Fix typo in tools/perf (Jiri Olsa) [927866]
- [idle] intel_idle: additional Haswell CPU-id (John Villalovos) [818357]
- [idle] intel_idle: support Haswell (John Villalovos) [818357]
- [fs] udf: avoid info leak on export (Nikola Pajkovsky) [922355] {CVE-2012-6548}
- [powerpc] oprofile: Fix error in oprofile power7_marked_instr_event() function (Steve Best) [912482]
- [kernel] tracing: Fix timer tracing (Jiri Olsa) [881030]
- [block] dump request state on seeing a corrupted request completion (Mike Snitzer) [957259]
- [scsi] lpfc: Fixed deadlock between hbalock and nlp_lock use (Rob Evers) [960717]
- [netdrv] cxgb4: set coalesce parameters on all queues (Steve Best) [895115]
- [kernel] tracing: Fix possible NULL pointer dereferences (Weiping Pan) [952213] {CVE-2013-3301}
- [kernel] tracing: Fix panic when lseek() called on "trace" opened for writing (Weiping Pan) [952213] {CVE-2013-3301}

* Wed May 08 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-376.el6]
- [netdrv] vmxnet3: prevent div-by-zero panic when ring resizing uninitialized dev (Neil Horman) [922299]
- [netdrv] vmxnet3: make local function static (Neil Horman) [922299]
- [netdrv] vmxnet3: set carrier state properly on probe (Neil Horman) [922299]
- [netdrv] vmxnet3: better RSS support (Neil Horman) [922299]
- [netdrv] vmxnet3: remove unused irq_share_mode (Neil Horman) [922299]
- [netdrv] vmxnet3: use static RSS key (Neil Horman) [922299]
- [netdrv] vmxnet3: use netdev_ printk wrappers (Neil Horman) [922299]
- [netdrv] vmxnet3: remove VMXNET3_MAX_DEVICES (Neil Horman) [922299]
- [netdrv] vmxnet3: remove device counter (Neil Horman) [922299]
- [netdrv] vmxnet3: use netdev_dbg (Neil Horman) [922299]
- [netdrv] vmxnet3: remove unnecessary bookkeeping (Neil Horman) [922299]
- [netdrv] vmxnet3: fix messages printed before registration (Neil Horman) [922299]
- [netdrv] vmxnet3: use netdev_alloc_skb_ip_align (Neil Horman) [922299]
- [netdrv] vmxnet3: fix drvinfo strings set in drivers (Neil Horman) [922299]
- [netdrv] vmxnet3: remove __dev* attributes (Neil Horman) [922299]
- [netdrv] vmxnet3: fix indentation (Neil Horman) [922299]
- [netdrv] vmxnet3: convert BUG_ON(true) into a simple BUG() (Neil Horman) [922299]
- [netdrv] vmxnet3: must split too big fragments (Neil Horman) [922299]
- [netdrv] vmxnet3: Fix race between dev_open() and register_netdev() (Neil Horman) [922299]
- [netdrv] vmxnet3: Define and apply a default policy for RX flow hash indirection (Neil Horman) [922299]
- [netdrv] vmxnet3: Centralise validation of ETHTOOL_{G, S}RXFHINDIR parameters (Neil Horman) [922299]
- [netdrv] vmxnet3: remove use of ndo_set_multicast_list in drivers (Neil Horman) [922299]
- [netdrv] vmxnet3: Enable GRO support (Neil Horman) [922299]
- [kernel] hrtimer: add expiry time overflow check in hrtimer_interrupt (Prarit Bhargava) [947659]
- [kernel] time: Move ktime_t overflow checking into timespec_valid_strict (Prarit Bhargava) [947659]
- [kernel] time: Improve sanity checking of timekeeping inputs (Prarit Bhargava) [947659]
- [powerpc] pseries: Enable the PFO-based RNG accelerator (Steve Best) [947106]
- [char] hw_random/pseries-rng: PFO-based hwrng driver (Steve Best) [947106]
- [powerpc] vio: Remove dma not supported warnings (Steve Best) [947106]
- [powerpc] pseries: Add PFO support to the VIO bus (Steve Best) [947106]
- [powerpc] pseries: Add new hvcall constants to support PFO (Steve Best) [947106]
- [virt] x86/paravirt: don't enter/leave lazy mode in interrupts (Andrew Jones) [874053]
- [powerpc] pSeries_lpar_hpte_remove fails from Adjunct partition being performed before the ANDCOND test (Steve Best) [952309]
- [powerpc] pseries/eeh: Fix crash when error happens during device probe (Steve Best) [905264]
- [kernel] resource: fix stack overflow in __reserve_region_with_split() (Myron Stowe) [858087]
- [md] dm-raid: Fix for "sync" directive ineffectiveness (Jonathan E Brassow) [859562]
- [block] fix max discard sectors limit (Mike Snitzer) [910054]
- [netdrv] vmxnet3: Fix inconsistent LRO state after initialization (Neil Horman) [918203]
- [netdrv] vmxnet3: fix ethtool ring buffer size setting (Neil Horman) [913615]
- [netdrv] ibmveth: Fix DMA unmap error (Steve Best) [902923]
- [net] atm: update msg_namelen in vcc_recvmsg() (Nikola Pajkovsky) [955225] {CVE-2013-3222}
- [net] veth: Dont kfree_skb() after dev_forward_skb() (Jiri Benc) [957713] {CVE-2013-2017}
- [x86] power: Correct the MSR_IA32_ENERGY_PERF_BIAS message (Neil Horman) [917147]
- [x86] msr: Fix typo in ENERGY_PERF_BIAS_POWERSAVE (Neil Horman) [917147]
- [x86] power: Initialize MSR_IA32_ENERGY_PERF_BIAS (Neil Horman) [917147]
- [x86] power: define RAPL MSRs (Neil Horman) [917147]
- [x86] turbostat: display SMI count by default (Neil Horman) [917147]
- [idle] intel_idle: disable Atom/Lincroft HW C-state auto-demotion (Neil Horman) [917147]
- [idle] intel_idle: disable NHM/WSM HW C-state auto-demotion (Neil Horman) [917147]
- [x86] turbostat: share kernel MSR #defines (Neil Horman) [917147]
- [fs] compat: fix build on MIPS/s390/ppc64 (Jeff Moyer) [885239]
- [fs] readv/writev: do the same MAX_RW_COUNT truncation that read/write does (Jeff Moyer) [885239]

* Mon May 06 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-375.el6]
- [fs] nfs: Fix handling of revoked delegations by setattr (Steve Dickson) [952329]
- [fs] nfs: Return the delegation if the server returns NFS4ERR_OPENMODE (Steve Dickson) [952329]
- [fs] nfs: Fix another potential state manager deadlock (Steve Dickson) [950598]
- [fs] nfs: Fix another open/open_recovery deadlock (Steve Dickson) [916806]
- [fs] nfs: Hold reference to layout hdr in layoutget (Steve Dickson) [916726]
- [fs] nfs: add "pnfs_" prefix to get_layout_hdr() and put_layout_hdr() (Steve Dickson) [916726]
- [fs] nfs: nfs4_open_done first must check that GETATTR decoded a file type (Steve Dickson) [916722]
- [net] sunrpc: Dont start the retransmission timer when out of socket space (Steve Dickson) [916735]
- [fs] nfs: Dont use SetPageError in the NFS writeback code (Steve Dickson) [912867]
- [fs] nfs: Dont decode skipped layoutgets (Steve Dickson) [904025]
- [fs] nfs: nfs4_proc_layoutget returns void (Steve Dickson) [904025]
- [fs] nfs: defer release of pages in layoutget (Steve Dickson) [904025]
- [fs] nfs: Use kcalloc() when allocating arrays (Steve Dickson) [904025]
- [fs] nfs: Fix an ABBA locking issue with session and state serialisation (Steve Dickson) [912842]
- [fs] nfs: Fix a race in the pNFS return-on-close code (Steve Dickson) [912842]
- [fs] nfs: Do not accept delegated opens when a delegation recall is in effect (Steve Dickson) [912842]
- [fs] nfs: Fix a reboot recovery race when opening a file (Steve Dickson) [908524]
- [fs] nfs: Ensure delegation recall and byte range lock removal don't conflict (Steve Dickson) [908524]
- [fs] nfs: Fix up the return values of nfs4_open_delegation_recall (Steve Dickson) [908524]
- [fs] nfs: Dont lose locks when a server reboots during delegation return (Steve Dickson) [908524]
- [fs] nfs: Move nfs4_wait_clnt_recover and nfs4_client_recover_expired_lease (Steve Dickson) [908524]
- [fs] nfs: Add NFSDBG_STATE (Steve Dickson) [908524]
- [fs] nfs: nfs_inode_return_delegation() should always flush dirty data (Steve Dickson) [908524]
- [fs] nfs: nfs_client_return_marked_delegations cant flush data (Steve Dickson) [908524]
- [fs] nfs: Prevent deadlocks between state recovery and file locking (Steve Dickson) [908524]
- [fs] nfs: Allow the state manager to mark an open_owner as being recovered (Steve Dickson) [908524]
- [kernel] seqlock: Dont smp_rmb in seqlock reader spin loop (Steve Dickson) [908524]
- [kernel] seqlock: add 'raw_seqcount_begin()' function (Steve Dickson) [908524]
- [kernel] seqlock: optimise seqlock (Steve Dickson) [908524]

* Fri May 03 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-374.el6]
- [net] tcp: Reallocate headroom if it would overflow csum_start (Thomas Graf) [896233]
- [net] tcp: take care of misalignments (Thomas Graf) [896233]
- [net] skbuff.c cleanup (Thomas Graf) [896233]
- [net] ipv6: fix incorrect route 'expires' value passed to userspace (Thomas Graf) [912029]

* Fri Apr 26 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-373.el6]
- [fs] nfs: don't allow nfs_find_actor to match inodes of the wrong type (Jeff Layton) [913660]
- [mm] hugetlbfs: add swap entry check in follow_hugetlb_page() (Naoya Horiguchi) [928883]
- [fs] binfmt_elf: fix hugetlb memory check in vma_dump_size() (Naoya Horiguchi) [928883]
- [x86] remove BUG_ON(TS_USEDFPU) in __sanitize_i387_state() (Oleg Nesterov) [920445]
- [fs] coredump: ensure the fpu state is flushed for proper multi-threaded core dump (Oleg Nesterov) [920445]
- [kernel] perf, x86: Fix raw_spin_unlock_irqrestore() usage (Jiri Olsa) [927177]
- [kernel] perf, x86: Implement user-space RDPMC support, to allow fast, user-space access to self-monitoring counters (Jiri Olsa) [927177]
- [kernel] perf: Fix mmap_page::offset computation (Jiri Olsa) [927177]
- [kernel] perf, arch: Rework perf_event_index() (Jiri Olsa) [927177]
- [kernel] perf: Update the mmap control page on mmap() (Jiri Olsa) [927177]
- [kernel] perf: Fix enable_on_exec for sibling events (Jiri Olsa) [927177]
- [kernel] perf: Remove superfluous arguments (Jiri Olsa) [927177]
- [kernel] perf, x86: Prefer fixed-purpose counters when scheduling (Jiri Olsa) [927177]
- [kernel] events: Don't divide events if it has field period (Jiri Olsa) [927177]
- [kernel] perf: Carve out callchain functionality (Jiri Olsa) [927177]
- [kernel] x86: Perf_event_amd.c needs <asm/apicdef.h> (Jiri Olsa) [927177]
- [kernel] perf_events: Fix slow and broken cgroup context switch code (Jiri Olsa) [927177]
- [kernel] perf, x86: Avoid kfree() in CPU_STARTING (Jiri Olsa) [927177]
- [kernel] x86, perf: Make copy_from_user_nmi() a library function (Jiri Olsa) [927177]
- [kernel] x86, perf: Add constraints for architectural PMU (Jiri Olsa) [927177]
- [kernel] perf: Remove the perf_output_begin(.sample) argument (Jiri Olsa) [927177]
- [kernel] perf: Remove the nmi parameter from the swevent and overflow interface (Jiri Olsa) [927177]
- [kernel] events: Ensure that timers are updated without requiring read() call (Jiri Olsa) [927177]
- [kernel] perf_event: Fix broken calc_timer_values() (Jiri Olsa) [927177]
- [kernel] events: Move lockless timer calculation into helper function (Jiri Olsa) [927177]
- [kernel] events: Add note to update_event_times comment about holding ctx->lock (Jiri Olsa) [927177]
- [kernel] perf_events: Fix perf buffer watermark setting (Jiri Olsa) [927177]
- [net] ieee802154: Remove static CFLAGS in net/ieee802154/Makefile (Aristeu Rozanski) [920620]
- [net] sunrpc: Add barriers to ensure read ordering in rpc_wake_up_task_queue_locked (Dave Wysochanski) [840860]

* Tue Apr 23 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-372.el6]
- [x86] apic: Add probe() for apic_flat (Prarit Bhargava) [953342]
- [x86] apic: Work around boot failure on HP ProLiant DL980 G7 Server systems (Prarit Bhargava) [912963]
- [x86] apic: Use probe routines to simplify apic selection (Prarit Bhargava) [912963]
- [x86] x2apic: Simplify apic init in SMP and UP builds (Prarit Bhargava) [912963]
- [virt] virtio-rng: fix crashes by disallowing multiple device registrations (Amit Shah) [953097]
- [virt] virtio-console: add locking around c_ovq operations (Amit Shah) [928207]
- [virt] virtio-console: rename cvq_lock to c_ivq_lock (Amit Shah) [928207]
- [virt] virtio_console: Merge struct buffer_token into struct port_buffer (Amit Shah) [840454]
- [virt] virtio_console: Free buffers from out-queue upon close (Amit Shah) [840454]
- [virt] virtio_console: Use kmalloc instead of kzalloc (Amit Shah) [840454]
- [virt] virtio_console: Free buffer if splice fails (Amit Shah) [840454]
- [virt] virtio-trace: Fix pthread flag for Makefile of trace-agent used (Amit Shah) [840454]
- [virt] virtio-trace: do not use unavailable fcntl (F_SETPIPE_SZ) (Amit Shah) [840454]
- [virt] tools: Add guest trace agent as a user tool (Amit Shah) [840454]
- [virt] virtio_console: Allocate scatterlist according to the current pipe size (Amit Shah) [840454]
- [trace] ftrace: Allow stealing pages from pipe buffer (Amit Shah) [840454]
- [virt] virtio_console: Wait until the port is ready on splice (Amit Shah) [840454]
- [virt] virtio_console: Add a failback for unstealable pipe buffer (Amit Shah) [840454]
- [virt] virtio_console: Add splice_write support (Amit Shah) [840454]
- [s390] kdump: Do not add standby memory for kdump (Hendrik Brueckner) [922943]
- [fs] vfs: remove unneeded permission check from path_init (Jeff Layton) [884863]
- [idle] intel_idle: Initialize driver_data correctly in ivb_cstates on IVB processor (Prarit Bhargava) [953630]
- [mm] fix fs oops due to dirty pages without buffers on s390 (Hendrik Brueckner) [692530]
- [netdrv] vmxnet3: set carrier state properly on probe (Neil Horman) [861131]

* Mon Apr 22 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-371.el6]
- [scsi] be2iscsi: Bump driver version (Rob Evers) [947550]
- [scsi] be2iscsi: Fix issue in passing the exp_cmdsn and max_cmdsn (Rob Evers) [947550]
- [scsi] be2iscsi: Fix possible reentrancy issue in be_iopoll (Rob Evers) [947550]
- [scsi] be2iscsi: Fix the copyright information (Rob Evers) [947550]
- [scsi] be2iscsi: Fix checking Adapter state while establishing CXN (Rob Evers) [947550]
- [scsi] be2iscsi: Fix dynamic CID allocation Mechanism in driver (Rob Evers) [947550]
- [scsi] be2iscsi: Fix the NOP-In handling code path (Rob Evers) [947550]
- [scsi] be2iscsi: Fix the Port Link Status issue (Rob Evers) [947550]
- [scsi] be2iscsi: Fix displaying the Active Session Count from driver (Rob Evers) [947550]
- [scsi] be2iscsi: Fix displaying the FW Version from driver (Rob Evers) [947550]
- [scsi] be2iscsi: Fix support for DEFQ extension (Rob Evers) [947550]
- [scsi] be2iscsi: Fix MACRO for checking the adapter type (Rob Evers) [947550]
- [scsi] be2iscsi: Fix freeing CXN specific driver resources. (Rob Evers) [947550]
- [scsi] be2iscsi: Fix MSIx support in SKH-R to 32 (Rob Evers) [947550]
- [scsi] be2iscsi: Fix MBX Command issues (Rob Evers) [947550]
- [scsi] be2iscsi: Fix returning Failure when MBX fails with Insufficient buffer error (Rob Evers) [947550]
- [scsi] be2iscsi: Send uninitialize pattern to FW (Rob Evers) [947550]
- [scsi] be2iscsi: Fix Unrecoverable Error Detection (Rob Evers) [947550]
- [scsi] be2iscsi: Fix for MBX timeout issue (Rob Evers) [947550]
- [scsi] be2iscsi: Update the copyright information (Rob Evers) [947550]
- [scsi] be2iscsi: Fix issue of displaying adapter family (Rob Evers) [947550]
- [scsi] be2iscsi: Fix Task Completion Event handling (Rob Evers) [947550]
- [scsi] be2iscsi: Fix session update context with V2 version (Rob Evers) [947550]
- [scsi] be2iscsi: Fix support for V2 version of WRB (Rob Evers) [947550]
- [scsi] be2iscsi: Fix support for handling CQ_CREATE V2 version (Rob Evers) [947550]
- [scsi] be2iscsi: Fix max EQ supported by the driver (Rob Evers) [947550]
- [scsi] be2iscsi: Fix driver support for Skyhawk-R adapter (Rob Evers) [947550]
- [scsi] be2iscsi: Fix return value and typo (Rob Evers) [947550]
- [scsi] be2iscsi: Fix kernel panic in blk_iopoll disable mode (Rob Evers) [947550]
- [scsi] be2iscsi: Issue an function level reset when driver is loaded (Rob Evers) [947550]
- [scsi] be2iscsi: Display driver name and version in device attribute (Rob Evers) [947550]
- [scsi] be2iscsi: Fix max supported EQ count to 8.a (Rob Evers) [947550]
- [scsi] be2iscsi: Fix memory leak in control path of driver (Rob Evers) [947550]
- [scsi] be2iscsi: Display Completion Event string instead of Opcode (Rob Evers) [947550]
- [scsi] be2iscsi: Fix the issue with soft reset (Rob Evers) [947550]
- [scsi] be2iscsi: cleanup a min_t() call (Rob Evers) [947550]
- [kernel] percpu-rw-sem: remove the percpu rw semaphore implementation (Jeff Moyer) [909482]
- [fs] direct-io: don't read inode->i_blkbits multiple times (Jeff Moyer) [909482]
- [fs] vfs: add missing virtual cache flush after editing partial pages (Jeff Moyer) [909482]
- [fs] vfs: fix O_DIRECT read past end of block device (Jeff Moyer) [909482]
- [fs] vfs: clear to the end of the buffer on partial buffer reads (Jeff Moyer) [909482]
- [fs] vfs: avoid "attempt to access beyond end of device" warnings (Jeff Moyer) [909482]
- [fs] blkdev_max_block: make private to fs/buffer.c (Jeff Moyer) [909482]
- [fs] blockdev: remove bd_block_size_semaphore again (Jeff Moyer) [909482]
- [fs] buffer.c: make block-size be per-page and protected by the page lock (Jeff Moyer) [909482]
- [fs] direct-io.c: adjust suspicious bit operation (Jeff Moyer) [909482]
- [fs] direct-io: optimize cache misses in the submission path (Jeff Moyer) [909482]
- [fs] direct-io.c: calculate fs_count correctly in get_more_blocks() (Jeff Moyer) [909482]
- [fs] direct-io: merge direct_io_walker into __blockdev_direct_IO (Jeff Moyer) [909482]
- [fs] direct-io: inline the complete submission path (Jeff Moyer) [909482]
- [fs] direct-io: separate map_bh from dio (Jeff Moyer) [909482]
- [fs] direct-io: use a slab cache for struct dio (Jeff Moyer) [909482]
- [fs] direct-io: rearrange fields in dio/dio_submit to avoid holes (Jeff Moyer) [909482]
- [fs] direct-io: fix a wrong comment (Jeff Moyer) [909482]
- [fs] direct-io: separate fields only used in the submission path from struct dio (Jeff Moyer) [909482]
- [powerpc] pci: convert devtree bus addresses to resource (Myron Stowe) [953181]
- [acpi] create _SUN sysfs file (Motohiro Kosaki) [908606]

* Tue Apr 16 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-370.el6]
- [pci] Remove spurious error for sriov_numvfs store and simplify flow (Don Dutile) [887398]
- [pci] Provide method to reduce the number of total VFs supported (Don Dutile) [887398]
- [pci] SRIOV control and status via sysfs (Don Dutile) [887398]
- [pci] Use is_visible() with boot_vga attribute for pci_dev (Don Dutile) [887398]
- [pci] Add pci_device_type to pdev's device struct (Don Dutile) [887398]
- [x86] Allow greater than 1TB of RAM on AMD x86_64 sytems (Larry Woodman) [869736 876275]
- [mm] writeback: Fix Kernel divide by zero panic in get_dirty_limits() (Rafael Aquini) [871599]
- [scsi] scsi_debug: Fix off-by-one bug when unmapping region (Ewan Milne) [902973]
- [md] dm-snap: provide module alias in dm-snapshot (Mikulas Patocka) [889973]
- [x86] mce: Fix return value of mce_chrdev_read() when erst is disabled (Prarit Bhargava) [742385]
- [x86] Prevent panic in init_memory_mapping() when booting more than 1TB on AMD systems (Larry Woodman) [869736]
- [kernel] TAINT_TECH_PREVIEW should not disable lock debugging (Prarit Bhargava) [872688]
- [Documentation] remove doc for obsolete dynamic-printk kernel-parameter (Prarit Bhargava) [883911]
- [kernel] coredump: backport E option for /proc/sys/kernel/coredump_pattern (Dave Anderson) [905122]
- [s390] mm: Fix crst upgrade of mmap with MAP_FIXED (Hendrik Brueckner) [915357]
- [virt] kvm/mmu: fix hashing for TDP and non-paging modes (Marcelo Tosatti) [908751]
- [virt] kvm/mmu: Fix free memory accounting race in mmu_alloc_roots() (Marcelo Tosatti) [908751]
- [virt] kvm/mmu: Don't flush shadow when enabling dirty tracking (Marcelo Tosatti) [908751]
- [mm] memcg: fix totalpages calculation for memory.swappiness==0 (Satoru Moriya) [887402]
- [mm] memcg: fix unit mismatch in memcg oom limit calculation (Satoru Moriya) [887397]
- [x86] pci: Allow x86 platforms to use translation offsets (Myron Stowe) [836569]
- [x86] pci: Clear host bridge aperture struct resource (Myron Stowe) [836569]
- [x86] pci: use _CRS bus number aperture for host bridges from ACPI (Myron Stowe) [836569]
- [x86] pci: fix unused variable warning in amd_bus.c (Myron Stowe) [836569]
- [x86] pci: merge pcibios_scan_root() and pci_scan_bus_on_node() (Myron Stowe) [836569]
- [x86] pci: dynamically allocate pci_root_info for native host bridge drivers (Myron Stowe) [836569]
- [x86] pci: embed pci_sysdata into pci_root_info on ACPI path (Myron Stowe) [836569]
- [x86] pci: embed name into pci_root_info struct (Myron Stowe) [836569]
- [x86] pci: add host bridge resource release for _CRS path (Myron Stowe) [836569]
- [x86] pci: refactor get_current_resources() (Myron Stowe) [836569]
- [pci] add host bridge release support (Myron Stowe) [836569]
- [pci] add generic device into pci_host_bridge struct (Myron Stowe) [836569]
- [pci] rename pci_host_bridge() to find_pci_root_bridge() (Myron Stowe) [836569]
- [x86] pci: fix memleak with get_current_resources() (Myron Stowe) [836569]
- [pci] move host bridge-related code to host-bridge.c (Myron Stowe) [836569]
- [pci] collapse pcibios_resource_to_bus (Myron Stowe) [836569]
- [powerpc] pci: get rid of device resource fixups (Myron Stowe) [836569]
- [pci] add generic pcibios_resource_to_bus() (Myron Stowe) [836569]
- [pci] convert bus addresses to resource when reading BARs (Myron Stowe) [836569]
- [pci] add struct pci_host_bridge_window with CPU/bus address offset (Myron Stowe) [836569]
- [pci] add struct pci_host_bridge and a list of all bridges found (Myron Stowe) [836569]
- [pci] don't publish new root bus until it's fully initialized (Myron Stowe) [836569]
- [pci] make pci_flags non-weak (Myron Stowe) [836569]
- [powerpc] pci: replace pci_probe_only with pci_flags (Myron Stowe) [836569]
- [powerpc] pci: make pci_probe_only default to 0 (Myron Stowe) [836569]
- [pci] add pci_clear_flags() (Myron Stowe) [836569]
- [pci] make pci_flags always available (Myron Stowe) [836569]
- [x86] pci: fix memleak when ACPI _CRS is not used (Myron Stowe) [836569]
- [x86] pci: don't fall back to defaults if _CRS has no apertures (Myron Stowe) [836569]
- [pci] remove pci_create_bus() (Myron Stowe) [836569]
- [x86] pci: convert to pci_create_root_bus() and pci_scan_root_bus() (Myron Stowe) [836569]
- [x86] pci: use pci_scan_bus() instead of pci_scan_bus_parented() (Myron Stowe) [836569]
- [powerpc] pci: convert to pci_create_root_bus() (Myron Stowe) [836569]
- [powerpc] pci: split PHB part out of pcibios_map_io_space() (Myron Stowe) [836569]
- [powerpc] pci: make pcibios_setup_phb_resources() static (Myron Stowe) [836569]
- [pci] deprecate pci_scan_bus_parented() (Myron Stowe) [836569]
- [pci] convert pci_scan_bus_parented() to use pci_create_root_bus() (Myron Stowe) [836569]
- [pci] convert pci_scan_bus() to use pci_create_root_bus() (Myron Stowe) [836569]
- [pci] add pci_scan_root_bus() that accepts resource list (Myron Stowe) [836569]
- [pci] add pci_create_root_bus() that accepts resource list (Myron Stowe) [836569]
- [pci] show host bridges and root bus resources (Myron Stowe) [836569]
- [pci] add helpers for building PCI bus resource lists (Myron Stowe) [836569]
- [x86] pci: Ignore CPU non-addressable _CRS reserved memory resources (Myron Stowe) [836569]
- [powerpc] pci: fix a brace coding style issue in probe.c (Myron Stowe) [836569]
- [powerpc] pci: move powerpc pci flag functions into asm-generic (Myron Stowe) [836569]
- [powerpc] rename ppc_pci_*_flags to pci_*_flags (Myron Stowe) [836569]
- [x86] pci/sysfs: move bus cpuaffinity to class dev_attrs (Myron Stowe) [836569]
- [x86] pci: add rescan to /sys/.../pci_bus/.../ (Myron Stowe) [836569]
- [x86] pci: use kasprintf in acpi.c (Myron Stowe) [836569]
- [x86] pci: Enable pci root res read out for 32bit too (Myron Stowe) [836569]
- [x86] pci: Add cap_resource() (Myron Stowe) [836569]
- [x86] pci: Use u64 instead of size_t in amd_bus.c (Myron Stowe) [836569]
- [x86] pci: AMD one chain system to use pci read out res (Myron Stowe) [836569]
- [x86] pci: Use resource_size_t in update_res (Myron Stowe) [836569]
- [x86] Move range related operation to one file (Myron Stowe) [836569]
- [x86] pci: fix section mismatch on update_res() (Myron Stowe) [836569]
- [x86] pci: seperate x86_pci_rootbus_res_quirks from amd_bus.c (Myron Stowe) [836569]
- [x86] pci: fix comment typo in bus_numa.h (Myron Stowe) [836569]
- [x86] mtrr: Fix sorting of mtrr after subtracting (Myron Stowe) [836569]
- [x86] pci: read root resources from IOH on Intel (Myron Stowe) [836569]
- [block] Consolidate command flag and queue limit checks for merges (Mike Snitzer) [910054]
- [scsi] sd: Permit merged discard requests (Mike Snitzer) [910054]
- [block] Clean up special command handling logic (Mike Snitzer) [910054]
- [block] separate out blk_rq_merge_ok() and blk_try_merge() from elevator functions (Mike Snitzer) [910054]
- [block] cleanup previous backport of blk_throtl_bio() reorganization (Mike Snitzer) [910054]
- [i2c] Adding support for Intel iSMT SMBus 2.0 host controller (Neil Horman) [910427]
- [asm-generic] architecture independent readq/writeq for 32bit environment (Neil Horman) [910427]
- [kvm] vmx: provide the vmclear function and a bitmap to support VMCLEAR in kdump (Andrew Jones) [908608]
- [x86] kexec: VMCLEAR VMCSs loaded on all cpus if necessary (Andrew Jones) [908608]
- [netdrv] igb: release already assigned MSI-X interrupts if setup fails (Stefan Assmann) [804724]
- [netdrv] igb: remove duplicate code for fallback interrupt initialization (Stefan Assmann) [804724]
- [netdrv] igb: Combine q_vector and ring allocation into a single function (Stefan Assmann) [804724]
- [netdrv] igb: Remove logic that was doing NUMA pseudo-aware allocations (Stefan Assmann) [804724]
- [netdrv] igb: Move the calls to set the Tx and Rx queues into igb_open (Stefan Assmann) [804724]
- [char] ipmi: add options to disable openfirmware and PCI scanning (Tony Camuso) [924736]
- [char] ipmi: use locks on watchdog timeout set on reboot (Tony Camuso) [924736]
- [char] ipmi: simplify locking (Tony Camuso) [924736]
- [char] ipmi: fix message handling during panics (Tony Camuso) [924736]
- [char] ipmi: Fix IPMI errors due to timing problems (Tony Camuso) [924736]
- [char] ipmi/ipmi_si_intf: fix cleanup_one_si section mismatch (Tony Camuso) [924736]
- [char] ipmi: fix OOPS caused by pnp_unregister_driver on unregistered driver (Tony Camuso) [924736]
- [Documentation] IPMI: Add the document description of ipmi_get_smi_info (Tony Camuso) [924736]
- [char] ipmi: fix __init and __exit attribute locations (Tony Camuso) [924736]
- [char] ipmi: proper spinlock initialization (Tony Camuso) [924736]
- [char] ipmi: fix hardcoded ipmi device exit path warning (Tony Camuso) [924736]
- [char] ipmi: fix acpi probe print (Tony Camuso) [924736]
- [char] ipmi: print info for spmi and smbios paths like acpi and pci (Tony Camuso) [924736]
- [char] ipmi: fix memleaking for add_smi when duplicating happen (Tony Camuso) [924736]
- [char] ipmi: update driver to use dev_printk and its constructs (Tony Camuso) [924736]
- [char] ipmi/ipmi_si_intf: fix variable 'addr_space' set but not used warning (Tony Camuso) [924736]
- [char] ipmi: fix sysfs lockdep warning in ipmi code (Tony Camuso) [924736]
- [char] ipmi: remove ipmi_smi.h self-include (Tony Camuso) [924736]
- [char] ipmi: fix slave_addrs setting to actually work (Tony Camuso) [924736]
- [char] ipmi: Use KCS_IDLE_STATE (Tony Camuso) [924736]
- [char] ipmi: refer to table as "SPMI", not "ACPI" (Tony Camuso) [924736]
- [mm] enforce mmap_min_addr on x86_64 (Rik van Riel) [790921]
- [mm] optional next-fit policy for arch_get_unmapped_area (Rik van Riel) [790921]
- [mm] fix quadratic behaviour in get_unmapped_area_topdown (Rik van Riel) [790921]
- [scsi] Revert: qla2xxx: Optimize existing port name server query matching (Chad Dupuis) [924804]
- [scsi] Revert: qla2xxx: Avoid losing any fc ports when loop id's are exhausted (Chad Dupuis) [924804]

* Thu Mar 28 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-369.el6]
- [fs] defer do_filp_open() access checks to may_open() (Eric Sandeen) [920752]
- [infiniband] ipoib: Add missing locking when CM object is deleted (Doug Ledford) [913645]
- [virt] kvm: accept unaligned MSR_KVM_SYSTEM_TIME writes (Petr Matousek) [917021] {CVE-2013-1796}
- [char] tty: hold lock across tty buffer finding and buffer filling (Prarit Bhargava) [901780]

* Thu Mar 28 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-368.el6]
- [net] tcp: fix for zero packets_in_flight was too broad (Thomas Graf) [920794]
- [net] tcp: frto should not set snd_cwnd to 0 (Thomas Graf) [920794]
- [net] tcp: fix an infinite loop in tcp_slow_start() (Thomas Graf) [920794]
- [net] tcp: fix ABC in tcp_slow_start() (Thomas Graf) [920794]
- [md] dm-thin: bump the target version numbers (Mike Snitzer) [922931]
- [md] dm-thin: use block_size_is_power_of_two (Mike Snitzer) [904161]
- [md] dm-thin: support a non-power-of-2 discard_granularity (Mike Snitzer) [904161]
- [md] dm-thin: fix queue limits stacking (Mike Snitzer) [904161]
- [md] dm: sync misc small differences from upstream (Mike Snitzer) [904161]
- [md] persistent-data: improve improve space map block alloc failure message (Mike Snitzer) [904161]
- [md] dm-thin: use DMERR_LIMIT for errors (Mike Snitzer) [904161]
- [md] persistent-data: use DMERR_LIMIT for errors (Mike Snitzer) [904161]
- [md] persistent-data: fix nested btree deletion (Mike Snitzer) [904161]
- [md] dm-thin: move bio_prison code to separate module (Mike Snitzer) [904161]
- [md] dm-thin: prepare to separate bio_prison code (Mike Snitzer) [904161]
- [md] persistent-data: convert to use le32_add_cpu (Mike Snitzer) [904161]
- [md] dm-bufio: use ACCESS_ONCE for sysfs values (Mike Snitzer) [904161]
- [md] dm-bufio: use list_move (Mike Snitzer) [904161]
- [md] dm-ioctl: use kmalloc if possible (Mike Snitzer) [904161]
- [md] dm-ioctl: remove PF_MEMALLOC (Mike Snitzer) [904161]
- [md] dm-ioctl: prevent unsafe change to dm_ioctl data_size (Mike Snitzer) [904161]
- [md] dm-snap: optimize track_chunk (Mike Snitzer) [904161]
- [md] dm: fix deadlock with request based dm and queue request_fn recursion (Mike Snitzer) [904161]
- [fs] ext3: Fix format string issues (Nikola Pajkovsky) [920785] {CVE-2013-1848}
- [netdrv] ehea: avoid accessing a NULL vgrp (Steve Best) [911359]
- [kernel] signal: always clear sa_restorer on execve (Nikola Pajkovsky) [920506] {CVE-2013-0914}
- [md] dm-thin: fix discard corruption (Mike Snitzer) [922931]
- [md] persistent-data: rename node to btree_node (Mike Snitzer) [922931]
- [netdrv] ixgbe: Only set gso_type to SKB_GSO_TCPV4 as RSC does not support IPv6 (Michael S. Tsirkin) [908196]
- [netdrv] bnx2x: set gso_type (Michael S. Tsirkin) [908196]
- [netdrv] qlcnic: set gso_type (Michael S. Tsirkin) [908196]
- [netdrv] ixgbe: fix gso type (Michael S. Tsirkin) [908196]
- [net] sunrpc: Get rid of the redundant xprt->shutdown bit field (J. Bruce Fields) [893584]
- [virt] kvm: do not #GP on unaligned MSR_KVM_SYSTEM_TIME write (Gleb Natapov) [917021] {CVE-2013-1796}
- [fs] gfs2: Allocate reservation structure before rename and link (Robert S Peterson) [922999]
- [drm] i915: bounds check execbuffer relocation count (Nikola Pajkovsky) [920525] {CVE-2013-0913}
- [x86] irq: add quirk for broken interrupt remapping on 55XX chipsets (Neil Horman) [887006]
- [md] dm: fix limits initialization when there are no data devices (Mike Snitzer) [908851]
- [kvm] Convert MSR_KVM_SYSTEM_TIME to use gfn_to_hva_cache functions (Gleb Natapov) [917025] {CVE-2013-1797}
- [kvm] Fix for buffer overflow in handling of MSR_KVM_SYSTEM_TIME (Gleb Natapov) [917021] {CVE-2013-1796}
- [kvm] Fix bounds checking in ioapic indirect register reads (Gleb Natapov) [917032] {CVE-2013-1798}
- [kvm] x86: release kvmclock page on reset (Gleb Natapov) [917025] {CVE-2013-1797}
- [security] keys: Fix race with concurrent install_user_keyrings() (David Howells) [913258] {CVE-2013-1792}

* Tue Mar 19 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-367.el6]
- [fs] xfs: use maximum schedule timeout when ail is empty (Brian Foster) [883905]
- [net] xfrm_user: fix info leak in copy_to_user_tmpl() (Thomas Graf) [922429] {CVE-2012-6537}
- [net] xfrm_user: fix info leak in copy_to_user_policy() (Thomas Graf) [922429] {CVE-2012-6537}
- [net] xfrm_user: fix info leak in copy_to_user_state() (Thomas Graf) [922429] {CVE-2012-6537}
- [net] xfrm_user: fix info leak in copy_to_user_auth() (Thomas Graf) [922429] {CVE-2012-6537}
- [net] atm: fix info leak in getsockopt(SO_ATMPVC) (Thomas Graf) [922387] {CVE-2012-6546}
- [net] atm: fix info leak via getsockname() (Thomas Graf) [922387] {CVE-2012-6546}
- [fs] nls: improve UTF8 -> UTF16 string conversion routine (Nikola Pajkovsky) [916119] {CVE-2013-1773}
- [fs] fat: Fix stat->f_namelen (Nikola Pajkovsky) [916119] {CVE-2013-1773}
- [netdrv] tun: fix ioctl() based info leaks (Thomas Graf) [922351] {CVE-2012-6547}
- [net] llc: fix info leak via getsockname() (Thomas Graf) [922333] {CVE-2012-6542}
- [virt] x86: Add a check to catch Xen emulation of Hyper-V (Andrew Jones) [918239]
- [fs] cifs: fix expand_dfs_referral (Sachin Prabhu) [902492]
- [fs] cifs: factor smb_vol allocation out of cifs_setup_volume_info (Sachin Prabhu) [902492]
- [fs] cifs: have cifs_cleanup_volume_info not take a double pointer (Sachin Prabhu) [902492]
- [fs] nfs: Dont allow NFS silly-renamed files to be deleted, no signal (Dave Wysochanski) [905095]

* Mon Mar 18 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-366.el6]
- [Documentation] vxlan: fix command usage in its doc (Amerigo Wang) [907447]
- [net] vxlan: Add ethtool drvinfo (Amerigo Wang) [907447]
- [net] vxlan: Use the underlying device index when joining/leaving multicast groups (Amerigo Wang) [907447]
- [net] vxlan: remove unused variable (Amerigo Wang) [907447]
- [net] vxlan: Update hard_header_len based on lowerdev when instantiating VXLAN (Amerigo Wang) [907447]
- [net] vxlan: fix a typo (Amerigo Wang) [907447]
- [net] vxlan: Fix error that was resulting in VXLAN MTU size being 10 bytes too large (Amerigo Wang) [907447]
- [net] vxlan: allow a user to set TTL value (Amerigo Wang) [907447]
- [net] vxlan: don't expire permanent entries (Amerigo Wang) [907447]
- [net] vxlan: fix oops when give unknown ifindex (Amerigo Wang) [907447]
- [net] vxlan: fix receive checksum handling (Amerigo Wang) [907447]
- [net] vxlan: add additional headroom (Amerigo Wang) [907447]
- [net] vxlan: allow configuring port range (Amerigo Wang) [907447]
- [net] vxlan: associate with tunnel socket on transmit (Amerigo Wang) [907447]
- [net] vxlan: fix byte order in hash function (Amerigo Wang) [907447]
- [net] vxlan: minor output refactoring (Amerigo Wang) [907447]
- [net] vxlan: fix more sparse warnings (Amerigo Wang) [907447]
- [net] vxlan: remove unused including <linux/version.h> (Amerigo Wang) [907447]
- [net] vxlan: put UDP socket in correct namespace (Amerigo Wang) [907447]
- [net] vxlan: virtual extensible lan (Amerigo Wang) [907447]
- [net] igmp: export symbol ip_mc_leave_group (Amerigo Wang) [907447]
- [net] netlink: Add nla_put_net{16,32,64}() helpers (Amerigo Wang) [907447]
- [net] dst: Introduce skb_tunnel_rx() helper (Amerigo Wang) [907447]
- [net] rtnetlink: do not check master for bridge ports (Amerigo Wang) [907447]
- [net] rtnetlink: notify events for FDB NTF_SELF adds and deletes (Amerigo Wang) [907447]
- [net] rtnetlink: add attributes to fdb interface (Amerigo Wang) [907447]
- [net] netdevice: make address const in device address management (Amerigo Wang) [907447]
- [net] add generic PF_BRIDGE:RTM_ FDB hooks (Amerigo Wang) [907447]
- [net] xfrm: fix RCU bugs (Amerigo Wang) [885247]
- [net] xfrm: Replace rwlock on xfrm_policy_afinfo with rcu (Amerigo Wang) [885247]
- [net] flow: Add a flow_cache_flush_deferred function (Amerigo Wang) [885247]
- [net] xfrm: Refcount destination entry on xfrm_lookup (Amerigo Wang) [885247]
- [net] xfrm: avoid possible oopse in xfrm_alloc_dst (Amerigo Wang) [885247]
- [net] xfrm: Fix xfrm_state_migrate leak (Amerigo Wang) [885247]
- [net] flow: Make flow cache namespace-aware (Amerigo Wang) [885247]
- [net] xfrm: do not assume that template resolving always returns xfrms (Amerigo Wang) [885247]
- [net] xfrm: check bundle policy existance before dereferencing it (Amerigo Wang) [885247]
- [net] xfrm: fix policy unreferencing on larval drop (Amerigo Wang) [885247]
- [net] xfrm6: ensure to use the same dev when building a bundle (Amerigo Wang) [885247]
- [net] xfrm: Fix crashes in xfrm_lookup() (Amerigo Wang) [885247]
- [net] flow: delayed deletion of flow cache entries (Amerigo Wang) [885247]
- [net] xfrm: remove policy garbage collection (Amerigo Wang) [885247]
- [net] xfrm: cache bundles instead of policies for outgoing flows (Amerigo Wang) [885247]
- [net] xfrm: deal with dst entries in netns (Amerigo Wang) [885247]
- [net] flow: virtualize flow cache entry methods (Amerigo Wang) [885247]
- [net] flow: structurize flow cache (Amerigo Wang) [885247]
- [net] xfrm: remove policy lock when accessing policy->walk.dead (Amerigo Wang) [885247]
- [net] xfrm: Flushing empty SAD generates false events (Amerigo Wang) [885247]
- [net] xfrm: Flushing empty SPD generates false events (Amerigo Wang) [885247]
- [net] pfkey: fix SA and SP flush sequence (Amerigo Wang) [885247]
- [net] xfrm: validate attributes (Amerigo Wang) [885247]
- [net] xfrm: verify policy direction at XFRM_MSG_POLEXPIRE handler (Amerigo Wang) [885247]
- [net] xfrm: Remove xfrm_state_genid (Amerigo Wang) [885247]
- [net] ipv4: check rt_genid in dst_check (Amerigo Wang) [885247]
- [net] xfrm: Fix bogus bundle flowi (Amerigo Wang) [885247]
- [net] xfrm: clone mark when cloning policy (Amerigo Wang) [885247]
- [net] xfrm: Allow user space manipulation of SPD mark (Amerigo Wang) [885247]
- [net] xfrm: Allow user space config of SAD mark (Amerigo Wang) [885247]
- [net] xfrm: SP lookups with mark (Amerigo Wang) [885247]
- [net] xfrm: SP lookups signature with mark (Amerigo Wang) [885247]
- [net] xfrm: SA lookups with mark (Amerigo Wang) [885247]
- [net] xfrm: SA lookups signature with mark (Amerigo Wang) [885247]
- [net] xfrm: introduce basic mark infrastructure (Amerigo Wang) [885247]

* Fri Mar 15 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-365.el6]
- [fs] NLM: Ensure that we resend all pending blocking locks after a reclaim (Steve Dickson) [913704]
- [fs] xfs: remove log force from xfs_buf_cond_lock() (Brian Foster) [896224]
- [fs] xfs: recheck buffer pinned status after push trylock failure (Brian Foster) [896224]
- [fs] nfs: Ensure that we check lock exclusive/shared type against open modes (Dave Wysochanski) [916324]
- [powerpc] pseries: Fix partition migration hang in stop_topology_update (Steve Best) [910597]
- [infiniband] qib: correction for faulty sparse warning correction (Jay Fenlason) [901701]
- [usb] io_ti: Fix NULL dereference in chase_port() (Nikola Pajkovsky) [916200] {CVE-2013-1774}
- [net] bluetooth: Fix incorrect strncpy() in hidp_setup_hid() (Nikola Pajkovsky) [914691] {CVE-2013-0349}
- [char] tty: set_termios/set_termiox should not return -EINTR (Oleg Nesterov) [904907]
- [netdrv] ehea: fix VLAN support (Steve Best) [911359]
- [net] xfrm_user: return error pointer instead of NULL (Thomas Graf) [919389] {CVE-2013-1826}
- [net] dccp: check ccid before NULL poiter dereference (Weiping Pan) [919188] {CVE-2013-1827}

* Thu Feb 28 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-364.el6]
- [Documentation] ipv6: Update ip-sysctl.txt documentation (Jacob Tanenbaum) [795367]
- [net] ipv6: add special mode forwarding=2 to send RS while configured as router (Jacob Tanenbaum) [795367]
- [net] ipv6: add special mode accept_ra=2 to accept RA while configured as a router (Jacob Tanenbaum) [795367]
- [net] netfilter: improve out-of-sync situation in TCP tracking (Flavio Leitner) [629857]
- [net] sctp: Add support to per-association statistics via a new SCTP_GET_ASSOC_STATS call (Michele Baldessari) [755486]
- [net] fix netdev_increment_features() (Amerigo Wang) [892868]
- [net] Disable all TSO features when SG is disabled (Amerigo Wang) [892868]
- [net] tcp: tcp_replace_ts_recent() should not be called from tcp_validate_incoming() (Weiping Pan) [843126]
- [net] tcp: RFC 5961 5.2 Blind Data Injection Attack Mitigation (Weiping Pan) [843126]
- [net] tcp: refine SYN handling in tcp_validate_incoming (Weiping Pan) [843126]
- [net] tcp: implement RFC 5961 4.2 (Weiping Pan) [843126]
- [net] tcp: implement RFC 5961 3.2 (Weiping Pan) [843126]
- [net] ipv6: Preserve ipv6 functionality needed by NET (Vlad Yasevich) [801856]
- [net] use right lock in __dev_remove_offload (Vlad Yasevich) [801856]
- [net] ipv6: Pull IPv6 GSO registration out of the module (Vlad Yasevich) [801856]
- [net] ipv4: Pull GSO registration out of inet_init() (Vlad Yasevich) [801856]
- [net] ipv6: Update ipv6 static library with newly needed functions (Vlad Yasevich) [801856]
- [net] ipv6: Move exthdr offload support into separate file (Vlad Yasevich) [801856]
- [net] ipv6: Separate out UDP offload functionality (Vlad Yasevich) [801856]
- [net] ipv6: Separate tcp offload functionality (Vlad Yasevich) [801856]
- [net] ipv6: Separate ipv6 offload support (Vlad Yasevich) [801856]
- [net] ipv6: Switch to using new offload infrastructure (Vlad Yasevich) [801856]
- [net] ipv4: Switch to using the new offload infrastructure (Vlad Yasevich) [801856]
- [net] ipv6: Add new offload registration infrastructure (Vlad Yasevich) [801856]
- [net] Add net protocol offload registration infrustructure (Vlad Yasevich) [801856]
- [net] Switch to using the new packet offload infrastructure (Vlad Yasevich) [801856]
- [net] Add generic packet offload infrastructure (Vlad Yasevich) [801856]
- [net] update SOCK_MIN_RCVBUF (Daniel Borkmann) [782886]
- [net] sctp: Fix list corruption resulting from freeing an association on a list (Jiri Pirko) [887868]
- [net] netfilter/ipset: timeout can be modified for already added elements (Daniel Borkmann) [881599]
- [net] tcp: Don't change unlocked socket state in tcp_v4_err() (Jiri Benc) [757658]
- [net] packet: fix network header offset in skb for raw sockets (Stefan Assmann) [845515]
- [mm] tmpfs: fix use-after-free of mempolicy object (Nikola Pajkovsky) [915715] {CVE-2013-1767}
- [fs] fuse: set page_descs length in fuse_buffered_write() (Brian Foster) [915135]
- [fs] vfs: fix pointer dereference validation in d_validate (Carlos Maiolino) [876600]

* Wed Feb 27 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-363.el6]
- [pci] Fix PCI Express Capability accessors for PCI_EXP_FLAGS (Myron Stowe) [912505]
- [pci] introduce accessor to retrieve PCIe Capabilities Register (Myron Stowe) [904203]
- [pci] Use PCI Express Capability accessors (Myron Stowe) [904203]
- [pci] pcie/portdrv: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [pci] portdrv: Don't create hotplug slots unless port supports hotplug (Myron Stowe) [904203]
- [drm] radeon: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [scsi] qla4xxx: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [scsi] qla4xxx: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [infiniband] qib: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [infiniband] mthca: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [wireless] iwlwifi: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [wireless] iwlegacy: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] ath9k: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] atl1c: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] cxgb4: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] cxgb3: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] myri10ge: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] niu: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] mlx4: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] igb: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] e1000e: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] tg3: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] bnx2x: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [netdrv] r8169: Preserve other Device Control bits when setting NOSNOOP_EN (Myron Stowe) [904203]
- [netdrv] r8169: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [pci] pcie/aspm: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [pci] pcie/aer: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [pci] pciehp: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [pci] pcie/portdrv: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [pci] hotplug: Use PCI Express Capability accessors (Myron Stowe) [904203]
- [pci] Use PCI Express Capability accessors (Myron Stowe) [904203]
- [pci] Add accessors for PCI Express Capability (Myron Stowe) [904203]
- [pci] Remove unused field pcie_type from struct pci_dev (Myron Stowe) [904203]
- [pci] Introduce pci_pcie_type(dev) to replace pci_dev->pcie_type (Myron Stowe) [904203]
- [pci] Add pcie_flags_reg to cache PCIe capabilities register (Myron Stowe) [904203]
- [scsi] qla2xxx: remove unnecessary reads of PCI_CAP_ID_EXP (Myron Stowe) [904203]
- [pci] remove redundant capabilities checking in pci_{save, restore}_pcie_state (Myron Stowe) [904203]
- [pci] pcie/aer: use pci_is_pcie() instead of obsolete pci_dev.is_pcie (Myron Stowe) [904203]
- [pci] move pci_find_saved_cap out of linux/pci.h (Myron Stowe) [904203]
- [netdrv] myri10ge: remove unnecessary read of PCI_CAP_ID_EXP (Myron Stowe) [904203]
- [netdrv] niu: remove unnecessary read of PCI_CAP_ID_EXP (Myron Stowe) [904203]
- [pci] Track the size of each saved capability data area (Myron Stowe) [904203]
- [pci] pcie/portdrv: remove redundant definitions (Myron Stowe) [904203]
- [pci] hotplug: use pci_is_pcie() (Myron Stowe) [904203]
- [pci] pcie/aspm: use pci_is_pcie() (Myron Stowe) [904203]
- [pci] pciehp: use pci_pcie_cap() (Myron Stowe) [904203]
- [pci] pcie/aspm: use pci_pcie_cap() (Myron Stowe) [904203]
- [pci] pcie/portdrv: use pci_pcie_cap() (Myron Stowe) [904203]

* Mon Feb 25 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-362.el6]
- [kernel] utrace: ensure arch_ptrace/ptrace_request can never race with SIGKILL (Oleg Nesterov) [912074] {CVE-2013-0871}
- [security] device_cgroup: fix RCU usage (Aristeu Rozanski) [819366]
- [security] device_cgroup: fix unchecked cgroup parent usage (Aristeu Rozanski) [819366]
- [security] device_cgroup: add proper checking when changing default behavior (Aristeu Rozanski) [819366]
- [security] device_cgroup: stop using simple_strtoul() (Aristeu Rozanski) [819366]
- [security] device_cgroup: rename deny_all to behavior (Aristeu Rozanski) [819366]
- [security] device_cgroup: fix invalid rcu dereference (Aristeu Rozanski) [819366]
- [security] device_cgroup: rename whitelist to exception list (Aristeu Rozanski) [819366]
- [security] device_cgroup: convert device_cgroup internally to policy + exceptions (Aristeu Rozanski) [819366]
- [security] device_cgroup: introduce dev_whitelist_clean() (Aristeu Rozanski) [819366]
- [security] device_cgroup: add "deny_all" in dev_cgroup structure (Aristeu Rozanski) [819366]
- [security] devcgroup_inode_permission: take "is it a device node" checks to inlined wrapper (Aristeu Rozanski) [819366]
- [security] rcu: Convert call_rcu(whitelist_item_free) to kfree_rcu() (Aristeu Rozanski) [819366]
- [fs] cifs: after upcalling for krb5 creds, invalidate key rather than revoking it (Niels de Vos) [885899]
- [fs] cifs: tmp_key_invalidate() should not set key->expiry to 0 (Niels de Vos) [885899]
- [block] disable discard request merge temporarily (Mike Snitzer) [907844]

* Thu Feb 14 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-361.el6]
- [netdrv] mlx4: Set number of msix vectors under SRIOV mode to firmware defaults (Michal Schmidt) [904726]
- [netdrv] mlx4: Fix bridged vSwitch configuration for non SRIOV mode (Michal Schmidt) [903644]
- [net] rtnetlink: Fix IFLA_EXT_MASK definition (regression) (Thomas Graf) [903220]
- [x86] msr: Add capabilities check (Nikola Pajkovsky) [908699] {CVE-2013-0268}
- [x86] msr: Remove incorrect, duplicated code in the MSR driver (Nikola Pajkovsky) [908699] {CVE-2013-0268}
- [virt] xen: don't assume ds is usable in xen_iret for 32-bit PVOPS (Andrew Jones) [906311] {CVE-2013-0228}

* Wed Feb 13 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-360.el6]
- [kernel] cputime: Avoid multiplication overflow on utime scaling (Stanislaw Gruszka) [862758]
- [net] sunrpc: When changing the queue priority, ensure that we change the owner (Steve Dickson) [902965]
- [net] sunrpc: Ensure we release the socket write lock if the rpc_task exits early (Steve Dickson) [902965]
- [fs] nfs: Ensure that we free the rpc_task after read and write cleanups are done (Steve Dickson) [902965]
- [net] sunrpc: Ensure that we free the rpc_task after cleanups are done (Steve Dickson) [902965]
- [net] sunrpc: Don't allow low priority tasks to pre-empt higher priority ones (Steve Dickson) [902965]
- [fs] nfs: Add sequence_priviliged_ops for nfs4_proc_sequence() (Steve Dickson) [902965]
- [fs] nfs: The NFSv4.0 client must send RENEW calls if it holds a delegation (Steve Dickson) [902965]
- [fs] nfs: nfs4_proc_renew should be declared static (Steve Dickson) [902965]
- [fs] nfs: nfs4_locku_done must release the sequence id (Steve Dickson) [902965]
- [fs] nfs: We must release the sequence id when we fail to get a session slot (Steve Dickson) [902965]
- [fs] nfs: Add debugging messages to NFSv4's CLOSE procedure (Steve Dickson) [902965]
- [net] sunrpc: Clear the connect flag when socket state is TCP_CLOSE_WAIT (Steve Dickson) [902965]
- [fs] nfs: cleanup DS stateid error handling (Steve Dickson) [902965]
- [fs] nfs: handle DS stateid errors (Steve Dickson) [902965]
- [fs] nfs: Fix potential races in xprt_lock_write_next() (Steve Dickson) [902965]
- [fs] nfs: Ensure correct locking when accessing the 'lock_states' list (Steve Dickson) [902965]
- [fs] nfs: Fix the handling of NFS4ERR_SEQ_MISORDERED errors (Steve Dickson) [902965]
- [block] cciss: use lun reset not target reset (Tomas Henzl) [893022]
- [block] cciss: get rid of message related magic numbers (Tomas Henzl) [893022]
- [fs] nfsd: default server numeric idmapping to off (J. Bruce Fields) [815908]
- [fs] nfsd: allow numeric idmapping (J. Bruce Fields) [815908]
- [x86] perf: Export Sandy Bridge uncore clockticks event in sysfs (Luming Yu) [886374]
- [x86] perf: Add Intel Westmere-EX uncore support (Luming Yu) [886374]
- [powerpc] perf: Sample only if SIAR-Valid bit is set in P7+ (Steve Best) [873425]
- [powerpc] oprofile: Fix marked events support on Power7+ not set (Steve Best) [873425]
- [powerpc] Define Power7+ PV constant PV_POWER7p (Steve Best) [873425]
- [netdrv] netxen: check for root bus in netxen_mask_aer_correctable (Nikolay Aleksandrov) [846123]
- [netdrv] be2net: fix unconditionally returning IRQ_HANDLED in INTx (Ivan Vecera) [909464]
- [netdrv] be2net: fix INTx ISR for interrupt behaviour on BE2 (Ivan Vecera) [909464]
- [netdrv] be2net: fix a possible events_get() race on BE2 (Ivan Vecera) [909464]
- [virt] hv_balloon: Make adjustments to the pressure report (Jason Wang) [902232]

* Mon Feb 11 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-359.el6]
- [fs] gfs2: Get a block reservation before resizing a file (Robert S Peterson) [875753]
- [net] ipv6: do not create neighbor entries for local delivery (Jiri Pirko) [896020]
- [net] bonding: check for assigned mac before adopting the slaves mac address (Veaceslav Falico) [905126]
- [fs] nfs: nfs4_xdr_enc_layout{commit, return} must return status (Steve Dickson) [907227]
- [fs] set s_type before destroy_super in sget() (Eric Sandeen) [904982]
- [scsi] ses: Avoid kernel panic when lun 0 is not mapped (Ewan Milne) [886867]
- [block] avoid divide-by-zero with zero discard granularity (Mike Snitzer) [901705]
- [block] discard granularity might not be power of 2 (Mike Snitzer) [901705]
- [netdrv] tg3: Fix crc errors on jumbo frame receive (Ivan Vecera) [895336]
- [netdrv] igb: set E1000_IMS_TS interrupt bit in igb_irq_enable (Stefan Assmann) [871795]
- [pci] intel-iommu: Prevent devices with RMRRs from being placed into SI Domain (Tony Camuso) [678451]
- [scsi] sd: Reshuffle init_sd to avoid crash (Ewan Milne) [888417]
- [mm] add numa node symlink for cpu devices in sysfs (Neil Horman) [878708]

* Tue Jan 29 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-358.el6]
- [fs] Fix sget() race with failing mount (Eric Sandeen) [883276]

* Mon Jan 28 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-357.el6]
- [virt] xen: Fix stack corruption in xen_failsafe_callback for 32bit PVOPS guests (Andrew Jones) [896050] {CVE-2013-0190}
- [block] sg_io: use different default filters for each device class (Paolo Bonzini) [875361] {CVE-2012-4542}
- [block] sg_io: prepare for adding per-device-type filters (Paolo Bonzini) [875361] {CVE-2012-4542}
- [virt] virtio-blk: Don't free ida when disk is in use (Asias He) [870344]
- [netdrv] mlx4: Remove FCS bytes from packet length (Doug Ledford) [893707]
- [net] netfilter: nf_ct_reasm: fix conntrack reassembly expire code (Amerigo Wang) [726807]

* Mon Jan 21 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-356.el6]
- [char] ipmi: use a tasklet for handling received messages (Prarit Bhargava) [890160]
- [char] ipmi: handle run_to_completion properly in deliver_recv_msg() (Prarit Bhargava) [890160]
- [usb] xhci: Reset reserved command ring TRBs on cleanup (Don Zickus) [843520]
- [usb] xhci: handle command after aborting the command ring (Don Zickus) [874541]
- [usb] xhci: cancel command after command timeout (Don Zickus) [874541]
- [usb] xhci: add aborting command ring function (Don Zickus) [874541]
- [usb] xhci: add cmd_ring_state (Don Zickus) [874541]
- [usb] xhci: Fix Null pointer dereferencing with non-DMI systems (Don Zickus) [874542]
- [usb] xhci: Intel Panther Point BEI quirk (Don Zickus) [874542]
- [usb] xhci: Increase XHCI suspend timeout to 16ms (Don Zickus) [874542]
- [powerpc] Revert: pseries/iommu: remove default window before attempting DDW manipulation (Steve Best) [890454]
- [serial] 8250_pnp: add Intermec CV60 touchscreen device (Mauro Carvalho Chehab) [894445]
- [char] ipmi: apply missing hunk from upstream commit 2407d77a (Tony Camuso) [882787]
- [acpi] Fix broken kernel build if CONFIG_ACPI_DEBUG is enabled (Lenny Szubowicz) [891948]
- [scsi] qla2xxx: Test and clear FCPORT_UPDATE_NEEDED atomically (Chad Dupuis) [854736]
- [mm] vmalloc: remove guard page from between vmap blocks (Johannes Weiner) [873737]
- [mm] vmalloc: vmap area cache (Johannes Weiner) [873737]
- [fs] vfs: prefer EEXIST to EROFS when creating on an RO filesystem (Eric Sandeen) [878091]
- [scsi] qla2xxx: change queue depth ramp print to debug print (Rob Evers) [893113]
- [fs] nfs: Fix umount when filelayout DS is also the MDS (Steve Dickson) [895194]
- [fs] nfs/pnfs: add set-clear layoutdriver interface (Steve Dickson) [895194]
- [fs] nfs: Don't call nfs4_deviceid_purge_client() unless we're NFSv4.1 (Steve Dickson) [895194]
- [fs] nfs: Wait for session recovery to finish before returning (Steve Dickson) [895176]
- [mm] compaction: validate pfn range passed to isolate_freepages_block (Johannes Weiner) [889456 890498]
- [drm] nouveau: ensure legacy vga is re-enabled during POST (Ben Skeggs) [625441]
- [netdrv] be2net: Remove stops to further access to BE NIC on UE bits (Ivan Vecera) [894344]
- [virt] kvm: invalid opcode oops on SET_SREGS with OSXSAVE bit set (Petr Matousek) [862904] {CVE-2012-4461}

* Tue Jan 15 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-355.el6]
- [netdrv] qlge: remove NETIF_F_TSO6 flag (Amerigo Wang) [891839]
- [fs] ext3: Remove BKL from ext3_put_super() and ext3_remount() (Carlos Maiolino) [885945]
- [lib] switch the protection of percpu_counter list to spinlock (Carlos Maiolino) [885945]
- [virt] hv: Add Hyper-V balloon driver (Jason Wang) [885572]
- [mm] export a function to get vm committed memory (Jason Wang) [885572]
- [drm] nouveau: extend prevent display switching issues by disabling pageflip (Ben Skeggs) [853226]
- [netdrv] mlx4: Fix advertisement of wrong PF context behaviour (Alex Williamson) [894060]

* Mon Jan 14 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-354.el6]
- [char] ipmi: add new kernel options to prevent automatic ipmi init (Tony Camuso) [877177]
- [usb] xhci: New system added for Compliance Mode Patch on SN65LVPE502CP (Don Zickus) [856709]
- [x86] quirks: Mark Haswell HDMI Audio as unsupported (Prarit Bhargava) [883428]
- [scsi] bfa: fix crash in bfa_cb_ioim_done when performing failover/failback tests (Vijay Guvva) [878618]
- [fs] autofs4: Fix sparse warning: context imbalance in autofs4_d_automount() different lock contexts for basic block (Ian Kent) [876795]
- [fs] jbd, jbd2: don't wake kjournald unnecessarily (Eric Sandeen) [886318]
- [scsi] qla4xxx: v5.03.00.00.06.04-k2 (Rob Evers) [890727]
- [scsi] qla4xxx: Correct the validation to check in get_sys_info mailbox (Rob Evers) [890727]
- [scsi] qla4xxx: Pass correct function param to qla4_8xxx_rd_direct (Rob Evers) [890727]
- [scsi] qla4xxx: v5.03.00.00.06.04-k1 (Chad Dupuis) [878048]
- [scsi] qla4xxx: update copyrights in LICENSE.qla4xxx (Chad Dupuis) [878048]
- [scsi] qla4xxx: Disable generating pause frames for ISP83XX (Chad Dupuis) [878048]
- [scsi] qla4xxx: Fix double clearing of risc_intr for ISP83XX (Chad Dupuis) [878048]
- [scsi] qla4xxx: IDC implementation for Loopback (Chad Dupuis) [878048]
- [scsi] qla4xxx: Fix panic while rmmod (Chad Dupuis) [878048]
- [scsi] qla4xxx: Fail probe_adapter if IRQ allocation fails (Chad Dupuis) [878048]
- [scsi] qla4xxx: Prevent MSI/MSI-X falling back to INTx for ISP82XX (Chad Dupuis) [878048]
- [scsi] qla4xxx: Update idc reg in case of PCI AER (Chad Dupuis) [878048]
- [scsi] qla4xxx: Fix double IDC locking in qla4_8xxx_error_recovery (Chad Dupuis) [878048]
- [scsi] qla4xxx: Clear interrupt while unloading driver for ISP83XX (Chad Dupuis) [878048]
- [scsi] qla4xxx: Print correct IDC version (Chad Dupuis) [878048]
- [scsi] qla4xxx: Added new mbox cmd to pass driver version to FW (Chad Dupuis) [878048]
- [scsi] qla4xxx: fix various printk and comment typos (Chad Dupuis) [878048]
- [fs] autofs4: use simple_empty() for empty directory check (Ian Kent) [876795]
- [fs] autofs4: dont clear DCACHE_NEED_AUTOMOUNT on rootless mount (Ian Kent) [876795]
- [fs] gfs2: Fix race in gfs2_rs_alloc (Abhijith Das) [878476]
- [fs] xfs: fix broken error handling in xfs_vm_writepage (Dave Chinner) [874539]
- [drm] radeon: force rn50 chip to always report connected on analog output (Jerome Glisse) [892723]
- [sound] alsa: add support for Teradici 2200 host card audio (Jaroslav Kysela) [890581]
- [md] dm-raid: Fix RAID10's check for sufficient redundancy (Jonathan E Brassow) [889358]
- [scsi] hpsa: update version number to 3.2.0 (Tomas Henzl) [891935]
- [netdrv] cxgb4: Initialize data structures before using (Steve Best) [885756]

* Mon Jan 07 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-353.el6]
- [mm] pageattr: prevent PSE and GLOABL leftovers to confuse pmd/pte_present and pmd_huge (Andrea Arcangeli) [878877]
- [fs] gfs2: Fix FITRIM argument handling (Abhijith Das) [866932]
- [fs] gfs2: Require user to provide argument for FITRIM (Abhijith Das) [866932]
- [fs] exec: do not leave bprm->interp on stack (Josh Poimboeuf) [880146] {CVE-2012-4530}
- [fs] exec: use -ELOOP for max recursion depth (Josh Poimboeuf) [880146] {CVE-2012-4530}
- [fs] btrfs: close exclusive opens with close_bdev_exclusive() (Zach Brown) [874505]
- [kernel] sched_rt: Fix hang where umount is stuck in synchronize_sched_expedited (Larry Woodman) [814768]

* Thu Jan 03 2013 Jarod Wilson <jarod@redhat.com> [2.6.32-352.el6]
- [md] raid10: Do not call md_raid10_unplug_device while holding spinlock (Jonathan E Brassow) [886658]
- [md] dm-thin: commit before gathering status (Mike Snitzer) [882426]
- [md] dm-thin: cleanup dead code (Mike Snitzer) [882426]
- [md] dm-thin: rename cell_defer_except to cell_defer_no_holder (Mike Snitzer) [882426]
- [md] dm-thin: emit "ignore_discard" in status if discards are disabled (Mike Snitzer) [882426]
- [md] dm-thin: wake the worker when a discard is prepared (Mike Snitzer) [882426]
- [md] dm-thin: fix race between simultaneous io and discards to same block (Mike Snitzer) [882426]
- [md] dm-thin: replace calls to cell_release_singleton with cell_defer_except (Mike Snitzer) [882426]
- [mm] Revert: ksm: numa awareness sysfs knob (Jarod Wilson) [743643]
- [fs] gfs2: Reset rd_last_alloc when it reaches the end of the rgrp (Robert S Peterson) [882381]
- [fs] gfs2: Stop looking for free blocks at end of rgrp (Robert S Peterson) [882381]
- [drm] nouveau: cache ramcfg value for RAM_RESTRICT_ZM_GROUP (Ben Skeggs) [878384]
- [drm] nouveau: disable use of tesla/fermi copy engines for buffer moves (Ben Skeggs) [878384]
- [fs] xfs: fix direct IO nested transaction deadlock (Dave Chinner) [876426]

* Thu Dec 20 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-351.el6]
- [kernel] ptrace-utrace: fix PTRACE_GETEVENTMSG(pid) in sub-namespace (Oleg Nesterov) [782330]
- [scsi] mpt2sas: fix for driver fails EEH recovery from injected pci bus error (Tomas Henzl) [829149]
- [mm] memcontrol: propagate LRU accounting state when splitting THP (Johannes Weiner) [881714]
- [net] sctp: proc: protect bind_addr->address_list accesses with rcu_read_lock() (Thomas Graf) [706038]
- [net] sctp: Add RCU protection to assoc->transport_addr_list (Thomas Graf) [706038]
- [s390] zfcp: Adapt to new FC_PORTSPEED semantics (Hendrik Brueckner) [855128]
- [virt] virtio_net: allow to change mac when iface is running (Jiri Pirko) [882868]
- [virt] kvm: Minimal hyper-v support (Vadim Rozenfeld) [871350]
- [fs] gfs2: Journal DLM lock has wrong label (Steven Whitehouse) [884822]
- [mm] huge_memory: fix typo in transparent_hugepage sysfs symlink (Jeremy Eder) [887308]
- [mm] ksm: numa awareness sysfs knob (Petr Holasek) [743643]
- [fs] btrfs: handle IS_ERR(inode) in btrfs_lookup() (Zach Brown) [870944]
- [kernel] sched: Add irq_{enter,exit}() to scheduler_ipi() (Stanislaw Gruszka) [836964]
- [kernel] panic: fix a possible deadlock in panic() (Tatsuya Kitamura) [871939]

* Tue Dec 18 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-350.el6]
- [powerpc] perf: power_pmu_start restores incorrect values, breaking frequency events (Jiri Olsa) [880525]
- [netdrv] mlx4: Allow choosing flow steering mode (Doug Ledford) [885191]
- [netdrv] mlx4: Adjustments to Flow Steering activation logic for SRIOV (Doug Ledford) [885191]
- [netdrv] mlx4: Fix wrong error flow in the flow steering wrapper (Doug Ledford) [885191]
- [netdrv] mlx4: Add QPN enforcement for flow steering rules set by VFs (Doug Ledford) [885191]
- [infiniband] mlx4: 64-byte CQE/EQE support (Doug Ledford) [885191]
- [netdrv] mlx4: Fix potential deadlock in mlx4_eq_int() (Doug Ledford) [885191]
- [infiniband] mlx4: Fix spinlock order to avoid lockdep warnings (Doug Ledford) [885191]
- [netdrv] mlx4: Removing reserve vectors (Doug Ledford) [885191]
- [netdrv] mlx4: Fix double-release-range in tx-rings (Doug Ledford) [885191]
- [infiniband] mlx4: Fix QP1 P_Key processing in the Primary Physical Function (PPF) (Doug Ledford) [885191]
- [infiniband] mlx4: Synchronize cleanup of MCGs in MCG paravirtualization (Doug Ledford) [885191]
- [net] bonding: Bonding driver does not consider the gso_max_size setting of slave devices (Ivan Vecera) [883643]
- [net] tcp: Fix >4GB writes on 64-bit (Daniel Borkmann) [885238]
- [net] bridge: skip forwarding delay if not using STP (Thomas Graf) [881682]
- [fs] nfs: Fix open(O_TRUNC) and ftruncate() error handling (Steve Dickson) [884263]
- [fs] nfsd: add proc file listing kernel's gss_krb5 enctypes (Steve Dickson) [877113]
- [fs] nfs: add nfs_sb_deactive_async to avoid deadlock (Steve Dickson) [871968]
- [fs] nfs: fix page dirtying in NFS DIO read codepath (Jeff Layton) [876514]
- [fs] nfs: don't zero out the rest of the page if we hit the EOF on a DIO READ (Jeff Layton) [876514]
- [fs] handle null sb in get_super_thawed (Eric Sandeen) [874521]
- [scsi] Fix race when removing SCSI devices (Tomas Henzl) [820880]
- [netdrv] be2net: enable GRO by default (Ivan Vecera) [849930]
- [netdrv] igb: fix compile warning if CONFIG_IGB_PTP is not set (Stefan Assmann) [886519]
- [netdrv] bnx2x: Prevent link flaps when booting from SAN (Michal Schmidt) [881068]
- [netdrv] bnx2x: Activate LFA (Michal Schmidt) [881068]
- [acpi] apei: Fixup common access width firmware bug (Prarit Bhargava) [880465]
- [acpi] apei: Avoid too much error reporting in runtime (Prarit Bhargava) [880465]
- [acpi] apei: Fix incorrect APEI register bit width check and usage (Prarit Bhargava) [880465]
- [virt] vhost: fix length for cross region descriptor (Michael S. Tsirkin) [862265]
- [fs] nfs: Use FS-Cache invalidation (David Howells) [699931]
- [fs] cachefiles: Implement invalidation (David Howells) [699931]
- [fs] vfs: Make more complete truncate operation available to CacheFiles (David Howells) [699931]
- [fs] fscache: Provide proper invalidation (David Howells) [699931]
- [fs] fscache: Fix operation state management and accounting (David Howells) [699931]
- [fs] fscache: Make cookie relinquishment wait for outstanding reads (David Howells) [699931]
- [fs] cachefiles: Make some debugging statements conditional (David Howells) [699931]
- [fs] fscache: Check cookie is still correct in __fscache_read_or_alloc_pages() (David Howells) [699931]
- [fs] fscache: Check that there are no read ops when cookie relinquished (David Howells) [699931]
- [fs] cachefiles: Downgrade the requirements passed to the allocator (David Howells) [699931]
- [fs] fscache: Validate page mapping pointer value (David Howells) [699931]
- [fs] fscache: Fix the marking of cached pages (David Howells) [699931]
- [fs] fscache: nfs_migrate_page() does not wait for FS-Cache to finish with a page (David Howells) [699931]
- [fs] fscache: Fix __fscache_uncache_all_inode_pages()'s outer loop (David Howells) [699931]
- [fs] fscache: Add a helper to bulk uncache pages on an inode (David Howells) [699931]
- [scsi] qla2xxx: Ramp down queue depth for attached SCSI devices when driver resources are low (Chad Dupuis) [829739]
- [scsi] qla2xxx: Determine the number of outstanding commands based on available resources (Chad Dupuis) [829739]
- [s390] zfcp: return early from slave_destroy if slave_alloc returned early (Hendrik Brueckner) [878372]
- [scsi] fcoe: fix fcoe enable on link toggle while it is still disabled (Neil Horman) [875271]
- [scsi] Log thin provisioning threshold event (Ewan Milne) [847998]
- [netdrv] qlge: NETIF_F_GRO needs to be part of hw_features instead of features (John Green) [849749]
- [s390] qeth: set new mac even if old mac is gone (Hendrik Brueckner) [883458]
- [s390] qeth: Fix IPA_CMD_QIPASSIST return code handling (Hendrik Brueckner) [882792]

* Mon Dec 17 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-349.el6]
- [redhat] kabi: additional whitelist symbols for RHEL-6.4 (Jiri Olsa) [866427]

* Mon Dec 10 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-348.el6]
- [ipc] mqueue: Prevent mq_send/receive memory corruption (Larry Woodman) [885030]
- [fs] nfs: prevent delegreturn attr deadlock (David Jeffery) [870142]
- [netdrv] tg3: Do not set TSS for 5719 and 5720 (John Feeney) [823371]
- [scsi] lpfc: Update lpfc version for 8.3.5.86.1p driver release (Rob Evers) [877149]
- [scsi] lpfc: Fixed setting sequential delivery bit in a service class that is not valid (Rob Evers) [877149]
- [scsi] lpfc: Fixed boot from san failure when SLI4 FC device presented on the same PCI bus (Rob Evers) [877149]
- [scsi] lpfc: Add LOGO support after ABTS compliance (Rob Evers) [877149]
- [scsi] lpfc: Fixed not reporting logical link speed to SCSI midlayer when QoS not on (Rob Evers) [877149]
- [scsi] lpfc: Fixed SCSI host create showing wrong link speed on SLI3 HBA ports (Rob Evers) [877149]
- [scsi] lpfc: Fixed kernel warning on spinlock usage on some distributions (Rob Evers) [877149]
- [scsi] lpfc: Fixed Linux generic firmware download on SLI4 devices with longer module names (Rob Evers) [877149]
- [scsi] lpfc: Fix error with fabric service parameters causing performance issues (Rob Evers) [877149]
- [scsi] lpfc: Fixed messages for misconfigured port errors (Rob Evers) [877149]
- [scsi] lpfc: Fix FCP2 Retries for non-r/w commands (Rob Evers) [877149]
- [scsi] lpfc: Fix incorrect comment in T10 DIF attributes (Rob Evers) [877149]
- [scsi] lpfc: Correct missing queue destroy on function reset (Rob Evers) [877149]
- [scsi] lpfc: Added checking BMBX register for RDY bit before writing the first address in (Rob Evers) [877149]
- [scsi] lpfc: Misc changes to optimize critical path (Rob Evers) [877149]
- [s390] qdio: fix kernel panic for zfcp 31-bit (Hendrik Brueckner) [878380]
- [s390] zcrypt: msgType50 (RSA-CRT) fix (Hendrik Brueckner) [875977]
- [netdrv] ixgbe: fix uninitialized event.type in ixgbe_ptp_check_pps_event (Andy Gospodarek) [884369]
- [netdrv] ixgbe: (PTP) Fix PPS interrupt code (Andy Gospodarek) [884369]
- [netdrv] ixgbe: Fix PTP X540 SDP alignment code for PPS signal (Andy Gospodarek) [884369]
- [s390] zfcp: support for hardware data router (Hendrik Brueckner) [823016]
- [s390] qdio: base support for hardware data router with zfcp (Hendrik Brueckner) [823016]
- [s390] qdio: Split SBAL entry flags (Hendrik Brueckner) [823016]
- [net] netfilter/ipset: Check and reject crazy /0 input parameters (Thomas Graf) [880920]
- [kernel] kmod: make __request_module() killable (Oleg Nesterov) [819529] {CVE-2012-4398}
- [kernel] kmod: introduce call_modprobe() helper (Oleg Nesterov) [819529] {CVE-2012-4398}
- [kernel] usermodehelper: implement UMH_KILLABLE (Oleg Nesterov) [819529] {CVE-2012-4398}
- [kernel] usermodehelper: introduce umh_complete(sub_info) (Oleg Nesterov) [819529] {CVE-2012-4398}
- [kernel] call_usermodehelper: simplify/fix UMH_NO_WAIT case (Oleg Nesterov) [819529] {CVE-2012-4398}
- [kernel] wait_for_helper: SIGCHLD from user-space can lead to use-after-free (Oleg Nesterov) [819529] {CVE-2012-4398}
- [netdrv] qlge: Backport offload features to vlan interfaces (John Green) [849749]
- [netdrv] igbvf: work around i350 erratum (Stefan Assmann) [870638]

* Thu Dec 06 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-347.el6]
- [netdrv] be2net: Update driver version to 4.4.161.0r (Ivan Vecera) [868896]
- [netdrv] be2net: Fix skyhawk VF PCI Device ID (Ivan Vecera) [868896]
- [netdrv] be2net: Fix FW flashing on Skyhawk-R (Ivan Vecera) [868896]
- [netdrv] be2net: Enabling Wake-on-LAN is not supported in S5 state (Ivan Vecera) [868896]
- [netdrv] be2net: Fix VF driver load on newer Lancer FW (Ivan Vecera) [868896]
- [netdrv] be2net: Fix unnecessary delay in PCI EEH (Ivan Vecera) [868896]
- [netdrv] be2net: Fix issues in error recovery due to wrong queue state (Ivan Vecera) [868896]
- [netdrv] be2net: Fix ethtool get_settings output for VF (Ivan Vecera) [868896]
- [netdrv] be2net: Fix error messages while driver load for VFs (Ivan Vecera) [868896]
- [netdrv] be2net: cleanup code related to be_link_status_query() (Ivan Vecera) [868896]
- [netdrv] be2net: Fix configuring VLAN for VF for Lancer (Ivan Vecera) [868896]
- [netdrv] be2net: Wait till resources are available for VF in error recovery (Ivan Vecera) [868896]
- [netdrv] be2net: Fix change MAC operation for VF for Lancer (Ivan Vecera) [868896]
- [netdrv] be2net: remove type argument of be_cmd_mac_addr_query() (Ivan Vecera) [868896]
- [netdrv] be2net: Fix setting QoS for VF for Lancer (Ivan Vecera) [868896]
- [netdrv] be2net: Fix driver load failure for different FW configs in Lancer (Ivan Vecera) [868896]
- [md] dm-thin: remove tech preview status (Mike Snitzer) [798835]
- [md] dm-thin: log errors using DMERR_LIMIT instead of DMERR (Mike Snitzer) [798835]
- [md] persistent-data: log errors using DMERR_LIMIT instead of DMERR (Mike Snitzer) [798835]
- [md] dm-block-manager: reinstate context for which block failed a validator check (Mike Snitzer) [798835]
- [netdrv] bnx2x: remove redundant warning log (Michal Schmidt) [879279]
- [pci] fix broadcom 57840_MF pci id (Michal Schmidt) [871475]
- [netdrv] bnx2x: Disable FCoE for 57840 since not yet supported by FW (Michal Schmidt) [872228]
- [netdrv] bnx2x: Fix no link on 577xx 10G-baseT (Michal Schmidt) [872228]
- [netdrv] bnx2x: Fix unrecognized SFP+ module after driver is loaded (Michal Schmidt) [872228]
- [netdrv] bnx2x: Fix potential incorrect link speed provision (Michal Schmidt) [872228]
- [netdrv] bnx2x: Restore global registers back to default (Michal Schmidt) [872228]
- [netdrv] bnx2x: Fix link down in 57712 following LFA (Michal Schmidt) [872228]
- [netdrv] bnx2x: Fix 57810 1G-KR link against certain switches (Michal Schmidt) [871532]
- [netdrv] bnx2x: fix handling mf storage modes (Michal Schmidt) [867872]
- [netdrv] bnx2x: use strlcpy() to copy a string (Michal Schmidt) [872228]
- [tools] perf: Fix a NULL pointer dereference (Jiri Olsa) [879509]
- [tools] perf: Add probe command into perf help message (Jiri Olsa) [879452]
- [net] sunrpc: Ensure that rpc_release_resources_task() can be called twice (Jeff Layton) [878204]
- [fs] nfs: Check validity of cl_rpcclient in nfs_server_list_show (Steve Best) [874834]
- [sound] alsa: fix pcm procfs race (Jaroslav Kysela) [867120]
- [kernel] module: Last symbol in a module's symtab is not shown in /proc/kallsyms (Seiji Aguchi) [878024]
- [scsi] isci: copy fis 0x34 response into proper buffer (David Milburn) [876912]
- [netdrv] bna: put back VLAN tag stripped in promisc mode when no VLAN is configured (Ivan Vecera) [870279]

* Tue Dec 04 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-346.el6]
- [net] ipset: list-set: fix adding 'after' (Thomas Graf) [880464]
- [net] ipset: take into account cidr value for the from address when creating the set (Thomas Graf) [879539]
- [net] net_sched: gred: Fix oops in gred_dump() in WRED mode (Thomas Graf) [874872]
- [net] IPv4: Send gratuitous ARP for secondary IP addresses also (Jason Wang) [875309]
- [net] arp_notify: unconditionally send gratuitous ARP for NETDEV_NOTIFY_PEERS (Jason Wang) [875309]
- [net] fix net.core.?mem_max defaults (Thomas Graf) [878072]
- [net] pktgen: fix crash when generating IPv6 packets (Thomas Graf) [877327]
- [net] netfilter/ipset: fix hash size checking in kernel (Thomas Graf) [876831]
- [net] sctp: send abort chunk when max_retrans exceeded (Neil Horman) [876249]

* Wed Nov 28 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-345.el6]
- [fs] ext4: race-condition protection for ext4_convert_unwritten_extents_endio (Lukas Czerner) [869906] {CVE-2012-4508}
- [fs] ext4: serialize fallocate with ext4_convert_unwritten_extents (Lukas Czerner) [869906] {CVE-2012-4508}
- [fs] ext4: flush the i_completed_io_list during ext4_truncate (Lukas Czerner) [869906] {CVE-2012-4508}
- [infiniband] ipoib: Fix AB-BA deadlock when deleting neighbours (Doug Ledford) [873949]
- [infiniband] ipoib: Fix memory leak in the neigh table deletion flow (Doug Ledford) [873949]
- [infiniband] ipoib: Fix RCU pointer dereference of wrong object (Doug Ledford) [873949]
- [misc] Make rcu_dereference_bh work (Doug Ledford) [873949]
- [infiniband] ipoib: Use a private hash table for path lookup in xmit path (Doug Ledford) [873949]
- [net] netlink: move min_dump_alloc to netlink_callback_extended (Weiping Pan) [872067]
- [infiniband] pass rdma_cm module to netlink_dump_start (Weiping Pan) [872067]
- [net] netlink: add reference of module in netlink_dump_start (Weiping Pan) [872067]
- [net] netfilter: add netlink_dump_control structure for netlink_dump_start() (Weiping Pan) [872067]
- [net] netlink: handle errors from netlink_dump() (Weiping Pan) [872067]
- [powerpc] mm: Export memory limit via device tree (Baoquan He) [674664]
- [powerpc] mm: Change memory_limit from phys_addr_t to unsigned long long (Baoquan He) [674664]
- [drm] radeon: For single CRTC GPUs move handling of CRTC_CRT_ON to crtc_dpms() (Jerome Glisse) [873728]
- [drm] radeon: Fix TV DAC Load Detection for single CRTC chips (Jerome Glisse) [873728]
- [drm] radeon: Clean up code in TV DAC load detection (Jerome Glisse) [873728]
- [drm] radeon: On DVI-I use Load Detection when EDID is bogus (Jerome Glisse) [873728]
- [drm] radeon: Fix primary DAC Load Detection for RV100 chips (Jerome Glisse) [873728]
- [drm] radeon: Fix Load Detection on legacy primary DAC (Jerome Glisse) [873728]
- [netdrv] ixgbe: PTP get_ts_info missing software support (Andy Gospodarek) [876810]
- [pci] dmar: use PF's pci-dev struct for IOMMU association for VFs (Don Dutile) [873462]

* Wed Nov 21 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-344.el6]
- [netdrv] pch_gbe: don't reset MAC_RX on FIFO overflow (Veaceslav Falico) [858747]
- [netdrv] pch_gbe: don't re-set RX_FIFO_ERR flag in napi_poll (Veaceslav Falico) [858747]
- [netdrv] pch_gbe: create functions for MAC_RX enable, disable (Veaceslav Falico) [858747]
- [s390] prevent kABI checking for transactional execution and RI (Hendrik Brueckner) [823011]
- [s390] add support for transactional memory (Hendrik Brueckner) [823011]
- [s390] add support for runtime instrumentation (Hendrik Brueckner) [823011]
- [block] sg_io: introduce unpriv_sgio queue flag (Paolo Bonzini) [841577]
- [block] sg_io: pass request_queue to blk_verify_command (Paolo Bonzini) [841577]
- [scsi] have scsi_internal_device_unblock take new state (Chris Leech) [854140]
- [scsi] add new SDEV_TRANSPORT_OFFLINE state (Chris Leech) [854140]
- [fs] sysfs: Cache the last sysfs_dirent to improve readdir scalability (Jes Sorensen) [869037]
- [fs] cifs: when CONFIG_HIGHMEM is set, serialize the write kmaps (Sachin Prabhu) [832252]
- [fs] cifs: abstract out function to marshal up the iovec array for async writes (Sachin Prabhu) [832252]
- [fs] cifs: on CONFIG_HIGHMEM machines, limit the wsize to the kmap space (Sachin Prabhu) [832252]
- [fs] gfs2: fix truncation of journaled data files (Abhijith Das) [864634]
- [fs] gfs2: re-fix kernel panic with small gfs2 filesystems (Abhijith Das) [838638]
- [target] iblock: Add parameter to specify read-only devices (Andy Grover) [877561]
- [ata] sata_svw: check DMA start bit before reset (David Milburn) [737836]
- [scsi] hpsa: Use LUN reset instead of target reset (Tomas Henzl) [875091]
- [net] bonding: prevent deadlock on slave store with alb mode (Veaceslav Falico) [849129]
- [net] fix divide by zero in tcp algorithm illinois (Flavio Leitner) [866514] {CVE-2012-4565}

* Mon Nov 19 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-343.el6]
- [mm] percpu: Fix kdump crash_notes content lost in case i386 debug (Baoquan He) [828045]
- [mm] percpu: fix chunk range calculation (Baoquan He) [828045]

* Fri Nov 16 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-342.el6]
- [netdrv] pch_gbe: align skbs to 64byte (Veaceslav Falico) [814481]
- [Documentation] nfs: Update kernel idmapping documentation (Steve Dickson) [823359]
- [scsi] cxgb3i, cxgb4i: driver updates for rhel6.4 (Jeff Garzik) [747142 747143]
- [net] rtnetlink: Fix problem with buffer allocation (Andy Gospodarek) [845081]
- [net] RTNETLINK adjusting values of min_ifinfo_dump_size (Andy Gospodarek) [845081]
- [net] rtnetlink: Compute and store minimum ifinfo dump size (Andy Gospodarek) [845081]
- [kernel] timekeeping: Fix timezone update (Prarit Bhargava) [868859]
- [net] sunrpc: add the ability to monitor dynamic slot allocation (Harshula Jayasuriya) [876632]
- [scsi] ibmvfc: Ignore fabric RSCNs when link is dead (Steve Best) [875945]
- [x86] abort secondary CPU bring-up gracefully if do_boot_cpu timed out on cpu_callin_mask (Igor Mammedov) [816899]
- [fs] vfs: get rid of S_BIAS (Ian Kent) [872813]
- [fs] gfs2: Test bufdata with buffer locked and gfs2_log_lock held (Benjamin Marzinski) [874319]
- [kernel] cpu: fix cpu_chain section mismatch (Frederic Weisbecker) [852148]
- [kernel] sched: Don't modify cpusets during suspend/resume (Frederic Weisbecker) [852148]
- [kernel] sched, cpuset: Drop __cpuexit from cpu hotplug callbacks (Frederic Weisbecker) [852148]
- [kernel] sched: adjust when cpu_active and cpuset configurations are updated during cpu on/offlining (Frederic Weisbecker) [852148]
- [kernel] cpu: return better errno on cpu hotplug failure (Frederic Weisbecker) [852148]
- [kernel] cpu: introduce cpu_notify(), __cpu_notify(), cpu_notify_nofail() (Frederic Weisbecker) [852148]
- [fs] fuse: optimize __fuse_direct_io() (Brian Foster) [858850]
- [fs] fuse: optimize fuse_get_user_pages() (Brian Foster) [858850]
- [fs] fuse: use get_user_pages_fast() (Brian Foster) [858850]
- [fs] fuse: pass iov to fuse_get_user_pages() (Brian Foster) [858850]
- [mm] minor cleanup of iov_iter_single_seg_count() (Brian Foster) [858850]
- [fs] fuse: use req->page_descs for argpages cases (Brian Foster) [858850]
- [fs] fuse: add per-page descriptor <offset, length> to fuse_req (Brian Foster) [858850]
- [fs] fuse: rework fuse_do_ioctl() (Brian Foster) [858850]
- [fs] fuse: rework fuse_perform_write() (Brian Foster) [858850]
- [fs] fuse: rework fuse_readpages() (Brian Foster) [858850]
- [fs] fuse: categorize fuse_get_req() (Brian Foster) [858850]
- [fs] fuse: general infrastructure for pages of variable size (Brian Foster) [858850]
- [mm] memcg: fix split_huge_page_refcounts() (Jerome Marchand) [808538]
- [mm] memcg: count pte references from every member of the reclaimed hierarchy (Jerome Marchand) [808538]
- [mm] make per-memcg LRU lists exclusive (Jerome Marchand) [808538]
- [mm] collect LRU list heads into struct lruvec (Jerome Marchand) [808538]
- [mm] vmscan: convert global reclaim to per-memcg LRU lists (Jerome Marchand) [808538]
- [mm] memcg: remove optimization of keeping the root_mem_cgroup LRU lists empty (Jerome Marchand) [808538]
- [mm] move memcg hierarchy reclaim to generic reclaim code (Jerome Marchand) [808538]
- [mm] memcg: per-priority per-zone hierarchy scan generations (Jerome Marchand) [808538]
- [mm] vmscan: distinguish between memcg triggering reclaim and memcg (Jerome Marchand) [808538]
- [mm] vmscan: distinguish global reclaim from global LRU scanning (Jerome Marchand) [808538]
- [mm] memcg: consolidate hierarchy iteration primitives (Jerome Marchand) [808538]
- [mm] vmscan: remove isolate_pages callback scan control (Jerome Marchand) [808538]
- [mm] memcg: Introduces for_each_mem_cgroup_all (Jerome Marchand) [808538]
- [mm] memcg: use for_each_mem_cgroup (Jerome Marchand) [808538]
- [mm] memcg: extract mem_group_usage() from mem_cgroup_read() (Jerome Marchand) [808538]
- [mm] memcg: skip scanning active lists based on individual size (Jerome Marchand) [808538]
- [mm] compaction: avoid double mem_cgroup_del_lru() (Jerome Marchand) [808538]
- [kernel] events: Switch to internal refcount, fix race with close() (Jiri Olsa) [874723]
- [kernel] events: De-schedule a task context when removing the last event (Jiri Olsa) [874723]
- [kernel] events: Change close() semantics for group events (Jiri Olsa) [874723]
- [kernel] events: Do no try to schedule task events if there are none (Jiri Olsa) [874723]
- [kernel] events: Do not set task_ctx pointer in cpuctx if there are no events in the context (Jiri Olsa) [874723]
- [kernel] events: Collect the schedule-in rules in one function (Jiri Olsa) [874723]
- [kernel] events: Fix initial task_ctx/event installation (Jiri Olsa) [874723]
- [kernel] events: Simplify and fix __perf_install_in_context() (Jiri Olsa) [874723]
- [kernel] events: Remove task_ctx_sched_in() (Jiri Olsa) [874723]
- [kernel] events: Clean up 'ctx' reference counting (Jiri Olsa) [874723]
- [s390] qeth: fix deadlock between recovery and bonding driver (Hendrik Brueckner) [869647]
- [fs] xfs: fix reading of wrapped log data (Dave Chinner) [874322]
- [x86] mm: fix signedness issue in mmap_rnd() (Petr Matousek) [875036]
- [net] netlink: fix for too early rmmod (Weiping Pan) [874444]
- [net] af_key: fix netns ops ordering on module load/unload (Weiping Pan) [874434]
- [net] ipv6/netfilter: fix overlap check for fragments (Amerigo Wang) [726807]

* Tue Nov 13 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-341.el6]
- [fs] cifs: deal with id_to_sid embedded sid reply corner case (Sachin Prabhu) [868433]
- [fs] cifs: fix hardcoded default security descriptor length (Sachin Prabhu) [868433]
- [fs] cifs: extra sanity checking for cifs.idmap keys (Sachin Prabhu) [868433]
- [fs] cifs: ensure we revalidate the inode after readdir if cifsacl is enabled (Sachin Prabhu) [868433]
- [fs] cifs: don't override the uid/gid in getattr when cifsacl is enabled (Sachin Prabhu) [868433]
- [fs] cifs: avoid extra allocation for small cifs.idmap keys (Sachin Prabhu) [868433]
- [fs] cifs: simplify id_to_sid and sid_to_id mapping code (Sachin Prabhu) [868433]
- [fs] cifs: remove uneeded __KERNEL__ block from cifsacl.h (Sachin Prabhu) [868433]
- [fs] cifs: fix the format specifiers in sid_to_str (Sachin Prabhu) [868433]
- [fs] cifs: redefine NUM_SUBAUTH constant from 5 to 15 (Sachin Prabhu) [868433]
- [fs] cifs: make cifs_copy_sid handle a source sid with variable size subauth arrays (Sachin Prabhu) [868433]
- [fs] cifs: make compare_sids static (Sachin Prabhu) [868433]
- [fs] cifs: use the NUM_AUTHS and NUM_SUBAUTHS constants in cifsacl code (Sachin Prabhu) [868433]
- [fs] cifs: move num_subauth check inside of CONFIG_CIFS_DEBUG2 check in parse_sid() (Sachin Prabhu) [868433]
- [fs] cifs: clean up id_mode_to_cifs_acl (Sachin Prabhu) [868433]
- [fs] cifs: fix potential buffer overrun in cifs.idmap handling code (Sachin Prabhu) [868433]
- [net] bonding: fix a NULL pointer dereference bug in bond_enslave() (Amerigo Wang) [873226]
- [fs] pnfs: export symbol nfs_fhget (Steve Dickson) [872232]
- [fs] pnfs: export the symbol nfs_fs_type (Steve Dickson) [872229]
- [net] pkt_sched: enable QFQ to support TSO/GSO (Amerigo Wang) [816888]
- [net] pkt_sched: fix virtual-start-time update in QFQ (Amerigo Wang) [816888]
- [net] sched: add missing group change to qfq_change_class (Amerigo Wang) [816888]

* Fri Nov 09 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-340.el6]
- [scsi] sd: fix crash when UA received on DIF enabled device (Ewan Milne) [865682]
- [scsi] hpsa: fix pci-IDs, add gen8plus Smart Array IDs (Tomas Henzl) [870513]
- [fs] nfs: fix bug in legacy DNS resolver (Steve Dickson) [873816]
- [fs] nfsd: add get_uint for u32's (Steve Dickson) [873816]
- [net] sunrpc: Ensure we return EAGAIN in xs_nospace if congestion is cleared (Steve Dickson) [871128]
- [net] sunrpc: Prevent races in xs_abort_connection() (Steve Dickson) [871128]
- [net] Revert: sunrpc: Ensure we close the socket on EPIPE errors too (Steve Dickson) [871128]
- [net] sunrpc: Get rid of the xs_error_report socket callback (Steve Dickson) [871128]
- [fs] ext4: Use proper flags in ext4_ext_insert_extent() (Lukas Czerner) [873394]
- [idle] intel_idle: enable Ivy Bridge Xeon support (Lenny Szubowicz) [870209]
- [md] dm-raid: Transiently failed devices do not undergo resync (Jonathan E Brassow) [870246]
- [md] dm-thin: bump thin and pool target versions to 1.5 (Mike Snitzer) [872249]
- [mm] Prevent kernel panic in NUMA related system calls after memory hot-add (Larry Woodman) [870350]

* Mon Nov 05 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-339.el6]
- [Documentation] vm: Transparent Hugepage Support (Baoquan He) [852802]
- [mm] huge_memory: create sysfs symlink to redhat_transparent_hugepage (Baoquan He) [852802]
- [net] openvswitch: allow to turn off TSO on internal devices (Amerigo Wang) [871275]
- [net] WARN if struct ip_options was allocated directly by kmalloc (Jiri Pirko) [872799]
- [net] fix bug that causes no RX queue entries to be created under /sys/devices (Tatsuya Kitamura) [869770]
- [fs] xfs: move allocation stack switch up to xfs_bmapi_allocate (Dave Chinner) [867277]
- [fs] xfs: introduce XFS_BMAPI_STACK_SWITCH (Dave Chinner) [867277]
- [fs] xfs: zero allocation_args on the kernel stack (Dave Chinner) [867277]
- [kernel] Do not include asm-generic/bitops/le.h directly, use linux/bitops.h (Jes Sorensen) [871142]
- [s390] dasd: move wake_up call (Hendrik Brueckner) [869753]
- [md] dm-raid: Use safe version of rdev_for_each (Jonathan E Brassow) [871630]

* Wed Oct 31 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-338.el6]
- [netdrv] igb: schedule watchdog every second to update statistics fixup (Stefan Assmann) [838404]
- [s390] smsgiucv: reestablish IUCV path after resume (Hendrik Brueckner) [869752]
- [kernel] events: Fix perf tool is_active old behaviour leftover (Jiri Olsa) [865380]
- [mm] hugetlb: fix non-atomic enqueue of huge page (Rafael Aquini) [869750]
- [char] random: Use arch-specific RNG to initialize the entropy store (Prarit Bhargava) [862344]
- [drm] i915: Use cpu relocations if the object is in the GTT but not mappable (Dave Airlie) [869856]
- [scsi] storvsc: Account for in-transit packets in the RESET path (Jason Wang) [870297]
- [netdrv] ixgbe: reduce PTP rx path overhead (Jiri Benc) [868214]
- [net] relax rcvbuf limits (Weiping Pan) [860778]
- [lib] Fix rwsem to not hang the system (David Howells) [852847]
- [input] wacom: add support to Cintiq 22HD (Aristeu Rozanski) [857062]

* Fri Oct 26 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-337.el6]
- [fs] ext4: Adding error check after calling ext4_mb_regular_allocator() (Eric Sandeen) [852810]
- [md] faulty: use disk_stack_limits() (Eric Sandeen) [868233]
- [fs] autofs4: fix reset pending flag on mount fail (Ian Kent) [866271]
- [net] netfilter/nfnetlink_queue: do not allow to set unsupported flag bits (Steve Best) [822598]
- [net] netfilter: Add fail-open support (Steve Best) [822598]
- [pci] intel-iommu: Increase the number of iommus supported to MAX_IO_APICS (George Beshers) [787724]
- [pci] intel-iommu: Fix identity mapping for sandy bridge (George Beshers) [787724]
- [netdrv] tg3: Support the get_ts_info ethtool method (Jiri Benc) [866624]
- [netdrv] tg3: enable transmit time stamping (Jiri Benc) [866624]
- [kernel] audit: do not print error when SELinux disabled (Eric Paris) [785936]
- [kernel] resource: make sure requested range is included in the root range (Johannes Weiner) [845632]
- [kernel] ntp: fix non privileged system time shifting (Jan Stancek) [868827]
- [x86] mce: Fix race in MCE cpu synchronization (Prarit Bhargava) [868110]
- [net] cfg80211, mac80211: avoid state mismatch on deauth (Stanislaw Gruszka) [866417]
- [net] mac80211: check if key has TKIP type before updating IV (Stanislaw Gruszka) [859355]

* Mon Oct 22 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-336.el6]
- [tools] perf: Catch event names from command line (Luming Yu) [696579 696580]
- [tools] perf: Allow pmu events parsing for RHEL6 (Luming Yu) [696579 696580]
- [x86] perf: Make UNCORE_PMU_HRTIMER_INTERVAL 64-bit (Luming Yu) [696579 696580]
- [kernel] events: provide PMU when initing events (Luming Yu) [696579 696580]
- [kernel] events: Remove perf_event_attr::type check (Luming Yu) [696579 696580]
- [x86] perf: Fix LLC-* and node-* events on Intel SandyBridge (Luming Yu) [696579 696580]
- [x86] perf: Add generic NODE cache events (Luming Yu) [696579 696580]
- [x86] perf: Fix format definition of SNB-EP uncore QPI box (Luming Yu) [696579 696580]
- [x86] perf: Add Intel Nehalem-EX uncore support (Luming Yu) [696579 696580]
- [x86] perf: Detect number of instances of uncore CBox (Luming Yu) [696579 696580]
- [x86] perf: Fix event constraint for SandyBridge-EP C-Box (Luming Yu) [696579 696580]
- [x86] perf: Use 0xff as pseudo code for fixed uncore event (Luming Yu) [696579 696580]
- [x86] perf: Fix section mismatch in uncore_pci_init() (Luming Yu) [696579 696580]
- [x86] perf: Lowercase uncore PMU event names (Luming Yu) [696579 696580]
- [x86] perf: Add Intel Nehalem and Sandy Bridge-EP uncore support (Luming Yu) [696579 696580]
- [x86] perf: Add generic PCI uncore PMU device support (Luming Yu) [696579 696580]
- [x86] perf: Add Intel Nehalem and Sandy Bridge uncore PMU support (Luming Yu) [696579 696580]
- [x86] perf: Add generic Intel uncore PMU support (Luming Yu) [696579 696580]
- [x86] perf: Clean up perf_event cpu code (Luming Yu) [696579 696580]
- [ata] ata_piix: defer disks to the Hyper-V drivers by default (Jason Wang) [834682]
- [ata] libata: add a host flag to ignore detected ATA devices (Jason Wang) [834682]
- [netdrv] hyperv: Add the Hyper-V network driver (Jason Wang) [834682]
- [scsi] hyperv: Add the storvsc driver (Jason Wang) [834682]
- [hid] hyperv: Add the Hyper-V mouse driver (Jason Wang) [834682]
- [virt] hyperv: Add the vmbus and util drivers (Jason Wang) [834682]
- [staging] hyperv: Get rid of all the staging hv drivers (Jason Wang) [834682]
- [scripts] hyperv: fix up alias creation logic for hv_vmbus_device_id (Jason Wang) [834682]
- [scripts] hyperv: Add code to parse struct hv_vmbus_device_id table (Jason Wang) [834682]
- [x86] cpu: Integrate the clocksource with Hyper-V detection code (Jason Wang) [834682]
- [x86] cpu: Export the symbol ms_hyperv (Jason Wang) [834682]
- [misc] vmware_balloon: use the new x86_hyper API (Jason Wang) [834682]
- [x86] hypervisor: Export the x86_hyper* symbols (Jason Wang) [834682]
- [x86] cpu: Clean up the hypervisor layer (Jason Wang) [834682]
- [x86] cpu: Detect running on a Microsoft HyperV system (Jason Wang) [834682]
- [virt] hyperv: Add HYPER-V header file (Jason Wang) [834682]
- [scsi] megaraid_sas: Version, Changelog, Copyright update (Tomas Henzl) [841724]
- [scsi] megaraid_sas: Remove duplicate code (Tomas Henzl) [841724]
- [scsi] megaraid_sas: Add SystemPD FastPath support (Tomas Henzl) [841724]
- [scsi] megaraid_sas: Add array boundary check for SystemPD (Tomas Henzl) [841724]
- [scsi] megaraid_sas: Load io_request DataLength in bytes (Tomas Henzl) [841724]
- [scsi] megaraid_sas: Add module param for configurable MSI-X vector count (Tomas Henzl) [841724]
- [scsi] megaraid_sas: Remove un-needed completion_lock spinlock calls (Tomas Henzl) [841724]
- [scsi] megaraid_sas: Move poll_aen_lock initializer (Tomas Henzl) [841724]
- [scsi] megaraid_sas: Add resetwaittime module parameter (Tomas Henzl) [841724]
- [scsi] megaraid_sas: Add throttlequeuedepth module parameter (Tomas Henzl) [841724]
- [scsi] megaraid_sas: Add fpRead/WriteCapable, fpRead/WriteAcrossStripe checks (Tomas Henzl) [841724]
- [net] sunrpc: Ensure that the TCP socket is closed when in CLOSE_WAIT (Steve Dickson) [863212]
- [fs] nfs: Make v3 mounts fail with ETIMEDOUTs instead EIO on mountd timeouts (Steve Dickson) [835966]
- [md] raid1: Don't release reference to device while handling read error (Jes Sorensen) [853049]
- [netdrv] sfc: backport cleanups (Nikolay Aleksandrov) [865751]
- [net] fix a sysctl check warning in conntrack reasm code (Amerigo Wang) [867688]

* Fri Oct 19 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-335.el6]
- [fs] fuse: implement NFS-like readdirplus support (Brian Foster) [841514]
- [drm] nouveau: prevent display switching issues by disabling pageflip (Ben Skeggs) [867698]
- [drm] nouveau: restore pre-suspend fence buffer context on resume (Ben Skeggs) [867698]
- [drm] nouveau: fix shadowing of ACPI ROM images larger than 64KiB (Ben Skeggs) [867698]
- [netdrv] igb: Add 1588 support to I210/I211 (Jiri Benc) [864881]
- [netdrv] igb: Prevent dropped Tx timestamps via work items and interrupts (Jiri Benc) [864881]
- [netdrv] igb: Store the MAC address in the name in the PTP struct (Jiri Benc) [864881]
- [netdrv] igb: Correct PTP support query from ethtool (Jiri Benc) [864881]
- [netdrv] igb: Update PTP function names/variables and locations (Jiri Benc) [864881]
- [netdrv] igb: Tidy up wrapping for CONFIG_IGB_PTP (Jiri Benc) [864881]
- [netdrv] igb: Support the get_ts_info ethtool method (Jiri Benc) [864881]
- [netdrv] igb: Add switch case for supported hardware to igb_ptp_remove (Jiri Benc) [864881]
- [netdrv] igb: Add Support for new i210/i211 devices (Jiri Benc) [864881]
- [netdrv] igb: offer a PTP Hardware Clock instead of the timecompare method (Jiri Benc) [864881]
- [netdrv] igb: add PTP Hardware Clock code (Jiri Benc) [864881]
- [net] mark ptp support as Tech Preview (Jiri Benc) [829785]
- [ptp] link the phc device to its parent device (Jiri Benc) [829785]
- [ptp] provide the clock's adjusted frequency (Jiri Benc) [829785]
- [ptp] remember the adjusted frequency (Jiri Benc) [829785]
- [ptp] Allow PHC devices to adjust PPS events for known delay (Jiri Benc) [829785]
- [ptp] Fix clock_getres() implementation (Jiri Benc) [829785]
- [ptp] Fix some locking bugs in ptp_read() (Jiri Benc) [829785]
- [ptp] Return -EFAULT on copy_to_user() errors (Jiri Benc) [829785]
- [pps] return PTR_ERR on error in device_create (Jiri Benc) [829785]
- [pps] class_create() returns an ERR_PTR, not NULL (Jiri Benc) [829785]
- [pps] simplify conditions a bit (Jiri Benc) [829785]
- [pps] make idr lock a mutex and protect idr_pre_get (Jiri Benc) [829785]
- [pps] move idr stuff to pps.c (Jiri Benc) [829785]
- [pps] convert printk/pr_* to dev_* (Jiri Benc) [829785]
- [pps] access pps device by direct pointer (Jiri Benc) [829785]
- [pps] fix race in PPS_FETCH handler (Jiri Benc) [829785]
- [pps] declare variables where they are used in switch (Jiri Benc) [829785]
- [pps] trivial fixes (Jiri Benc) [829785]
- [drm] i915: use correct CONFIG for iommu in rhel6 (Dave Airlie) [865666]
- [gpu] vga_switcheroo: Don't require handler init callback (Dave Airlie) [867169]
- [x86] amd_iommu: attach device fails on the last pci device (Don Dutile) [861164]

* Thu Oct 18 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-334.el6]
- [mm] compaction: clear PG_migrate_skip based on compaction and reclaim activity (Rik van Riel) [713546 783248]
- [mm] compaction: fix bit ranges in {get,clear,set}_pageblock_skip() (Rik van Riel) [713546 783248]
- [netdrv] e1000e: add device IDs for i218 (Clarkville-LP) (Dean Nelson) [862764]
- [infiniband] mxl4: Fix build error on platforms where UL is not 64bit (Doug Ledford) [586028 756396]
- [netdrv] mlx4: Adjust flow steering attach wrapper so that IB works on SR-IOV VFs (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Create paravirt contexts for VFs when master IB driver initializes (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Modify proxy/tunnel QP mechanism so that guests do no calculations (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Paravirtualize Node Guids for slaves (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Activate SR-IOV mode for IB (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Miscellaneous adjustments for SR-IOV IB support (Doug Ledford) [586028 756396]
- [netdrv] mlx4: INIT/CLOSE port logic for IB ports in SR-IOV mode (Doug Ledford) [586028 756396]
- [netdrv] mlx4: Adjustments to SET_PORT for IB SR-IOV (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Add iov directory in sysfs under the ib device (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Propagate P_Key and guid change port management events to slaves (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Add alias_guid mechanism (Doug Ledford) [586028 756396]
- [netdrv] mlx4: Add IB port-state machine and port mgmt event propagation (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Add CM paravirtualization (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Add multicast group (MCG) paravirtualization for SR-IOV (Doug Ledford) [586028 756396]
- [infiniband] mlx4: MAD_IFC paravirtualization (Doug Ledford) [586028 756396]
- [infiniband] mlx4: SR-IOV multiplex and demultiplex MADs (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Implement QP paravirtualization and maintain phys_pkey_cache for smp_snoop (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Initialize SR-IOV IB support for slaves in master context (Doug Ledford) [586028 756396]
- [infiniband] mlx4: Add proxy and tunnel QPs to the reserved QP area (Doug Ledford) [586028 756396]
- [infiniband] mlx4: SR-IOV IB context objects and proxy/tunnel SQP support (Doug Ledford) [586028 756396]
- [infiniband] core: Add ib_find_exact_cached_pkey() (Doug Ledford) [586028 756396]
- [infiniband] core: Handle table with full and partial membership for the same P_Key (Doug Ledford) [586028 756396]
- [infiniband] core: Handle table with full and partial membership for the same P_Key (Doug Ledford) [586028 756396]
- [net] rds: fix rds-ping spinlock recursion (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] cma: Check that retry count values are in range (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] nes: Add missing break to switch. (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: dont orphan skbs in mlx4_en_xmit() (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Disable SENSE_PORT for multifunction devices (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Clean up enabling of SENSE_PORT for older (ConnectX-1/-2) HCAs (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Stash PCI ID driver_data in mlx4_priv structure (Doug Ledford) [826346 826348 826349]
- [infiniband] srp: Avoid having aborted requests hang (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] srp: Fix use-after-free in srp_reset_req() (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] nes: Fix compilation error when nes_debug is enabled (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] nes: Print hardware resource type (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] nes: Fix for crash when TX checksum offload is off (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] nes: Fix for incorrect MSS when TSO is on (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] nes: Fix incorrect resolving of the loopback MAC address (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: Fix crash on uninitialized priv->cmd.slave_sem (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Trivial cleanups to driver log messages (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Trivial readability fix: "0X30" -> "0x30" (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Remove annoying debug message in the resource tracker (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fix wrong offset in parsing query device caps response (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Fill in sq_sig_type in query QP (Doug Ledford) [826346 826348 826349]
- [infiniband] ipoib: Fix use-after-free of multicast object (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] cma: Use consistent component mask for IPoIB port space multicast joins (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] core: Remove unused variables in ucm/ucma (Doug Ledford) [818562 826346 826348 826349]
- [net] rds: Don't disable BH on BH context (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] qib: Fix local access validation for user MRs (Doug Ledford) [818562]
- [infiniband] qib: Add a qib driver version (Doug Ledford) [818562]
- [infiniband] qib: Fix failure of compliance test C14-024#06_LocalPortNum (Doug Ledford) [818562]
- [netdrv] mlx4: Fix integer overflows so 8TBs of memory registration works (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Return the error value in case of command initialization failure (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fixing error flow in case of QUERY_FW failure (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Add security check / enforcement for flow steering rules set for VMs (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Put Firmware flow steering structures in common header files (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Check iboe netdev pointer before dereferencing it (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Clean up buddy bitmap allocation (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fix integer overflow issues around MTT table (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Allow large mlx4_buddy bitmaps (Doug Ledford) [826346 826348 826349]
- [infiniband] srp: Fix a race condition (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] qib: Fix error return code in qib_init_7322_variables() (Doug Ledford) [818562]
- [infiniband] Fix typos in infiniband drivers (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: fix mcg.c error return code (Doug Ledford) [826346 826348 826349]
- [infiniband] ucma.c: Fix for events with wrong context on iWARP (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] mlx4: Fix possible deadlock on sm_lock spinlock (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Remove port type restrictions (Doug Ledford) [826346 826348 826349]
- [infiniband] qib: Fix size of cc_supported_table_entries (Doug Ledford) [818562]
- [infiniband] ucma: Convert open-coded equivalent to memdup_user() (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] qib: checkpatch fixes (Doug Ledford) [818562]
- [infiniband] qib: Add congestion control agent implementation (Doug Ledford) [818562]
- [infiniband] qib: Reduce sdma_lock contention (Doug Ledford) [818562]
- [infiniband] qib: Fix an incorrect log message (Doug Ledford) [818562]
- [netdrv] mlx4: map entire pages to increase throughput (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Move MAC_MASK to a common place (Doug Ledford) [826346 826348 826349]
- [infiniband] qib: Fix QP RCU sparse warnings (Doug Ledford) [818562]
- [netdrv] mlx4: dereferencing freed memory (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: off by one in parse_trans_rule() (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Put physical GID and P_Key table sizes in mlx4_phys_caps struct and paravirtualize them (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Allow guests to have IB ports (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Implement mechanism for reserved Q_Keys (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Free ICM table in case of error (Doug Ledford) [826346 826348 826349]
- [infiniband] cm: Destroy idr as part of the module init error flow (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: Remove double function declarations (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Fill the masked_atomic_cap attribute in query device (Doug Ledford) [826346 826348 826349]
- [infiniband] mthca: Fill in sq_sig_type in query QP (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] mthca: Warning about event for non-existent QPs should show event type (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] ipoib: fix skb truesize underestimatiom (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] qib: Fix sparse RCU warnings in qib_keys.c (Doug Ledford) [818562]
- [netdrv] mlx4: Initialize IB port capabilities for all slaves (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Use port management change event instead of smp_snoop (Doug Ledford) [826346 826348 826349]
- [infiniband] qib: RCU locking for MR validation (Doug Ledford) [818562]
- [infiniband] qib: Avoid returning EBUSY from MR deregister (Doug Ledford) [818562]
- [infiniband] qib: Fix UC MR refs for immediate operations (Doug Ledford) [818562]
- [infiniband] core: Move CM_xxx_ATTR_ID macros from cm_msgs.h to ib_cm.h (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] sa: Add GuidInfoRecord query support (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] mlx4: Add debug prints (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Pass an invalid PCI id number to VFs (Doug Ledford) [826346 826348 826349]
- [infiniband] cma: Allow user to restrict listens to bound address family (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] cma: Listen on specific address family (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] cma: Bind to a specific address family (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: Add support for drop action through ethtool (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Manage flow steering rules with ethtool (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: set number of rx rings used by RSS using ethtool (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Implement promiscuous mode with device managed flow-steering (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Add resource tracking for device managed flow steering rules (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Add device managed flow steering firmware API (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Add firmware commands to support device managed flow steering (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Set steering mode according to device capabilities (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Re-design multicast attachments flow (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Change resource tracking ID to be 64 bit (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Change resource tracking mechanism to use red-black tree (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: set maximal number of default RSS queues (Doug Ledford) [826346 826348 826349]
- [infiniband] netlink: Move away from NLMSG_NEW() (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: Release QP range in free_resources (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Use single completion vector after NOP failure (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Set correct port parameters during device initialization (Doug Ledford) [826346 826348 826349]
- [infiniband] cma: QP type check on received REQs should be AND not OR (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] mlx4: Fix max_wqe capacity reported from query device (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fix setting VL_cap in mlx4_SET_PORT wrapper flow (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Fix EQ deallocation in legacy mode (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fix obscure mlx4_cmd_box parameter in QUERY_DEV_CAP (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Check port out-of-range before using in mlx4_slave_cap (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fixes for VF / Guest startup flow (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fix improper use of "port" parameter in mlx4_en_event (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fix number of EQs used in ICM initialisation (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fix the slave_id out-of-range test in mlx4_eq_int (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Fix mlx4_ib_add() error flow (Doug Ledford) [826346 826348 826349]
- [infiniband] core: Fix IB_SA_COMP_MASK macro (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] iser: Fix error flow in iser ep connection establishment (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] mlx4: Increase the number of vectors (EQs) available for ULPs (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: num cores tx rings for every UP (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fixed error flow in rem_slave_eqs (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Add XRC domains and counters to resource tracker (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fix potential kernel Oops in res tracker during Dom0 driver unload (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Address build warnings on set but not used variables (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fix init_port mask state for slaves (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Change SYNC_TPT to be native (not wrapped) (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Remove unused *_str functions from the resource tracker (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Do not reset module-parameter num_vfs when fail to enable sriov (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Change bitmap allocator to work in round-robin fashion (Doug Ledford) [826346 826348 826349]
- [infiniband] nes: Don't call event handler if pointer is NULL (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] nes: Fix for the ORD value of the connecting peer (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] qib: Add cache line awareness to qib_qp and qib_devdata structures (Doug Ledford) [818562]
- [infiniband] qib: MADs with misset M_Keys should return failure (Doug Ledford) [818562]
- [infiniband] qib: Fix M_Key lease timeout handling (Doug Ledford) [818562]
- [infiniband] qib: Fix QLE734X link cycling (Doug Ledford) [818562]
- [infiniband] qib: Display correct value for number of contexts (Doug Ledford) [818562]
- [infiniband] qib: Correct ordering of reregister vs. port active events (Doug Ledford) [818562]
- [infiniband] qib: Optimize pio ack buffer allocation (Doug Ledford) [818562]
- [infiniband] qib: Add prefetch for eager buffers (Doug Ledford) [818562]
- [infiniband] mlx4: Replace printk(KERN_yyy...) with pr_yyy(...) (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Add second capabilities flags field (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Put priority bits in WQE of IBoE MLX QP (Doug Ledford) [826346 826348 826349]
- [infiniband] core: Add raw packet QP type (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] mlx4: Add raw packet QP support (Doug Ledford) [826346 826348 826349]
- [infiniband] uverbs: Make lockdep output more readable (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] uverbs: Lock SRQ / CQ / PD objects in a consistent order (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] cma: Fix lockdep false positive recursive locking (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] ipath: Replace open-coded ARRAY_SIZE with macro (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] ipath: Replace open-coded ARRAY_SIZE with macro (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] core: Use qp->usecnt to track multicast attach/detach (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] mad: Don't send response for failed MADs (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] mad: Set 'D' bit in response for unhandled MADs (Doug Ledford) [818562 826346 826348 826349]
- [net] mlx4: Moving to Interrupts for TX completions (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Added Ethtool support for TX Interrupt coalescing (Doug Ledford) [826346 826348 826349]
- [net] rds: Move all of the network sysctls without a namespace into init_net (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: Fix spelling typo in net (Doug Ledford) [826346 826348 826349]
- [infiniband] rdma_cm: TOS <=> UP mapping for IBoE (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: sk_prio <=> UP for untagged traffic (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Use netif_set_real_num_{rx, tx}_queues() (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: DCB QoS support (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: set port QoS attributes (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Force user priority by QP attribute (Doug Ledford) [826346 826348 826349]
- [infiniband] core: Don't return EINVAL from sysfs rate attribute for invalid speeds (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] mlx4: Don't return an invalid speed when a port is down (Doug Ledford) [826346 826348 826349]
- [infiniband] Stop using NLA_PUT*() (Doug Ledford) [818562 826346 826348 826349]
- [net] rds: use gfp flags from caller in conn_alloc() (Doug Ledford) [818562 826346 826348 826349]
- [net] rds: Remove printk from rds_sendmsg (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: Scale size of MTT table with system RAM (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Allow dynamic MTU configuration for IB ports (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Fix info returned when querying IBoE ports (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Fix possible missed completion event (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Report thermal error events (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Fix one more static exported function (Doug Ledford) [826346 826348 826349]
- [infiniband] Change CQE csum_ok field to a bit flag (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] iwcm: Reject connect requests if cmid is not in LISTEN state (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: Get rid of redundant ext_port_cap flags (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: defining functions as static (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: remove unused functions (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: remove unused functions (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: fixing sparse warnings when copying mac, address to gid entry (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: fix sparse warnings on wrong type for RSS keys (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: fix sparse warnings on TX blue flame buffer (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Saving mem access on data path (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: remove sparse errors (Doug Ledford) [826346 826348 826349]
- [infiniband] ucma: Fix AB-BA deadlock (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] ehca: Fix ilog2() compile failure (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] Use central enum for speed instead of hard-coded values (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] iser: Free IB connection resources in the proper place (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] srp: Consolidate repetitive sysfs code (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] srp: Use pr_fmt() and pr_err()/pr_warn() (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] core: Fix SDR rates in sysfs (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: dont change mac_header on xmit (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: Enforce device max FMR maps in FMR alloc (Doug Ledford) [826346 826348 826349]
- [infiniband] mlx4: Set bad_wr for invalid send opcode (Doug Ledford) [826346 826348 826349]
- [infiniband] mad: Return error response for unsupported MADs (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] mad: Add MAD error codes from IBA spec (Doug Ledford) [818562 826346 826348 826349]
- [infiniband] qib: Avoid filtering LID on SMA portinfo (Doug Ledford) [818562]
- [infiniband] qib: Add logic for affinity hint (Doug Ledford) [818562]
- [infiniband] nes: Fixes for sparse endianness warnings (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: remove unnecessary variables and arguments (Doug Ledford) [826346 826348 826349]
- [netdrv] mlx4: remove unused field high_prios (Doug Ledford) [826346 826348 826349]
- [net] rds: Fix typo in iw_recv.c and ib_recv.c (Doug Ledford) [818562 826346 826348 826349]
- [netdrv] mlx4: Fix typo in cmd.c (Doug Ledford) [826346 826348 826349]
- [net] ipv4/route: export symbol ip_tos2prio (Doug Ledford) [818562 826346 826348 826349]
- [misc] Backport of pr_*_once() functions (Doug Ledford) [818562 826346 826348 826349]
- [mm] Revert: reduce memcg memory overhead (Jarod Wilson) [808538]

* Wed Oct 17 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-333.el6]
- [drm] i915: block haswell support (Dave Airlie) [862376]
- [powerpc] fadump: Remove the phyp assisted dump code (Steve Best) [739124]
- [powerpc] pseries: Call ibm, os-term if the ibm, extended-os-term is present (Steve Best) [739124]
- [powerpc] fadump: Invalidate the fadump registration during machine shutdown (Steve Best) [739124]
- [powerpc] fadump: Invalidate registration and release reserved memory for general use (Steve Best) [739124]
- [fs] proc/vmcore: Introduce cleanup routine to invalidate /proc/vmcore (Steve Best) [739124]
- [powerpc] fadump: Add PT_NOTE program header for vmcoreinfo (Steve Best) [739124]
- [powerpc] fadump: Convert firmware-assisted cpu state dump data into elf notes (Steve Best) [739124]
- [powerpc] fadump: Initialize elfcore header and add PT_LOAD program headers (Steve Best) [739124]
- [powerpc] fadump: Register for firmware assisted dump (Steve Best) [739124]
- [powerpc] fadump: Reserve the memory for firmware assisted dump (Steve Best) [739124]
- [powerpc] fadump: Add documentation for firmware-assisted dump (Steve Best) [739124]
- [net] Add rtnetlink init_rcvwnd to set the TCP initial receive window (Jesper Brouer) [795598]
- [scsi] fcoe: Fix write errors on NPIV ports (Neil Horman) [857575]
- [scsi] fcoe: Allocate fcoe_ctlr with fcoe_interface, not as a member (Neil Horman) [857575]
- [scsi] fcoe: Fix up rmmod crash (Neil Horman) [860846]
- [fs] NFSv4.1: Clean up layoutreturn (Steve Dickson) [837871]
- [net] nfs: Fix buffer overflow checking in __nfs4_get_acl_uncached (Sachin Prabhu) [822871] {CVE-2012-2375}
- [net] nfs: Fix the acl cache size calculation (Sachin Prabhu) [822871] {CVE-2012-2375}
- [net] nfs: Fix range checking in __nfs4_get_acl_uncached and __nfs4_proc_set_acl (Sachin Prabhu) [822871] {CVE-2012-2375}
- [net] nfs: nfs_getaclargs.acl_len is a size_t (Sachin Prabhu) [822871] {CVE-2012-2375}
- [net] nfs: Don't use private xdr_stream fields in decode_getacl (Sachin Prabhu) [822871] {CVE-2012-2375}
- [net] nfs: Fix pointer arithmetic in decode_getacl (Sachin Prabhu) [822871] {CVE-2012-2375}
- [net] nfs: Simplify the GETATTR attribute length calculation (Sachin Prabhu) [822871] {CVE-2012-2375}
- [net] sunrpc: Add the helper xdr_stream_pos (Sachin Prabhu) [822871] {CVE-2012-2375}
- [net] sunrpc: Don't decode beyond the end of the RPC reply message (Sachin Prabhu) [822871] {CVE-2012-2375}
- [net] sunrpc: Clean up xdr_set_iov() (Sachin Prabhu) [822871] {CVE-2012-2375}
- [net] sunrpc: xdr_read_pages needs to clear xdr->page_ptr (Sachin Prabhu) [822871] {CVE-2012-2375}
- [fs] nfs: Avoid beyond bounds copy while caching ACL (Sachin Prabhu) [822871] {CVE-2012-2375}
- [fs] nfs: Avoid reading past buffer when calling GETACL (Sachin Prabhu) [822871] {CVE-2012-2375}
- [virt] kvm: Use accessors function to access cr4 (Gleb Natapov) [866452]
- [fs] xfs: report projid32bit feature in geometry call (Eric Sandeen) [865929]
- [usb] serial/ti_usb: fix module removal (Don Zickus) [864186]
- [fs] nfs: do not send an empty SETATTR compound (J. Bruce Fields) [863912]

* Mon Oct 15 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-332.el6]
- [scsi] libfc: fix lun reset failure bugs in fc_fcp_resp handling of FCP_RSP_INFO (Neil Horman) [789103]
- [scsi] libfc: fix retries with FDMI lport states (Neil Horman) [789103]
- [scsi] fcoe: remove lport from net device before doing per cpu rx thread cleanup (Neil Horman) [789103]
- [scsi] libfc: flush lport worker after its disabled (Neil Horman) [789103]
- [scsi] fcoe: defer releasing master lport until complete fcoe interface cleanuped up (Neil Horman) [789103]
- [scsi] fcoe: Support extra MAC descriptor to be used as FCoE MAC (Neil Horman) [789103]
- [scsi] foce: remove bh disable from fcoe sw transport rcv function (Neil Horman) [789103]
- [scsi] fcoe: remove frame dropping code from fcoe_percpu_clean (Neil Horman) [789103]
- [scsi] fcoe: reduce contention for fcoe_rx_list lock (Neil Horman) [789103]
- [scsi] libfc: fcoe_transport_create fails in single-CPU environment (Neil Horman) [789103]
- [scsi] fcoe: Remove duplicate vn port reset operation (Neil Horman) [789103]
- [scsi] fcoe: Remove reference counting on 'stuct fcoe_interface' (Neil Horman) [789103]
- [scsi] fcoe: Allow exposing FDMI attributes via sysfs (Neil Horman) [789103]
- [scsi] fcoe: fix fcoe in a DCB environment by adding DCB notifiers to set skb priority (Neil Horman) [789103]
- [net] dcb: Use ifindex instead of ifname (Neil Horman) [789103]
- [scsi] libfc: avoid exchanges collision during lport reset (Neil Horman) [789103]
- [scsi] libfc: fix fc_eh_host_reset (Neil Horman) [789103]
- [scsi] fcoe: Fix deadlock between fip's recv_work and rtnl (Neil Horman) [789103]
- [scsi] fcoe: Move common functions to fcoe_transport library (Neil Horman) [789103]
- [scsi] fcoe: convert to SKB paged frag API (Neil Horman) [789103]
- [scsi] fcoe: Rearrange fcoe port and NPIV port cleanup (Neil Horman) [789103]
- [scsi] libfc: add ddp_targ() to libfc function template to supprot FCoE DDP in target mode (Neil Horman) [789103]
- [net] add ndo_fcoe_ddp_target() to support FCoE DDP in target mode (Neil Horman) [789103]
- [scsi] fcoe: support ndo_fcoe_ddp_target() for DDP in FCoE target (Neil Horman) [789103]
- [scsi] fcoe: support ndo_fcoe_ddp_target() for DDP in FCoE targe (Neil Horman) [789103]
- [scsi] fcoe: Prevent creation of an NPIV port with duplicate WWPN (Neil Horman) [789103]
- [scsi] fcoe: Incorrect CVL handling for NPIV ports (Neil Horman) [789103]
- [scsi] fcoe: have fcoe log off and lport destroy before ndo_fcoe_disable (Neil Horman) [789103]
- [scsi] libfc: remove duplicate ema_list init (Neil Horman) [789103]
- [scsi] libfc: Move host_lock usage into ramp_up/down routines (Neil Horman) [789103]
- [scsi] use list_move() instead of list_del()/list_add() combination (Neil Horman) [789103]
- [scsi] fcoe: correct checking for bonding (Neil Horman) [789103]
- [scsi] libfc: initialize EM anchors list and then update npiv EMs (Neil Horman) [789103]
- [scsi] fcoe: Move common code from fcoe to libfcoe module (Neil Horman) [789103]
- [scsi] fcoe: use dedicated workqueue instead of system_wq (Neil Horman) [789103]
- [fs] quota: move remount handling into the filesystem (Lukas Czerner) [805769]
- [fs] allow fs to handle quota enable/disable kABI friendly (Lukas Czerner) [805769]
- [fs] cifs: fix oops while traversing open file list (Sachin Prabhu) [707700]
- [fs] cifs: add a cache= option to better describe the different cache flavors (Sachin Prabhu) [850751]
- [s390] scm_block: Force cluster writes (Hendrik Brueckner) [834290]
- [s390] cio: Add scm block driver (Hendrik Brueckner) [834290]
- [s390] cio: add eadm subchannel driver (Hendrik Brueckner) [834290]
- [s390] cio: move asms to generic header (Hendrik Brueckner) [834290]
- [s390] cio: Add scm notification (Hendrik Brueckner) [834290]
- [s390] cio: Add SCM bus driver (Hendrik Brueckner) [834290]
- [s390] chsc: implement store SCM information (Hendrik Brueckner) [834290]
- [s390] cio: Add eadm related structures (Hendrik Brueckner) [834290]
- [s390] cio: move orb definitions to separate header (Hendrik Brueckner) [834290]
- [s390] css: Add eadm facility bits (Hendrik Brueckner) [834290]
- [s390] css: Allow drivers to trigger sch evaluation (Hendrik Brueckner) [834290]
- [fs] block_dev: Fix crash when block device is read and block size is changed at the same time (Mikulas Patocka) [855906]
- [tracing] remove kabi workaround that is no longer needed (Jeff Moyer) [855906]
- [mm] tracing: Move include of trace/events/kmem.h out of header into slab.c (Jeff Moyer) [855906]
- [mm] slab: Move kmalloc tracepoint out of inline code (Jeff Moyer) [855906]
- [virt] kvm: fix race with level interrupts (Michael S. Tsirkin) [847722]
- [usb] usbhid: Fix use-after-free in USBHID (James Paradis) [857518]
- [kernel] sched_rt: Ignore RT queue throttling if idle task has RT policy (Igor Mammedov) [843541]
- [md] Don't truncate size at 4TB for RAID0 and Linear (Jes Sorensen) [865637]
- [scsi] ibmvfc: Fix double completion on abort timeout (Steve Best) [865115]

* Fri Oct 12 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-331.el6]
- [fs] nfs: tear down caches in nfs_init_writepagecache when allocation fails (Steve Dickson) [857555]
- [fs] pnfs: client fails to select correct DS from multipath (Steve Dickson) [851312]
- [fs] ext4: remove mb_groups before tearing down the buddy_cache (Lukas Czerner) [859457]
- [usb] Add kernel parameter to force io_watchdog for Intel EHCI HCD (James Paradis) [846024]
- [fs] btrfs: Convert to new freezing mechanism (Zach Brown) [698324]
- [fs] btrfs: Push mnt_want_write() outside of i_mutex (Zach Brown) [698324]
- [fs] btrfs: fix min csum item size warnings in 32bit (Zach Brown) [698324]
- [fs] btrfs: backport from mainline linux 3.5 kernel (Zach Brown) [698324]
- [kernel] tracing: Don't use p->len field to determine output in __print_*() functions (Zach Brown) [698324]
- [kernel] tracing: Don't print an extra separator of flags (Zach Brown) [698324]
- [kernel] tracing: Add __print_symbolic_u64 to avoid warnings on 32bit machine (Zach Brown) [698324]
- [fs] btrfs: add BTRFS_MINOR for auto-loading (Zach Brown) [698324]
- [fs] add FS_NOCOW_FL inode attribute flag (Zach Brown) [698324]
- [fs] ext4: fix undefined bit shift result in ext4_fill_flex_info (Lukas Czerner) [809691] {CVE-2012-2100}
- [fs] ext4: fix undefined behavior in ext4_fill_flex_info() (Lukas Czerner) [809691] {CVE-2012-2100}
- [virt] kvm: change PT_FIRST_AVAIL_BITS_SHIFT to avoid conflict with EPT Dirty bit (Don Dugger) [736906]
- [virt] kvm/vmx: Enable EPT A/D bits if supported by turning on relevant bit in EPTP (Don Dugger) [736906]
- [virt] kvm/vmx: Use EPT Access bit in response to memory notifiers (Don Dugger) [736906]
- [virt] kvm/vmx: Add EPT A/D bits definitions (Don Dugger) [736906]
- [virt] kvm/vmx: Add parameter to control A/D bits support, default is on (Don Dugger) [736906]
- [s390] zfcp: disable DIX support (Hendrik Brueckner) [694237]
- [s390] zfcp: non-experimental support for DIF/DIX (Hendrik Brueckner) [694237]
- [s390] zfcp: Introduce experimental support for DIF/DIX (Hendrik Brueckner) [694237]
- [s390] zfcp: Enable data division support for FCP devices (Hendrik Brueckner) [694237]
- [s390] zfcp: Update FCP protocol related code (Hendrik Brueckner) [694237]
- [mm] memcg: count pte references from every member of the reclaimed hierarchy (Jerome Marchand) [808538]
- [mm] make per-memcg LRU lists exclusive (Jerome Marchand) [808538]
- [mm] collect LRU list heads into struct lruvec (Jerome Marchand) [808538]
- [mm] vmscan: convert global reclaim to per-memcg LRU lists (Jerome Marchand) [808538]
- [mm] memcg: remove optimization of keeping the root_mem_cgroup LRU lists empty (Jerome Marchand) [808538]
- [mm] move memcg hierarchy reclaim to generic reclaim code (Jerome Marchand) [808538]
- [mm] memcg: per-priority per-zone hierarchy scan generations (Jerome Marchand) [808538]
- [mm] vmscan: distinguish between memcg triggering reclaim and memcg (Jerome Marchand) [808538]
- [mm] vmscan: distinguish global reclaim from global LRU scanning (Jerome Marchand) [808538]
- [mm] memcg: consolidate hierarchy iteration primitives (Jerome Marchand) [808538]
- [mm] vmscan: remove isolate_pages callback scan control (Jerome Marchand) [808538]
- [mm] memcg: Introduces for_each_mem_cgroup_all (Jerome Marchand) [808538]
- [mm] memcg: use for_each_mem_cgroup (Jerome Marchand) [808538]
- [mm] memcg: extract mem_group_usage() from mem_cgroup_read() (Jerome Marchand) [808538]
- [s390] hugetlb: use direct TLB flushing for hugetlbfs pages (Hendrik Brueckner) [861177]
- [s390] mm: fix user access page-table walk code (Hendrik Brueckner) [861176]
- [s390] dasd: fix pathgroup race (Hendrik Brueckner) [859526]
- [fs] gfs2: Consolidate free block searching functions (Bob Peterson) [848109]
- [fs] gfs2: Fix unclaimed_blocks() wrapping bug and clean up (Bob Peterson) [848109]
- [fs] gfs2: Improve block reservation tracing (Bob Peterson) [848109]
- [fs] gfs2: Fall back to ignoring reservations, if there are no other blocks left (Bob Peterson) [848109]
- [fs] gfs2: Use rbm for gfs2_setbit() (Bob Peterson) [848109]
- [fs] gfs2: Use rbm for gfs2_testbit() (Bob Peterson) [848109]
- [fs] gfs2: Update rgblk_free() to use rbm (Bob Peterson) [848109]
- [fs] gfs2: Update gfs2_get_block_type() to use rbm (Bob Peterson) [848109]
- [fs] gfs2: Replace rgblk_search with gfs2_rbm_find (Bob Peterson) [848109]
- [fs] gfs2: Add structure to contain rgrp, bitmap, offset tuple (Bob Peterson) [848109]
- [fs] gfs2: Eliminate redundant calls to may_grant (Bob Peterson) [848109]
- [fs] gfs2: Combine functions gfs2_glock_dq_wait and wait_on_demote (Bob Peterson) [848109]
- [fs] gfs2: Combine functions gfs2_glock_wait and wait_on_holder (Bob Peterson) [848109]
- [fs] gfs2: inline __gfs2_glock_schedule_for_reclaim (Bob Peterson) [848109]
- [fs] gfs2: change function gfs2_direct_IO to use a normal gfs2_glock_dq (Bob Peterson) [848109]
- [fs] gfs2: Allow more dirty buffers and reduce journal commits (Bob Peterson) [848109]
- [fs] gfs2: eliminate log elements and simplify (Bob Peterson) [848109]
- [fs] gfs2: Eliminate vestigial sd_log_le_rg (Bob Peterson) [848109]
- [fs] gfs2: Make gfs2_log_fake_buf() write the buffer too (Bob Peterson) [848109]
- [fs] gfs2: Move two functions from log.c to lops.c (Bob Peterson) [848109]
- [fs] gfs2: Drop "pull" argument from log_write_header() (Bob Peterson) [848109]
- [fs] gfs2: Add missing static to bd_cmp() (Bob Peterson) [848109]
- [fs] gfs2: Remove rs_requested field from reservations (Bob Peterson) [848109]
- [block] Fix hanging kernel threads in blk_execute_rq() (James Paradis) [855984]
- [target] Fix crash in iblock backstore (Andy Grover) [863221]
- [target] Do not print error if can't load target_core_stgt (Andy Grover) [822075]

* Thu Oct 11 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-330.el6]
- [netdrv] sfc: Fix division by zero when using one RX channel and no SR-IOV (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Backport cleanup (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix calculation of vf_i in map_vi_index() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Correct validation of peer_page_count in efx_vfdi_set_status_page() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add SR-IOV back-end support for SFC9000 family (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Work around bogus 'uninitialised variable' warning (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add support for TX MAC filters (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add support for configuring RX unicast/multicast default filters (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove now-unused filter function (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Implement ethtool RX NFC rules API instead of n-tuple API (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add support for retrieving and removing filters by ID (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Use consistent types for filter IDs, indices and search depths (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Change filter ID generation to satisfy priority semantics of RX NFC (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix assertions in efx_filter_rfs() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix loop condition for efx_filter_search() when !for_insert (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Implement hardware acceleration of RFS (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Limit filter search depth further for performance hints (i.e. RFS) (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Generalise filter spec initialisation (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove filter table IDs from filter functions (Nikolay Aleksandrov) [824042]
- [netdrv] drivers/net: use vzalloc() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Don't try to set filters with search depths we know won't work (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Implement the ethtool RX n-tuple control functions (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add filter table management (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add support for RXFH (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Update cleanup (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix num_tc usage (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: By default refill RX rings as soon as space for a batch (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fill RX rings completely full, rather than to 95 full (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix missing cleanup in failure path of efx_pci_probe() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Do not attempt to flush queues if DMA is disabled (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Log the part number on probe (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove efx_channel::last_eventq_read_ptr (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Run event/IRQ self-test asynchronously when interface is brought up (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Encapsulate access to efx_{channel, nic}::last_irq_cpu in self-test (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Test all event queues in parallel (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Raise self-test timeouts (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove TX completions from adaptive IRQ scoring (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Update comments on efx_rx_packet_gro() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove redundant function efx_nic_has_mc() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix assignment of ip_summed for pre-allocated skbs (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Correct efx_for_each_possible_channel_tx_queue() to skip non-TX channels (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Minor formatting cleanup (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Reverse initial buffer table allocation to allow for later resizing (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Allocate SRAM between buffer table and descriptor caches at init time (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add support for 'extra' channel types (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add support for 'extra' channel types (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Make all CPU/IRQ/channel/queue counts unsigned (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Make buffer table indices and counts consistently unsigned (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Disable flow control during flushes (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Generalise event generation to cover VF-owned event queues (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Use proper function to test for RX channel in efx_poll() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Leave interrupts and event queues enabled whenever we can (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Generate RX fill events based on RX queues, not channels (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Generalise driver event generation (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Warn if unable to create MTDs (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Do not retry hardware probe if it schedules a reset (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Skip RX end-of-batch work on channels without an RX queue (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Use a more sensible cast in efx_rx_buf_offset() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: MTD: Leave the DEBUG macro alone (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Replace efx_rx_buffer::is_page and other booleans with a flags field (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Move the end of the non-GRO RX path into its own function (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove redundant 'rc' variable, always set to 0 (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Minor formatting fixes (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Use existing local variables instead of repeated indirect lookups (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove remnants of on-load self-test (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove obsolete function efx_dev_name() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Update the description of SFC_MTD (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add hwmon driver for boards using SFC9000-family controllers (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Clean up test interrupt handling (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Partly revert "sfc: Handle serious errors in exactly one interrupt handler" (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove dependence on NAPI polling in efx_test_eventq_irq() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Correct interrupt timer quantum for Siena (normal and turbo mode) (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Support extraction of CAPABILITIES from GET_BOARD_CFG response. (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Consistently test DEBUG macro, not EFX_ENABLE_DEBUG (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove efx_nic_type::push_multicast_hash operation (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Merge efx_mcdi_mac_check_fault() and efx_mcdi_get_mac_faults() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Merge efx_mac_operations into efx_nic_type (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Hold efx_nic::stats_lock while reading efx_nic::mac_stats (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Use new names for MC shared memory layout constants (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Make handling of MC reboot more reliable (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove fallback for invalid permanent MAC address (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Set default parallelism to per-core by default (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Rename efx_wanted_channels() to efx_wanted_parallelism() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Update MCDI (firmware interface) definitions (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove unnecessary inclusion of <asm/io.h>, prompted by checkpatch (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Const-qualify static data as appropriate, partly prompted by checkpatch (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove parentheses around return expressions, reported by checkpatch (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Avoid assignment in an if-statement, reported by checkpatch (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix some formatting errors reported by checkpatch (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: fix assignment of 0/1 to bool variables. (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Use skb_fill_page_desc() to simplify passing of page buffers to GRO (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Use kcalloc instead of kzalloc to allocate array (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add moduleparam.h to drivers as required. (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: add skb frag size accessors (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove unnecessary driver assignments of ethtool_ringparam fields to zero (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: use DMA_x_DEVICE and dma_mapping_error with skb_frag_dma_map (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: convert to SKB paged frag API. (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: ethtool: Clean up definitions of rule location arrays in RX NFC (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Use correct fields of struct ethtool_coalesce (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Validate IRQ moderation parameters in efx_init_irq_moderation() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Correct reporting and validation of TX interrupt coalescing (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Use consistent types for interrupt coalescing parameters (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Correct error code for unsupported interrupt coalescing parameters (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove 'Communications' after 'Solarflare' in references to hardware (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove 'Solarstorm' from Kconfig descriptions (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix Siena mac statistics on big endian platforms (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Allow resets to be upgraded; use atomic ops for safety (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove casts of void * (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add appropriate <linux/prefetch.h> include for prefetch users (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Don't use enums as a bitmask. (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Use netif_device_{detach, attach}() around reset and self-test (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix TX queue numbering when separate_tx_channels=1 (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix return value from efx_ethtool_set_rx_ntuple() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: ethtool: cosmetic: Use ethtool ethtool_cmd_speed API (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: ethtool: Use full 32 bit speed range in ethtool's set_settings (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: ethtool: Call ethtool's get/set_settings callbacks with cleaned data (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Fix common misspellings (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Do not use efx_process_channel_now() in online self-test (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Stop the TX queues during loopback self-tests (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: make function tables const (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Enable all TSO features on VLANs (Nikolay Aleksandrov) [824042]
- [netdrv] net: Add NETIF_F_ALL_TSO define to include/linux/netdevice.h (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Move test of rx_checksum_enabled from nic.c to rx.c (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Bump version to 3.1 (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Remove configurable FIFO thresholds for pause frame generation (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Expose TX push and TSO counters through ethtool statistics (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Update copyright dates (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Do not read STAT1.FAULT in efx_mdio_check_mmd() (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Read MC firmware version when requested through ethtool (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Reduce size of efx_rx_buffer further by removing data member (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Reduce size of efx_rx_buffer by unionising skb and page (Nikolay Aleksandrov) [824042]
- [netdrv] Revert "[netdrv] sfc: disable RX hash insertion" (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Add TX queues for high-priority traffic (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Distinguish queue lookup from test for queue existence (Nikolay Aleksandrov) [824042]
- [netdrv] sfc: Move TX queue core queue mapping into tx.c (Nikolay Aleksandrov) [824042]
- [alsa] usb: Enable TerraTec DMX 6Fire USB and Edirol UA-101/UA-1000 drivers (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add endpoint usage definitions to ch9.h (Jaroslav Kysela) [664586]
- [alsa] pcm: Call pgprot_noncached() for vmalloc'ed buffers (Jaroslav Kysela) [664586]
- [alsa] ua101: use vmalloc buffer helper functions (Jaroslav Kysela) [664586]
- [alsa] pcm: add vmalloc buffer helper functions (Jaroslav Kysela) [664586]
- [alsa] usb: use old usb_buffer_alloc()/usb_buffer_free() fcns (Jaroslav Kysela) [664586]
- [alsa] ua101: fix crash when unplugging (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: Select missing SND_VMASTER option in Kconfig (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: Update kernel configuration (Jaroslav Kysela) [664586]
- [alsa] ua101: remove experimental status (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: Fix signedness bug (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: Add support for S32_LE format (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: Fix pcm rate assignment (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: signedness bug in usb6fire_pcm_prepare() (Jaroslav Kysela) [664586]
- [alsa] usb: disable broken hw volume for Tenx TP6911 (Jaroslav Kysela) [664586]
- [alsa] usb: print small buffers via *ph[C] (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: use NULL instead of 0 for pointer assignment (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: don't use custom hex_to_bin() (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: Fix double-free bug in usb6fire_fw_ezusb_upload() (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: Don't leak firmware in error path (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: use the kernel's built-in bit reverse table (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: Improve firmware loader (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: add analog input volume control (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: add mute control for analog outputs (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: add individual volume control for analog channels (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: add tlv to controls (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: Add support of digital-thru mixer (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: remove driver version information (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Avoid unnecessary EP setups in prepare (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Move configuration to prepare. (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Don't require hw_params in endpoint. (Jaroslav Kysela) [664586]
- [alsa] usbaudio: set period_bytes in substream. (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix bogus error messages for delay accounting (Jaroslav Kysela) [664586]
- [alsa] usb: Add quirks for Playback Designs devices (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Support for (original) Xbox Communicator (Jaroslav Kysela) [664586]
- [alsa] usb: fix cross-interface streaming devices (Jaroslav Kysela) [664586]
- [alsa] usb: fix calls to next_packet_size (Jaroslav Kysela) [664586]
- [alsa] usb: restore delay information (Jaroslav Kysela) [664586]
- [alsa] usb: use list_for_each_safe for endpoint resources (Jaroslav Kysela) [664586]
- [alsa] usb: Fix URB cancellation at stream start (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Remove obsoleted fields in struct snd_usb_substream (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix scheduling-while-atomic bug in PCM capture stream (Jaroslav Kysela) [664586]
- [alsa] usb: fix clock source validity index (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: initialize card pointer (Jaroslav Kysela) [664586]
- [alsa] usb: move calls to usb_set_interface (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix the first PCM interface assignment (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add BOSS GT-100 support (Jaroslav Kysela) [664586]
- [alsa] usbaudio: ignore ctrl errors on QuickCam Pro for Notebooks (Jaroslav Kysela) [664586]
- [alsa] usbaudio: ignore ctrl errors on QuickCam E3500 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Convert table to preferred C99 format (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Use a table of mixer controls (Jaroslav Kysela) [664586]
- [alsa] usb: make snd_usb_substream_capture_trigger static (Jaroslav Kysela) [664586]
- [alsa] usb: fix sync pipe check (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix substream assignments (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix rate_list memory leak (Jaroslav Kysela) [664586]
- [alsa] usb: fix stream info output in /proc (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Call get_min_max_*() after determining the name string (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix comment (Jaroslav Kysela) [664586]
- [alsa] usb: fix some typos in endpoint.c documentation (Jaroslav Kysela) [664586]
- [alsa] usbaudio: sound/usb/endpoint.c: suppress warning (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add missing error checks in snd_ebox44_create_mixer() (Jaroslav Kysela) [664586]
- [alsa] usbaudio: M-Audio Fast Track Ultra: Add effect controls (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Rename Fast Track Ultra mixer quirk functions (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add TLV to M-Audio Fast Track Ultra controls (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Rename and export mixer_vol_tlv (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Unify M-Audio Fast Track Ultra and Ebox-44 mixer quirks. (Jaroslav Kysela) [664586]
- [alsa] usb: remove refactorization left-overs (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Replace mixer for Electrix Ebox-44 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Skip un-parseable mixer units instead of erroring (Jaroslav Kysela) [664586]
- [alsa] usb: Remove obsoleted fields from struct snd_usb_substream (Jaroslav Kysela) [664586]
- [alsa] usb: Fix fill_max flag set (Jaroslav Kysela) [664586]
- [alsa] usb: Remove unused variable (Jaroslav Kysela) [664586]
- [alsa] usb: add some documentation (Jaroslav Kysela) [664586]
- [alsa] usb: add support for implicit feedback (Jaroslav Kysela) [664586]
- [alsa] usb: remove old streaming logic (Jaroslav Kysela) [664586]
- [alsa] usb: switch over to new endpoint streaming logic (Jaroslav Kysela) [664586]
- [alsa] usb: implement new endpoint streaming model (Jaroslav Kysela) [664586]
- [alsa] usb: add snd_usb_audio-wide mutex (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix build error by consitification of rate list (Jaroslav Kysela) [664586]
- [alsa] usx2y: Fix typo in usbusx2yaudio.c and usx2yhwdeppcm.c (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: Fix the return of XRUN (Jaroslav Kysela) [664586]
- [alsa] usbaudio: avoid integer overflow in create_fixed_stream_quirk() (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add Edirol UM-3G support (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Avoid flood of frame-active debug messages (Jaroslav Kysela) [664586]
- [alsa] snd-usb-us122l: Delete calls to preempt_disable (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix possible hang and overflow in parse_uac2_sample_rate_range() (Jaroslav Kysela) [664586]
- [alsa] usbaudio: convert sound/* to use module_usb_driver() (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add Yamaha MOX6/MOX8 support (Jaroslav Kysela) [664586]
- [alsa] usb: added VOX ToneLab ST midi handling (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Support for Roland GAIA SH-01 Synthesizer (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Use kmemdup rather than duplicating its implementation (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add Logitech HD Webcam c510 to quirk-384 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix the missing volume quirks at delayed init (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix possible access over audio_feature_info[] array (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: Add support for Maschine (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: Fix NULL dereference in input.c (Jaroslav Kysela) [664586]
- [alsa] usbaudio: increase control transfer timeout (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Check for possible chip NULL pointer before clearing probing flag (Jaroslav Kysela) [664586]
- [alsa] usbaudio: clear chip->probing on error exit (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Added support for Roland UM-ONE midi-usb interface (Jaroslav Kysela) [664586]
- [alsa] usb: move code from urb.c to endpoint.c (Jaroslav Kysela) [664586]
- [alsa] usb: re-order code (Jaroslav Kysela) [664586]
- [alsa] usb: re-order the Makefile (Jaroslav Kysela) [664586]
- [alsa] usb: refine delay information with USB frame counter (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add Starr Labs USB MIDI support (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Check the dB-range validity in the later read, too (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix missing mixer dB information (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: track submitted output urbs (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: Correct offset fields of outbound iso_frame_desc (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add quirk for BOSS Micro BR-80 (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: Fix keymap for RigKontrol3 (Jaroslav Kysela) [664586]
- [alsa] usb: Fix uninitialized variable usage (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add quirk for Keith McMillen StringPort (Jaroslav Kysela) [664586]
- [alsa] usb: operate on given mixer interface only (Jaroslav Kysela) [664586]
- [alsa] usb: avoid dividing by zero on invalid input (Jaroslav Kysela) [664586]
- [alsa] usb: Accept UAC2 FORMAT_TYPE descriptors with bLength > 6 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add quirk for Roland / BOSS BR-800 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add quirks for M-Audio Fast Track Pro and Quattro (Jaroslav Kysela) [664586]
- [alsa] usbaudio: replace "void *" with more specific pointers (Jaroslav Kysela) [664586]
- [alsa] usb: turn off de-emphasis in s/pdif for cm6206 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: more control quirks for M-Audio FastTrack devices (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add new quirk type QUIRK_AUDIO_STANDARD_MIXER (Jaroslav Kysela) [664586]
- [alsa] usbaudio: export snd_usb_feature_unit_ctl (Jaroslav Kysela) [664586]
- [alsa] usbaudio: rework add_control_to_empty() (Jaroslav Kysela) [664586]
- [alsa] usbaudio: move assignment of chip->ctrl_intf (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add support for USB X-Fi S51 Pro (Jaroslav Kysela) [664586]
- [alsa] usbaudio: handle "Fast Track Ultra" with USB_DEVICE_VENDOR_SPEC() (Jaroslav Kysela) [664586]
- [alsa] usbaudio: assume valid clock (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add quirks for Roland GR-55 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add quirk for KORG PANDORA PX5D MIDI interface (Jaroslav Kysela) [664586]
- [alsa] usbaudio: remove invalid extra mixers for Komplete Audio 6 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: include format.h in format.c (Jaroslav Kysela) [664586]
- [alsa] usbaudio: make hwc_debug a noop in case HW_CONST_DEBUG is not set (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Terratec Aureon 7.1 USB ID as C-Media cm6206 quirks (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Don't expose broken dB ranges (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add quirks for Audio Kontrol 6 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: define another USB ID for a buggy USB MIDI cable (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Support for Boss JS-8 Jam Station (Jaroslav Kysela) [664586]
- [alsa] usb: Remove trailing spaces from USB card name strings (Jaroslav Kysela) [664586]
- [alsa] usbaudio: implement USB autosuspend (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix suspend/resume (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add "cval->res = 384" quirk for Logitech Webcam C600 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add volume range check and warn if it too big (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix oops due to cleanup race when disconnecting (Jaroslav Kysela) [664586]
- [alsa] usbaudio: reconstruct some dispatcher functions to use switch-case (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add support for Native Instruments MK2 devices (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: Add support for Traktor Audio 2 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Enable the E-MU 0204 USB (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add Cakewalk UM-1G support (Jaroslav Kysela) [664586]
- [alsa] usb/6fire: Driver for TerraTec DMX 6Fire USB (Jaroslav Kysela) [664586]
- [alsa] snd-usb-us122l: Fix missing NULL checks (Jaroslav Kysela) [664586]
- [alsa] snd-usb-us122l: Fix MIDI output (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add Edirol SD-90 PCM support (Jaroslav Kysela) [664586]
- [alsa] usbaudio: use enum control info helper (Jaroslav Kysela) [664586]
- [alsa] usb: fixed typos (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Support for Power/Status LED on Creative USB X-Fi S51 (Jaroslav Kysela) [664586]
- [alsa] usb: driver neglects kmalloc return value check and may deref NULL (Jaroslav Kysela) [664586]
- [alsa] usbaudio: automatically detect feedback format (Jaroslav Kysela) [664586]
- [alsa] usb: Creative USB X-Fi volume knob support (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add Novation Launchpad support (Jaroslav Kysela) [664586]
- [alsa] usb/usx2y: simplify conditional (Jaroslav Kysela) [664586]
- [alsa] usb/mixer: remove bogus cast (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix an unused-variable compile warning (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add more Yamaha USB MIDI devices (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: Add support for Traktor Kontrol S4 (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: drop version number (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix Fast Track Ultra (8R) 44.1 sample rates (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add BOSS ME-25 support (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add Roland A-PRO support (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add Edirol PCR-1 PCM support (Jaroslav Kysela) [664586]
- [alsa] usb: Release capture substream URBs properly (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix detection of vendor-specific device protocol settings (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Assume first control interface is for audio (Jaroslav Kysela) [664586]
- [alsa] usb: USB3 SuperSpeed sound support (Jaroslav Kysela) [664586]
- [alsa] sound/usb/format: silence uninitialized variable warnings (Jaroslav Kysela) [664586]
- [alsa] usb: Correct audio problem for Hauppage HVR-850 and others rel. to urb data align (Jaroslav Kysela) [664586]
- [alsa] usb: fix comnment/printk typos concerning "empty" (Jaroslav Kysela) [664586]
- [alsa] usbaudio: silence a superfluous warning (Jaroslav Kysela) [664586]
- [alsa] usb: Fix compile error with CONFIG_SND_DEBUG_VERBOSE=y (Jaroslav Kysela) [664586]
- [alsa] usbaudio: simplify control interface access (Jaroslav Kysela) [664586]
- [alsa] usbaudio: move and add some comments (Jaroslav Kysela) [664586]
- [alsa] usb-midi: whitespace fixes (Jaroslav Kysela) [664586]
- [alsa] usbaudio: unify UAC macros and struct names (Jaroslav Kysela) [664586]
- [alsa] usbaudio: clean up includes in clock.c (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add volume resolution quirk for some Logitech webcams (Jaroslav Kysela) [664586]
- [alsa] usb/endpoint: fix dangling pointer use (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix UAC2 control value queries (Jaroslav Kysela) [664586]
- [alsa] usbaudio: parse UAC2 sample rate ranges correctly (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix control messages for USB_RECIP_INTERFACE (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add check for faulty clock in parse_audio_format_rates_v2() (Jaroslav Kysela) [664586]
- [alsa] usbaudio: export UAC2 clock selectors as mixer controls (Jaroslav Kysela) [664586]
- [alsa] usbaudio: clean up find_audio_control_unit() (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add UAC2 sepecific Feature Unit controls (Jaroslav Kysela) [664586]
- [alsa] usbaudio: unify constants from specification (Jaroslav Kysela) [664586]
- [alsa] usbaudio: parse clock topology of UAC2 devices (Jaroslav Kysela) [664586]
- [alsa] usbaudio: support partially write-protected UAC2 controls (Jaroslav Kysela) [664586]
- [alsa] audio-v2.h: add more UAC2 details (Jaroslav Kysela) [664586]
- [alsa] usbaudio: UAC2: clean up parsing of bmaControls (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: Bump version number to 1.3.21 (Jaroslav Kysela) [664586]
- [alsa] Revert: snd-usb-caiaq: Set default input mode of A4DJ (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: Simplify single case to an 'if' (Jaroslav Kysela) [664586]
- [alsa] snd-usb-caiaq: Restore 'Control vinyl' input mode on A4DJ (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix feature unit parser for UAC2 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add support for UAC2 pitch control (Jaroslav Kysela) [664586]
- [alsa] usbaudio: parse UAC2 endpoint descriptors correctly (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix return values (Jaroslav Kysela) [664586]
- [alsa] usbaudio: parse more format descriptors with structs (Jaroslav Kysela) [664586]
- [alsa] usb/caiaq: fix Traktor Kontrol X1 ABS_HAT2X axis (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add support for Akai MPD16 (Jaroslav Kysela) [664586]
- [alsa] usb: fixup for usb_buffer_alloc/free rename (Jaroslav Kysela) [664586]
- [alsa] usbaudio: fix selector unit string index accessor (Jaroslav Kysela) [664586]
- [alsa] usbaudio: include/usb/*.h checkpatch cleanup (Jaroslav Kysela) [664586]
- [alsa] sound/usb: add preliminary support for UAC2 interrupts (Jaroslav Kysela) [664586]
- [alsa] audio.h: add __attribute__((packed)) to uac_iso_endpoint_descriptor (Jaroslav Kysela) [664586]
- [alsa] sound/usb: fix UAC1 regression (Jaroslav Kysela) [664586]
- [alsa] usbmixer: use get_iface_desc() rather than direct structure (Jaroslav Kysela) [664586]
- [alsa] usb: update gfp/slab.h includes (Jaroslav Kysela) [664586]
- [alsa] usb pcm: use of kmalloc requires the include of slab.h (Jaroslav Kysela) [664586]
- [alsa] usb: use of kmalloc/kfree requires the include of slab.h (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Add basic support for M-Audio Fast Track Ultra series (Jaroslav Kysela) [664586]
- [alsa] usb-mixer: Add support for Audio Class v2.0 (Jaroslav Kysela) [664586]
- [alsa] usb-mixer: parse descriptors with structs (Jaroslav Kysela) [664586]
- [alsa] usbmixer: rename usbmixer.[ch] -> mixer.[ch] (Jaroslav Kysela) [664586]
- [alsa] usb-mixer: use defines from audio.h (Jaroslav Kysela) [664586]
- [alsa] usb: fix usb build error when PM is not enabled (Jaroslav Kysela) [664586]
- [alsa] audio.h: split parts of header into audio-v2.h (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add support for samplerate setting on v2 devices (Jaroslav Kysela) [664586]
- [alsa] usbaudio: support multiple formats with audio class v2 devices (Jaroslav Kysela) [664586]
- [alsa] usbaudio: use a format bitmask per alternate setting (Jaroslav Kysela) [664586]
- [alsa] usbaudio: rename substream format field to altset_idx (Jaroslav Kysela) [664586]
- [alsa] usb-mixer: factor out quirks (Jaroslav Kysela) [664586]
- [alsa] usbaudio: refactor code (Jaroslav Kysela) [664586]
- [alsa] usbaudio: header file cleanups (Jaroslav Kysela) [664586]
- [alsa] usbaudio: move ua101 driver (Jaroslav Kysela) [664586]
- [alsa] usb/caiaq: Add support for Traktor Kontrol X1 (Jaroslav Kysela) [664586]
- [alsa] ua101: add Edirol UA-1000 support (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Fix wrong bitrate for Creative Creative VF0470 Live Cam (Jaroslav Kysela) [664586]
- [alsa] sound/usb/caiaq/midi.h: Checkpatch cleanup (Jaroslav Kysela) [664586]
- [alsa] usbaudio: remove debug "SAMPLE BYTES" printk line (Jaroslav Kysela) [664586]
- [alsa] audio.h: Fix field order in uac_format_type_i_ext_descriptor (Jaroslav Kysela) [664586]
- [alsa] usbaudio: consolidate header files (Jaroslav Kysela) [664586]
- [alsa] usbmixer: bail out early when parsing audio class v2 descriptors (Jaroslav Kysela) [664586]
- [alsa] usbaudio: implement basic set of class v2.0 parser (Jaroslav Kysela) [664586]
- [alsa] usbaudio: introduce new types for audio class v2 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: parse USB descriptors with structs (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Mbox support, output only (Jaroslav Kysela) [664586]
- [alsa] usbmixer: use MAX_ID_ELEMS where possible (Jaroslav Kysela) [664586]
- [alsa] usbmixer: add usb_id value to usbmixer proc file (Jaroslav Kysela) [664586]
- [alsa] usbmixer: introduce /proc/asound/card#/usbmixer file (Jaroslav Kysela) [664586]
- [alsa] usbaudio: MIDI support for Access Music VirusTI (Jaroslav Kysela) [664586]
- [alsa] usbaudio: reduce MIDI packet size to work around broken firmware (Jaroslav Kysela) [664586]
- [alsa] usbmixer: add possibility to remap dB values (Jaroslav Kysela) [664586]
- [alsa] usbaudio: use usbquirk.h for detection of HVR-950Q/850 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: relax urb data align. restriction HVR-950Q and HVR-850 only (Jaroslav Kysela) [664586]
- [alsa] usbaudio: make buffer pointer based on bytes instead on frames (Jaroslav Kysela) [664586]
- [alsa] usbaudio: Added functionality for E-mu 0404USB/0202USB/TrackerPre (Jaroslav Kysela) [664586]
- [alsa] usbaudio: use vmalloc buffer helper functions (Jaroslav Kysela) [664586]
- [alsa] add Edirol UA-101 support (Jaroslav Kysela) [664586]
- [alsa] snd-usb-us122l: add product IDs of US-122MKII and US-144MKII (Jaroslav Kysela) [664586]
- [alsa] usb: Fix mixer map for Hercules Gamesurround Muse Pocket LT (Jaroslav Kysela) [664586]
- [alsa] usbmidi: Use hweight16 (Jaroslav Kysela) [664586]
- [alsa] usbaudio: add Roland UA-1G support (Jaroslav Kysela) [664586]
- [alsa] usxxx: cleanup chip field (Jaroslav Kysela) [664586]
- [alsa] usb: make the USB MIDI module more independent (0/268) (Jaroslav Kysela) [664586]
- [alsa] usbaudio: allow switching altsetting on Roland USB MIDI devices (Jaroslav Kysela) [664586]
- [alsa] snd-usb-us122l: corrent error number for not probing US-144 on ehci-hcd (Jaroslav Kysela) [664586]
- [alsa] snd-usb-us122l: add support for US-144 (Jaroslav Kysela) [664586]

* Thu Oct 11 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-329.el6]
- [char] ipmi: Fix KABI issues with acpi_ipmi addition (Matthew Garrett) [803653]
- [acpi] acpi_ipmi: Add a default handler for IPMI operation regions (Matthew Garrett) [803653]
- [char] ipmi: Add a callback to indicate that probing has finished (Matthew Garrett) [803653]
- [acpi] ipmi: Reorder makefiles (Matthew Garrett) [803653]
- [acpi] acpi_ipmi: Add the IPMI opregion driver to enable ACPI to access BMC controller (Matthew Garrett) [803653]
- [char] ipmi: Add one interface to get more info of low-level IPMI device (Matthew Garrett) [803653]
- [char] ipmi: fix ACPI detection with regspacing (Matthew Garrett) [803653]
- [char] ipmi: convert tracking of the ACPI device pointer to a PNP device (Matthew Garrett) [803653]
- [char] ipmi: add PNP discovery (ACPI namespace via PNPACPI) (Matthew Garrett) [803653]
- [pnp] pnpacpi: add interface to retrieve ACPI device from a PNPACPI device (Matthew Garrett) [803653]
- [pnp] pnpacpi: save struct acpi_device, not just acpi_handle (Matthew Garrett) [803653]
- [mm] hugetlb: do not use vma_hugecache_offset() for vma_prio_tree_foreach (Frederic Weisbecker) [843035] {CVE-2012-2133}
- [mm] hugepages: fix use after free bug in "quota" handling (Frederic Weisbecker) [843035] {CVE-2012-2133}
- [mm] hugetlb: fix pgoff computation when unmapping page from vma (Frederic Weisbecker) [843035] {CVE-2012-2133}
- [mm] hugetlb: fix ENOSPC returned by handle_mm_fault() (Frederic Weisbecker) [843035] {CVE-2012-2133}
- [block] loop: remove the incorrect write_begin/write_end shortcut (Lukas Czerner) [766815]
- [block] loop: Fix discard_alignment default setting (Lukas Czerner) [766815]
- [block] loop: fix loop block driver discard and encryption comment (Lukas Czerner) [766815]
- [block] loop: add discard support for loop devices (Lukas Czerner) [766815]
- [s390] dasd: check count address during online setting (Hendrik Brueckner) [853234]
- [scsi] fix softlockup regression on hot remove (Chris Leech) [863077]

* Tue Oct 09 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-328.el6]
- [netdrv] qlge: fix endian issue (Chad Dupuis) [826571]
- [netdrv] qlge: Bumped driver version to 1.00.00.31 (Chad Dupuis) [826571]
- [netdrv] qlge: Refactoring of ethtool stats (Chad Dupuis) [826571]
- [netdrv] qlge: Moving low level frame error to ethtool statistics (Chad Dupuis) [826571]
- [netdrv] qlge: Fixed double pci free upon tx_ring->q allocation failure (Chad Dupuis) [826571]
- [netdrv] qlge: Added missing case statement to ethtool get_strings (Chad Dupuis) [826571]
- [netdrv] qlge: Clean up ethtool set WOL routine (Chad Dupuis) [826571]
- [netdrv] qlge: Fix ethtool WOL calls to operate only on devices that support WOL (Chad Dupuis) [826571]
- [netdrv] qlge: Cleanup atomic queue threshold check (Chad Dupuis) [826571]
- [netdrv] qlge: Fix TX queue stoppage due to full condition (Chad Dupuis) [826571]
- [virt] virtio-scsi: fix copying of sg_list in the presence of of HighMem pages (Paolo Bonzini) [816059 840458]
- [virt] virtio-scsi: support online resizing of disks (Paolo Bonzini) [840458]
- [virt] virtio-scsi: initialize scatterlist structure for events (Paolo Bonzini) [840458]
- [virt] virtio-scsi: hotplug support for virtio-scsi (Paolo Bonzini) [840458]
- [virt] virtio-scsi: split scatterlist per target (Paolo Bonzini) [841622]
- [virt] virtio-scsi: release sg_lock after add_buf (Paolo Bonzini) [841622]
- [virt] virtio-scsi: split locking per vq (Paolo Bonzini) [841622]
- [virt] virtio-scsi: unlock during kick (Paolo Bonzini) [841622]
- [virt] virtio: support unlocked queue kick (Paolo Bonzini) [841622]
- [virt] kvm: Add PCIDE bit to the guest/host mask for CR4 (Don Dugger) [736907]
- [virt] kvm/vmx: Implement PCID/INVPCID for guests with EPT (Don Dugger) [736907]
- [virt] kvm: Add cpuid_update() callback to kvm_x86_ops (Don Dugger) [736907]
- [virt] kvm: expose Intel cpu new features (HLE, RTM) to guest (Don Dugger) [736907]
- [virt] kvm: retain pvclock guest stopped bit in guest memory (Amit Shah) [739151]
- [virt] kvm: fix pvclock guest stopped flag reporting (Amit Shah) [739151]
- [virt] kvmclock: remove check_and_clear_guest_paused warning (Amit Shah) [739151]
- [virt] kvmclock: remove unneeded EXPORT macro (Amit Shah) [739151]
- [virt] watchdog: add check for suspended vm in softlockup detector (Amit Shah) [739151]
- [virt] kvm: Add ioctl for KVM_KVMCLOCK_CTRL (Amit Shah) [739151]
- [virt] kvmclock: Add functions to check if the host has stopped the vm (Amit Shah) [739151]
- [virt] x86, pvclock: Add flag to indicate that a vm was stopped by the host (Amit Shah) [739151]
- [scsi] mpt2sas: Bump driver vesion to 13.101.00.00 (Tomas Henzl) [826414]
- [scsi] mpt2sas: Fix for panic happening because of improper memory allocation (Tomas Henzl) [826414]
- [scsi] mpt2sas: Fix for hard drive going OFFLINE when hard reset issued and simultaneously another hard drive is hot unplugged (Tomas Henzl) [826414]
- [scsi] mpt2sas: Set the phy identifier of the end device to the phy number of the parent device it is linked to (Tomas Henzl) [826414]
- [scsi] mpt2sas: While enabling phy, read the current port number from sas iounit page 0 instead of page 1 (Tomas Henzl) [826414]
- [scsi] mpt2sas: Fix linux driver sparse errors (Tomas Henzl) [826414]
- [scsi] mpt2sas: Fix security scan issues reported by source code analysis tool (Tomas Henzl) [826414]
- [scsi] mpt2sas: better protect sas_device, raid_device, and expander_device lists (Tomas Henzl) [826414]
- [scsi] mpt2sas: Perform Target Reset instead of HBA reset when a SATA_PASSTHROUGH cmd timeout happens (Tomas Henzl) [826414]
- [scsi] mpt2sas: Added multisegment mode support for Linux BSG Driver (Tomas Henzl) [826414]
- [scsi] mpt2sas: Removed redundant global mutex for IOCTLs (Tomas Henzl) [826414]
- [scsi] mpt2sas: MPI next revision header update (Tomas Henzl) [826414]
- [scsi] mpt2sas: use pci_dev->revision (Tomas Henzl) [826414]
- [scsi] mpt2sas: remove extraneous sas_log_info messages (Tomas Henzl) [826414]
- [scsi] mpt2sas: spell "primitive" correctly in function prototype (Tomas Henzl) [826414]
- [scsi] mpt2sas: Fix mismatch in mpt2sas_base_hard_reset_handler() mutex lock-unlock (Tomas Henzl) [826414]
- [netdrv] bnx2x: fix rx performance regression due to small ring size (Michal Schmidt) [862244]

* Tue Oct 09 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-327.el6]
- [fs] xfs: handle EOF correctly in xfs_vm_writepage (Dave Chinner) [859242]
- [fs] xfs: really fix the cursor leak in xfs_alloc_ag_vextent_near (Dave Chinner) [859242]
- [fs] xfs: fix allocbt cursor leak in xfs_alloc_ag_vextent_near (Dave Chinner) [859242]
- [fs] xfs: kill copy and paste segment checks in xfs_file_aio_read (Dave Chinner) [859242]
- [fs] xfs: xfs_vm_writepage clear iomap_valid when !buffer_uptodate (REV2) (Dave Chinner) [859242]
- [fs] xfs: switch to proper __bitwise type for KM_... flags (Dave Chinner) [859242]
- [fs] xfs: add trace points for log forces (Dave Chinner) [859242]
- [fs] xfs: fix memory reclaim deadlock on agi buffer (Dave Chinner) [859242]
- [fs] xfs: stop the sync worker before xfs_unmountfs (Dave Chinner) [737529]
- [fs] xfs: flush outstanding buffers on log mount failure (Dave Chinner) [737529]
- [fs] xfs: prevent recursion in xfs_buf_iorequest (Dave Chinner) [859242]
- [fs] xfs: Properly exclude IO type flags from buffer flags (Dave Chinner) [859242]
- [fs] xfs: use iolock on XFS_IOC_ALLOCSP calls (Dave Chinner) [859242]
- [fs] xfs: use kmem_zone_zalloc for buffers (Dave Chinner) [859242]
- [fs] xfs: fix incorrect b_offset initialisation (Dave Chinner) [859242]
- [fs] xfs: check for buffer errors before waiting (Dave Chinner) [859242]
- [fs] xfs: fix buffer lookup race on allocation failure (Dave Chinner) [859242]
- [fs] xfs: Use preallocation for inodes with extsz hints (Dave Chinner) [859242]
- [fs] xfs: limit specualtive delalloc to maxioffset (Dave Chinner) [859242]
- [fs] xfs: don't assert on delalloc regions beyond EOF (Dave Chinner) [859242]
- [fs] xfs: prevent needless mount warning causing test failures (Dave Chinner) [859242]
- [fs] xfs: punch new delalloc blocks out of failed writes inside EOF. (Dave Chinner) [859242]
- [fs] xfs: page type check in writeback only checks last buffer (Dave Chinner) [859242]
- [fs] xfs: using GFP_NOFS for blkdev_issue_flush (Dave Chinner) [859242]
- [fs] xfs: punch all delalloc blocks beyond EOF on write failure. (Dave Chinner) [859242]
- [fs] xfs: use shared ilock mode for direct IO writes by default (Dave Chinner) [807503]
- [fs] xfs: push the ilock into xfs_zero_eof (Dave Chinner) [807503]
- [fs] xfs: reduce ilock hold times in xfs_setattr_size (Dave Chinner) [807503]
- [fs] xfs: reduce ilock hold times in xfs_file_aio_write_checks (Dave Chinner) [807503]
- [fs] xfs: avoid taking the ilock unnessecarily in xfs_qm_dqattach (Dave Chinner) [807503]
- [fs] xfs: Ensure inode reclaim can run during quotacheck (Dave Chinner) [859242]
- [fs] xfs: don't fill statvfs with project quota for a directory (Dave Chinner) [859242]
- [fs] xfs: add lots of attribute trace points (Dave Chinner) [859242]
- [fs] xfs: fix fstrim offset calculations (Dave Chinner) [859242]
- [fs] xfs: Account log unmount transaction correctly (Dave Chinner) [859242]
- [fs] xfs: trace xfs_name strings correctly (Dave Chinner) [859242]
- [fs] xfs: don't defer metadata allocation to the workqueue (Dave Chinner) [693280]
- [fs] xfs: introduce an allocation workqueue (Dave Chinner) [693280]
- [fs] xfs: Fix open flag handling in open_by_handle code (Dave Chinner) [859242]
- [fs] xfs: fix deadlock in xfs_rtfree_extent (Dave Chinner) [859242]
- [fs] xfs: fallback to vmalloc for large buffers in xfs_getbmap (Dave Chinner) [858353]
- [fs] xfs: fallback to vmalloc for large buffers in xfs_attrmulti_attr_get (Dave Chinner) [858353]
- [fs] xfs: reimplement fdatasync support (Dave Chinner) [845233]
- [fs] xfs: split in-core and on-disk inode log item fields (Dave Chinner) [845233]
- [fs] xfs: make xfs_inode_item_size idempotent (Dave Chinner) [845233]
- [fs] xfs: log timestamp updates (Dave Chinner) [845233]
- [fs] xfs: log file size updates at I/O completion time (Dave Chinner) [845233]
- [fs] xfs: log file size updates as part of unwritten extent conversion (Dave Chinner) [845233]
- [fs] xfs: do not require an ioend for new EOF calculation (Dave Chinner) [845233]
- [fs] xfs: only take the ILOCK in xfs_reclaim_inode() (Dave Chinner) [845233]
- [fs] xfs: split and cleanup xfs_log_reserve (Dave Chinner) [854465]
- [fs] xfs: share code for grant head availability checks (Dave Chinner) [854465]
- [fs] xfs: share code for grant head wakeups (Dave Chinner) [854465]
- [fs] xfs: share code for grant head waiting (Dave Chinner) [854465]
- [fs] xfs: add xlog_grant_head_wake_all (Dave Chinner) [854465]
- [fs] xfs: add xlog_grant_head_init (Dave Chinner) [854465]
- [fs] xfs: add the xlog_grant_head structure (Dave Chinner) [854465]
- [fs] xfs: remove log space waitqueues (Dave Chinner) [854465]
- [fs] xfs: cleanup xfs_log_space_wake (Dave Chinner) [854465]
- [fs] xfs: remove xfs_trans_unlocked_item (Dave Chinner) [854465]
- [fs] xfs: do exact log space wakeups in xlog_ungrant_log_space (Dave Chinner) [854465]
- [fs] xfs: split tail_lsn assignments from log space wakeups (Dave Chinner) [854465]
- [fs] xfs: xfs_trans_add_item() - don't assign in ASSERT() when compare is intended (Dave Chinner) [859242]
- [fs] xfs: show uuid when mount fails due to duplicate uuid (Dave Chinner) [859242]
- [fs] xfs: pass KM_SLEEP flag to kmem_realloc() in xlog_recover_add_to_cnt_trans() (Dave Chinner) [859242]
- [fs] xfs: cleanup xfs_file_aio_write (Dave Chinner) [845233]
- [fs] xfs: always return with the iolock held from xfs_file_aio_write_checks (Dave Chinner) [845233]
- [fs] xfs: remove the i_new_size field in struct xfs_inode (Dave Chinner) [845233]
- [fs] xfs: remove the i_size field in struct xfs_inode (Dave Chinner) [845233]
- [fs] xfs: make i_flags an unsigned long (Dave Chinner) [845233]
- [fs] xfs: fix force shutdown handling in xfs_end_io (Dave Chinner) [845233]
- [fs] xfs: simplify xfs_qm_detach_gdquots (Dave Chinner) [859242]
- [fs] xfs: make sure to really flush all dquots in xfs_qm_quotacheck (Dave Chinner) [859242]
- [fs] xfs: untangle SYNC_WAIT and SYNC_TRYLOCK meanings for xfs_qm_dqflush (Dave Chinner) [859242]
- [fs] xfs: fix allocation length overflow in xfs_bmapi_write() (Dave Chinner) [859242]
- [fs] xfs: do not flush data workqueues in xfs_flush_buftarg (Dave Chinner) [859242]
- [fs] xfs: use xfs_ioerror_alert in xfs_buf_iodone_callbacks (Dave Chinner) [859242]
- [fs] xfs: clean up xfs_ioerror_alert (Dave Chinner) [859242]
- [fs] xfs: clean up buffer allocation (Dave Chinner) [859242]
- [fs] xfs: optimize fsync on directories (Dave Chinner) [859242]
- [fs] xfs: reduce the number of log forces from tail pushing (Dave Chinner) [859242]
- [fs] xfs: Dont allocate new buffers on every call to _xfs_buf_find (Dave Chinner) [859242]
- [fs] xfs: XFS_TRANS_SWAPEXT is not a valid flag for xfs_trans_commit (Dave Chinner) [859242]
- [fs] xfs: don't ignore error code from xfs_bmbt_update (Dave Chinner) [859242]
- [fs] xfs: Check the return value of xfs_trans_get_buf() (Dave Chinner) [859242]
- [fs] xfs: Check the return value of xfs_buf_get() (Dave Chinner) [859242]
- [fs] xfs: improve ioend error handling (Dave Chinner) [807503]
- [fs] xfs: wait for I/O completion when writing out pages in xfs_setattr_size (Dave Chinner) [807503]
- [fs] xfs: reduce ioend latency (Dave Chinner) [807503]
- [fs] xfs: defer AIO/DIO completions (Dave Chinner) [807503]
- [fs] xfs: remove dead ENODEV handling in xfs_destroy_ioend (Dave Chinner) [807503]
- [fs] xfs: Fix oops on IO error during xlog_recover_process_iunlinks() (Dave Chinner) [859242]
- [fs] xfs: fix nfs export of 64-bit inodes numbers on 32-bit kernels (Dave Chinner) [859242]
- [fs] xfs: fix attr2 vs large data fork assert (Dave Chinner) [859242]
- [fs] xfs: use doalloc flag in xfs_qm_dqattach_one() (Dave Chinner) [859242]
- [fs] xfs: Return -EIO when xfs_vn_getattr() failed (Dave Chinner) [859242]
- [fs] xfs: use a cursor for bulk AIL insertion (Dave Chinner) [859242]
- [fs] xfs: start periodic workers later (Dave Chinner) [859242]
- [fs] xfs: fix possible overflow in xfs_ioc_trim() (Dave Chinner) [700324]
- [fs] xfs: fix endian conversion issue in discard code (Dave Chinner) [700324]
- [fs] xfs: do not discard alloc btree blocks (Dave Chinner) [700324]
- [fs] xfs: add online discard support (Dave Chinner) [700324]
- [fs] xfs: fix buffer flushing during unmount (Dave Chinner) [737529]
- [fs] xfs: force buffer writeback before blocking on the ilock in inode reclaim (Dave Chinner) [737529]
- [fs] xfs: fix xfs_mark_inode_dirty during umount (Dave Chinner) [737529]
- [fs] xfs: fix error handling for synchronous writes (Dave Chinner) [845233]
- [fs] xfs: log all dirty inodes in xfs_fs_sync_fs (Dave Chinner) [845233]
- [fs] xfs: log the inode in ->write_inode calls for kupdate (Dave Chinner) [845233]
- [fs] xfs: fix ->write_inode return values (Dave Chinner) [845233]
- [fs] Documentation: Correct s_umount state for freeze_fs/unfreeze_fs (Eric Sandeen) [768304]
- [fs] missed mnt_drop_write() in do_dentry_open() (Eric Sandeen) [768304]
- [fs] ext2: Implement freezing (Eric Sandeen) [768304]
- [fs] btrfs: Convert to new freezing mechanism (Eric Sandeen) [768304]
- [fs] fuse: Convert to new freezing mechanism (Eric Sandeen) [768304]
- [fs] ext3: Enable the new freeze paths w/ the special KABI flag (Eric Sandeen) [768304]
- [fs] gfs2: Convert to new freezing mechanism (Eric Sandeen) [768304]
- [fs] xfs: Convert to new freezing code (Eric Sandeen) [768304]
- [fs] ext4: Convert to new freezing mechanism (Eric Sandeen) [768304]
- [fs] ext4: allow an active handle to be started when freezing (Eric Sandeen) [768304]
- [fs] ext4: fix freeze deadlock under IO (Eric Sandeen) [768304]
- [fs] ext4: don't return to userspace after freezing the fs with a mutex held (Eric Sandeen) [768304]
- [fs] Use old freeze mechanism when appropriate (Eric Sandeen) [768304]
- [fs] Protect write paths by sb_start_write - sb_end_write (Eric Sandeen) [768304]
- [fs] Skip atime update on frozen filesystem (Eric Sandeen) [768304]
- [fs] Add freezing handling to mnt_want_write() / mnt_drop_write() (Eric Sandeen) [768304]
- [fs] Add old freeze paths back in; use if FS_HAS_NEW_FREEZE fs flag is not set (Eric Sandeen) [768304]
- [fs] Improve filesystem freezing handling (Eric Sandeen) [768304]
- [fs] Move grabbing s_umount to callers of grab_super() (Eric Sandeen) [768304]
- [fs] get rid of open-coded grab_super() in get_active_super() (Eric Sandeen) [768304]
- [fs] nfsd: Push mnt_want_write() outside of i_mutex (Eric Sandeen) [768304]
- [fs] new helpers: fh_{want,drop}_write() (Eric Sandeen) [768304]
- [fs] nfsd: link returns nfserr_delay when breaking lease (Eric Sandeen) [768304]
- [fs] nfsd: don't leak dentry count on mnt_want_write failure (Eric Sandeen) [768304]
- [fs] btrfs: Push mnt_want_write() outside of i_mutex (Eric Sandeen) [768304]
- [fs] fat: Push mnt_want_write() outside of i_mutex (Eric Sandeen) [768304]
- [fs] Push mnt_want_write() outside of i_mutex (Eric Sandeen) [768304]
- [fs] mm: Continue to update file time in fault paths for OOT filesystems (Eric Sandeen) [768304]
- [fs] mm: Make default vm_ops provide ->page_mkwrite handler (Eric Sandeen) [768304]
- [fs] mm: Update file times from fault path only if .page_mkwrite is not set (Eric Sandeen) [768304]
- [fs] sysfs: Push file_update_time() into bin_page_mkwrite() (Eric Sandeen) [768304]
- [fs] gfs2: Push file_update_time() into gfs2_page_mkwrite() (Eric Sandeen) [768304]
- [fs] Push file_update_time() into __block_page_mkwrite() (Eric Sandeen) [768304]
- [fs] fb_defio: Push file_update_time() into fb_deferred_io_mkwrite() (Eric Sandeen) [768304]
- [fs] pipe: block pipe_write() on a frozen filesystem (Eric Sandeen) [768304]
- [fs] namespace.c: avoid panic for NULL mnt_ns in do_add_mount() (Eric Sandeen) [732340]
- [fs] ext4: always set then trimmed blocks count into len (Lukas Czerner) [858012]
- [fs] ext4: fix trimmed block count accounting (Lukas Czerner) [858012]
- [fs] ext4: fix start and len arguments handling in ext4_trim_fs() (Lukas Czerner) [858012]
- [fs] xfs: fix race while discarding buffers (Carlos Maiolino) [829066]
- [fs] gfs2: Write out dirty inode metadata in delayed deletes (Robert S Peterson) [748827]

* Tue Oct 09 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-326.el6]
- [mm] vmscan: add in_reclaim_compaction (Rik van Riel) [713546 783248]
- [mm] vmscan: stop reclaim/compaction earlier due to insufficient progress if !__GFP_REPEAT (Rik van Riel) [713546 783248]
- [usb] ch9: define Set SEL and Set Isoch Delay macros (Don Zickus) [836217]
- [usb] ch9: add function defines from ch9, USB 3.0 spec (Don Zickus) [836217]
- [usb] xhci: fix compilation error for non-PCI based stacks (Don Zickus) [836217]
- [usb] xhci: use ioremap_nocache in xhci-plat (Don Zickus) [836217]
- [usb] xhci: Fix Compliance Mode on SN65LVPE502CP Hardware (Don Zickus) [836217]
- [usb] xhci: Make handover code more robust (Don Zickus) [836217]
- [usb] xhci: Fix a logical vs bitwise AND bug (Don Zickus) [836217]
- [usb] xhci: Only switch the switchable ports (Don Zickus) [836217]
- [usb] xhci: Recognize USB 3.0 devices as superspeed at powerup (Don Zickus) [836217]
- [usb] xhci: Switch PPT ports to EHCI on shutdown (Don Zickus) [836217]
- [usb] xhci: Fix bug after deq ptr set to link TRB (Don Zickus) [836217]
- [usb] xhci: Add Etron XHCI_TRUST_TX_LENGTH quirk (Don Zickus) [836217]
- [usb] xhci: Increase reset timeout for Renesas 720201 host (Don Zickus) [836217]
- [usb] Add a sysfs file to show LTM capabilities (Don Zickus) [815470]
- [usb] Enable Latency Tolerance Messaging (LTM) (Don Zickus) [815470]
- [usb] xhci: Export Latency Tolerance Messaging capabilities (Don Zickus) [815470]
- [usb] xhci: Fix hang on back-to-back Set TR Deq Ptr commands (Don Zickus) [836217]
- [usb] xhci: Add support for root hub port status CAS (Don Zickus) [836217]
- [usb] xhci: Increase the timeout for controller save/restore state operation (Don Zickus) [836217]
- [usb] xhci: Don't free endpoints in xhci_mem_cleanup() (Don Zickus) [836217]
- [usb] xhci: Fix invalid loop check in xhci_free_tt_info() (Don Zickus) [836217]
- [usb] xhci: fix resource leak in xhci power loss path (Don Zickus) [836217]
- [usb] enable USB2 LPM if port suspend fails (Don Zickus) [836217]
- [usb] xhci: Add new short TX quirk for Fresco Logic host (Don Zickus) [836217]
- [usb] xhci: testing sizeof xhci_doorbell_array 2 time (Don Zickus) [836217]
- [usb] xhci: print URB's expected length in decimal, not hex (Don Zickus) [836217]
- [usb] xhci: Add Lynx Point to list of Intel switchable hosts (Don Zickus) [817872]
- [usb] xhci: Handle COMP_TX_ERR for isoc tds (Don Zickus) [836217]
- [usb] xhci: keep track of ports being resumed and indicate in hub_status_data (Don Zickus) [836217]
- [usb] xhci: Correct the #define XHCI_LEGACY_DISABLE_SMI (Don Zickus) [836217]
- [usb] xhci: use gfp flags from caller instead of GFP_ATOMIC (Don Zickus) [836217]
- [usb] xhci: add XHCI_RESET_ON_RESUME quirk for VIA xhci host (Don Zickus) [836217]
- [usb] fix bug of device descriptor got from superspeed device (Don Zickus) [836217]
- [usb] xhci: Fix register save/restore order (Don Zickus) [836217]
- [usb] xhci: Restore event ring dequeue pointer on resume (Don Zickus) [836217]
- [usb] xhci: Don't write zeroed pointers to xHC registers (Don Zickus) [836217]
- [usb] xhci: Warn when hosts don't halt (Don Zickus) [836217]
- [usb] xhci: don't re-enable IE constantly (Don Zickus) [836217]
- [usb] xhci: fix section mismatch in xhci-pci (Don Zickus) [836217]
- [usb] xhci: correct to print the true HSEE of USBCMD (Don Zickus) [836217]
- [usb] Don't make USB_ARCH_HAS_{XHCI, OHCI, EHCI} depend on USB_SUPPORT (Don Zickus) [836217]
- [usb] xhci: add platform driver support (Don Zickus) [836217]
- [usb] xhci: update sg tablesize (Don Zickus) [836217]
- [usb] xhci: check enqueue pointer advance into dequeue seg (Don Zickus) [836217]
- [usb] xhci: Allocate 2 segments for transfer ring (Don Zickus) [836217]
- [usb] xhci: dynamic ring expansion (Don Zickus) [836217]
- [usb] xhci: set cycle state when allocate rings (Don Zickus) [836217]
- [usb] xhci: factor out segments allocation and free function (Don Zickus) [836217]
- [usb] xhci: count free TRBs on transfer ring (Don Zickus) [836217]
- [usb] xhci: store ring's last segment and segment numbers (Don Zickus) [836217]
- [usb] xhci: store ring's type (Don Zickus) [836217]
- [usb] xhci: use __ffs() instead of hardcoding shift (Don Zickus) [836217]
- [usb] xhci: BESL calculation based on USB2.0 LPM errata (Don Zickus) [836217]
- [usb] Set wakeup bits for all children hubs (Don Zickus) [836217]
- [usb] xhci: Support device-initiated USB 3.0 resume (Don Zickus) [836217]
- [usb] Refactor hub remote wake handling (Don Zickus) [836217]
- [usb] xhci: Enable USB 3.0 hub remote wakeup (Don Zickus) [836217]
- [usb] Suspend functions before putting dev into U3 (Don Zickus) [836217]
- [usb] xhci: Enable remote wakeup for USB3 devices (Don Zickus) [836217]
- [usb] xhci: Kick khubd when USB3 resume really completes (Don Zickus) [836217]
- [usb] Adding #define in hub_configure() and hcd.c file (Don Zickus) [836217]
- [fs] ext4: fix failure exits (Lukas Czerner) [859545]
- [fs] ext4: Free resources in some error path in ext4_fill_super (Lukas Czerner) [859545]
- [fs] ext4: fix missing iput of root inode for some mount error paths (Lukas Czerner) [859545]
- [fs] ext4: avoid hangs in ext4_da_should_update_i_disksize() (Lukas Czerner) [859545]
- [fs] ext4: display the correct mount option in /proc/mounts for [no]init_itable (Lukas Czerner) [859545]
- [fs] ext4: fix ext4_end_io_dio() racing against fsync() (Lukas Czerner) [859545]
- [fs] ext4: fix racy use-after-free in ext4_end_io_dio() (Lukas Czerner) [859545]
- [fs] ext4: initialization of ext4_li_mtx needs to be done earlier (Lukas Czerner) [859545]
- [md] dm-raid: Fix possible kernel panic from bad index check (Jonathan E Brassow) [855448]
- [md] raid10: Add plugging functions (Jonathan E Brassow) [854058]
- [md] dm-raid: Validate RAID10 replacement devices (Jonathan E Brassow) [854058]
- [md] dm-raid: Move some code to its own function (Jonathan E Brassow) [854058]
- [md] raid10: Adjust for no gendisk structure (Jonathan E Brassow) [854058]
- [md] dm-raid: Should select MD_RAID10 module (Jonathan E Brassow) [854058]
- [md] dm-raid: Support RAID10 (Jonathan E Brassow) [854058]
- [md] raid10: export md_raid10_congested (Jonathan E Brassow) [854058]
- [md] raid: Move macros (Jonathan E Brassow) [854058]
- [md] raid1: rename mirror_info struct (Jonathan E Brassow) [854058]
- [md] raid10: Rename mirror_info struct (Jonathan E Brassow) [854058]
- [md] raid10: Fix compiler warning (Jonathan E Brassow) [854058]
- [dm] dm-raid: Use md_error (Jonathan E Brassow) [854058]
- [scsi] scsi_dh_rdac: minor return fix for rdac (Rob Evers) [822984]
- [scsi] scsi_dh_rdac: Consolidate rdac strings together (Rob Evers) [822984]
- [scsi] scsi_dh_rdac: Add a new netapp vendor/product string (Rob Evers) [822984]
- [firmware] netxen_nic: add firmware version 4.0.588 (Veaceslav Falico) [826664]

* Mon Oct 08 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-325.el6]
- [fs] Check for immutable/append flag in fallocate path (Lukas Czerner) [739101]
- [fs] ext4: remove restrictive checks for EOFBLOCKS_FL (Lukas Czerner) [739101]
- [fs] ext4: fix kernel BUG on large-scale rm -rf commands (Lukas Czerner) [739101]
- [fs] ext4: fix hole punch failure when depth is greater than 0 (Lukas Czerner) [739101]
- [fs] ext4: hole-punch use truncate_pagecache_range (Lukas Czerner) [739101]
- [mm] add truncate_pagecache_range() (Lukas Czerner) [739101]
- [fs] ext4: correct ext4_punch_hole return codes (Lukas Czerner) [739101]
- [fs] ext4: give more helpful error message in ext4_ext_rm_leaf() (Lukas Czerner) [739101]
- [fs] ext4: remove unused code from ext4_ext_map_blocks() (Lukas Czerner) [739101]
- [fs] ext4: rewrite punch hole to use ext4_ext_remove_space() (Lukas Czerner) [739101]
- [fs] ext4: correctly handle pages w/o buffers in ext4_discard_partial_buffers() (Lukas Czerner) [739101]
- [fs] ext4: remove messy logic from ext4_ext_rm_leaf (Lukas Czerner) [739101]
- [fs] ext4: only call ext4_jbd2_file_inode when an inode has been extended (Lukas Czerner) [739101]
- [fs] ext4: fix 2nd xfstests 127 punch hole failure (Lukas Czerner) [739101]
- [fs] ext4: teach ext4_ext_split to calculate extents efficiently (Lukas Czerner) [739101]
- [fs] ext4: Fix flag testing in ext4_ext_insert_extent() (Lukas Czerner) [739101]
- [fs] ext4: let ext4_discard_partial_buffers handle unaligned range correctly (Lukas Czerner) [739101]
- [fs] ext4: return ENOMEM if find_or_create_pages fails (Lukas Czerner) [739101]
- [fs] ext4: move vars to local scope in ext4_discard_partial_page_buffers_no_lock() (Lukas Czerner) [739101]
- [fs] ext4: fix xfstests 75, 112, 127 punch hole failure (Lukas Czerner) [739101]
- [fs] ext4: Add new ext4_discard_partial_page_buffers routines (Lukas Czerner) [739101]
- [fs] ext4: add action of moving index in ext4_ext_rm_idx for Punch Hole (Lukas Czerner) [739101]
- [fs] ext4: punch hole optimizations: skip un-needed extent lookup (Lukas Czerner) [739101]
- [fs] ext4: enable "punch hole" functionality (Lukas Czerner) [739101]
- [fs] ext4: add "punch hole" flag to ext4_map_blocks() (Lukas Czerner) [739101]
- [fs] ext4: punch out extents (Lukas Czerner) [739101]
- [fs] ext4: add new function ext4_block_zero_page_range() (Lukas Czerner) [739101]
- [fs] ext4: add flag to ext4_has_free_blocks (Lukas Czerner) [739101]
- [fs] ext4: fix endianness breakage in ext4_split_extent_at() (Lukas Czerner) [739101]
- [fs] ext4: add ext4_split_extent_at() and ext4_split_extent() (Lukas Czerner) [739101]
- [fs] ext4: add a function merging extents right and left (Lukas Czerner) [739101]
- [fs] ext4: rename {ext, idx}_pblock and inline small extent functions (Lukas Czerner) [739101]
- [fs] ext4: Add flags and structure used in ext4_ext_map_blocks() (Lukas Czerner) [739101]
- [mm] fix possible cause of a page_mapped BUG (Lukas Czerner) [739101]
- [fs] make the feature checks in ->fallocate future proof (Lukas Czerner) [739101]
- [fs] btrfs: fail if we try to use hole punch (Lukas Czerner) [739101]
- [fs] gfs2: fail if we try to use hole punch (Lukas Czerner) [739101]
- [fs] ext4: fail if we try to use hole punch (Lukas Czerner) [739101]
- [fs] xfs: handle hole punching via fallocate properly (Lukas Czerner) [739101]
- [fs] add hole punching to fallocate (Lukas Czerner) [739101]
- [fs] nfs: prevent race that allowed use of freed layout in _pnfs_return_layout (Steve Dickson) [858361]
- [fs] nfs: need to put_layout_hdr on _pnfs_return_layout error path (Steve Dickson) [858361]
- [fs] nfs: fix several problems with _pnfs_return_layout (Steve Dickson) [858361]
- [fs] nfs: fix pnfs regression with directio writes (Steve Dickson) [858361]
- [fs] nfs: fix pnfs regression with directio reads (Steve Dickson) [858361]
- [fs] nfs: Create an write_pageio_init() function (Steve Dickson) [858361]
- [fs] nfs: Create an read_pageio_init() function (Steve Dickson) [858361]
- [fs] nfs: Fix list manipulation snafus in fs/nfs/direct.c (Steve Dickson) [858361]
- [fs] nfs: Initialise commit_info.rpc_out when !defined(CONFIG_nfs_V4) (Steve Dickson) [858361]
- [fs] nfs: Fix a refcounting issue in O_DIRECT (Steve Dickson) [858361]
- [fs] nfs: fix directio refcount bug on commit (Steve Dickson) [858361]
- [fs] nfs: Fix a commit bug (Steve Dickson) [858361]
- [fs] nfs: Fix a bad reference count issue in the pnfs commit code (Steve Dickson) [858361]
- [fs] nfs: Clean up - Simplify reference counting in fs/nfs/direct.c (Steve Dickson) [858357]
- [fs] nfs: Clean up - Rename nfs_unlock_request and nfs_unlock_request_dont_release (Steve Dickson) [858357]
- [fs] nfs: Clean up - simplify nfs_lock_request() (Steve Dickson) [858357]
- [fs] nfs: nfs_set_page_writeback no longer needs to reference the page (Steve Dickson) [858357]
- [fs] nfs: Prevent a deadlock in the new writeback code (Steve Dickson) [858357]
- [fs] nfs: Fix sparse warnings (Steve Dickson) [858357]
- [fs] nfs: COMMIT does not need post-op attributes (Steve Dickson) [858357]
- [fs] nfs: Dont request cache consistency attributes on some writes (Steve Dickson) [858357]
- [fs] nfs: Simplify the nfs_read_completion functions (Steve Dickson) [858357]
- [fs] nfs: Clean up nfs read and write error paths (Steve Dickson) [858357]
- [fs] nfs: Read cleanups (Steve Dickson) [858357]
- [fs] nfs: Use kmem_cache_zalloc() in nfs_direct_req_alloc (Steve Dickson) [858357]
- [fs] nfs: Fix O_DIRECT compile warnings (Steve Dickson) [857110]
- [fs] nfs: Simplify O_DIRECT page referencing (Steve Dickson) [857110]
- [fs] nfs: O_DIRECT pgio_completion_ops error_cleanup must unlock the request (Steve Dickson) [857110]
- [fs] nfs: Ensure that we break out of read/write_schedule_segment on error (Steve Dickson) [857110]
- [fs] nfs: Define dummy nfs_init_cinfo() and nfs_init_cinfo_from_inode() (Steve Dickson) [857110]
- [fs] nfs: Define nfs_direct_write_schedule_work() when v3 and v4 are disabled (Steve Dickson) [857110]
- [fs] nfs: pnfs_pageio_init_read() and init_write() need an extra argument (Steve Dickson) [857110]
- [fs] nfs: Fix a use-before-initialised warning in fs/nfs/write.c and fs/nfs/pnfs.c (Steve Dickson) [857110]
- [fs] nfs: Prevent garbage cinfo->ds from leaking out (Steve Dickson) [857110]
- [fs] nfs: rewrite directio write to use async coalesce code (Steve Dickson) [857110]
- [fs] nfs: avoid some stat gathering for direct io (Steve Dickson) [857110]
- [fs] nfs: add dreq to nfs_commit_info (Steve Dickson) [857110]
- [fs] nfs: create nfs_commit_completion_ops (Steve Dickson) [857110]
- [fs] nfs: create struct nfs_commit_info (Steve Dickson) [857110]
- [fs] nfs: create nfs_generic_commit_list (Steve Dickson) [857110]
- [fs] nfs: rewrite directio read to use async coalesce code (Steve Dickson) [857110]
- [fs] ext3: Replace lock/unlock_super() with an explicit lock for resizing (Eric Sandeen) [804988]
- [fs] cifs: Initialise mid_q_entry before putting it on the pending queue (Sachin Prabhu) [832209]
- [fs] ext4: correct comments for ext4_free_blocks() (Lukas Czerner) [847981]
- [fs] ext4: fix i_blocks/quota accounting when extent insertion fails (Lukas Czerner) [847981]
- [fs] ext4: Add flags to the ext4_free_blocks() (Lukas Czerner) [847981]
- [fs] ext4: fold ext4_free_blocks() and ext4_mb_free_blocks() (Lukas Czerner) [847981]

* Sat Oct 06 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-324.el6]
- [alsa] oxygen: remove no_period_wakeup handling (Jaroslav Kysela) [816880]
- [alsa] firewire-speakers, oxygen, ua101: allow > 10 s periods (Jaroslav Kysela) [816880]
- [alsa] virtuoso: Xonar DS: fix polarity of front output (Jaroslav Kysela) [816880]
- [alsa] oxygen: add Xonar DGX support (Jaroslav Kysela) [816880]
- [alsa] oxygen, virtuoso: fix exchanged L/R volumes of aux and CD inputs (Jaroslav Kysela) [816880]
- [alsa] virtuoso: add S/PDIF input support for all Xonars (Jaroslav Kysela) [816880]
- [alsa] oxygen: Xonar DG: fix CS4245 register writes (Jaroslav Kysela) [816880]
- [alsa] oxygen: fix Xonar DG input (Jaroslav Kysela) [816880]
- [alsa] include delay.h for msleep in Xonar DG support (Jaroslav Kysela) [816880]
- [alsa] virtuoso: fix Essence ST(X) S/PDIF input (Jaroslav Kysela) [816880]
- [alsa] virtuoso: fix silent analog output on Xonar Essence ST Deluxe (Jaroslav Kysela) [816880]
- [alsa] oxygen: fix output routing on Xonar DG (Jaroslav Kysela) [816880]
- [alsa] Xonar, CS43xx: Don't overrun static array (Jaroslav Kysela) [816880]
- [alsa] oxygen: add S/PDIF source selection for Claro cards (Jaroslav Kysela) [816880]
- [alsa] oxygen: fix CD/MIDI for X-Meridian (2G) (Jaroslav Kysela) [816880]
- [alsa] oxygen: add some card names (Jaroslav Kysela) [816880]
- [alsa] oxygen: do not show chip revision in card longname (Jaroslav Kysela) [816880]
- [alsa] oxygen: X-Meridian: add S/PDIF source selection (Jaroslav Kysela) [816880]
- [alsa] oxygen: add digital input validity check switch (Jaroslav Kysela) [816880]
- [alsa] core, oxygen, virtuoso: add an enum control info helper (Jaroslav Kysela) [816880]
- [alsa] virtuoso: add Xonar HDAV1.3 Slim support (Jaroslav Kysela) [816880]
- [alsa] oxygen: add Xonar DG support (Jaroslav Kysela) [816880]
- [alsa] oxygen: add X-Meridian 2G support (Jaroslav Kysela) [816880]
- [alsa] oxygen: add more PCI IDs (Jaroslav Kysela) [816880]
- [alsa] virtuoso: reduce MCLK in double rate modes (Jaroslav Kysela) [816880]
- [alsa] oxygen: simplify model-specific MCLK handling (Jaroslav Kysela) [816880]
- [alsa] virtuoso: use headphone gain setting only on front DAC (Jaroslav Kysela) [816880]
- [alsa] virtuoso: handle DAC oversampling automatically (Jaroslav Kysela) [816880]
- [alsa] virtuoso: use lower master clock with H6 daughterboard (Jaroslav Kysela) [816880]
- [alsa] virtuoso: configure correct master clock frequency on the CS2000 (Jaroslav Kysela) [816880]
- [alsa] virtuoso: remove non-working controls on Essence ST Deluxe (Jaroslav Kysela) [816880]
- [alsa] virtuoso: change PCM1796 format to I2S (Jaroslav Kysela) [816880]
- [alsa] virtuoso: wait for PCM1796 clock to become stable (Jaroslav Kysela) [816880]
- [alsa] virtuoso: do not use fast I2C speed (Jaroslav Kysela) [816880]
- [alsa] oxygen: fix SPI clocks slower than 6.25 MHz (Jaroslav Kysela) [816880]
- [alsa] oxygen: remove oxygen_model::private_data field (Jaroslav Kysela) [816880]
- [alsa] oxygen: allow different number of PCM and mixer channels (Jaroslav Kysela) [816880]
- [alsa] oxygen: update hardware comments (Jaroslav Kysela) [816880]
- [alsa] oxygen: show correct package ID (Jaroslav Kysela) [816880]
- [alsa] oxygen: allow to dump codec registers (Jaroslav Kysela) [816880]
- [alsa] virtuoso: Xonar DS: add stereo upmixing to center/LFE channels (Jaroslav Kysela) [816880]
- [alsa] virtuoso: automatically handle Xonar DS headphone routing (Jaroslav Kysela) [816880]
- [alsa] virtuoso: add Xonar DS headphone jack detection (Jaroslav Kysela) [816880]
- [alsa] virtuoso: fix Xonar DS input switches (Jaroslav Kysela) [816880]
- [alsa] virtuoso: fix WM8766 register writes with MSB (Jaroslav Kysela) [816880]
- [alsa] virtuoso: fix setting of Xonar DS line-in/mic-in controls (Jaroslav Kysela) [816880]
- [alsa] oxygen: change || to && (Jaroslav Kysela) [816880]
- [alsa] virtuoso: fix front panel routing for D1/DX/ST(X) (Jaroslav Kysela) [816880]
- [alsa] virtuoso: add HDMI enable switch for HDAV1.3 (Jaroslav Kysela) [816880]
- [alsa] virtuoso: initialize unknown GPIO bits (Jaroslav Kysela) [816880]
- [alsa] oxygen: add HiFier Serenade support (Jaroslav Kysela) [816880]
- [alsa] oxygen: reorganize PCI IDs (Jaroslav Kysela) [816880]
- [alsa] oxygen: add Kuroutoshikou CMI8787-HG2PCI support (Jaroslav Kysela) [816880]
- [alsa] oxygen: support for period wakeup disabling (Jaroslav Kysela) [816880]
- [alsa] oxygen: merge HiFier driver into snd-oxygen (Jaroslav Kysela) [816880]
- [alsa] oxygen: Add a SSID for CMI8787-HG2PCI (Jaroslav Kysela) [816880]
- [alsa] oxygen: add PEX8111 initialization (Jaroslav Kysela) [816880]
- [alsa] oxygen: rewrite PCIe bridge initialization (Jaroslav Kysela) [816880]
- [alsa] oxygen: fix for PI7C9X110 compatibility (Jaroslav Kysela) [816880]
- [alsa] oxygen: do not try to restore nonexistent EEPROM (Jaroslav Kysela) [816880]
- [alsa] oxygen: reduce minimum period count (Jaroslav Kysela) [816880]
- [alsa] oxygen: fix input monitor dB scale (Jaroslav Kysela) [816880]
- [alsa] oxygen: fix chip ID register symbols (Jaroslav Kysela) [816880]
- [alsa] virtuoso: fix Xonar STX anti-pop delay (Jaroslav Kysela) [816880]
- [alsa] virtuoso: add HDAV1.3 Slim PCI ID (Jaroslav Kysela) [816880]
- [alsa] oxygen: handle CD input configuration with a flag (Jaroslav Kysela) [816880]
- [alsa] virtuoso: fix Xonar DS chip name (Jaroslav Kysela) [816880]
- [alsa] oxygen: fix analog capture on Claro halo cards (Jaroslav Kysela) [816880]
- [alsa] virtuoso: work around missing reset in the Xonar DS Windows driver (Jaroslav Kysela) [816880]
- [alsa] virtuoso: fix Xonar D1/DX front panel microphone (Jaroslav Kysela) [816880]
- [alsa] virtuoso: add Xonar DS support (Jaroslav Kysela) [816880]
- [alsa] oxygen: add high-pass filter control (Jaroslav Kysela) [816880]
- [alsa] oxygen: add digital filter control (Jaroslav Kysela) [816880]
- [alsa] virtuoso: add PCM1796 oversampling control (Jaroslav Kysela) [816880]
- [alsa] oxygen: allow custom MCLK rates (Jaroslav Kysela) [816880]
- [alsa] virtuoso: add headphone impedance control (Jaroslav Kysela) [816880]
- [alsa] oxygen: cache codec registers (Jaroslav Kysela) [816880]
- [alsa] virtuoso: fix Xonar Essence ST support (Jaroslav Kysela) [816880]
- [alsa] oxygen: fix input monitor control names (Jaroslav Kysela) [816880]
- [alsa] oxygen: more hardware documentation (Jaroslav Kysela) [816880]
- [alsa] oxygen: add stereo upmixing to center/LFE channels (Jaroslav Kysela) [816880]
- [alsa] oxygen: better defaults for upmixing control (Jaroslav Kysela) [816880]
- [alsa] virtuoso: split virtuoso.c (Jaroslav Kysela) [816880]
- [mm] migrate: fix kABI issues (Rik van Riel) [713546 783248]
- [mm] compaction: Restart compaction from near where it left off (Rik van Riel) [713546 783248]
- [mm] compaction: Cache if a pageblock was scanned and no pages were isolated (Rik van Riel) [713546 783248]
- [mm] compaction: Abort compaction loop if lock is contended or run too long (Rik van Riel) [713546 783248]
- [mm] compaction: Abort async compaction if locks are contended or taking too long (Rik van Riel) [713546 783248]
- [mm] vmscan: consider swap space when deciding whether to continue reclaim (Rik van Riel) [713546 783248]
- [mm] vmscan: when reclaiming for compaction, ensure there are sufficient free pages available (Rik van Riel) [713546 783248]
- [mm] compaction: introduce sync-light migration for use by compaction (Rik van Riel) [713546 783248]
- [mm] page_alloc: do not call direct reclaim for THP allocations while compaction is deferred (Rik van Riel) [713546 783248]
- [mm] compaction: allow compaction to isolate dirty pages (Rik van Riel) [713546 783248]
- [mm] migration: clean up unmap_and_move() (Rik van Riel) [713546 783248]
- [mm] compaction: make isolate_lru_page() filter-aware again (Rik van Riel) [713546 783248]
- [mm] compaction: make isolate_lru_page() filter-aware (Rik van Riel) [713546 783248]
- [mm] vmscan: change isolate mode from #define to bitwise type (Rik van Riel) [713546 783248]
- [mm] compaction: determine if dirty pages can be migrated without blocking within ->migratepage (Rik van Riel) [713546 783248]
- [mm] vmscan: do not OOM if aborting reclaim to start compaction (Rik van Riel) [713546 783248]
- [mm] vmscan: abort reclaim/compaction if compaction can proceed (Rik van Riel) [713546 783248]
- [mm] vmscan: limit direct reclaim for higher order allocations (Rik van Riel) [713546 783248]
- [mm] vmscan: check if we isolated a compound page during lumpy scan (Rik van Riel) [713546 783248]
- [mm] compaction: use synchronous compaction for /proc/sys/vm/compact_memory (Rik van Riel) [713546 783248]
- [mm] vmscan: reclaim order-0 and use compaction instead of lumpy reclaim (Rik van Riel) [713546 783248]
- [mm] shmem: fix up rhel-6.4 kABI issues (Rafael Aquini) [857000]
- [mm] shmem: remove shmem_readpage() (Rafael Aquini) [857000]
- [mm] shmem: refine shmem_file_splice_read() (Rafael Aquini) [857000]
- [mm] shmem: clone shmem_file_splice_read() (Rafael Aquini) [857000]
- [watchdog] hpwdt: Fix kdump issue in hpwdt (Don Zickus) [828941]
- [watchdog] hpwdt: Unregister NMI events on exit (Don Zickus) [818372]
- [x86] nmi: Add new NMI queues to deal with IO_CHK and SERR (Don Zickus) [818372]
- [watchdog] hpwdt: Only BYTE reads/writes to WD Timer port 0x72 (Don Zickus) [818372]
- [net] ipvs: IPv6 MTU checking cleanup and bugfix (Jesper Brouer) [854066]
- [net] ipvs: allow transmit of GRO aggregated skbs (Jesper Brouer) [854066]
- [netdrv] ixgbevf: propagate page->pfmemalloc from skb_alloc_page to skb (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Fix namespace issue with ixgbe_write_eitr (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Add lock around mailbox ops to prevent simultaneous access (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Fix multiple issues in ixgbevf_get/set_ringparam (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Consolidate Tx context descriptor creation code (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Add support for PCI error handling (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Add netdev to ring structure (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Do not rewind the Rx ring before bumping tail (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Update descriptor macros to accept pointers and drop _ADV suffix (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Use igb style interrupt masks instead of ixgbe style (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Move Tx clean-up into NAPI context (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Update q_vector to contain ring pointers instead of bitmaps (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Fix panic when loading driver (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Cleanup accounting for space needed at start of xmit_frame (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Drop use of eitr_low and eitr_high for hard coded values (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Drop netdev_registered value since that is already stored in netdev (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Drop all dead or unnecessary code (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Fix nearly-kernel-doc comments for various functions (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Update version string (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Make sure jumbo frames are set correctly after PF reset (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Add support to recognize 100mb link speed (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: make wired ethernet driver message level consistent (rev2) (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: print MAC via printk format specifier (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: rename dev_hw_addr_random and remove redundant second (Andy Gospodarek) [819105]
- [netdrv] ixgbevf: Remove unnecessary k.alloc/v.alloc OOM messages (Andy Gospodarek) [819105]
- [kernel] perf: Change and simplify ctx::is_active semantics (Jiri Olsa) [853215]
- [kernel] ntp: Fix STA_INS/DEL clearing bug (Prarit Bhargava) [862271]
- [acpi] Add acpi_ns_remove_null_elements() to prevent null dereference on package elements (Lenny Szubowicz) [835744]
- [usb] core: Fix device removal race condition (James Paradis) [849188]
- [fs] sysfs: fix corruption in rb-tree caused by name change (John Green) [839984]
- [mm] x86_32: fix SHLIB_BASE address typo (Aristeu S. Rozanski F) [804956] {CVE-2012-1568}
- [netdrv] bnx2x: remove false warning regarding interrupt number (Michal Schmidt) [860007]

* Fri Oct 05 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-323.el6]
- [net] vlan: Match underlying dev carrier on vlan add (Amerigo Wang) [845172]
- [net] link_watch: allow vlans to get carrier changes faster (Amerigo Wang) [845172]
- [net] allow netif_carrier to be called safely from IRQ (Amerigo Wang) [845172]
- [net] netdevice: provide common routine for macvlan and vlan operstate management (Amerigo Wang) [845172]
- [scsi] bnx2fc: Fix incorrect memset in bnx2fc_parse_fcp_rsp (Tomas Henzl) [860174]
- [scsi] bnx2fc: Remove potential NULL dereference (Tomas Henzl) [860174]
- [scsi] isci: Allow SSP tasks into the task management path (David Milburn) [860241]
- [netdrv] igb: Change how we check for pre-existing and assigned VFs (Stefan Assmann) [819102]
- [netdrv] igb: Supported and Advertised Pause Frame (Stefan Assmann) [819102]
- [netdrv] igb: reduce Rx header size (Stefan Assmann) [819102]
- [netdrv] igb: Add loopback test support for i210 (Stefan Assmann) [819102]
- [netdrv] igb: implement 580 MDI setting support (Stefan Assmann) [819102]
- [netdrv] igb: Fix register defines for all non-82575 hardware (Stefan Assmann) [819102]
- [netdrv] igb: fix panic while dumping packets on Tx hang with IOMMU (Stefan Assmann) [819102]
- [netdrv] igb: add delay to allow igb loopback test to succeed on 8086:10c9 (Stefan Assmann) [819102]
- [netdrv] igb: don't break user visible strings over multiple lines in igb_ethtool.c (Stefan Assmann) [819102]
- [netdrv] igb: correct hardware type (i210/i211) check in igb_loopback_test() (Stefan Assmann) [819102]
- [netdrv] igb: Fix for failure to init on some 82576 devices (Stefan Assmann) [819102]
- [netdrv] igb: reset PHY in the link_up process to recover PHY setting after power down (Stefan Assmann) [819102]
- [netdrv] igb: Use eth_random_addr (Stefan Assmann) [819102]
- [netdrv] igb: Fix (nearly-)kernel-doc comments for various functions (Stefan Assmann) [819102]
- [netdrv] igb: Version bump (Stefan Assmann) [819102]
- [netdrv] igb: Update firmware info output (Stefan Assmann) [819102]
- [netdrv] igb: Streamline RSS queue and queue pairing assignment logic (Stefan Assmann) [819102]
- [netdrv] igb: A fix to VF TX rate limit (Stefan Assmann) [819102]
- [netdrv] igb: Fix incorrect RAR address entries for i210/i211 device (Stefan Assmann) [819102]
- [netdrv] igb: Disable the BMC-to-OS Watchdog Enable bit for DMAC (Stefan Assmann) [819102]
- [netdrv] igb: Add Support for new i210/i211 devices (Stefan Assmann) [819102]
- [netdrv] igb: Add function and pointers for 82580 low power state settings (Stefan Assmann) [819102]
- [netdrv] igb: fix rtnl race in PM resume path (Stefan Assmann) [819102]
- [netdrv] igb: Use netif_set_real_num_{rx,tx}_queues() (Stefan Assmann) [819102]
- [netdrv] igb: output register's information related to RX/TX queue (Stefan Assmann) [819102]
- [netdrv] igb: Force flow control off during reset when forcing speed (Stefan Assmann) [819102]
- [netdrv] igb: Update version to 3.4.7 (Stefan Assmann) [819102]
- [netdrv] intel: make wired ethernet driver message level consistent (Stefan Assmann) [819102]
- [netdrv] igb: fix warning about unused function (Stefan Assmann) [819102]
- [netdrv] igb: fix vf lookup (Stefan Assmann) [819102]
- [netdrv] igb: Update Copyright on all Intel copyrighted files (Stefan Assmann) [819102]
- [netdrv] igb: make local functions static (Stefan Assmann) [819102]

* Fri Oct 05 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-322.el6]
- [netdrv] e1000e: use correct type for read of 32-bit register (Dean Nelson) [819103]
- [netdrv] ixgbe: add new configuration options (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add skb frag size accessors (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix VLAN stripping and filtering problems (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix nearly-kernel-doc comments for ptp functions (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix PHC loophole allowing misconfiguration of increment register (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Check PTP Rx timestamps via BPF filter (Andy Gospodarek) [819101]
- [netdrv] ixgbe: PTP Fix hwtstamp mode settings (Andy Gospodarek) [819101]
- [netdrv] ixgbe: ptp code cleanup (Andy Gospodarek) [819101]
- [netdrv] ixgbe: support software timestamping (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add support for get_ts_info (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Enable timesync clock-out feature for PPS support on X540 (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Hardware Timestamping + PTP Hardware Clock (PHC) (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add missing braces (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix panic while dumping packets on Tx hang with IOMMU (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Use 1TC DCB instead of disabling DCB for MSI and legacy interrupts (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add support for new 82599 device (Andy Gospodarek) [819101]
- [netdrv] ixgbe: remove extra unused queues in DCB + FCoE case (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix RAR entry counting for generic and fdb_add() (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Use num_tcs.pg_tcs as upper limit for TC when checking based on UP (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Reduce Rx header size to what is actually used (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix handling of FDIR_HASH flag (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix build with PCI_IOV enabled. (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Change how we check for pre-existing and assigned VFs (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Drop probe_vf and merge functionality into ixgbe_enable_sriov (Andy Gospodarek) [819101]
- [netdrv] ixgbe: use PCI_VENDOR_ID_INTEL (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Enable FCoE FSO and CRC offloads based on CAPABLE instead of ENABLED flag (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Only enable anti-spoof on VF pools (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Correctly set SAN MAC RAR pool to default pool of PF (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Make FCoE allocation and configuration closer to how rings work (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Merge all FCoE percpu values into a single structure (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Cleanup configuration of FCoE registers (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Drop references to deprecated pci_ DMA api and instead use dma_ API (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix memory leak when SR-IOV VFs are direct assigned (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Use VMDq offset to indicate the default pool (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Cleanup holes in flags after removing several of them (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Retire RSS enabled and capable flags (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Add support for SR-IOV w/ DCB or RSS (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Update configure virtualization to allow for multiple PF pools (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Cleanup logic for MRQC and MTQC configuration (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Update the logic for ixgbe_cache_ring_dcb and DCB RSS configuration (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Move configuration of set_real_num_rx/tx_queues into open (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Handle failures in the ixgbe_setup_rx/tx_resources calls (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Ping the VFs on link status change to trigger link change (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Merge FCoE set_num and cache_ring calls into RSS/DCB config (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Add function for obtaining FCoE TC based on FCoE user priority (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Populate the prio_tc_map in ixgbe_setup_tc (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Cleanup unpacking code for DCB (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Simplify logic for getting traffic class from user priority (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Merge RSS and flow director ring register caching and configuration (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Clean up a useless switch statement and dead code in configure_srrctl (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Add feature offset value to ring features (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Add upper limit to ring features (Andy Gospodarek) [819101]
- [netdrv] ixgbe: count q_vectors instead of MSI-X vectors (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix nearly-kernel-doc comments for various functions (Andy Gospodarek) [819101]
- [netdrv] ixgbe: DCB and SR-IOV can not co-exist and will cause hangs (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Do not pad FCoE frames as this can cause issues with FCoE DDP (Andy Gospodarek) [819101]
- [netdrv] ixgbe: simplify padding and length checks (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix memory leak in ixgbe when receiving traffic on DDP enabled rings (Andy Gospodarek) [819101]
- [netdrv] ixgbe: clean up ixgbe_get_settings ethtool function (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add support for 1G SX modules (Andy Gospodarek) [819101]
- [netdrv] ixgbe: do not compile ixgbe_sysfs.c when CONFIG_IXGBE_HWMON is not set (Andy Gospodarek) [819101]
- [netdrv] ixgbe: align flow control DV macros with datasheet (Andy Gospodarek) [819101]
- [netdrv] ixgbe: IXGBE_RXD_STAT_VP set even with Rx stripping enabled (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix_features rxvlan is independent of DCB and needs to be set (Andy Gospodarek) [819101]
- [netdrv] ixgbe: update version number (Andy Gospodarek) [819101]
- [netdrv] ixgbe: cleanup the hwmon function calls (Andy Gospodarek) [819101]
- [netdrv] ixgbe: correct disable_rx_buff timeout (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix bogus error message (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Set Drop_EN bit when multiple Rx queues are present w/o flow control (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Clean up priority based flow control (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Exit on error case in VF message processing (Andy Gospodarek) [819101]
- [netdrv] ixgbe: dcb: IEEE PFC stats and reset logic incorrect (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Update link flow control to correctly handle multiple packet buffer DCB (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Reorder link flow control functions in ixgbe_common.c (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Use __free_pages instead of put_page to release pages (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Make ixgbe_fc_autoneg return void and always set current_mode (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Reorder the ring to q_vector mapping to improve performance (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Track instances of buffer available but no DMA resources present (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix race condition with shutdown (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix use after free on module remove (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Reset max_vfs to zero when user request is out of range (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Deny MACVLAN requests from VFs with admin set MAC (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add hwmon interface to export thermal data (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add support functions to access thermal data (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix calling skb_put on nonlinear skb assertion bug (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix a memory leak in IEEE DCB (Andy Gospodarek) [819101]
- [netdrv] ixgbe: check for WoL support in single function (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Identify FCoE rings earlier to resolve memory corruption w/ FCoE (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add missing rtnl_lock in PM resume path (Andy Gospodarek) [819101]
- [netdrv] ixgbe: UTA table incorrectly programmed (Andy Gospodarek) [819101]
- [netdrv] ixgbe: allow RAR table to be updated in promisc mode (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add I2C clock stretching (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix WoL issue with fiber (Andy Gospodarek) [819101]
- [netdrv] ixgbe: consolidate reporting of MSIX vectors into a single function (Andy Gospodarek) [819101]
- [netdrv] ixgbe: update version number (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix typo in enumeration name (Andy Gospodarek) [819101]
- [netdrv] ixgbe: make wired ethernet driver message level consistent (rev2) (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix issues with SR-IOV loopback when flow control is disabled (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix namespace issues when FCoE/DCB is not enabled (Andy Gospodarek) [819101]
- [netdrv] ixgbe: FCoE: Add support for ndo_get_fcoe_hbainfo() call (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Add support for enabling UDP RSS via the ethtool rx-flow-hash command (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Whitespace cleanups (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Two minor fixes for RSS and FDIR set queues functions (Andy Gospodarek) [819101]
- [netdrv] ixgbe: drop err_eeprom tag which is at same location as err_sw_init (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Move poll routine in order to improve readability (Andy Gospodarek) [819101]
- [netdrv] ixgbe: cleanup logic for the service timer and VF hang detection (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Update layout of ixgbe_ring structure to improve cache performance (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Store Tx flags and protocol information to tx_buffer sooner (Andy Gospodarek) [819101]
- [netdrv] ixgbe: always write DMA for single_mapped value with skb (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Write gso_segs and bytcount to the ring sooner (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Place skb on first buffer_info structure to avoid using stack space (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Use packets to track Tx completions instead of a seperate value (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Modify setup of descriptor flags to avoid conditional jumps (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Make certain that all frames fit minimum size requirements (Andy Gospodarek) [819101]
- [netdrv] ixgbe: cleanup logic in ixgbe_change_mtu (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Replace standard receive path with a page based receive (Andy Gospodarek) [819101]
- [netdrv] ixgbe: dcb: use DCB config values for FCoE traffic class on open (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix race condition where RX buffer could become corrupted. (Andy Gospodarek) [819101]
- [netdrv] ixgbe: use typed min/max functions where possible (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix obvious return value bug. (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Replace eitr_low and eitr_high with static values in ixgbe_update_itr (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Do not disable read relaxed ordering when DCA is enabled (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Simplify logic for ethtool loopback frame creation and testing (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Add iterator for cycling through rings on a q_vector (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Allocate rings as part of the q_vector (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Drop unnecessary napi_schedule_prep and spare blank line from ixgbe_intr (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Default to queue pairs when number of queues is less than CPUs (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Address issues with Tx WHTRESH value not being set correctly (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Reorder adapter contents for better cache utilization (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Do no clear Tx status bits since eop_desc provides enough info (Andy Gospodarek) [819101]
- [netdrv] ixgbe: remove tie between NAPI work limits and interrupt moderation (Andy Gospodarek) [819101]
- [netdrv] ixgbe: dcb: check setup_tc return codes (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Fix comments that are out of date or formatted incorrectly (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix spelling errors (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Minor formatting and comment corrections for ixgbe_xmit_frame_ring (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Remove boolean comparisons to true/false (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Combine post-DMA processing of sk_buff fields into single function (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Drop the _ADV of descriptor macros since all ixgbe descriptors are ADV (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Add function for testing status bits in Rx descriptor (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Let the Rx buffer allocation clear status bits instead of cleanup (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Address fact that RSC was not setting GSO size for incoming frames (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Minor refactor of RSC (Andy Gospodarek) [819101]
- [netdrv] ixgbe: ethtool: stats user buffer overrun (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix stats handling (Andy Gospodarek) [819101]
- [netdrv] ixgbe: convert to ndo_fix_features (Andy Gospodarek) [819101]
- [netdrv] ixgbe: Update ethtool_rxnfc::rule_cnt on return from ETHTOOL_GRXCLSRLALL (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add support for displaying ntuple filters via the nfc interface (Andy Gospodarek) [819101]
- [netdrv] ixgbe: fix ring assignment issues for SR-IOV and drop cases (Andy Gospodarek) [819101]
- [netdrv] ixgbe: add support for nfc addition and removal of filters (Andy Gospodarek) [819101]
- [net] ethtool: Add a common function for drivers with transmit time stamping (Jiri Benc) [829785]
- [net] ethtool: Introduce a method for getting time stamping capabilities (Jiri Benc) [829785]
- [ptp] Add a method for obtaining the device index (Jiri Benc) [829785]
- [ptp] Added a brand new class driver for ptp clocks (Jiri Benc) [829785]
- [pps] unify timestamp gathering (Jiri Benc) [829785]
- [ptp] added a BPF to help drivers detect PTP packets (Jiri Benc) [829785]
- [net] skbuff: add driver hook for tx time stamping (Jiri Benc) [829785]
- [net] add net_tstamp.h to headers_install (Jiri Benc) [829785]
- [kernel] posix-clock: Replace mutex with reader/writer semaphore (Jiri Benc) [829785]
- [kernel] posix-clock: Introduce dynamic clocks (Jiri Benc) [829785]
- [kernel] posix-timers: Cleanup namespace (Jiri Benc) [829785]
- [kernel] posix-timers: Add support for fd based clocks (Jiri Benc) [829785]
- [x86] Add clock_adjtime (Jiri Benc) [829785]
- [kernel] posix-timers: Introduce a syscall for clock tuning (Jiri Benc) [829785]
- [kernel] time: Splitout compat timex accessors (Jiri Benc) [829785]
- [kernel] ntp: Add ADJ_SETOFFSET mode bit (Jiri Benc) [829785]
- [kernel] posix-timers: Update comment (Jiri Benc) [829785]
- [kernel] posix-timers: Make posix-cpu-timers functions static (Jiri Benc) [829785]
- [kernel] posix-timers: Remove CLOCK_DISPATCH leftovers (Jiri Benc) [829785]
- [kernel] posix-timers: Convert timer_delete() to clockid_to_kclock() (Jiri Benc) [829785]
- [kernel] posix-timers: Convert timer_gettime() to clockid_to_kclock() (Jiri Benc) [829785]
- [kernel] posix-timers: Convert timer_settime() to clockid_to_kclock() (Jiri Benc) [829785]
- [kernel] posix-timers: Convert timer_create() to clockid_to_kclock() (Jiri Benc) [829785]
- [kernel] posix-timers: Remove useless res field from k_clock (Jiri Benc) [829785]
- [kernel] posix-timers: Convert clock_getres() to clockid_to_kclock() (Jiri Benc) [829785]
- [kernel] posix-timers: Make clock_getres and clock_get mandatory (Jiri Benc) [829785]
- [kernel] posix-timers: Convert clock_gettime() to clockid_to_kclock() (Jiri Benc) [829785]
- [kernel] posix-timers: Convert clock_settime to clockid_to_kclock() (Jiri Benc) [829785]
- [kernel] posix-cpu-timers: Remove the stub nanosleep functions (Jiri Benc) [829785]
- [kernel] posix-timers: Cleanup restart_block usage (Jiri Benc) [829785]
- [kernel] posix-timers: Convert clock_nanosleep_restart to clockid_to_kclock() (Jiri Benc) [829785]
- [kernel] posix-timers: Convert clock_nanosleep to clockid_to_kclock() (Jiri Benc) [829785]
- [kernel] posix-timers: Introduce clockid_to_kclock() (Jiri Benc) [829785]
- [kernel] posix-timers: Introduce clock_posix_cpu (Jiri Benc) [829785]
- [kernel] posix-timers: Cleanup struct initializers (Jiri Benc) [829785]
- [kernel] posix-timers: Define nanosleep not supported error separate (Jiri Benc) [829785]
- [kernel] posix-timers: Move copy_to_user(created_timer_id) down in timer_create() (Jiri Benc) [829785]
- [kernel] posix-timers: Fix error path in timer_create (Jiri Benc) [829785]

* Fri Oct 05 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-321.el6]
- [netdrv] be2net: fix vfs enumeration (Ivan Vecera) [819782]
- [netdrv] be2net: Regression bug wherein VFs creation broken for multiple cards (Ivan Vecera) [819782]
- [pci] intel-iommu: use physfn to search drhd for VF (Ivan Vecera) [819782]
- [netdrv] be2net: do not use SCRATCHPAD register (Ivan Vecera) [819782]
- [netdrv] be2net: fix max VFs reported by HW (Ivan Vecera) [819782]
- [netdrv] be2net: avoid disabling sriov while VFs are assigned (Ivan Vecera) [819782]
- [netdrv] be2net: add skb frag size accessors (Ivan Vecera) [827593]
- [netdrv] be2net: convert to SKB paged frag API. (Ivan Vecera) [827593]
- [netdrv] be2net: use PCIe AER capability (Ivan Vecera) [827593]
- [netdrv] be2net: modify log msg for lack of privilege error (Ivan Vecera) [827593]
- [netdrv] be2net: fixup malloc/free of adapter->pmac_id (Ivan Vecera) [827593]
- [netdrv] be2net: fix FW default for VF tx-rate (Ivan Vecera) [827593]
- [netdrv] be2net: create RSS rings even in multi-channel configs (Ivan Vecera) [827593]
- [netdrv] be2net: Add a missing CR in the end of message (Ivan Vecera) [827593]
- [netdrv] be2net: Fix to parse RSS hash from Receive completions correctly. (Ivan Vecera) [827593]
- [netdrv] be2net: Missing byteswap in be_get_fw_log_level causes oops on PowerPC (Ivan Vecera) [827593]
- [netdrv] be2net: Ignore physical link async event for Lancer (Ivan Vecera) [827593]
- [netdrv] be2net: Fix VF driver load for Lancer (Ivan Vecera) [827593]
- [netdrv] be2net: dont pull too much data in skb linear part (Ivan Vecera) [827593]
- [netdrv] be2net: update driver version (Ivan Vecera) [827593]
- [netdrv] be2net: Add description about various RSS hash types (Ivan Vecera) [827593]
- [netdrv] be2net: Enable RSS UDP hashing for Lancer and Skyhawk (Ivan Vecera) [827593]
- [netdrv] be2net: Fix port name in message during driver load (Ivan Vecera) [827593]
- [netdrv] be2net: Fix cleanup path when EQ creation fails (Ivan Vecera) [827593]
- [netdrv] be2net: Activate new FW after FW download for Lancer (Ivan Vecera) [827593]
- [netdrv] be2net: Fix initialization sequence for Lancer (Ivan Vecera) [827593]
- [netdrv] be2net: Fix die temperature stat for Lancer (Ivan Vecera) [827593]
- [netdrv] be2net: Fix error while toggling autoneg of pause parameters (Ivan Vecera) [827593]
- [netdrv] be2net: Fix Endian (Ivan Vecera) [827593]
- [netdrv] be2net: set maximal number of default RSS queues (Ivan Vecera) [827593]
- [netdrv] be2net: Fix to trim skb for padded vlan packets to workaround an ASIC Bug (Ivan Vecera) [827593]
- [netdrv] be2net: Explicitly clear the reserved field in the Tx Descriptor (Ivan Vecera) [827593]
- [netdrv] be2net: Increase statistics structure size for skyhawk. (Ivan Vecera) [827593]
- [netdrv] be2net: Modify error message to incorporate subsystem (Ivan Vecera) [827593]
- [netdrv] be2net: fix a race in be_xmit() (Ivan Vecera) [827593]
- [netdrv] be2net: Fix driver load for VFs for Lancer (Ivan Vecera) [827593]
- [netdrv] be2net: update driver version (Ivan Vecera) [827593]
- [netdrv] be2net: remove unnecessary usage of unlikely() (Ivan Vecera) [827593]
- [netdrv] be2net: fix reporting number of actual rx queues (Ivan Vecera) [827593]
- [netdrv] be2net: do not modify PCI MaxReadReq size (Ivan Vecera) [827593]
- [netdrv] be2net: cleanup be_vid_config() (Ivan Vecera) [827593]
- [netdrv] be2net: don't call vid_config() when there's no vlan config (Ivan Vecera) [827593]
- [netdrv] be2net: Add functionality to support RoCE driver (Ivan Vecera) [827593]
- [netdrv] be2net: Add function to issue mailbox cmd on MQ (Ivan Vecera) [827593]
- [netdrv] be2net: Fix to allow get/set of debug levels in the firmware. (Ivan Vecera) [827593]
- [netdrv] be2net: Fix to apply duplex value as unknown when link is down. (Ivan Vecera) [827593]
- [netdrv] be2net: Fix to not set link speed for disabled functions of a UMC card (Ivan Vecera) [827593]
- [netdrv] be2net: update the driver version (Ivan Vecera) [827593]
- [netdrv] be2net: fix speed displayed by ethtool on certain SKUs (Ivan Vecera) [827593]
- [netdrv] be2net: Fix FW download for BE (Ivan Vecera) [827593]
- [netdrv] be2net: Fix Lancer statistics (Ivan Vecera) [827593]
- [netdrv] be2net: Fix ethtool self test for Lancer (Ivan Vecera) [827593]
- [netdrv] be2net: Fix VLAN/multicast packet reception (Ivan Vecera) [827593]
- [netdrv] be2net: fix ethtool get settings (Ivan Vecera) [827593]
- [netdrv] be2net: Fix number of vlan slots in flex mode (Ivan Vecera) [827593]
- [netdrv] be2net: enable WOL by default if h/w supports it (Ivan Vecera) [827593]
- [netdrv] be2net: Remove unused OFFSET_IN_PAGE() macro (Ivan Vecera) [827593]
- [netdrv] be2net: update driver version (Ivan Vecera) [827593]
- [netdrv] be2net: reset queue address after freeing (Ivan Vecera) [827593]
- [netdrv] be2net: fix tx completion cleanup (Ivan Vecera) [827593]
- [netdrv] be2net: event queue re-design (Ivan Vecera) [827593]
- [netdrv] be2net: allocate more headroom in incoming skbs (Ivan Vecera) [827593]
- [tools] perf: Add missing files to build the python binding (Jiri Olsa) [860404]
- [tools] perf: Remove brace expansion from clean target (Jiri Olsa) [860404]
- [tools] perf/kvm top: Limit guest kernel info message to once (Jiri Olsa) [860404]
- [tools] perf: Introduce intlist (Jiri Olsa) [860404]
- [tools] perf: Change strlist to use the new rblist (Jiri Olsa) [860404]
- [tools] perf: Introducing rblist (Jiri Olsa) [860404]
- [tools] perf/kvm: Use strtol for walking guestmount directory (Jiri Olsa) [860404]
- [tools] perf/tool: Save cmdline from user in file header vs what is passed to record (Jiri Olsa) [860404]
- [tools] perf/top: Error handling for counter creation should parallel perf-record (Jiri Olsa) [860404]
- [tools] perf/session: Remove no longer used synthesize_sample method (Jiri Olsa) [860404]
- [tools] perf/evsel: Adopt parse_sample method from perf_event (Jiri Olsa) [860404]
- [tools] perf/evlist: Introduce perf_evlist__parse_sample (Jiri Olsa) [860404]
- [tools] perf/session: Use perf_evlist__id_hdr_size more extensively (Jiri Olsa) [860404]
- [tools] perf/session: Use perf_evlist__sample_id_all more extensively (Jiri Olsa) [860404]
- [tools] perf/session: Use perf_evlist__sample_type more extensively (Jiri Olsa) [860404]
- [tools] perf/evsel: Precalculate the sample size (Jiri Olsa) [860404]
- [tools] perf/target: Fix check on buffer size (Jiri Olsa) [860404]
- [tools] perf/symbols: Fix array sizes for binary types arrays (Jiri Olsa) [860404]
- [tools] perf/test: Fix parse events automated tests (Jiri Olsa) [860404]
- [tools] perf/annotate: Prevent overflow in size calculation (Jiri Olsa) [860404]
- [tools] perf: Fix build error with bison 2.6 (Jiri Olsa) [860404]
- [tools] perf: use XSI-complaint version of strerror_r() instead of GNU-specific (Jiri Olsa) [860404]
- [tools] perf: Make the breakpoint events sample period default to 1 (Jiri Olsa) [860404]
- [tools] perf/test: Add dso data caching tests (Jiri Olsa) [860404]
- [tools] perf/symbols: Add dso data caching (Jiri Olsa) [860404]
- [tools] perf/symbols: Add interface to read DSO image data (Jiri Olsa) [860404]
- [tools] perf/symbols: Factor DSO symtab types to generic binary types (Jiri Olsa) [860404]
- [tools] perf/hists: Print newline between hists callchains (Jiri Olsa) [860404]
- [tools] perf: Fix trace events storms due to weight demux (Jiri Olsa) [860404]
- [tools] perf/hists: Return correct number of characters printed in callchain (Jiri Olsa) [860404]
- [tools] perf: Dump exclude_{guest, host}, precise_ip header info too (Jiri Olsa) [860404]
- [tools] perf/kvm: Limit repetitive guestmount message to once per directory (Jiri Olsa) [860404]
- [tools] perf/kvm: Fix bug resolving guest kernel syms (Jiri Olsa) [860404]
- [tools] perf/kvm: Guest userspace samples should not be lumped with host uspace (Jiri Olsa) [860404]
- [tools] perf/kvm: Set name for VM process in guest machine (Jiri Olsa) [860404]
- [tools] perf/symbols: Add machine id to modules debug message (Jiri Olsa) [860404]
- [tools] perf: Split event symbols arrays to hw and sw parts (Jiri Olsa) [860404]
- [tools] perf: Split out PE_VALUE_SYM parsing token to SW and HW tokens (Jiri Olsa) [860404]
- [tools] perf: Add empty rule for new line in event syntax parsing (Jiri Olsa) [860404]
- [tools] perf/test: Use ARRAY_SIZE in parse events tests (Jiri Olsa) [860404]
- [tools] perf: Adding round_up/round_down macros (Jiri Olsa) [860404]
- [tools] perf/symbols: Add '.note' check into search for NOTE section (Jiri Olsa) [860404]
- [tools] perf: Fix generation of pmu list (Jiri Olsa) [860404]
- [tools] perf/evsel: Handle hw breakpoints event names in perf_evsel__name() (Jiri Olsa) [860404]
- [tools] perf: Fix hw breakpoint's type modifier parsing (Jiri Olsa) [860404]
- [tools] perf: Trivial build fix (Jiri Olsa) [860404]
- [tools] perf/report: Delay sample_type checks in pipe mode (Jiri Olsa) [860404]
- [tools] perf/bench: Documentation update (Jiri Olsa) [860404]
- [tools] perf/symbols: Follow .gnu_debuglink section to find separate symbols (Jiri Olsa) [860404]
- [tools] perf: Stop using a global trace events description list (Jiri Olsa) [860404]
- [tools] perf/test: Fix parse events test to follow proper raw event name (Jiri Olsa) [860404]
- [tools] perf/evsel: Fix a build failure on cross compilation (Jiri Olsa) [860404]
- [tools] perf/annotate: Check null of sym pointer before using it (Jiri Olsa) [860404]
- [tools] perf/evsel: Make some methods private (Jiri Olsa) [860404]
- [tools] perf: Remove unused evsel parameter from machine__resolve_callchain (Jiri Olsa) [860404]
- [tools] perf/evsel: Reconstruct raw event with modifiers from perf_event_attr (Jiri Olsa) [860404]
- [tools] perf: Remove __event_name (Jiri Olsa) [860404]
- [tools] perf: Don't access evsel->name directly (Jiri Olsa) [860404]
- [tools] perf/script: Replace __event_name uses with perf_evsel__name (Jiri Olsa) [860404]
- [tools] perf: Move all users of event_name to perf_evsel__name (Jiri Olsa) [860404]
- [tools] perf/evsel: Handle all event types in perf_evsel__name (Jiri Olsa) [860404]
- [tools] perf: Reconstruct sw event with modifiers from perf_event_attr (Jiri Olsa) [860404]
- [tools] perf: Reconstruct hw cache event with modifiers from perf_event_attr (Jiri Olsa) [860404]
- [tools] perf/evsel: Carve out event modifier formatting (Jiri Olsa) [860404]
- [tools] perf/hists: Implement printing snapshots to files (Jiri Olsa) [860404]
- [tools] perf/lib: Introduce rtrim (Jiri Olsa) [860404]
- [tools] perf/ui/gtk: Use struct perf_error_ops (Jiri Olsa) [860404]
- [tools] perf/ui/gtk: Add GTK info_bar widget to browser window (Jiri Olsa) [860404]
- [tools] perf/ui/gtk: Add GTK statusbar widget to browser window (Jiri Olsa) [860404]
- [tools] perf/ui/gtk: Introduce struct perf_gtk_context (Jiri Olsa) [860404]
- [tools] perf/ui: Introduce struct perf_error_ops (Jiri Olsa) [860404]
- [tools] perf: Add sort by src line/number (Jiri Olsa) [860404]
- [tools] perf: Add automated test for pure terms parsing (Jiri Olsa) [860404]
- [tools] perf: Add PMU event alias support (Jiri Olsa) [860404]
- [kernel] irq: export irq_modify_status symbol (Stanislaw Gruszka) [862025]
- [hid] hidraw: fix window in hidraw_release (Don Zickus) [839973]
- [hid] hidraw: protect hidraw_disconnect() better (Don Zickus) [839973]
- [hid] hidraw: remove excessive _EMERG messages from hidraw (Don Zickus) [839973]
- [hid] hidraw: fix hidraw_disconnect() (Don Zickus) [839973]
- [hid] fix a NULL pointer dereference in hidraw_write (Don Zickus) [839973]
- [hid] fix a NULL pointer dereference in hidraw_ioctl (Don Zickus) [839973]
- [hid] remove BKL from hidraw (Don Zickus) [839973]
- [x86] bordenville: enable gpio, watchdog and mfd hardware (Neil Horman) [817979]

* Thu Oct 04 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-320.el6]
- [alsa] hda: make sure alc268 does not OOPS on codec parse (Jaroslav Kysela) [838558]
- [alsa] hda: Fix ugly debug prints with CONFIG_SND_VERBOSE_PRINTK=y (Jaroslav Kysela) [838558]
- [alsa] hda: remove *_quirks.c (obsolete) (Jaroslav Kysela) [838558]
- [alsa] hda: avoid non-standard "Docking" name in mixers (Jaroslav Kysela) [838558]
- [alsa] hda: limit internal mic boost for Asus X202E (Jaroslav Kysela) [838558]
- [alsa] hda: Add another pci id for Haswell board (Jaroslav Kysela) [838558]
- [alsa] hda: Add mic-mute LED control for HP laptop (Jaroslav Kysela) [838558]
- [alsa] hda: Yet another position_fix quirk for ASUS machines (Jaroslav Kysela) [838558]
- [alsa] hda: Allow to pass position_fix=0 explicitly (Jaroslav Kysela) [838558]
- [alsa] hda: Fix disordered enum definitions in patch_cirrus.c (Jaroslav Kysela) [838558]
- [alsa] hda: Add support for MacBook Pro 10,1 (Jaroslav Kysela) [838558]
- [alsa] hda: Replace with the generic fixup codes in patch_cirrus.c (Jaroslav Kysela) [838558]
- [alsa] hda: Check bit mask for codec SSID in snd_hda_pick_fixup() (Jaroslav Kysela) [838558]
- [alsa] hda/intel: add position_fix quirk for Asus K53E (Jaroslav Kysela) [838558]
- [alsa] hda: Fix Oops at codec reset/reconfig (Jaroslav Kysela) [838558]
- [alsa] hda: Remove ignore_misc_bit (Jaroslav Kysela) [838558]
- [alsa] hda: Move non-PCM check to per_pin in patch_hdmi.c (Jaroslav Kysela) [838558]
- [alsa] hda: fix control names for multiple speaker out on IDT/STAC (Jaroslav Kysela) [838558]
- [alsa] hda: Fix missing Master volume for STAC9200/925x (Jaroslav Kysela) [838558]
- [alsa] hda/hdmi: Setup channel mapping for non_pcm audio (Jaroslav Kysela) [838558]
- [alsa] hda/hdmi: Enable HBR feature on Intel chips (Jaroslav Kysela) [838558]
- [alsa] hda/hdmi: Fix channel_allocation array wrong order (Jaroslav Kysela) [838558]
- [alsa] hda: add missing function declaration (Jaroslav Kysela) [838558]
- [alsa] hda: Avoid unnecessary parameter read for EPSS (Jaroslav Kysela) [838558]
- [alsa] hda: Implement snd_hda_power_sync() helper function (Jaroslav Kysela) [838558]
- [alsa] hda: Don't trust codec EPSS bit for IDT 92HD83xx & co (Jaroslav Kysela) [838558]
- [alsa] hda: Make clear built-in driver optimization (Jaroslav Kysela) [838558]
- [alsa] hda: Call snd_hda_jack_report_sync() generically in hda_codec.c (Jaroslav Kysela) [838558]
- [alsa] hda: Do not set GPIOs for speakers on IDT if there are no speakers (Jaroslav Kysela) [838558]
- [alsa] hda: Add missing ifdef CONFIG_SND_HDA_POWER_SAVE to tracepoints (Jaroslav Kysela) [838558]
- [alsa] hda: Check the power state when power_save option is changed (Jaroslav Kysela) [838558]
- [alsa] hda: Add tracepoints at snd_hda_power_up/down entrances. (Jaroslav Kysela) [838558]
- [alsa] hda: Add 3stack-automute model to AD1882 codec (Jaroslav Kysela) [838558]
- [alsa] hda: show ICT/KAE control bits (Jaroslav Kysela) [838558]
- [alsa] hda: Fix forgotten ifdef CONFIG_SND_HDA_PATCH_LOADER (Jaroslav Kysela) [838558]
- [alsa] hda: Deferred probing with request_firmware_nowait() (Jaroslav Kysela) [838558]
- [alsa] hda: Load firmware in hda_intel.c (Jaroslav Kysela) [838558]
- [alsa] hda: Fix leftover codec->power_transition (Jaroslav Kysela) [838558]
- [alsa] hda: don't create dysfunctional mixer controls for ca0132 (Jaroslav Kysela) [838558]
- [alsa] hda: Don't send invalid volume knob command on IDT 92hd75bxx (Jaroslav Kysela) [838558]
- [alsa] hda: Fix 'Beep Playback Switch' with no underlying mute switch (Jaroslav Kysela) [838558]
- [alsa] hda: fix Copyright debug message (Jaroslav Kysela) [838558]
- [alsa] hda: bug fix on checking the supported power states of a codec (Jaroslav Kysela) [838558]
- [alsa] hda: Fix panned "Beep Playback Switch" (Jaroslav Kysela) [838558]
- [alsa] hda/intel: Add Device IDs for Intel Lynx Point-LP PCH (Jaroslav Kysela) [838558]
- [alsa] hda: Fix pop noise in headphones on S3 for Asus X55A, X55V (Jaroslav Kysela) [838558]
- [alsa] hda: Add missing SPDIF I/O setup for CA0132 (Jaroslav Kysela) [838558]
- [alsa] hda: Use the standard PCM ops for CA0132 (Jaroslav Kysela) [838558]
- [alsa] hda: Fix superfluous "-in" suffix from CA0132 capture items (Jaroslav Kysela) [838558]
- [alsa] hda: Add codec->pcm_format_first flag (Jaroslav Kysela) [838558]
- [alsa] hda: Fix double quirk for Quanta FL1 / Lenovo Ideapad (Jaroslav Kysela) [838558]
- [alsa] hda: remove redundant auto quirks for conexant 506x (Jaroslav Kysela) [838558]
- [alsa] hda: remove quirk for Dell Vostro 1015 (Jaroslav Kysela) [838558]
- [alsa] hda: add dock support for Thinkpad X230 (Jaroslav Kysela) [838558]
- [alsa] hda: Fix regression of HDMI codec probing (Jaroslav Kysela) [838558]
- [alsa] hda: add dock support for Thinkpad T430s (Jaroslav Kysela) [838558]
- [alsa] hda: Support dock on Lenovo Thinkpad T530 with ALC269VC (Jaroslav Kysela) [838558]
- [alsa] hda: Fix mute-LED GPIO initialization for IDT codecs (Jaroslav Kysela) [838558]
- [alsa] hda: Fix polarity of mute LED on HP Mini 210 (Jaroslav Kysela) [838558]
- [alsa] hda: Workaround for silent output on VAIO Z with ALC889 (Jaroslav Kysela) [838558]
- [alsa] hda: Fix WARNING from HDMI/DP parser (Jaroslav Kysela) [838558]
- [alsa] hda: Detach from converter at closing in patch_hdmi.c (Jaroslav Kysela) [838558]
- [alsa] hda: Fix mute-LED GPIO setup for HP Mini 210 (Jaroslav Kysela) [838558]
- [alsa] hda: Fix invalid D3 of headphone DAC on VT202x codecs (Jaroslav Kysela) [838558]
- [alsa] hda: add dock support for Thinkpad X230 Tablet (Jaroslav Kysela) [838558]
- [alsa] hda: Turn on PIN_OUT from hdmi playback prepare. (Jaroslav Kysela) [838558]
- [alsa] hda: Add support for Realtek ALC282 (Jaroslav Kysela) [838558]
- [alsa] hda: Fix index number conflicts of phantom jacks (Jaroslav Kysela) [838558]
- [alsa] hda: Add new GPU codec ID to snd-hda (Jaroslav Kysela) [838558]
- [alsa] hda: Fix driver type of Haswell controller to AZX_DRIVER_SCH (Jaroslav Kysela) [838558]
- [alsa] hda: add Haswell HDMI codec id (Jaroslav Kysela) [838558]
- [alsa] hda: Add DeviceID for Haswell HDA (Jaroslav Kysela) [838558]
- [alsa] hda: Always call standard unsolicited event for Realtek codecs (Jaroslav Kysela) [838558]
- [alsa] hda: Avoid possible race of beep on/off (Jaroslav Kysela) [838558]
- [alsa] hda: Move beep helper functions to hda_beep.c (Jaroslav Kysela) [838558]
- [alsa] hda: give 3-pin jack the name "Headphone Mic Jack" (Jaroslav Kysela) [838558]
- [alsa] hda: Support single 3-pin jack without VREF on the actual pin (Jaroslav Kysela) [838558]
- [alsa] hda: Fix no sound from ALC662 after Windows reboot (Jaroslav Kysela) [838558]
- [alsa] hda: Fix power-map regression for HP dv6 & co (Jaroslav Kysela) [838558]
- [alsa] hda: Initialize caches at codec reconfiguration (Jaroslav Kysela) [838558]
- [alsa] hda: Fix memory leaks at module unload (Jaroslav Kysela) [838558]
- [alsa] hda: Fix memory leaks in Realtek & Conexant codec parsers (Jaroslav Kysela) [838558]
- [alsa] hda: Add Realtek ALC280 codec support (Jaroslav Kysela) [838558]
- [alsa] hda: Remove suprefluous EAPD init verbs for ALC660vd (Jaroslav Kysela) [838558]
- [alsa] hda: Add inv-dmic model to possible Realtek codecs (Jaroslav Kysela) [838558]
- [alsa] hda: Add inverted mic quirks for Asus U41SV, Acer 1810TZ and AOD260 (Jaroslav Kysela) [838558]
- [alsa] hda: Add the inverted digital mic workaround to Realtek codecs (Jaroslav Kysela) [838558]
- [alsa] hda: Don't power up when not powered down. (Jaroslav Kysela) [838558]
- [alsa] hda: Add inverted internal mic quirk for Lenovo S205 (Jaroslav Kysela) [838558]
- [alsa] hda: Fix ALC272X codec detection (Jaroslav Kysela) [838558]
- [alsa] hda: Correct info print in HDMI non-intrinsic unsol event (Jaroslav Kysela) [838558]
- [alsa] hda: Don't rely on event tag for simple_hdmi (Jaroslav Kysela) [838558]
- [alsa] hda: Remove loop from simple_hdmi*() (Jaroslav Kysela) [838558]
- [alsa] hda: Move one-time init codes from generic_hdmi_init() (Jaroslav Kysela) [838558]
- [alsa] hda: Add missing snd_hda_jack_detect_enable() for simple_hdmi*() (Jaroslav Kysela) [838558]
- [alsa] hda: Fix the pin nid assignment in patch_hdmi.c (Jaroslav Kysela) [838558]
- [alsa] hda: Enable unsol event for ATI and Nvidia HDMI codecs too (Jaroslav Kysela) [838558]
- [alsa] hda: Remove invalid init verbs for Nvidia 2ch codecs (Jaroslav Kysela) [838558]
- [alsa] hda: Use common codes for ATI, Nvidia and VIA simple codecs (Jaroslav Kysela) [838558]
- [alsa] hda: Merge ATI/VIA HDMI simple init functions (Jaroslav Kysela) [838558]
- [alsa] hda: Add the support for VIA HDMI pin detection (Jaroslav Kysela) [838558]
- [alsa] hda/intel: activate COMBO mode for Intel client chipsets (Jaroslav Kysela) [838558]
- [alsa] hda: Create phantom jacks for fixed inputs and outputs (Jaroslav Kysela) [838558]
- [alsa] hda: add support for HD-Audio CODECes of VIA HDMI GFX Cards (Jaroslav Kysela) [838558]
- [alsa] hda: add support for HD-Audio of VIA HDMI GFX Cards (Jaroslav Kysela) [838558]
- [alsa] hda: power setting error check (Jaroslav Kysela) [838558]
- [alsa] hda: check proper return value (Jaroslav Kysela) [838558]
- [alsa] hda: reduce msleep time if EPSS power states supported (Jaroslav Kysela) [838558]
- [alsa] hda: check supported power states (Jaroslav Kysela) [838558]
- [alsa] hda: Show D3cold state in proc files (Jaroslav Kysela) [838558]
- [alsa] hda: add power states information in proc (Jaroslav Kysela) [838558]
- [alsa] hda: Handle open while transitioning to D3. (Jaroslav Kysela) [838558]
- [alsa] hda: Don't forget to call init verbs added by fixup list (Jaroslav Kysela) [838558]
- [alsa] hda: Pin fixup for Zotac Z68 motherboard (Jaroslav Kysela) [838558]
- [alsa] hda: Fix detection of Creative SoundCore3D controllers (Jaroslav Kysela) [838558]
- [alsa] hda: HDMI Audio init all connectors when VGA-switcheroo is off (Jaroslav Kysela) [838558]
- [alsa] hda: Fix uninitialized HDMI controllers with VGA-switcheroo (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Add new codec support for ALC269VD (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Fix unused variable compile warning (Jaroslav Kysela) [838558]
- [alsa] hda: Fix possible races of accesses to connection list array (Jaroslav Kysela) [838558]
- [alsa] hda: unlock on error in azx_interrupt() (Jaroslav Kysela) [838558]
- [alsa] hda/idt: Cache the power-map bits (Jaroslav Kysela) [838558]
- [alsa] hda/idt: Clean up power-map check code (Jaroslav Kysela) [838558]
- [alsa] hda: Evaluate gpio_led hints at the right moment (Jaroslav Kysela) [838558]
- [alsa] hda/idt: Fix power-map for speaker-pins with some HP laptops (Jaroslav Kysela) [838558]
- [alsa] hda: Support VGA-switcheroo (disabled for RHEL6) (Jaroslav Kysela) [838558]
- [alsa] hda: Add a hook capability to vmaster controls (Jaroslav Kysela) [838558]
- [alsa] hda: Export snd_hda_lock_devices() (Jaroslav Kysela) [838558]
- [alsa] hda: Check the dead HDMI audio controller by vga-switcheroo (Jaroslav Kysela) [838558]
- [alsa] hda: Disable FLOAT format support (Jaroslav Kysela) [838558]
- [alsa] hda/conexant: Correct vendor IDs for new codecs (Jaroslav Kysela) [838558]
- [alsa] hda: Fix concurrent hash accesses (Jaroslav Kysela) [838558]
- [alsa] hda: Protect SPDIF-related stuff via spdif_mutex (Jaroslav Kysela) [838558]
- [alsa] hda: Add Conexant CX20751/2/3/4 codec support (Jaroslav Kysela) [838558]
- [alsa] hda: Add the support for Creative SoundCore3D (Jaroslav Kysela) [838558]
- [alsa] hda: More robustify the power-up/down sequence (Jaroslav Kysela) [838558]
- [alsa] hda: Remove pre_resume and post_suspend ops (Jaroslav Kysela) [838558]
- [alsa] hda: Lessen CPU usage when waiting for chip to respond (Jaroslav Kysela) [838558]
- [alsa] hda: Move BIOS pin-parser code to hda_auto_parser.c (Jaroslav Kysela) [838558]
- [alsa] hda: Move up the fixup helper functions to the library module (Jaroslav Kysela) [838558]
- [alsa] hda: Protect the power-saving count with spinlock (Jaroslav Kysela) [838558]
- [alsa] hda: Clear the power-saving states properly at reset (Jaroslav Kysela) [838558]
- [alsa] hda: Always resume the codec immediately (Jaroslav Kysela) [838558]
- [alsa] hda: Fix possible access to uninitialized work struct (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Call a common helper for alc_spec initialization (Jaroslav Kysela) [838558]
- [alsa] hda: Revert "ALSA: hda - Set codec to D3 forcibly even if not used" (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Call alc_auto_parse_customize_define() always after fixup (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Add missing CD-input pin for MSI-7350 mobo (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Add a fixup for Acer Aspire 5739G (Jaroslav Kysela) [838558]
- [alsa] hda: Fix oops caused by recent commit "Fix internal mic for Lenovo Ideapad U300s" (Jaroslav Kysela) [838558]
- [alsa] hda: Fix internal mic for Lenovo Ideapad U300s (Jaroslav Kysela) [838558]
- [alsa] hda: Skip pin capability sanity check for bogus values (Jaroslav Kysela) [838558]
- [alsa] hda: Add snd_hda_get_default_vref() helper function (Jaroslav Kysela) [838558]
- [alsa] hda: Introduce snd_hda_set_pin_ctl*() helper functions (Jaroslav Kysela) [838558]
- [alsa] hda/conexant: Set up the missing docking-station pins (Jaroslav Kysela) [838558]
- [alsa] hda: Add external mic quirk for Asus Zenbook UX31E (Jaroslav Kysela) [838558]
- [alsa] hda/conexant: Don't set HP pin-control bit unconditionally (Jaroslav Kysela) [838558]
- [alsa] hda/sigmatel: Fix inverted mute LED (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Fix regression on Quanta/Gericom KN1 (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Fix mem leak (and rid us of trailing whitespace). (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Add quirk for Mac Pro 5,1 machines (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Add a fixup entry for Acer Aspire 8940G (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Fix GPIO1 setup for Acer Aspire 4930 & co (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Add a few ALC882 model strings back (Jaroslav Kysela) [838558]
- [alsa] hda: hide HDMI/ELD printks unless snd.debug=2 (Jaroslav Kysela) [838558]
- [alsa] hda: clean up CX20549 test mixer setup (Jaroslav Kysela) [838558]
- [alsa] hda: CX20549 doesn't need pin_amp_workaround. (Jaroslav Kysela) [838558]
- [alsa] hda: Remove CD control from model=benq for CX20549 (Jaroslav Kysela) [838558]
- [alsa] hda: fix record volume controls of CX20459 ("Venice") (Jaroslav Kysela) [838558]
- [alsa] hda: Rename capture sources of CX20549 to match common conventions (Jaroslav Kysela) [838558]
- [alsa] hda: Fix proc output for ADC amp values of CX20549 (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Fix ADC assignment with a shared HP/Mic pin (Jaroslav Kysela) [838558]
- [alsa] hda: Fix build with CONFIG_PM=n (Jaroslav Kysela) [838558]
- [alsa] hda: Fix build of patch_sigmatel.c without CONFIG_SND_HDA_POWER_SAVE (Jaroslav Kysela) [838558]
- [alsa] hda: fix printing of high HDMI sample rates (Jaroslav Kysela) [838558]
- [alsa] hda: Add expose_enum_ctl flag to snd_hda_add_vmaster_hook() (Jaroslav Kysela) [838558]
- [alsa] hda: Add "Mute-LED Mode" enum control (Jaroslav Kysela) [838558]
- [alsa] hda: Add EAPD control to Conexnat auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda: Rewrite the mute-LED control with vmaster hook for ALC269 (Jaroslav Kysela) [838558]
- [alsa] hda: Rewrite the mute-LED hook with vmaster hook in patch_sigmatel.c (Jaroslav Kysela) [838558]
- [alsa] hda: Return the created kcontrol in __snd_hda_add_vmaster() (Jaroslav Kysela) [838558]
- [alsa] hda: Typos: change aditional to additional. (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Reuse init_hook for ALC269VB coef setup (Jaroslav Kysela) [838558]
- [alsa] hda: Fix silent speaker output on Acer Aspire 6935 (Jaroslav Kysela) [838558]
- [alsa] hda: Initialize vmaster slave volumes (Jaroslav Kysela) [838558]
- [alsa] hda: Set codec to D3 forcibly even if not used (Jaroslav Kysela) [838558]
- [alsa] hda: Add Gigabyte GA-MA790X to the beep whitelist (Jaroslav Kysela) [838558]
- [alsa] hda: fix broken automute/autoswitch for Realtek (Jaroslav Kysela) [838558]
- [alsa] hda/conexant: Clear unsol events on unused pins (Jaroslav Kysela) [838558]
- [alsa] hda: Enable docking-station SPDIF for Thinkpad (Jaroslav Kysela) [838558]
- [alsa] hda: Add position_fix=4 (COMBO) option (Jaroslav Kysela) [838558]
- [alsa] hda: Fix audio playback support on HP Zephyr system (Jaroslav Kysela) [838558]
- [alsa] hda: add id for Atom Cedar Trail HDMI codec (Jaroslav Kysela) [838558]
- [alsa] hda/via: Add a few sanity checks (Jaroslav Kysela) [838558]
- [alsa] hda/via: Don't create duplicated boost controls (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Small code cleanups (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Fix the wrong offset for two-speaker systems (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Fix the possible conflicts of Bass Speaker name (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Create individual mute switches for shared DAC (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Fix possible Oops with NULL input_mux (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Parse aa-loopback items dynamically (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Remove the last static quirks for ALC882 (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Add model=fixup not to apply fix-ups (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Drop all ALC880 static quirks (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Drop model=asus* from ALC880 (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Rewrite ALC880 model=asus-w1v with auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Rewrite ALC880 model=z71v with auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Rewrite ALC880 model=uniwill-dig with auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Rewrite ALC880 model=uniwill with auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Rewrite ALC880 model=uniwill-p53 with auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Rewrite ALC880 model=F1734 with auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Rewrite ALC880 model=futjisu with auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Apply probe-fixup really after probing (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Replace ALC880 model=tcl with auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Drop ALC880 model=clevo (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Refactor the DAC filler function (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Rewrite ALC880 model=w810 with auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Rewrite ALC880 model=lg with the auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Adjust badness calculation for multi-ios (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Show multi-io pins in debug prints (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Try harder to fit the single-connections (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Finer tuning of auto-parser with badness evaluation (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Improve the signel-connection check (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Disable static fixups for ASUS with ALC269 (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Remove leftover static quirks for ALC260 (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Drop model=fujitsu from ALC260 static quirks (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Drop model=favorit100 for ALC260 (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Add the support for HP Presario B1900 (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Replace ALC260 model=replacer with the auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Replace ALC260 model=acer with the auto-parser (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Add the fixup codes for ALC260 model=will (Jaroslav Kysela) [838558]
- [alsa] hda: Add another jack-detection suppression for ASUS ALC892 (Jaroslav Kysela) [838558]
- [alsa] hda: Suppress auto-mute feature on some machines with ALC861 (Jaroslav Kysela) [838558]
- [alsa] hda: Add codec->no_jack_detect flag (Jaroslav Kysela) [838558]
- [alsa] hda: Make is_jack_detectable() as non-inlined (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Apply the coef-setup only to ALC269VB (Jaroslav Kysela) [838558]
- [alsa] hda: add quirk to detect CD input on Gigabyte EP45-DS3 (Jaroslav Kysela) [838558]
- [alsa] hda: Kill hyphenated names (Jaroslav Kysela) [838558]
- [alsa] hda: Always set HP pin in unsol handler for STAC/IDT codecs (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Fix resume of multiple input sources (Jaroslav Kysela) [838558]
- [alsa] hda/realtek: Fix overflow of vol/sw check bitmap (Jaroslav Kysela) [838558]
- [alsa] hda: Fix initialization of secondary capture source on VT1705 (Jaroslav Kysela) [838558]
- [alsa] hda: Fix mute-LED VREF value for new HP laptops (Jaroslav Kysela) [838558]
- [alsa] hda: Fix error handling in patch_ca0132.c (Jaroslav Kysela) [838558]
- [alsa] hda: add support for Uniwill ECS M31EI notebook (Jaroslav Kysela) [838558]
- [x86] Mark Intel Crystal Well CPU as supported (Prarit Bhargava) [861060]
- [x86] Mark Intel Ivy Town Processor as Supported (Prarit Bhargava) [847372]
- [x86] apic: Use x2apic physical mode based on FADT setting (Prarit Bhargava) [832162]
- [s390] zcrypt: Add support for CEX4 crypto card (Hendrik Brueckner) [823010]

* Thu Oct 04 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-319.el6]
- [md] dm-thin: support discard with non power of two blocksize (Mike Snitzer) [858858]
- [md] dm-thin: fix discard support for data devices (Mike Snitzer) [858858]
- [md] dm-thin: tidy discard support (Mike Snitzer) [858858]
- [md] dm-thin: do not set discard_zeroes_data (Mike Snitzer) [858858]
- [md] dm: handle requests beyond end of device instead of using BUG_ON (Mike Snitzer) [858858]
- [md] dm: retain table limits when swapping to new table with no devices (Mike Snitzer) [858858]
- [md] dm-table: clear add_random unless all devices have it set (Mike Snitzer) [858858]
- [md] dm-mpath: only retry ioctl when no paths if queue_if_no_path set (Mike Snitzer) [858858]
- [md] dm-mpath: fix check for null mpio in end_io fn (Mike Snitzer) [858858]
- [block] split discard into aligned requests (Mike Snitzer) [858858]
- [block] reorganize rounding of max_discard_sectors (Mike Snitzer) [858858]
- [scsi] Fix dm-multipath starvation when scsi host is busy (Mike Snitzer) [858858]
- [netdrv] vmxnet3: fix interrupt control bitmap (Neil Horman) [829953]
- [netdrv] vmxnet3: Remove casts to same type (Neil Horman) [829953]
- [netdrv] vmxnet3: Fix log messages and corrects some typos (Neil Horman) [829953]
- [netdrv] vmxnet3: Fix transport header size (Neil Horman) [829953]
- [netdrv] vmxnet3: Fix typo in vmxnet3_drv.c (Neil Horman) [829953]
- [netdrv] vmxnet3: Remove alloc_etherdev error messages (Neil Horman) [829953]
- [netdrv] vmxnet3: Remove unnecessary k.alloc/v.alloc OOM messages (Neil Horman) [829953]
- [netdrv] vmxnet3: cleanup tso headers manipulation (Neil Horman) [829953]
- [netdrv] vmxnet3: make ethtool ops const (Neil Horman) [829953]
- [netdrv] vmxnet3: Sweep away N/A fw_version dustbunnies from the .get_drvinfo routine of a number of drivers (Neil Horman) [829953]
- [netdrv] vmxnet3: Add module.h to drivers who were implicitly using it (Neil Horman) [829953]
- [netdrv] vmxnet3: add skb frag size accessors (Neil Horman) [829953]
- [netdrv] vmxnet3: fix skb truesize underestimation (Neil Horman) [829953]
- [netdrv] vmxnet3: use DMA_x_DEVICE and dma_mapping_error with skb_frag_dma_map (Neil Horman) [829953]
- [netdrv] vmxnet3: convert to SKB paged frag API (Neil Horman) [829953]
- [netdrv] vmxnet3: Don't enable vlan filters in promiscuous mode (Neil Horman) [829953]
- [netdrv] vmxnet3: Fix advertising HW_CSUM feature to use csum_start (Neil Horman) [829953]
- [netdrv] net: fix assignment of 0/1 to bool variables (John Feeney) [826718]
- [netdrv] tg3: Update version to 3.124 (John Feeney) [826718]
- [netdrv] tg3: Fix race condition in tg3_get_stats64() (John Feeney) [826718]
- [netdrv] tg3: Add New 5719 Read DMA workaround (John Feeney) [826718]
- [netdrv] tg3: Fix Read DMA workaround for 5719 A0 (John Feeney) [826718]
- [netdrv] tg3: Request APE_LOCK_PHY before PHY access (John Feeney) [826718]
- [netdrv] tg3: Add hwmon support for temperature (John Feeney) [826718]
- [netdrv] tg3: Add APE scratchpad read function (John Feeney) [826718]
- [netdrv] tg3: Add common function tg3_ape_event_lock() (John Feeney) [826718]
- [netdrv] tg3: Fix the setting of the APE_HAS_NCSI flag (John Feeney) [826718]
- [netdrv] tg3: add device id of Apple Thunderbolt Ethernet device (John Feeney) [826718]
- [netdrv] tg3: Apply short DMA frag workaround to 5906 (John Feeney) [826718]
- [netdrv] tg3: remove redundant NULL test before release_firmware() call (John Feeney) [826718]
- [netdrv] tg3: Avoid panic from reserved statblk field access (John Feeney) [826718]
- [netdrv] tg3: Fix 5717 serdes powerdown problem (John Feeney) [826718]
- [netdrv] tg3: Remove all #inclusions of asm/system.h (John Feeney) [826718]
- [netdrv] tg3: Fix RSS ring refill race condition (John Feeney) [826718]
- [netdrv] tg3: Recode PCI MRRS adjustment as a PCI quirk (John Feeney) [826718]
- [netdrv] tg3: Fix poor tx performance on 57766 after MTU change (John Feeney) [826718]
- [netdrv] tg3: Add memory barriers to sync BD data (John Feeney) [826718]
- [netdrv] tg3: Fix jumbo loopback test on 5719 (John Feeney) [826718]
- [netdrv] tg3: Fix tg3_get_stats64 for 5700 / 5701 devs (John Feeney) [826718]
- [netdrv] tg3: unify return value of .ndo_set_mac_address if address is invalid (John Feeney) [826718]
- [netdrv] tg3: Create timer helper functions (John Feeney) [826718]
- [netdrv] tg3: Clear RECOVERY_PENDING with reset_task_cancel (John Feeney) [826718]
- [netdrv] tg3: Remove SPEED_UNKNOWN checks (John Feeney) [826718]
- [netdrv] tg3: Fix link check in tg3_adjust_link (John Feeney) [826718]
- [netdrv] tg3: remove IRQF_SAMPLE_RANDOM flag (John Feeney) [826718]
- [netdrv] tg3: Update copyright (John Feeney) [826718]
- [netdrv] tg3: Use *_UNKNOWN ethtool definitions (John Feeney) [826718]
- [netdrv] tg3: Remove unneeded link_config.orig_... members (John Feeney) [826718]
- [netdrv] tg3: Remove unused link config code (John Feeney) [826718]
- [netdrv] tg3: Consolidate ASIC rev detection code (John Feeney) [826718]
- [netdrv] tg3: Reduce UMP event collision window (John Feeney) [826718]
- [netdrv] tg3: Fix copper autoneg adv checks (John Feeney) [826718]
- [netdrv] tg3: Fix stats while interface is down (John Feeney) [826718]
- [netdrv] tg3: Disable new DMA engine for 57766 (John Feeney) [826718]
- [netdrv] tg3: Move transmit comment to a better location (John Feeney) [826718]
- [netdrv] tg3: Eliminate unneeded prototype (John Feeney) [826718]
- [netdrv] tg3: Relocate tg3_find_peer (John Feeney) [826718]
- [netdrv] tg3: Move tg3_nvram_write_block functions (John Feeney) [826718]
- [netdrv] tg3: Move tg3_set_rx_mode (John Feeney) [826718]
- [netdrv] tg3: Move tg3_change_mtu to a better location (John Feeney) [826718]
- [netdrv] tg3: Relocate tg3_reset_task (John Feeney) [826718]
- [netdrv] tg3: Move tg3_restart_hw to a better location (John Feeney) [826718]
- [netdrv] tg3: Remove alloc_etherdev error messages (John Feeney) [826718]
- [netdrv] tg3: Break out RSS indir table init and assignment (John Feeney) [826718]
- [netdrv] tg3: Use mii_advertise_flowctrl (John Feeney) [826718]
- [netdrv] tg3: Make the TX BD DMA limit configurable (John Feeney) [826718]
- [netdrv] tg3: Enable EEE support for capable 10/100 devs (John Feeney) [826718]
- [netdrv] tg3: Track LP advertising (John Feeney) [826718]
- [netdrv] tg3: Integrate flowctrl check into AN adv check (John Feeney) [826718]
- [netdrv] tg3: Fix advertisement handling (John Feeney) [826718]
- [netdrv] tg3: Change mii to ethtool advertisement function names (John Feeney) [826718]
- [netdrv] tg3: Add ethtool to mii advertisment conversion helpers (John Feeney) [826718]
- [firmware] add Ralink rt2800 firmware images (Stanislaw Gruszka) [841604]
- [mm] x86_32: randomize SHLIB_BASE (Aristeu Rozanski) [804956] {CVE-2012-1568}

* Wed Oct 03 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-318.el6]
- [kernel] cgroups: don't attach task to subsystem if migration failed (Frederic Weisbecker) [751817]
- [kernel] cgroups: more safe tasklist locking in cgroup_attach_proc (Frederic Weisbecker) [751817]
- [kernel] cgroups: use flex_array in attach_proc (Frederic Weisbecker) [751817]
- [lib] flex_array: allow zero length flex arrays (Frederic Weisbecker) [751817]
- [lib] flex_array: fix flex_array_put_ptr macro to be valid C (Frederic Weisbecker) [751817]
- [lib] flex_array: add helpers to get and put to make pointers easy to use (Frederic Weisbecker) [751817]
- [kernel] cgroups: make procs file writable (Frederic Weisbecker) [751817]
- [kernel] cgroups: add per-thread subsystem callbacks (Frederic Weisbecker) [751817]
- [kernel] cgroup_freezer: fix freezing groups with stopped tasks (Frederic Weisbecker) [751817]
- [kernel] cgroup_freezer: update_freezer_state() does incorrect state transitions (Frederic Weisbecker) [751817]
- [kernel] cgroups: read-write lock CLONE_THREAD forking per threadgroup (Frederic Weisbecker) [751817]
- [kernel] cgroup_freezer: fix can_attach() to prohibit moving from/to freezing/frozen cgroups (Frederic Weisbecker) [751817]
- [kernel] cgroup_freezer: unnecessary test in cgroup_freezing_or_frozen() (Frederic Weisbecker) [751817]
- [kernel] cgroup_freezer: Update stale locking comments (Frederic Weisbecker) [751817]
- [net] nf_defrag_ipv6: fix oops on module unloading (Amerigo Wang) [726807]

* Wed Oct 03 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-317.el6]
- [fs] ext4: check for zero length extent (Lukas Czerner) [813097]
- [fs] cifs: Fix the conflict between rwpidforward and rw mount options (Sachin Prabhu) [852747]
- [fs] cifs: Fix wrong length in cifs_iovec_read (Sachin Prabhu) [851694]
- [fs] gfs2: Make write size hinting code common (Bob Peterson) [753337]
- [fs] gfs2: Fix missing allocation data for set/remove xattr (Bob Peterson) [753337]
- [fs] gfs2: Take account of blockages when using reserved blocks (Bob Peterson) [753337]
- [fs] gfs2: Reduce file fragmentation (Bob Peterson) [753337]
- [fs] gfs2: Eliminate unnecessary check for state > 3 in bitfit (Bob Peterson) [753337]
- [fs] gfs2: Fold quota data into the reservations struct (Bob Peterson) [753337]
- [fs] gfs2: Extend the life of the reservations structure (Bob Peterson) [753337]
- [fs] gfs2: Add rgrp information to block_alloc trace point (Bob Peterson) [753337]
- [fs] gfs2: Eliminate unused "new" parameter to gfs2_meta_indirect_buffer (Bob Peterson) [753337]
- [fs] gfs2: Remove redundant metadata block type check (Bob Peterson) [753337]
- [fs] gfs2: Eliminate needless parameter from function gfs2_setbit (Bob Peterson) [753337]
- [fs] gfs2: Use variable rather than qa to determine if unstuff necessary (Bob Peterson) [753337]
- [fs] gfs2: Remove i_disksize (Bob Peterson) [753337]
- [fs] gfs2: New truncate sequence (Bob Peterson) [753337]
- [fs] gfs2: Change variable blk to biblk (Bob Peterson) [753337]
- [fs] gfs2: Fix function parameter comments in rgrp.c (Bob Peterson) [753337]
- [fs] gfs2: Eliminate offset parameter to gfs2_setbit (Bob Peterson) [753337]
- [fs] gfs2: Use slab for block reservation memory (Bob Peterson) [753337]
- [fs] gfs2: make function gfs2_page_add_databufs static (Bob Peterson) [753337]
- [fs] gfs2: Rename function gfs2_close to gfs2_release (Bob Peterson) [753337]
- [fs] gfs2: Dump better debug info if a bitmap inconsistency is detected (Bob Peterson) [753337]
- [fs] gfs2: Use seq_vprintf for glocks debugfs file (Robert S Peterson) [847377]
- [fs] seq_file: Add seq_vprintf function and export it (Robert S Peterson) [847377]
- [fs] gfs2: Size seq_file buffer more carefully (Robert S Peterson) [847377]
- [fs] gfs2: Cache last hash bucket for glock seq_files (Robert S Peterson) [847377]
- [fs] gfs2: Increase buffer size for glocks and glstats debugfs files (Robert S Peterson) [847377]
- [fs] gfs2: glock statistics gathering (Robert S Peterson) [806385]
- [fs] jbd: clear revoked flag on buffers before a new transaction started (Lukas Czerner) [804281]
- [fs] ext3: Avoid filesystem corruption after a crash under heavy delete load (Lukas Czerner) [804281]
- [fs] nfs: prepare coalesce testing for directio (Steve Dickson) [854746]
- [fs] nfs: create completion structure to pass into page_init functions (Steve Dickson) [854746]
- [fs] nfs: remove unused wb_complete field from struct nfs_page (Steve Dickson) [854746]
- [fs] nfs: merge _full and _partial write rpc_ops (Steve Dickson) [854746]
- [fs] nfs: Don't use DATA_SYNC writes (Steve Dickson) [854746]
- [fs] nfs: merge _full and _partial read rpc_ops (Steve Dickson) [854746]
- [fs] nfs: Dont rely on PageError in nfs_readpage_release_partial (Steve Dickson) [854746]
- [fs] nfs: create struct nfs_page_array (Steve Dickson) [854746]
- [fs] nfs: create common nfs_pgio_header for both read and write (Steve Dickson) [854746]
- [fs] nfs: make pnfs_ld_[read|write]_done consistent (Steve Dickson) [854746]
- [fs] pnfs: make _set_lo_fail generic (Steve Dickson) [854746]
- [fs] nfs: Get rid of the unused nfs_read_data->flags field (Steve Dickson) [854746]
- [fs] nfs: Get rid of the unused nfs_write_data->flags field (Steve Dickson) [854746]
- [fs] nfs: Remove unused variable from write.c (Steve Dickson) [854746]
- [fs] nfs: Get rid of the nfs_rdata_mempool (Steve Dickson) [854746]
- [fs] nfs: Get rid of unnecessary calls to ClearPageError() in read code (Steve Dickson) [854746]
- [fs] nfs: Get rid of nfs_restart_rpc() (Steve Dickson) [854746]
- [fs] nfs: use req_offset where appropriate (Steve Dickson) [854746]
- [fs] nfs: Clean up - simplify the switch to read/write-through-MDS (Steve Dickson) [846714]
- [fs] nfs: remove unnecessary casts of void pointers in nfs4filelayout.c (Steve Dickson) [846714]
- [fs] nfs: reverse arg order in nfs_initiate_[read|write] (Steve Dickson) [846714]
- [fs] nfs: add a struct nfs_commit_data to replace nfs_write_data in commits (Steve Dickson) [846714]
- [fs] nfs: Remove nfs4_setup_sequence from generic read code (Steve Dickson) [846714]
- [fs] nfs: Remove nfs4_setup_sequence from generic write code (Steve Dickson) [846714]
- [fs] nfs: Add a new helper nfs4_init_sequence() (Steve Dickson) [846714]
- [fs] nfs: Add lseg to struct nfs4_fl_commit_bucket (Steve Dickson) [846714]
- [fs] nfs: Revert pnfs ugliness from the generic nfs read code path (Steve Dickson) [846714]
- [fs] nfs: File layout only supports whole file layouts (Steve Dickson) [846714]
- [fs] nfs: make pnfs_ld_[read|write]_done consistent (Steve Dickson) [846714]
- [fs] nfs: Remove pnfs bloat from the generic write path (Steve Dickson) [846714]
- [fs] pnfs: Must return layout on IO error (Steve Dickson) [846714]
- [fs] pnfs: layoutret_on_setattr (Steve Dickson) [846714]
- [fs] nfs: Revert coalesce small, page-aligned direct I/Os (Steve Dickson) [846708]
- [fs] nfs: dprintks in directio code were referencing task after put (Steve Dickson) [846708]
- [fs] nfs: grab open context in direct read (Steve Dickson) [846708]
- [fs] nfs: put open context on error in nfs_flush_multi (Steve Dickson) [846708]
- [fs] nfs: put open context on error in nfs_pagein_multi (Steve Dickson) [846708]
- [fs] nfs: remove duplicate variable declaration in filelayout_clear_request_commit (Steve Dickson) [846708]
- [fs] nfs: Use cond_resched_lock() to reduce latencies in the commit scans (Steve Dickson) [846708]
- [kernel] list: add list_safe_reset_next (Steve Dickson) [846708]
- [fs] nfs: Fix a few issues in filelayout_commit_pagelist (Steve Dickson) [846708]
- [fs] ext3, ext4: don't clear orphan list on ro mount with errors (Eric Sandeen) [852771]
- [block] replace __getblk_slow misfix by grow_dev_page fix (Jeff Moyer) [534080]
- [fs] buffer: remove BUG() in possible but rare condition (Jeff Moyer) [534080]
- [fs] gfs2: Add kobject release method (Robert S Peterson) [826089]
- [fs] nfs: check for req==NULL in nfs_try_to_update_request cleanup (Steve Dickson) [846688]
- [fs] nfs: ncommit count is being double decremented (Steve Dickson) [846688]
- [fs] nfs: Clean ups and bugfixes for the pnfs read/writeback/commit code (Steve Dickson) [846688]
- [fs] nfs: Revert pnfs ugliness from the generic nfs read code path (Steve Dickson) [846688]
- [fs] pnfs: recoalesce when ld read pagelist fails (Steve Dickson) [846688]
- [fs] nfs: Move the pnfs write code into pnfs.c (Steve Dickson) [846688]
- [fs] nfs: Move the pnfs read code into pnfs.c (Steve Dickson) [846688]
- [fs] nfs: Cache rpc_ops in struct nfs_pageio_descriptor (Steve Dickson) [846688]
- [fs] nfs: split out the RPC transmission from nfs_pagein_multi/one (Steve Dickson) [846688]
- [fs] nfs: Clean up nfs_read_rpcsetup and nfs_write_rpcsetup (Steve Dickson) [846688]
- [fs] pnfs: recoalesce when ld write pagelist fails (Steve Dickson) [833091]
- [fs] nfs: Allow the nfs_pageio_descriptor to signal that a re-coalesce is needed (Steve Dickson) [833091]
- [fs] nfs: Use stable writes when not doing a bulk flush (Steve Dickson) [833091]
- [fs] nfs: remove nfs_inode radix tree (Steve Dickson) [833091]
- [fs] nfs: nfs_open_context doesn't need struct path either (Steve Dickson) [833091]
- [fs] nfs: nfs4_opendata doesn't need struct path either (Steve Dickson) [833091]
- [fs] nfs: nfs4_closedata doesn't need to mess with struct path (Steve Dickson) [833091]
- [fs] nfs: Fix a hang in the writeback path (Steve Dickson) [833091]
- [fs] nfs: remove nfs_PAGE_TAG_LOCKED (Steve Dickson) [833091]

* Tue Oct 02 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-316.el6]
- [netdrv] qlcnic: get rid of a redundant test for NULL before call to release_firmware() (Chad Dupuis) [826572]
- [netdrv] qlcnic: remove unnecessary setting of skb->dev (Chad Dupuis) [826572]
- [netdrv] qlcnic: off by one in qlcnic_init_pci_info() (Chad Dupuis) [826572]
- [netdrv] qlcnic: vlan workaround for mac deletion bug in firmware (Chad Dupuis) [826572]
- [netdrv] qlcnic: fix turnaround delay during migration (Chad Dupuis) [826572]
- [netdrv] qlcnic: Fix protcol type in case of inband vlan. (Chad Dupuis) [826572]
- [netdrv] qlcnic: fix unsupported CDRP command error message. (Chad Dupuis) [826572]
- [netdrv] qlcnic: Fix estimation of recv MSS in case of LRO (Chad Dupuis) [826572]
- [netdrv] qlcnic: Allow a predefined set of capture masks for FW dump (Chad Dupuis) [826572]
- [netdrv] qlcnic: Adding mac statistics to ethtool. (Chad Dupuis) [826572]
- [netdrv] qlcnic: Register device in FAILED state. (Chad Dupuis) [826572]
- [netdrv] qlcnic: Bug fix for LRO (Chad Dupuis) [826572]
- [netdrv] qlcnic: Added sysfs Node fwdump_state (Chad Dupuis) [826572]
- [scsi] aacraid: respond automatically to volumes added by config tool (Rich Bono) [857561]
- [scsi] aacraid: reset should disable MSI interrupt (Rich Bono) [857561]
- [scsi] aacraid: prohibit access to array container space (Rich Bono) [857561]
- [scsi] aacraid: expose physical devices for models with newer firmware (Rich Bono) [857561]
- [scsi] aacraid: add support for handling ATA pass-through commands (Rich Bono) [857561]
- [infiniband] cxgb4: Fix endianness of addition to mpa->private_data_size (Jay Fenlason) [747145]
- [infiniband] cxgb4: Fix crash when peer address is 0.0.0.0 (Jay Fenlason) [747145]
- [infiniband] cxgb4: Add query_qp support (Jay Fenlason) [747145]
- [infiniband] cxgb4: Remove kfifo usage (Jay Fenlason) [747145]
- [infiniband] cxgb4: DB Drop Recovery for RDMA and LLD queues (Jay Fenlason) [747145]
- [infiniband] cxgb4: Disable interrupts in c4iw_ev_dispatch() (Jay Fenlason) [747145]
- [infiniband] cxgb4: Add DB Overflow Avoidance (Jay Fenlason) [747145]
- [infiniband] cxgb4: Use dst parameter in import_ep() (Jay Fenlason) [747145]
- [infiniband] cxgb4: Add missing peer2peer check in MPAv2 code (Jay Fenlason) [747145]
- [infiniband] cxgb4: Consolidate 3 copies of the same operation into 1 helper function (Jay Fenlason) [747145]
- [infiniband] cxgb4: Rename dst_get_neighbour{, _raw} to dst_get_neighbour_noref{, _raw} (Jay Fenlason) [747145]
- [infiniband] cxgb4: Fix RCU lockdep splats (Jay Fenlason) [747145]
- [infiniband] cxgb4: Abstract dst->neighbour accesses behind helpers (Jay Fenlason) [747145]
- [edac] mce_amd: Drop too granulary family model checks (Mauro Carvalho Chehab) [822275]
- [edac] mce_amd: Constify error tables (Mauro Carvalho Chehab) [822275]
- [edac] mce_amd: Correct bank 5 error signatures (Mauro Carvalho Chehab) [822275]
- [edac] mce_amd: Rework NB MCE signatures (Mauro Carvalho Chehab) [822275]
- [edac] amd64_edac: Fix K8 revD and later chip select sizes (Mauro Carvalho Chehab) [822275]
- [edac] amd64_edac: Fix missing csrows sysfs nodes (Mauro Carvalho Chehab) [822275]
- [edac] amd64_edac: Cleanup return type of amd64_determine_edac_cap() (Mauro Carvalho Chehab) [822275]
- [edac] amd64_edac: Add a fix for Erratum 505 (Mauro Carvalho Chehab) [822275]
- [edac] mce_amd: Simplify NB MCE decoder interface (Mauro Carvalho Chehab) [822275]
- [edac] mce_amd: Drop local coreid reporting (Mauro Carvalho Chehab) [822275]
- [edac] mce_amd: Print valid addr when reporting an error (Mauro Carvalho Chehab) [822275]
- [edac] mce_amd: Print CPU number when reporting the error (Mauro Carvalho Chehab) [822275]
- [firmware] bnx2x: add FW 7.2.51.0 (Michal Schmidt) [819842]
- [netdrv] bnx2x: enable previously disabled ethtool ops (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: convert to .set_phys_id extended ethtool op (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Utilize Link Flap Avoidance (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Link Flap Avoidance (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: link code refactoring (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: use native EEE instead of auto-greeen (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: correct & clean 10G EEE requirements (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: EEE code refactoring (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: add EEE support for 4-port devices (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: EEE status is read locally (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: use list_move_tail instead of list_del/list_add_tail (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix rx checksum validation for IPv6 (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Add missing afex code (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix registers dumped (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: correct advertisement of pause capabilities (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: display the correct duplex value (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: prevent timeouts when using PFC (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix stats copying logic (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Avoid sending multiple statistics queries (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Correct the ndo_poll_controller call (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Move netif_napi_add to the open call (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Fix compiler warnings (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Fix recovery flow cleanup during probe (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix unload previous driver flow when flr-capable (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix mem leak when command is unknown (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: remove cast around the kmalloc in bnx2x_prev_mark_path (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Correct EEE statistics gathering (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Add new 57840 device IDs (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: organize BDs calculation for stop/resume (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Fix non-kernel-doc comments with kernel-doc start markers (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Fix (nearly-)kernel-doc comment (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: set maximal number of default RSS queues (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Change bnx2x_tests_str_arr to static char (Michal Schmidt) [819842 826277 826295 826302]
- [scsi] bnx2i: use strlcpy() instead of memcpy() for strings (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x, bnx2fc, bnx2i, cnic: Add statistics support and FCoE capabilities advertisement (Michal Schmidt) [819842 826277 826295 826302]
- [scsi] bnx2i: Fixed NULL ptr deference for 1G bnx2 Linux iSCSI offload (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Allocate UIO resources only on devices that support iSCSI. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Allocate kcq resource only on devices that support FCoE. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Add function pointers to arm IRQ for different devices. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Free UIO rings when the device is closed. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Add functions to allocate and free UIO rings (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Fix non-kernel-doc comments with kernel-doc start markers (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: remove invalid reference to list iterator variable (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Fix mmap regression. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Handle RAMROD_CMD_ID_CLOSE error. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Remove uio mem[0]. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Read bnx2x function number from internal register (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Fix occasional NULL pointer dereference during reboot. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] cnic: Remove casts to same type (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2fc: Bumped version to 1.0.12 (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2fc: use list_entry instead of explicit cast (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2fc: Improve error recovery by handling parity errors (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2fc: Support interface creation on non-VLAN interface also (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2fc: Reduce object size by consolidating formats (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2i: Removed the reference to the netdev->base_addr (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix link for BCM57711 with 84823 phy (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix I2C non-respondent issue (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: link module eeprom (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: 1G sfp+ module handling (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: revised link register access (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: treat 0 speed as link down (copper) (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: link cleanup (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: sfp+ Tx fault detection added (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Change date and version to 1.72.51-0 (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Support DCBX for all functions (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Add support for ethtool -L (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Allow up to 63 RSS queues (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Split the FP structure (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Move the CNIC L2 CIDs to be right after the RSS CIDs (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Make the transmission queues adjacent (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Allow more than 64 L2 CIDs (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Add support for 4-tupple UDP RSS (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Return only online tests for MF (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Add support for external LB (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: correct LPI pass-through configuration (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix panic when TX ring is full (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix checksum validation (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Added EEE Ethtool support. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Added EEE support (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: bug fix when loading after SAN boot (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix handling single MSIX mode for 57710/57711 (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: remove some bloat (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: off by one in bnx2x_ets_e3b0_sp_pri_to_cos_set() (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Update driver version to 1.72.50-0 (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: remove gro workaround (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: add afex support (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Clear MDC/MDIO warning message (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Fix BCM57711+BCM84823 link issue (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Clear BCM84833 LED after fan failure (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Fix BCM84833 PHY FW version presentation (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Fix link issue for BCM8727 boards. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Restore 1G LED on BCM57712+BCM8727 designs. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Fix BCM578x0-SFI pre-emphasis settings (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Fix BCM57810-KR AN speed transition (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Fix BCM57810-KR FC (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: PFC fix (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: add missing parenthesis to prevent u32 overflow (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Change to driver version 1.72.10-0 (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Change comments and white spaces (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: change to the rss engine (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: congestion management re-organization (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Added support for a new device - 57811 (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: added support for working with one msix irq. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: enable inta on the pci bus when used (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: remove unnecessary dmae code (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: remove unnecessary .h dependencies (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: fix vector traveling while looking for an empty entry (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: previous driver unload revised (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: validate FW trace prior to its printing (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: changed iscsi/fcoe mac init and macros (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: added TLV_NOT_FOUND flags to the dcb (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: removed dcb unused code (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: reduced sparse warnings (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: revised driver prints (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: use ethtool_rxfh_indir_default() (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: call netif_set_real_num_rx_queues() (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: code doesn't use stats for allocating Rx BDs (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: ethtool returns req. AN even when AN fails (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: ethtool now returns unknown speed/duplex (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: mark functions as loaded on shared memory (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: use param's id instead of sp_obj's id (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: set_one_mac_e1x uses raw's state as input (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: removed unused function bnx2x_queue_set_cos_cid (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: move LLH_CAM to header, apply naming conventions (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: update driver version to 1.72.10-0 (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: add gro_check (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: make bnx2x_close() static again (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: use eth_hw_addr_random() and reset addr_assign_type (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: allow all functions to display the phy FW version (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: removed code re-checking memory base after device open (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: allow BCM84833 phy to advertise 100Base-T speeds (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: notify cnic of address of info-to-the-mcp (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: allocate smaller Rx rings for 1G functions (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: allocate memory dynamically in ethtool self-test. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: force 10G on 84833 phy should be autoneg with only 10G advertised (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: added autoneg-restart after link advertisement changes (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: ethtool publishes link partners speed and FC (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: half duplex support added for several boards (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Remove boolean comparisons to true/false (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: Look inside vlan when determining checksum proto. (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] bnx2x: cut down on pointless differences from upstream (Michal Schmidt) [819842 826277 826295 826302]
- [netdrv] igb: schedule watchdog every second to update the statistics (Stefan Assmann) [838404]
- [pci] Set device power state to PCI_D0 for device without native PM support (Laszlo Ersek) [849223]

* Fri Sep 28 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-315.el6]
- [block] fix up use after free in __blkdev_get (Jeff Moyer) [847838]
- [firmware] r8169: update the firmware for RTL8168F variant (Ivan Vecera) [842651]
- [netdrv] r8169: use unlimited DMA burst for TX (Ivan Vecera) [842651]
- [netdrv] r8169: add D-Link DGE-560T identifiers. (Ivan Vecera) [842651]
- [netdrv] r8169: verbose error message. (Ivan Vecera) [842651]
- [netdrv] r8169: remove rtl_ocpdr_cond. (Ivan Vecera) [842651]
- [netdrv] r8169: fix argument in rtl_hw_init_8168g. (Ivan Vecera) [842651]
- [netdrv] r8169: support RTL8168G (Ivan Vecera) [842651]
- [netdrv] r8169: abstract out loop conditions. (Ivan Vecera) [842651]
- [netdrv] r8169: ephy, eri and efuse functions signature changes. (Ivan Vecera) [842651]
- [netdrv] r8169: csi_ops signature change. (Ivan Vecera) [842651]
- [netdrv] r8169: mdio_ops signature change. (Ivan Vecera) [842651]
- [netdrv] r8169: add RTL8106E support. (Ivan Vecera) [842651]
- [netdrv] r8169: RxConfig hack for the 8168evl. (Ivan Vecera) [842651]
- [netdrv] r8169: avoid NAPI scheduling delay. (Ivan Vecera) [842651]
- [netdrv] r8169: call netif_napi_del at errpaths and at driver unload (Ivan Vecera) [842651]
- [netdrv] r8169: fix unsigned int wraparound with TSO (Ivan Vecera) [842651]
- [netdrv] r8169: support the new RTL8411 chip. (Ivan Vecera) [842651]
- [netdrv] r8169: adjust some functions of 8111f (Ivan Vecera) [842651]
- [netdrv] r8169: support the new RTL8402 chip. (Ivan Vecera) [842651]
- [netdrv] r8169: add device specific CSI access helpers. (Ivan Vecera) [842651]
- [netdrv] r8169: modify pll power function (Ivan Vecera) [842651]
- [netdrv] r8169: 8168c and later require bit 0x20 to be set in Config2 for PME signaling. (Ivan Vecera) [842651]
- [netdrv] r8169: Config1 is read-only on 8168c and later. (Ivan Vecera) [842651]
- [netdrv] r8169: enable napi on resume. (Ivan Vecera) [842651]
- [netdrv] r8169: fix comment typo (Ivan Vecera) [842651]
- [netdrv] r8169: stop using net_device.{base_addr, irq}. (Ivan Vecera) [842651]
- [netdrv] r8169: move rtl_cfg_info closer to its caller. (Ivan Vecera) [842651]
- [netdrv] r8169: move the netpoll handler after the irq handler. (Ivan Vecera) [842651]
- [netdrv] r8169: move rtl8169_open after rtl_task it depends on. (Ivan Vecera) [842651]
- [netdrv] r8169: move rtl_set_rx_mode before its rtl_hw_start callers. (Ivan Vecera) [842651]
- [netdrv] r8169: move net_device_ops beyond the methods it references. (Ivan Vecera) [842651]
- [netdrv] r8169: move the driver probe method to the end of the driver file. (Ivan Vecera) [842651]
- [netdrv] r8169: move the driver removal method to the end of the driver file. (Ivan Vecera) [842651]
- [netdrv] r8169: runtime resume before shutdown. (Ivan Vecera) [842651]
- [netdrv] r8169: corrupted IP fragments fix for large mtu. (Ivan Vecera) [842651]
- [netdrv] r8169: Remove alloc_etherdev error messages (Ivan Vecera) [842651]
- [netdrv] r8169: spinlock redux. (Ivan Vecera) [842651]
- [netdrv] r8169: avoid a useless work scheduling. (Ivan Vecera) [842651]
- [netdrv] r8169: move task enable boolean to bitfield. (Ivan Vecera) [842651]
- [netdrv] r8169: bh locking redux and task scheduling. (Ivan Vecera) [842651]
- [netdrv] r8169: fix early queue wake-up. (Ivan Vecera) [842651]
- [netdrv] r8169: remove work from irq handler. (Ivan Vecera) [842651]
- [netdrv] r8169: missing barriers. (Ivan Vecera) [842651]
- [netdrv] r8169: irq mask helpers. (Ivan Vecera) [842651]
- [netdrv] r8169: factor out IntrMask writes. (Ivan Vecera) [842651]
- [netdrv] r8169: stop delaying workqueue. (Ivan Vecera) [842651]
- [netdrv] r8169: remove rtl8169_reinit_task. (Ivan Vecera) [842651]
- [netdrv] r8169: remove hardcoded PCIe registers accesses. (Ivan Vecera) [842651]
- [netdrv] r8169: increase the delay parameter of pm_schedule_suspend (Ivan Vecera) [842651]
- [netdrv] r8169: Fix runtime power management (Ivan Vecera) [842651]
- [netdrv] r8169 / PCI / PM: Add simplified runtime PM support (rev. 3) (Ivan Vecera) [842651]
- [netdrv] r8169: fix potentially dangerous trailing '; ' in #defined values/expressions (Ivan Vecera) [842651]
- [netdrv] r8169: fix wrong eee setting for rlt8111evl (Ivan Vecera) [842651]
- [netdrv] r8169: fix driver shutdown WoL regression. (Ivan Vecera) [842651]
- [netdrv] r8169: add skb frag size accessors (Ivan Vecera) [842651]
- [netdrv] r8169: do not enable the TBI for anything but the original 8169. (Ivan Vecera) [842651]
- [netdrv] r8169: remove erroneous processing of always set bit. (Ivan Vecera) [842651]
- [netdrv] r8169: fix WOL setting for 8105 and 8111evl (Ivan Vecera) [842651]
- [netdrv] r8169: add MODULE_FIRMWARE for the firmware of 8111evl (Ivan Vecera) [842651]
- [netdrv] r8169: convert to SKB paged frag API. (Ivan Vecera) [842651]
- [netdrv] bna: fix assignment of 0/1 to bool variables (Ivan Vecera) [830018]
- [netdrv] bna: Fix non-kernel-doc comments with kernel-doc start markers (Ivan Vecera) [830018]
- [netdrv] bna: Fix (nearly-)kernel-doc comments for various functions (Ivan Vecera) [830018]
- [netdrv] bna: Remove casts to same type (Ivan Vecera) [830018]
- [netdrv] bna: remove redundant NULL test before release_firmware() (Ivan Vecera) [830018]
- [netdrv] bna: Update driver version to 3.0.23.0 (Ivan Vecera) [830018]
- [netdrv] bna: Function name changes and cleanups (Ivan Vecera) [830018]
- [netdrv] bna: Remove tx tasklet (Ivan Vecera) [830018]
- [netdrv] bna: tx rx cleanup fix (Ivan Vecera) [830018]
- [netdrv] bna: ioc cleanups (Ivan Vecera) [830018]
- [netdrv] bna: Flash controller ioc pll init fixes (Ivan Vecera) [830018]
- [netdrv] bna: Serialize smem access during adapter initialization (Ivan Vecera) [830018]
- [netdrv] bna: Remove boolean comparisons to true/false (Ivan Vecera) [830018]
- [netdrv] bna: fix error handling of bnad_get_flash_partition_by_offset() (Ivan Vecera) [830018]
- [netdrv] bna: Implement ethtool flash_device entry point (Ivan Vecera) [830018]
- [netdrv] bna: Remove alloc_etherdev error messages (Ivan Vecera) [830018]
- [netdrv] bna: Remove unnecessary k.alloc/v.alloc OOM messages (Ivan Vecera) [830018]
- [netdrv] bna: fix sparse warnings/errors (Ivan Vecera) [830018]
- [netdrv] bna: make ethtool_ops and strings const (Ivan Vecera) [830018]
- [netdrv] bna: Add debugfs interface (Ivan Vecera) [830018]
- [netdrv] bna: Added flash sub-module and ethtool eeprom entry points (Ivan Vecera) [830018]
- [netdrv] bna: Convert MAC_ADDRLEN uses to ETH_ALEN (Ivan Vecera) [830018]
- [netdrv] bna: sweep the floors and convert some .get_drvinfo routines to strlcpy (Ivan Vecera) [830018]
- [netdrv] bna: add skb frag size accessors (Ivan Vecera) [830018]
- [netdrv] be2net: implement unicast filtering (Ivan Vecera) [813400]
- [netdrv] bna: don't set ndo_set_rx_mode (Ivan Vecera) [815303]
- [net] Statically initialize init_net.dev_base_head (Weiping Pan) [853302]
- [net] cgroup: fix access the unallocated memory in netprio cgroup (Weiping Pan) [853302]
- [net] cgroup: fix out of bounds accesses (Weiping Pan) [853302]
- [net] cgroup: fix panic in netprio_cgroup (Weiping Pan) [853302]
- [netdrv] enic: remove unnecessary setting of skb->dev (Stefan Assmann) [829503]
- [netdrv] enic: Convert compare_ether_addr to ether_addr_equal (Stefan Assmann) [829503]
- [netdrv] enic: replace open-coded ARRAY_SIZE with macro (Stefan Assmann) [829503]
- [netdrv] enic: Stop using NLA_PUT*() (Stefan Assmann) [829503]
- [netdrv] enic: Fix addr valid check in enic_set_vf_mac (Stefan Assmann) [829503]
- [netdrv] enic: fix an endian bug in enic_probe() (Stefan Assmann) [829503]
- [netdrv] enic: Fix endianness bug (Stefan Assmann) [829503]
- [pci] x2apic: fix optout message (Prarit Bhargava) [860729]
- [tools] perf: fix parallel build (Eric Sandeen) [859259]
- [scsi] remove no longer valid BUG_ON in scsi_lld_busy (Jeff Garzik) [842881]
- [net] Add netif_get_num_default_rss_queues (Michal Schmidt) [859399]

* Fri Sep 28 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-314.el6]
- [usb] serial: qcserial avoid pointing to freed memory (Don Zickus) [699676]
- [usb] serial: Fix qcserial memory leak on rmmod (Don Zickus) [699676]
- [usb] serial: fix a memory leak in qcprobe error path (Don Zickus) [699676]
- [virt] kvmclock: unbreak registration by aligning with upstream (Michael S. Tsirkin) [856198]
- [x86] apic: replace eoi_write on apic disable (Michael S. Tsirkin) [856198]
- [scsi] qla4xxx: v5.03.00.00.06.04-k0 (Chad Dupuis) [826570]
- [scsi] qla4xxx: Update Copyright header (Chad Dupuis) [826570]
- [scsi] qla4xxx: Added support for ISP83XX (Chad Dupuis) [826570]
- [scsi] qla4xxx: Added new function qla4_8xxx_get_minidump (Chad Dupuis) [826570]
- [scsi] qla4xxx: Set IDC version in correct way (Chad Dupuis) [826570]
- [scsi] qla4xxx: Replace all !is_qla8022() with is_qla40XX() (Chad Dupuis) [826570]
- [scsi] qla4xxx: Added new functions in isp_ops (Chad Dupuis) [826570]
- [scsi] qla4xxx: Clean-up and optimize macros (Chad Dupuis) [826570]
- [scsi] qla4xxx: Rename macros from 82XX to 8XXX (Chad Dupuis) [826570]
- [scsi] qla4xxx: Update func name from ql4_ to qla4_ (Chad Dupuis) [826570]
- [scsi] qla4xxx: Update structure and variable names (Chad Dupuis) [826570]
- [scsi] qla4xxx: Update function name from 8xxx to 82xx (Chad Dupuis) [826570]
- [scsi] qla4xxx: v5.02.00.00.06.04-k1 (Chad Dupuis) [826570]
- [scsi] qla4xxx: Wait for cmd to complete before chip reset for ISP40XX (Chad Dupuis) [826570]
- [scsi] qla4xxx: Clear interrupt while unloading driver (Chad Dupuis) [826570]
- [scsi] qla4xxx: Fix lockdep warning in qla4xxx_post_work() (Chad Dupuis) [826570]
- [scsi] qla4xxx: v5.02.00.00.06.04-k0 (Chad Dupuis) [826570]
- [scsi] qla4xxx: Properly handle SCSI underrun while processing status IOCBs (Chad Dupuis) [826570]
- [scsi] qla4xxx: Fix multiple conn login event issue during session recovery (Chad Dupuis) [826570]
- [scsi] qla4xxx: Fix gcc warning for x86 system (Chad Dupuis) [826570]
- [scsi] qla4xxx: Fix memory corruption issue in qla4xxx_ep_connect (Chad Dupuis) [826570]
- [scsi] qla4xxx: remove unnecessary read of PCI_CAP_ID_EXP (Chad Dupuis) [826570]
- [scsi] qla4xxx: Fix Spell check (Chad Dupuis) [826570]
- [scsi] qla4xxx: Fix a Sparse warning message (Chad Dupuis) [826570]
- [scsi] qla4xxx: multi-session fix for flash ddbs (Chad Dupuis) [826570]
- [scsi] qla4xxx: v5.02.00.00.06.03-k5 (Chad Dupuis) [826570]
- [scsi] qla4xxx: Capture minidump for ISP82XX on firmware failure (Chad Dupuis) [826570]
- [scsi] qla4xxx: Add change_queue_depth API support (Chad Dupuis) [826570]
- [scsi] qla4xxx: Fix clear ddb mbx command failure issue (Chad Dupuis) [826570]
- [scsi] qla4xxx: Fix kernel panic during discovery logout (Chad Dupuis) [826570]
- [scsi] qla4xxx: Correct early completion of pending mbox (Chad Dupuis) [826570]
- [scsi] qla4xxx: use pci_dev->revision (Chad Dupuis) [826570]
- [drm] edid: limit printk when facing bad edid (Dave Airlie) [857792]
- [drm] backport 3.6 drm into rhel6.4 kernel (Dave Airlie) [857792]
- [mm] backport the extended prefault helpers from upstream (Dave Airlie) [857792]
- [gpu] vga drivers backport (Dave Airlie) [857792]
- [base] dma-buf: backport dma-buf support (Dave Airlie) [857792]
- [acpi] export symbol acpi_get_table_with_size (Dave Airlie) [857792]
- [kernel] sched: Add __wake_up_all_locked() API (Dave Airlie) [857792]
- [kernel] sched: wait_event_interruptible_locked() interface (Dave Airlie) [857792]
- [pci] pci_regs: define LNKSTA2 pcie cap + bits (Dave Airlie) [857792]
- [mm] slab: introduce kmalloc_array() (Dave Airlie) [857792]
- [fs] sysfs: Add sysfs_merge_group() and sysfs_unmerge_group() (Dave Airlie) [857792]
- [i2c] export bit-banging algo functions (Dave Airlie) [857792]
- [netdrv] bnx2: Clean up remainint iounmap (Neil Horman) [826727]
- [netdrv] bnx2: Try to recover from PCI block reset (Neil Horman) [826727]
- [netdrv] bnx2: Fix bug in bnx2_free_tx_skbs() (Neil Horman) [826727]
- [netdrv] bnx2: Add missing netif_tx_disable() in bnx2_close() (Neil Horman) [826727]
- [netdrv] bnx2: Add "fall through" comments (Neil Horman) [826727]
- [netdrv] bnx2: Update version 2.2.2 (Neil Horman) [826727]
- [netdrv] bnx2: Read PCI function number from internal register (Neil Horman) [826727]
- [netdrv] bnx2: Dump additional BC_STATE during firmware sync timeout (Neil Horman) [826727]
- [netdrv] bnx2: Dump all FTQ_CTL registers during tx_timeout (Neil Horman) [826727]
- [netdrv] bnx2: Remove casts to same type (Neil Horman) [826727]
- [netdrv] bnx2: replace open-coded ARRAY_SIZE with macro (Neil Horman) [826727]
- [netdrv] bnx2: stop using net_device.{base_addr, irq} (Neil Horman) [826727]
- [netdrv] bnx2: unify return value of .ndo_set_mac_address if address is invalid (Neil Horman) [826727]
- [usb] ti_usb: fix printk format warning (Don Zickus) [846419]
- [usb] ti_usb_3410_5052: adding multitech dialup fax/modem devices (Don Zickus) [846419]
- [pci] Enable ATS at the device state restore (Don Dugger) [767886]
- [pci] intel-iommu: Move duplicate list-mangling code into unlink_domain_info() helper (Don Dugger) [767886]
- [pci] intel-iommu: Add device info into list before doing context mapping (Don Dugger) [767886]
- [netdrv] igbvf: Fix (nearly-)kernel-doc comments for various functions (Stefan Assmann) [819104]
- [netdrv] igbvf: fix divide by zero (Stefan Assmann) [819104]
- [netdrv] igbvf: fix the bug when initializing the igbvf (Stefan Assmann) [819104]
- [netdrv] intel: make wired ethernet driver message level consistent (rev2) (Stefan Assmann) [819104]
- [netdrv] igbvf: Use ETH_ALEN (Stefan Assmann) [819104]
- [netdrv] igbvf: reset netdevice addr_assign_type if changed (Stefan Assmann) [819104]
- [netdrv] igbvf: rename dev_hw_addr_random and remove redundant second (Stefan Assmann) [819104]
- [netdrv] igbvf: refactor Interrupt Throttle Rate code (Stefan Assmann) [819104]
- [netdrv] igbvf: change copyright date (Stefan Assmann) [819104]
- [netdrv] igbvf: remove unneeded cast (Stefan Assmann) [819104]
- [x86] cpu: keep SEP flag enabled on 64-bit if execshield is on (Eduardo Habkost) [821463]
- [x86] Revert: intel_idle: disable NHM/WSM HW C-state auto-demotion (Matthew Garrett) [834097]
- [block] cciss: fix handling of protocol error (Tomas Henzl) [858292]
- [ata] ata_piix: IDE-mode SATA patch for Intel DH89xxCC DeviceIDs (David Milburn) [859491]
- [scsi] hpsa: fix handling of protocol error (Tomas Henzl) [857956]
- [x86] mce: Introduce mce_gather_info() (Luming Yu) [855775]
- [mm] hwpoison: Remove extra unwanted call to send_sig_info() (Lenny Szubowicz) [855775]

* Thu Sep 27 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-313.el6]
- [misc] sgi-xp: fails to load when cpu 0 is out of IRQ resources (George Beshers) [854677]
- [misc] sgi-xp: nested calls to spin_lock_irqsave() (George Beshers) [854677]
- [net] openvswitch: Make Open vSwitch use non-accel VLAN tagging (Thomas Graf) [859048]
- [net] vlan: dont drop packets from unknown vlans in promiscuous mode (Thomas Graf) [859048]
- [netdrv] e1000e: update driver version number (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup - remove unnecessary variable (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup - remove inapplicable comment (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup strict checkpatch check (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup strict checkpatch MEMORY_BARRIER checks (Dean Nelson) [819103]
- [netdrv] e1000e: DoS while TSO enabled caused by link partner with small MSS (Dean Nelson) [819103]
- [netdrv] e1000e: fix panic while dumping packets on Tx hang with IOMMU (Dean Nelson) [819103]
- [netdrv] e1000e: 82571 Tx Data Corruption during Tx hang recovery (Dean Nelson) [819103]
- [netdrv] e1000e: fix test for PHY being accessible on 82577/8/9 and I217 (Dean Nelson) [819103]
- [netdrv] e1000e: Correct link check logic for 82571 serdes (Dean Nelson) [819103]
- [netdrv] e1000e: Program the correct register for ITR when using MSI-X. (Dean Nelson) [819103]
- [netdrv] e1000e: Cleanup code logic in e1000_check_for_serdes_link_82571() (Dean Nelson) [819103]
- [netdrv] e1000e: Fix (nearly-)kernel-doc comments for various functions (Dean Nelson) [819103]
- [netdrv] e1000e: remove use of IP payload checksum (Dean Nelson) [819103]
- [netdrv] e1000e: use more informative logging macros when netdev not yet registered (Dean Nelson) [819103]
- [netdrv] e1000e: test for valid check_reset_block function pointer (Dean Nelson) [819103]
- [netdrv] e1000e: fix Rapid Start Technology support for i217 (Dean Nelson) [819103]
- [netdrv] e1000e: fix typo in definition of E1000_CTRL_EXT_FORCE_SMBUS (Dean Nelson) [819103]
- [netdrv] e1000e: Fix merge conflict (net->net-next) (Dean Nelson) [819103]
- [netdrv] e1000e: clear REQ and GNT in EECD (82571 && 82572) (Dean Nelson) [819103]
- [netdrv] e1000e: enable forced master/slave on 82577 (Dean Nelson) [819103]
- [netdrv] e1000e: initial support for i217 (Dean Nelson) [819103]
- [netdrv] e1000e: Remove special case for 82573/82574 ASPM L1 disablement (Dean Nelson) [819103]
- [netdrv] e1000e: Disable ASPM L1 on 82574 (Dean Nelson) [819103]
- [netdrv] e1000e: Driver workaround for IPv6 Header Extension Erratum. (Dean Nelson) [819103]
- [netdrv] e1000e: Resolve intermittent negotiation issue on 82574/82583. (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup long {read|write}_reg_locked PHY ops function pointers (Dean Nelson) [819103]
- [netdrv] e1000e: suggest a possible workaround to a device hang on 82577/8 (Dean Nelson) [819103]
- [netdrv] e1000e: fix .ndo_set_rx_mode for 82579 (Dean Nelson) [819103]
- [netdrv] e1000e: PHY initialization flow changes for 82577/8/9 (Dean Nelson) [819103]
- [netdrv] e1000e: workaround EEPROM configuration change on 82579 (Dean Nelson) [819103]
- [netdrv] e1000e: 82579 potential system hang on stress when ME enabled (Dean Nelson) [819103]
- [netdrv] e1000e: 82579 packet drop workaround (Dean Nelson) [819103]
- [netdrv] e1000e: Enable DMA Burst Mode on 82574 by default. (Dean Nelson) [819103]
- [netdrv] e1000e: Disable Far-End LoopBack following reset on 80003ES2LAN. (Dean Nelson) [819103]
- [netdrv] e1000e: Fix default interrupt throttle rate not set in NIC HW (Dean Nelson) [819103]
- [netdrv] e1000e: MSI interrupt test failed, using legacy interrupt (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup boolean logic (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup remaining strings split across multiple lines (Dean Nelson) [819103]
- [netdrv] e1000e: issues in Sx on 82577/8/9 (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup indexed register arrays (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup NAPI routine (Dean Nelson) [819103]
- [netdrv] e1000e: Minor comment clean-up. (Dean Nelson) [819103]
- [netdrv] e1000e: Guarantee descriptor writeback flush success. (Dean Nelson) [819103]
- [netdrv] e1000e: make wired ethernet driver message level consistent (rev2) (Dean Nelson) [819103]
- [netdrv] e1000e: use msleep instead of mdelay (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup whitespace and indentation (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup incorrect filename in comment (Dean Nelson) [819103]
- [netdrv] e1000e: rename e1000e_reload_nvm() and call as function pointer (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup - remove unnecessary variable (Dean Nelson) [819103]
- [netdrv] e1000e: use true/false for boolean send_xon, do not assume always true (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup comment in e1000_hash_mc_addr() (Dean Nelson) [819103]
- [netdrv] e1000e: rename e1000e_config_collision_dist() and call as function pointer (Dean Nelson) [819103]
- [netdrv] e1000e: comment correction in e1000e_set_kmrn_lock_loss_workaround_ich8lan (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup calls to setup_physical_interface function pointer (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup use of check_reset_block function pointer (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup use of check_mng_mode function pointer (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: rename e1000e_setup_link() and call as function pointer (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: rename e1000e_id_led_init() and call as function pointer (Dean Nelson) [819103]
- [netdrv] e1000e: cosmetic comment changes to make lines less than 80 characters (Dean Nelson) [819103]
- [netdrv] e1000e: cosmetic change to boolean comparisons (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup goto statements to exit points without common work (Dean Nelson) [819103]
- [netdrv] e1000e: potentially incorrect return for e1000e_setup_fiber_serdes_link (Dean Nelson) [819103]
- [netdrv] e1000e: potentially incorrect return for e1000_init_hw_ich8lan (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: minor whitespace addition (insert blank line separator) (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: remove unnecessary variable initializations (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: remove unnecessary test and return (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: remove unnecessary variable ret_val (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: remove unreachable statement (Dean Nelson) [819103]
- [netdrv] e1000e: potentially incorrect return for e1000_set_d3_lplu_state_ich8lan (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: always return 0 (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: remove unnecessary assignments just before returning (Dean Nelson) [819103]
- [netdrv] e1000e: potential incorrect return for e1000_setup_copper_link_80003es2lan (Dean Nelson) [819103]
- [netdrv] e1000e: potentially incorrect return for e1000_cfg_kmrn_10_100_80003es2lan (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: rename goto labels to be more meaningful (Dean Nelson) [819103]
- [netdrv] e1000e: cleanup: use goto for common work needed by multiple exit points (Dean Nelson) [819103]
- [netdrv] e1000e: replace '1' with 'true' for boolean get_link_status (Dean Nelson) [819103]
- [netdrv] e1000e: pass pointer to hw struct for e1000_init_mac_params_XXX() (Dean Nelson) [819103]
- [netdrv] e1000e: use true/false for bool autoneg_false (Dean Nelson) [819103]
- [netdrv] e1000e: remove unnecessary parentheses (Dean Nelson) [819103]
- [netdrv] e1000e: remove unnecessary returns from void functions (Dean Nelson) [819103]
- [netdrv] e1000e: remove test that is always false (Dean Nelson) [819103]
- [netdrv] e1000e: add skb frag size accessors (Dean Nelson) [819103]
- [scsi] qla2xxx: Update version number to 8.04.00.08.06.4-k. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Use the right field for container_of. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Allow MSI interrupt registration for ISP82xx. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Don't toggle RISC interrupt bits after IRQ lines are attached. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix incorrect status reporting on DIF errors. (Chad Dupuis) [826565]
- [scsi] qla2xxx: T10 DIF - ISP83xx changes. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix for legacy interrupts for ISP83xx. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Enable fw attributes for ISP24xx and above. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Get fcal position map should not be called for p2p topology. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Set Maximum Read Request Size to 4K. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Enclose adapter related calls in adapter check in failed state handler. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix for handling some error conditions in loopback. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix description of qla2xmaxqdepth parameter. (Chad Dupuis) [826565]
- [scsi] qla2xxx: set idc version if function is first one to come. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Do not restrict the number of NPIV ports for ISP83xx. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Do PCI fundamental reset for ISP83xx (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fail initialization if unable to load RISC code. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Ensure PLOGI is sent to Fabric Management-Server upon request. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Remove setting Scsi_host->this_id during adapter probe. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Use defines instead of hardcoded values for intr status. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Dont call nic restart firmware if it is already active and running. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Wrong PCIe(2.5Gb/s x8) speed in the kerenel message for ISP82xx. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Perform ROM mbx cmd access only after ISP soft-reset during f/w recovery. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Implement beacon support for ISP83xx. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix for continuous rescan attempts in arbitrated loop topology. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Only enable link up on the correct interrupt event. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Update the driver copyright. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Don't register to legacy interrupt for ISP82xx. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Changes for ISP83xx loopback support. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Add bit to identify adapters for thermal temp. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Implemetation of mctp. (Chad Dupuis) [826565]
- [scsi] qla2xxx: IDC implementation for ISP83xx. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Add FW DUMP SIZE sysfs attribute. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Implementation of bidirectional. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Use bitmap to store loop_id's for fcports. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Display mailbox failure by default. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix typo in qla2xxx files (Chad Dupuis) [826565]
- [scsi] qla2xxx: Remove redundant NULL check before release_firmware() call. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Add check in qla82xx_watchdog for failed hardware state. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Add I2C BSG interface. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Bind to ISP8031 devices. (Chad Dupuis) [826565]
- [scsi] Revert: qla2xxx: During loopdown perform Diagnostic loopback. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Display proper firmware version when new minidump template is gathered for ISP82xx. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Don't capture minidump for ISP82xx on flash update from application. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Log link up and link down messages to track link flops. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix discrepencies between RHEL 6 and upstream. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Avoid losing any fc ports when loop id's are exhausted. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Optimize existing port name server query matching. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Remove mirrored field vp_idx from struct fc_port. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fixups for ISP83xx. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Display proper supported speeds for 16G FC adapters. (Chad Dupuis) [826565]
- [scsi] qla2xxx: handle default case in qla2x00_request_firmware() (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix typo in qla_mbx.c (Chad Dupuis) [826565]
- [scsi] qla2xxx: Micro optimization in queuecommand handler (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix typo in qla_init.c (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix typo in qla_bsg.c (Chad Dupuis) [826565]
- [scsi] qla2xxx: Stats should be different from physical and virtual ports (Chad Dupuis) [826565]
- [scsi] qla2xxx: Add ql_dbg_verbose logging level. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Handle interrupt registration failures more gracefully. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Change "Done" to "Entering" in the debug print statement in qla2x00_port_logout. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Detect PEG errors. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Remove unneeded DPC wakeups from qla82xx_watchdog. (Chad Dupuis) [826565]
- [scsi] qla2xxx: Fix typo in bus-reset handler. (Chad Dupuis) [826565]
- [mm] thp: fix pmd_present for split_huge_page and PROT_NONE with THP (Andrea Arcangeli) [858385]
- [wireless] rt2x00: Add support for BUFFALO WLI-UC-GNM2 to rt2800usb (Stanislaw Gruszka) [841578]
- [wireless] cfg80211: process pending events when unregistering net device (Stanislaw Gruszka) [841578]
- [net] mac80211: cancel mesh path timer (Stanislaw Gruszka) [841578]
- [wireless] iwlwifi: fix debug print in iwl_sta_calc_ht_flags (Stanislaw Gruszka) [841578]
- [wireless] rt61pci: fix NULL pointer dereference in config_lna_gain (Stanislaw Gruszka) [841578]
- [wireless] iwlwifi: disable greenfield transmissions as a workaround (Stanislaw Gruszka) [841578]
- [net] mac80211: fail authentication when AP denied authentication (Stanislaw Gruszka) [841578]
- [wireless] reg: restore previous behaviour of chan->max_power calculations (Stanislaw Gruszka) [841578]
- [net] mac80211: fix read outside array bounds (Stanislaw Gruszka) [841578]
- [wireless] ath9k: Add PID/VID support for AR1111 (Stanislaw Gruszka) [841578]
- [wireless] b43: fix crash with OpenFWWF (Stanislaw Gruszka) [841578]
- [wireless] iwlwifi: Check BSS ctx active before call mac80211 (Stanislaw Gruszka) [841578]
- [wireless] rndis_wlan: release BSS structures returned by cfg80211_inform_bss() (Stanislaw Gruszka) [841578]
- [net] mac80211: fix crash with single-queue drivers (Stanislaw Gruszka) [841578]
- [wireless] rt2800usb: 2001:3c17 is an RT3370 device (Stanislaw Gruszka) [841578]
- [wireless] Backport ti drivers from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport orinoco driver from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport rtl818x driver from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport ipw2x00 driver from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport p54 driver from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport ath drivers family from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport b43legacy driver from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport bcma bus driver from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport b43 driver from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport ssb bus driver from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport rt2x00 driver from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport iwlwifi driver from linux 3.5 (Stanislaw Gruszka) [818672 841578]
- [wireless] Backport iwlegacy driver from 3.5 (Stanislaw Gruszka) [841578]
- [wireless] Backport mac80211 from linux 3.5 (Stanislaw Gruszka) [841578]
- [wireless] fix kabi breakage caused by wireless update (Stanislaw Gruszka) [841578]
- [wireless] Backport wireless core from linux 3.5 (Stanislaw Gruszka) [841578]
- [x86] pci: Add option to not assign BAR's if not already assigned (George Beshers) [859966]
- [edac] sb_edac: Avoid overflow errors at memory size calculation (Mauro Carvalho Chehab) [859132]
- [Documentation] kernel-parameters.txt: Add intel_idle.max_cstate (Prarit Bhargava) [858337]
- [kernel] rcu: Remove function versions of __kfree_rcu and offset (Neil Horman) [813086]
- [scsi] fix NULL request_queue in scsi_requeue_run_queue() (Jeff Garzik) [842881]
- [netdrv] tg3: Set RX_CHECKSUMS appropriately (John Feeney) [828967]
- [firmware] iwlwifi: update firmware for 6205 (Stanislaw Gruszka) [850579]
- [netdrv] pch_gbe: vlan skb len fix (Veaceslav Falico) [851682]
- [net] ipv4/cipso: don't follow a NULL pointer when setsockopt() is called (Amerigo Wang) [842872]
- [net] bridge: Fix timer typo that may render snooping less effective (Nikolay Aleksandrov) [676938]

* Tue Sep 25 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-312.el6]
- [net] svcrpc: fix BUG() in svc_tcp_clear_pages (J. Bruce Fields) [769045]
- [fs] nfs: Properly handle the case where the delegation is revoked (Steve Dickson) [842435]
- [fs] nfs: Move cl_delegations to the nfs_server struct (Steve Dickson) [842435]
- [fs] nfs: Introduce nfs_detach_delegations() (Steve Dickson) [842435]
- [fs] nfs: Fix a number of RCU issues in the NFSv4 delegation code (Steve Dickson) [842435]
- [netdrv] netxen: fix link notification order (Veaceslav Falico) [826574]
- [netdrv] netxen: remove unnecessary setting of skb->dev (Veaceslav Falico) [826574]
- [netdrv] netxen: restrict force firmware dump when dump is disabled (Veaceslav Falico) [826574]
- [netdrv] netxen: Error return off by one for XG port (Veaceslav Falico) [826574]
- [netdrv] netxen: Error return off by one in netxen_nic_set_pauseparam() (Veaceslav Falico) [826574]
- [netdrv] netxen: Fix estimation of recv MSS in case of LRO (Veaceslav Falico) [826574]
- [netdrv] netxen: added miniDIMM support in driver (Veaceslav Falico) [826574]
- [netdrv] netxen: Allow only useful and recommended firmware dump capture mask values (Veaceslav Falico) [826574]
- [netdrv] netxen_nic: disable minidump by default (Veaceslav Falico) [826574]
- [netdrv] netxen: get rid of a redundant test for NULL before call to release_firmware() (Veaceslav Falico) [826574]
- [netdrv] netxen: Fix endian bug (Veaceslav Falico) [826574]
- [netdrv] netxen: unify return value of .ndo_set_mac_address if address is invalid (Veaceslav Falico) [826574]
- [mm] coredump: add VM_NODUMP, MADV_DONTDUMP, MADV_DODUMP (Jason Baron) [739001]
- [mm] coredump: remove VM_ALWAYSDUMP flag (Jason Baron) [739001]
- [net] ipv6: unify conntrack reassembly expire code with standard one (Amerigo Wang) [726807]
- [net] ipv6: add a new namespace for nf_conntrack_reasm (Amerigo Wang) [726807]
- [net] ipv6: fix overlap check for fragments (Amerigo Wang) [726807]
- [net] netfilter: discard overlapping IPv6 fragment (Amerigo Wang) [726807]
- [net] netfilter: defrag: remove one redundant atomic ops (Amerigo Wang) [726807]
- [acpi] Fix logic for removing mappings in 'acpi_unmap' (Myron Stowe) [816517]
- [acpi] acpica: Expand OSL memory read/write interfaces to 64 bits (Myron Stowe) [816517]
- [acpi] Remove ./drivers/acpi/atomicio.[ch] (Myron Stowe) [816517]
- [acpi] Add RAM mapping support to ACPI (Myron Stowe) [816517]
- [acpi] apei: Add 64-bit read/write support for APEI on i386 (Myron Stowe) [816517]
- [acpi] apei: Convert atomicio routines (Myron Stowe) [816517]
- [acpi] Export interfaces for ioremapping/iounmapping ACPI registers (Myron Stowe) [816517]
- [acpi] Fix a fix section mismatch (Myron Stowe) [816517]
- [net] ethtool: update ethtool_rx_flow_spec and avoid kabi breakage (Nikolay Aleksandrov) [847019]
- [net] ethtool: add ntuple flow specifier data to network flow classifier (Nikolay Aleksandrov) [847019]
- [net] ethtool: Add Ethernet MAC-level filtering/steering (Nikolay Aleksandrov) [847019]
- [net] ethtool: Remove unimplemented flow specification types (Nikolay Aleksandrov) [847019]
- [net] ethtool: Allow drivers to select RX NFC rule locations (Nikolay Aleksandrov) [847019]
- [net] ethtool: Fix potential user buffer overflow for ETHTOOL_{G, S}RXFH (Nikolay Aleksandrov) [847019]
- [net] ethtool: add rtnetlink & sched.h in ifndef GENKSYMS (Nikolay Aleksandrov) [847019]
- [net] ethtool: Added kernel support in EEE Ethtool commands (Nikolay Aleksandrov) [847019]
- [net] ethtool: Add reset operation (Nikolay Aleksandrov) [847019]
- [net] ethtool: Change ETHTOOL_PHYS_ID implementation to allow dropping RTNL (Nikolay Aleksandrov) [847019]
- [net] ethtool: Extend the ethtool API to obtain plugin module eeprom data (Nikolay Aleksandrov) [847019]
- [net] ethtool: Added support for FW dump (Nikolay Aleksandrov) [847019]
- [net] ethtool support to configure number of channels (Nikolay Aleksandrov) [847019]
- [scsi] scsi_dh_alua: Enable STPG for unavailable ports (Ewan Milne) [857145]
- [net] skbuff: do not take an additional reference in skb_frag_set_page (Neil Horman) [859433]
- [i2c] add support for iSMT on bordenville (Neil Horman) [791368]
- [pci] iommu, dmar: Use pr_format() instead of PREFIX to tidy up pr_*() calls (Don Dutile) [726531]
- [pci] iommu, dmar: Reserve mmio space used by the IOMMU, if the BIOS forgets to (Don Dutile) [726531]
- [pci] intel-iommu: Replace printks with appropriate pr_*() (Don Dutile) [726531]
- [mm] fix potential anon_vma locking issue in mprotect() (Andrea Arcangeli) [858389]
- [block] mtip32xx: fix user_buffer check in exec_drive_command (David Milburn) [837370]
- [block] mtip32xx: remove HOTPLUG_PCI_PCIE dependancy (David Milburn) [837370]
- [block] mtip32xx: Convert macro definitions for flag bits to enum (David Milburn) [837370]
- [block] mtip32xx: Remove 'registers' and 'flags' from sysfs (David Milburn) [837370]
- [block] mtip32xx: Changes to sysfs entries (David Milburn) [837370]
- [block] mtip32xx: minor performance tweak (David Milburn) [837370]
- [block] mtip32xx: Fix to support more than one sector in exec_drive_command() (David Milburn) [837370]
- [block] mtip32xx: Use plain spinlock for 'cmd_issue_lock' (David Milburn) [837370]
- [block] mtip32xx: Set block queue boundary variables (David Milburn) [837370]
- [block] mtip32xx: Fix to handle TFE for PIO(IOCTL/internal) commands (David Milburn) [837370]
- [block] mtip32xx: Change HDIO_GET_IDENTITY to return stored data (David Milburn) [837370]
- [block] mtip32xx: Set custom timeouts for PIO commands (David Milburn) [837370]
- [block] mtip32xx: fix clearing an incorrect register in mtip_init_port (David Milburn) [837370]
- [block] mtip32xx: release the semaphore on an error path (David Milburn) [837370]
- [block] mtip32xx: dump tagmap on failure (David Milburn) [837370]
- [block] mtip32xx: fix handling of commands in various scenarios (David Milburn) [837370]
- [block] mtip32xx: Shorten macro names (David Milburn) [837370]
- [block] mtip32xx: misc changes (David Milburn) [837370]
- [block] mtip32xx: Add new sysfs entry 'status' (David Milburn) [837370]
- [block] mtip32xx: make setting comp_time as common (David Milburn) [837370]
- [block] mtip32xx: Add new bitwise flag 'dd_flag' (David Milburn) [837370]
- [block] mtip32xx: fix error handling in mtip_init() (David Milburn) [837370]
- [block] mtip32xx: fix incorrect value set for drv_cleanup_done, and re-initialize and start port in mtip_restart_port() (David Milburn) [837370]
- [kernel] tracing: Convert format output to seq_file (Jiri Olsa) [797067]
- [kernel] tracing: Remove show_format and related macros from TRACE_EVENT (Jiri Olsa) [797067]
- [kernel] tracing: Use defined fields and print_fmt to print formats (Jiri Olsa) [797067]
- [kernel] tracing: Init print_fmt for kprobe events (Jiri Olsa) [797067]
- [kernel] tracing: Init print_fmt for syscall events (Jiri Olsa) [797067]
- [kernel] tracing: Add print_fmt field (Jiri Olsa) [797067]
- [kernel] tracing: Have __dynamic_array() define a field (Jiri Olsa) [797067]
- [pci] remove redundant checking in PCI Express capability routines (Myron Stowe) [832591]
- [pci] Introduce command line option to disable ARI (Myron Stowe) [832591]
- [pci] use pci_is_pcie() in pci core (Myron Stowe) [832591]
- [serial] Basic support for Moschip 9900 family I/O chips (Steve Best) [850941]
- [idle] intel_idle: ivybridge support (Matthew Garrett) [746722]
- [block] Avoid missed wakeup in request waitqueue (Asias He) [848260]
- [netdrv] mlx4: check promisc on proper port (Doug Ledford) [854052]
- [netdrv] mlx4: attach multicast with correct flag (Doug Ledford) [854376]
- [netdrv] mlx4: remove redundant adding of steering type to gid (Doug Ledford) [854053]
- [netdrv] Revert: Fix a merge issue (Doug Ledford) [854053]
- [scsi] lpfc: Update lpfc version to 8.3.5.82.1p (Rob Evers) [827566]
- [scsi] lpfc: Fix null pointer error for piocbq (Rob Evers) [827566]
- [scsi] lpfc: Add missing jumps to mempool_free (Rob Evers) [827566]
- [scsi] lpfc: Fixed leaking memory from pci dma pool (Rob Evers) [827566]
- [scsi] lpfc: Log SCSI XRI on abort handler timeout (Rob Evers) [827566]
- [scsi] lpfc: Fix logging too many fcp underruns (Rob Evers) [827566]
- [scsi] lpfc: Fixed SCSI device reset escalation (Rob Evers) [827566]
- [scsi] lpfc: Fix BlockGuard messages (Rob Evers) [827566]
- [scsi] lpfc: Fix param field to mask for LOCAL_REJ. (Rob Evers) [827566]
- [scsi] lpfc: Add SLI-4 V1 Cap/Res desc support (Rob Evers) [827566]
- [scsi] lpfc: complete list of commands w/ ext. tmo (Rob Evers) [827566]
- [scsi] lpfc: Fix adding fc_host rport entries (Rob Evers) [827566]
- [scsi] lpfc: Fix conflicts in log message numbers (Rob Evers) [827566]
- [scsi] lpfc: Cosmetic changes (Rob Evers) [827566]
- [scsi] lpfc: Fix discovery bug when swapping cables (Rob Evers) [827566]
- [scsi] lpfc: Fixed scsi_eh escalation kernel panic (Rob Evers) [827566]
- [scsi] lpfc: check data transfered on writes (Rob Evers) [827566]
- [scsi] lpfc: remove incorrect message 2520 (Rob Evers) [827566]
- [scsi] lpfc: destroy rrq_pool during driver removal (Rob Evers) [827566]
- [scsi] lpfc: attach OCe14000 adapters (Rob Evers) [827566]
- [scsi] lpfc: set valid bit for loopback testing (Rob Evers) [827566]
- [scsi] lpfc: report misconfigured ports (Rob Evers) [827566]
- [scsi] lpfc: Fix Panic During IO Test (Rob Evers) [827566]
- [scsi] lpfc: dynamic delay multiplier param. (Rob Evers) [827566]
- [scsi] lpfc: Fix abort status (Rob Evers) [827566]
- [scsi] lpfc: Fixed PCI resource provision (Rob Evers) [827566]
- [scsi] lpfc: Fix system hang due to bad mod params (Rob Evers) [827566]
- [scsi] lpfc: Fixed debug helper routine (Rob Evers) [827566]
- [scsi] lpfc: Fix using the wrong xritag (Rob Evers) [827566]
- [scsi] lpfc: Debug routines for dumping SLI4 queues (Rob Evers) [827566]
- [scsi] lpfc: LPe16000 discovery fixes (Rob Evers) [827566]
- [scsi] lpfc: Reregister VPI for SLI3 (Rob Evers) [827566]
- [scsi] lpfc: Fix log message 2597 when no error (Rob Evers) [827566]
- [scsi] lpfc: FCP LOG for Finisar trace correlation (Rob Evers) [827566]
- [scsi] lpfc: Fix error displayed (Rob Evers) [827566]
- [scsi] lpfc: Fix Read Link status data (Rob Evers) [827566]
- [scsi] lpfc: dix, create vports on FCoE SLI4 HBA (Rob Evers) [827566]
- [scsi] lpfc: Fix flogi after flogi ack from target (Rob Evers) [827566]
- [scsi] lpfc: add get controller attributes command (Rob Evers) [827566]
- [scsi] lpfc: handle SLI4-port XRI profile change (Rob Evers) [827566]
- [scsi] lpfc: Add -Werror compilation flag (Rob Evers) [827566]
- [scsi] lpfc: Change def. DA_ID to enabled (Rob Evers) [827566]
- [scsi] lpfc: remove scsi vport host when unloading (Rob Evers) [827566]
- [scsi] lpfc: Increment T10 DIF error injection (Rob Evers) [827566]
- [scsi] lpfc: Update copyright date for files (Rob Evers) [827566]
- [scsi] lpfc: Refine T10 DIF debugfs error injection (Rob Evers) [827566]
- [scsi] lpfc: Make BA_ACC work on exchange (Rob Evers) [827566]
- [scsi] lpfc: Fix KERNEL allocation while lock held (Rob Evers) [827566]
- [scsi] lpfc: Fix usage of bghm for BlockGuard errs (Rob Evers) [827566]
- [scsi] lpfc: inject T10 DIF errors via debugfs (Rob Evers) [827566]
- [scsi] lpfc: Fix BlockGuard for prot. data from HBA (Rob Evers) [827566]
- [scsi] lpfc: add logs in port error/reset (Rob Evers) [827566]
- [scsi] lpfc: Sync up with upstream lpfc driver code (Rob Evers) [827566]
- [scsi] lpfc: Fixed T10 DIF/Blockguard on 16Gb FC (Rob Evers) [827566]
- [scsi] lpfc: Fix files depending on module.h (Rob Evers) [827566]
- [usb] core: fix deadlock in bConfigurationValue attribute method (Don Zickus) [832126]
- [usb] allow drivers to use allocated bandwidth until unbound (Don Zickus) [832126]
- [tools] perf: Add automated tests for event group parsing (Jiri Olsa) [695765]
- [tools] perf: Enable grouping logic for parsed events (Jiri Olsa) [695765]
- [tools] perf: Add support to update event modifier (Jiri Olsa) [695765]
- [tools] perf: Add support to parse event group syntax (Jiri Olsa) [695765]
- [tools] perf: Fix parse events automated tests (Jiri Olsa) [695765]
- [tools] perf: Add support to reuse event grammar to parse out terms (Jiri Olsa) [695765]
- [tools] perf: Make the event parser re-entrant (Jiri Olsa) [695765]
- [tools] perf: Use data struct for arg passing in event parse function (Jiri Olsa) [695765]
- [scsi] ipr: missing unlock before a return (Steve Best) [822647]
- [scsi] ipr: Driver version 2.5.4 (Steve Best) [822647]
- [scsi] ipr: Reduce interrupt lock time (Steve Best) [822647]
- [scsi] ipr: Reduce queuecommand lock time (Steve Best) [822647]
- [scsi] ipr: Driver version 2.5.3 (Steve Best) [822647]
- [scsi] ipr: Increase alignment boundary of command blocks (Steve Best) [822647]
- [scsi] ipr: Increase max concurrent oustanding commands (Steve Best) [822647]
- [scsi] ipr: Remove unnecessary memory barriers (Steve Best) [822647]
- [scsi] ipr: Remove unnecessary interrupt clearing on new adapters (Steve Best) [822647]
- [scsi] ipr: Fix target id allocation re-use problem (Steve Best) [822647]
- [scsi] ipr: update PCI ID definitions for new adapters (Steve Best) [822647]
- [infiniband] cxgb3: Fix typos in infiniband drivers (Jay Fenlason) [747144]
- [infiniband] cxgb3: Don't pass irq flags to flush_qp() (Jay Fenlason) [747144]
- [infiniband] cxgb3, cxgb4: Remove dead code (Jay Fenlason) [747144]
- [virt] kvm: Don't automatically expose the TSC deadline timer in cpuid (Don Dugger) [740712]
- [virt] kvm: emulate lapic tsc deadline timer for guest (Don Dugger) [740712]
- [virt] kvm: x86 TSC deadline definitions (Don Dugger) [740712]
- [kernel] cgroup: add cgroup_root_mutex (Frederic Weisbecker) [844531]
- [md] raid1: don't abort a resync on the first badblock (Jes Sorensen) [858219]
- [mm] Hold a file reference in madvise_remove (Jerome Marchand) [849739] {CVE-2012-3511}
- [net] ethtool: Extend ethtool_ops, add new ethtool types (Nikolay Aleksandrov) [844395]
- [scsi] aacraid: Series 7 Async. (performance) mode support (Rich Bono) [824892 832495]
- [scsi] aacraid: Fix endian issues in core and SRC portions of driver (Rich Bono) [824892 832495]
- [scsi] aacraid: Relax the tight timeout loop on fib commands (Rich Bono) [824892 832495]
- [scsi] aacraid: Better handling of in-flight events on thread stop (Rich Bono) [824892 832495]
- [scsi] aacraid: Use resource_size_t for IO mem pointers and offsets (Rich Bono) [824892 832495]
- [scsi] aacraid: add an iounmap call to aac_src_ioremap (Rich Bono) [824892 832495]
- [scsi] aacraid: Added Sync.mode to support series 7/8/9 controllers (Rich Bono) [824892 832495]
- [scsi] aacraid: use lower snprintf() limit (Rich Bono) [824892 832495]
- [scsi] aacraid: Drop __TIME__ usage (Rich Bono) [824892 832495]
- [scsi] aacraid: Do not set DMA mask to 32 bit first if adapter only supports 31 (Rich Bono) [824892 832495]

* Fri Sep 21 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-311.el6]
- [netdrv] mlx4: check promisc on proper port (Doug Ledford) [854052]
- [netdrv] mlx4: attach multicast with correct flag (Doug Ledford) [854376]
- [netdrv] mlx4: remove redundant adding of steering type to gid (Doug Ledford) [854053]
- [netdrv] Revert: Fix a merge issue (Doug Ledford) [854053]
- [scsi] lpfc: Update lpfc version to 8.3.5.82.1p (Rob Evers) [827566]
- [scsi] lpfc: Fix null pointer error for piocbq (Rob Evers) [827566]
- [scsi] lpfc: Add missing jumps to mempool_free (Rob Evers) [827566]
- [scsi] lpfc: Fixed leaking memory from pci dma pool (Rob Evers) [827566]
- [scsi] lpfc: Log SCSI XRI on abort handler timeout (Rob Evers) [827566]
- [scsi] lpfc: Fix logging too many fcp underruns (Rob Evers) [827566]
- [scsi] lpfc: Fixed SCSI device reset escalation (Rob Evers) [827566]
- [scsi] lpfc: Fix BlockGuard messages (Rob Evers) [827566]
- [scsi] lpfc: Fix param field to mask for LOCAL_REJ. (Rob Evers) [827566]
- [scsi] lpfc: Add SLI-4 V1 Cap/Res desc support (Rob Evers) [827566]
- [scsi] lpfc: complete list of commands w/ ext. tmo (Rob Evers) [827566]
- [scsi] lpfc: Fix adding fc_host rport entries (Rob Evers) [827566]
- [scsi] lpfc: Fix conflicts in log message numbers (Rob Evers) [827566]
- [scsi] lpfc: Cosmetic changes (Rob Evers) [827566]
- [scsi] lpfc: Fix discovery bug when swapping cables (Rob Evers) [827566]
- [scsi] lpfc: Fixed scsi_eh escalation kernel panic (Rob Evers) [827566]
- [scsi] lpfc: check data transfered on writes (Rob Evers) [827566]
- [scsi] lpfc: remove incorrect message 2520 (Rob Evers) [827566]
- [scsi] lpfc: destroy rrq_pool during driver removal (Rob Evers) [827566]
- [scsi] lpfc: attach OCe14000 adapters (Rob Evers) [827566]
- [scsi] lpfc: set valid bit for loopback testing (Rob Evers) [827566]
- [scsi] lpfc: report misconfigured ports (Rob Evers) [827566]
- [scsi] lpfc: Fix Panic During IO Test (Rob Evers) [827566]
- [scsi] lpfc: dynamic delay multiplier param. (Rob Evers) [827566]
- [scsi] lpfc: Fix abort status (Rob Evers) [827566]
- [scsi] lpfc: Fixed PCI resource provision (Rob Evers) [827566]
- [scsi] lpfc: Fix system hang due to bad mod params (Rob Evers) [827566]
- [scsi] lpfc: Fixed debug helper routine (Rob Evers) [827566]
- [scsi] lpfc: Fix using the wrong xritag (Rob Evers) [827566]
- [scsi] lpfc: Debug routines for dumping SLI4 queues (Rob Evers) [827566]
- [scsi] lpfc: LPe16000 discovery fixes (Rob Evers) [827566]
- [scsi] lpfc: Reregister VPI for SLI3 (Rob Evers) [827566]
- [scsi] lpfc: Fix log message 2597 when no error (Rob Evers) [827566]
- [scsi] lpfc: FCP LOG for Finisar trace correlation (Rob Evers) [827566]
- [scsi] lpfc: Fix error displayed (Rob Evers) [827566]
- [scsi] lpfc: Fix Read Link status data (Rob Evers) [827566]
- [scsi] lpfc: dix, create vports on FCoE SLI4 HBA (Rob Evers) [827566]
- [scsi] lpfc: Fix flogi after flogi ack from target (Rob Evers) [827566]
- [scsi] lpfc: add get controller attributes command (Rob Evers) [827566]
- [scsi] lpfc: handle SLI4-port XRI profile change (Rob Evers) [827566]
- [scsi] lpfc: Add -Werror compilation flag (Rob Evers) [827566]
- [scsi] lpfc: Change def. DA_ID to enabled (Rob Evers) [827566]
- [scsi] lpfc: remove scsi vport host when unloading (Rob Evers) [827566]
- [scsi] lpfc: Increment T10 DIF error injection (Rob Evers) [827566]
- [scsi] lpfc: Update copyright date for files (Rob Evers) [827566]
- [scsi] lpfc: Refine T10 DIF debugfs error injection (Rob Evers) [827566]
- [scsi] lpfc: Make BA_ACC work on exchange (Rob Evers) [827566]
- [scsi] lpfc: Fix KERNEL allocation while lock held (Rob Evers) [827566]
- [scsi] lpfc: Fix usage of bghm for BlockGuard errs (Rob Evers) [827566]
- [scsi] lpfc: inject T10 DIF errors via debugfs (Rob Evers) [827566]
- [scsi] lpfc: Fix BlockGuard for prot. data from HBA (Rob Evers) [827566]
- [scsi] lpfc: add logs in port error/reset (Rob Evers) [827566]
- [scsi] lpfc: Sync up with upstream lpfc driver code (Rob Evers) [827566]
- [scsi] lpfc: Fixed T10 DIF/Blockguard on 16Gb FC (Rob Evers) [827566]
- [scsi] lpfc: Fix files depending on module.h (Rob Evers) [827566]
- [usb] core: fix deadlock in bConfigurationValue attribute method (Don Zickus) [832126]
- [usb] allow drivers to use allocated bandwidth until unbound (Don Zickus) [832126]
- [tools] perf: Add automated tests for event group parsing (Jiri Olsa) [695765]
- [tools] perf: Enable grouping logic for parsed events (Jiri Olsa) [695765]
- [tools] perf: Add support to update event modifier (Jiri Olsa) [695765]
- [tools] perf: Add support to parse event group syntax (Jiri Olsa) [695765]
- [tools] perf: Fix parse events automated tests (Jiri Olsa) [695765]
- [tools] perf: Add support to reuse event grammar to parse out terms (Jiri Olsa) [695765]
- [tools] perf: Make the event parser re-entrant (Jiri Olsa) [695765]
- [tools] perf: Use data struct for arg passing in event parse function (Jiri Olsa) [695765]
- [scsi] ipr: missing unlock before a return (Steve Best) [822647]
- [scsi] ipr: Driver version 2.5.4 (Steve Best) [822647]
- [scsi] ipr: Reduce interrupt lock time (Steve Best) [822647]
- [scsi] ipr: Reduce queuecommand lock time (Steve Best) [822647]
- [scsi] ipr: Driver version 2.5.3 (Steve Best) [822647]
- [scsi] ipr: Increase alignment boundary of command blocks (Steve Best) [822647]
- [scsi] ipr: Increase max concurrent oustanding commands (Steve Best) [822647]
- [scsi] ipr: Remove unnecessary memory barriers (Steve Best) [822647]
- [scsi] ipr: Remove unnecessary interrupt clearing on new adapters (Steve Best) [822647]
- [scsi] ipr: Fix target id allocation re-use problem (Steve Best) [822647]
- [scsi] ipr: update PCI ID definitions for new adapters (Steve Best) [822647]
- [infiniband] cxgb3: Fix typos in infiniband drivers (Jay Fenlason) [747144]
- [infiniband] cxgb3: Don't pass irq flags to flush_qp() (Jay Fenlason) [747144]
- [infiniband] cxgb3, cxgb4: Remove dead code (Jay Fenlason) [747144]
- [virt] kvm: Don't automatically expose the TSC deadline timer in cpuid (Don Dugger) [740712]
- [virt] kvm: emulate lapic tsc deadline timer for guest (Don Dugger) [740712]
- [virt] kvm: x86 TSC deadline definitions (Don Dugger) [740712]
- [kernel] cgroup: add cgroup_root_mutex (Frederic Weisbecker) [844531]
- [md] raid1: don't abort a resync on the first badblock (Jes Sorensen) [858219]
- [mm] Hold a file reference in madvise_remove (Jerome Marchand) [849739] {CVE-2012-3511}
- [net] ethtool: Extend ethtool_ops, add new ethtool types (Nikolay Aleksandrov) [844395]
- [scsi] aacraid: Series 7 Async. (performance) mode support (Rich Bono) [824892 832495]
- [scsi] aacraid: Fix endian issues in core and SRC portions of driver (Rich Bono) [824892 832495]
- [scsi] aacraid: Relax the tight timeout loop on fib commands (Rich Bono) [824892 832495]
- [scsi] aacraid: Better handling of in-flight events on thread stop (Rich Bono) [824892 832495]
- [scsi] aacraid: Use resource_size_t for IO mem pointers and offsets (Rich Bono) [824892 832495]
- [scsi] aacraid: add an iounmap call to aac_src_ioremap (Rich Bono) [824892 832495]
- [scsi] aacraid: Added Sync.mode to support series 7/8/9 controllers (Rich Bono) [824892 832495]
- [scsi] aacraid: use lower snprintf() limit (Rich Bono) [824892 832495]
- [scsi] aacraid: Drop __TIME__ usage (Rich Bono) [824892 832495]
- [scsi] aacraid: Do not set DMA mask to 32 bit first if adapter only supports 31 (Rich Bono) [824892 832495]

* Wed Sep 19 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-310.el6]
- [net] core: Fix napi_gro_frags vs netpoll path (Amerigo Wang) [845347]
- [netdrv] benet: disable BH in callers of be_process_mcc() (Amerigo Wang) [845347]
- [net] bonding: remove IFF_IN_NETPOLL flag (Amerigo Wang) [845347]
- [mm] mmu_notifier: restore kabi (Andrea Arcangeli) [854584]
- [mm] mmu_notifier: have mmu_notifiers use a global SRCU so they may safely schedule (Andrea Arcangeli) [854584]
- [mm] mmu_notifier: fix-inconsistent-memory-between-secondary-mmu-and-host-fix (Andrea Arcangeli) [854584]
- [mm] mmu_notifier: fix inconsistent memory between secondary MMU and host (Andrea Arcangeli) [854584]
- [mm] mmu_notifier: fix freed page still mapped in secondary MMU (Andrea Arcangeli) [854584]
- [mm] Revert: Have mmu_notifiers use SRCU so they may safely schedule (Andrea Arcangeli) [854584]
- [x86] amd_iommu: Cache pdev pointer to root-bridge (Frank Arnold) [814709]
- [x86] amd_iommu: Make sure IOMMU interrupts are re-enabled on resume (Frank Arnold) [814709]
- [x86] amd_iommu: Set iommu configuration flags in enable-loop (Frank Arnold) [814709]
- [x86] amd_iommu: enable iommu before attaching devices (Frank Arnold) [814709]
- [netdrv] cxgb3: treewide use of RCU_INIT_POINTER (Jay Fenlason) [847358]
- [netdrv] cxgb3: Add export.h to files using EXPORT_SYMBOL/THIS_MODULE (Jay Fenlason) [847358]
- [netdrv] cxgb3: unify return value of .ndo_set_mac_address if address is invalid (Jay Fenlason) [847358]
- [netdrv] cxgb3: update firmware version (Jay Fenlason) [847358]
- [netdrv] cxgb3: add skb frag size accessors (Jay Fenlason) [847358]
- [netdrv] cxgb3: convert to SKB paged frag API (Jay Fenlason) [847358]
- [netdrv] cxgb3: remove use of ndo_set_multicast_list in drivers (Jay Fenlason) [847358]
- [netdrv] pch_gbe: add extra clean tx (Veaceslav Falico) [853112]
- [netdrv] pch_gbe: fix transmit watchdog timeout (Veaceslav Falico) [853112]
- [netdrv] pch_gbe: fix transmit races (Veaceslav Falico) [853112]
- [x86] cpu/amd: Fix crash as Xen Dom0 on AMD Trinity systems (Frank Arnold) [822278]
- [x86] cpu/amd: Re-enable CPU topology extensions in case BIOS has disabled it (Frank Arnold) [822278]
- [net] openvswitch: set openvswitch_handle_frame_hook (Thomas Graf) [854628]
- [lib] flex_array: flex_array_prealloc takes a number of elements, not an end (Thomas Graf) [854628]
- [net] openvswitch: Fix FLOW_BUFSIZE definition (Thomas Graf) [854628]
- [net] openvswitch: Fix typo (Thomas Graf) [854628]
- [net] openvswitch: Relax set header validation (Thomas Graf) [854628]
- [net] openvswitch: Do not send notification if ovs_vport_set_options() failed (Thomas Graf) [854628]
- [net] openvswitch: Enable retrieval of TCP flags from IPv6 traffic (Thomas Graf) [854628]
- [net] openvswitch: Fix typo in documentation (Thomas Graf) [854628]
- [net] openvswitch: Replace Nicira Networks (Thomas Graf) [854628]
- [net] openvswitch: Check gso_type for correct sk_buff in queue_gso_packets() (Thomas Graf) [854628]
- [net] openvswitch: Check currect return value from skb_gso_segment() (Thomas Graf) [854628]
- [net] openvswitch: Reset upper layer protocol info on internal devices (Thomas Graf) [854628]
- [sound] alsa: snd-aloop copy fix (Jaroslav Kysela) [854696]
- [base] driver-core: fix device_register race (Rob Evers) [833098]
- [netdrv] 8139cp: set intr mask after its handler is registered (Jason Wang) [815199]
- [netdrv] pch_gbe: Do not abort probe on bad MAC (Veaceslav Falico) [851675]
- [pci] fix upstream P2P bridge checks when enabling OBFF and LTR (Myron Stowe) [834711]

* Mon Sep 17 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-309.el6]
- [mm] fix contig_page_data kABI breakage and related memory corruption (Satoru Moriya) [853007]
- [mm] hugetlbfs: close race during teardown of hugetlbfs shared page tables (Rafael Aquini) [856325]
- [mm] hugetlbfs: Correctly detect if page tables have just been shared (Rafael Aquini) [856325]
- [mm] Revert: Eliminate kernel crash due to races in hugetlbfs (Rafael Aquini) [856325]
- [net] sctp: backport sctp cache ipv6 source after route lookup (Michele Baldessari) [855759]
- [net] sctp: backport support of sctp multi-homing ipv6 source address selection (Michele Baldessari) [855759]
- [net] ipv6: backport RTA_PREFSRC ipv6 source route selection support (Michele Baldessari) [851118]
- [input] wacom: add Intuos5 Touch Ring LED support (Aristeu Rozanski) [841611]
- [net] core: allocate skbs on local node (Andy Gospodarek) [843163]
- [netdrv] sfc: Fix maximum number of TSO segments and minimum TX queue size (Nikolay Aleksandrov) [845557] {CVE-2012-3412}
- [net] etherdevice: Rename random_ether_addr to eth_random_addr (Neil Horman) [813086]
- [net] etherdevice: rename dev_hw_addr_random and remove redundant second (Neil Horman) [813086]
- [pcmcia] Introduce PCMCIA_DEVICE_PROD_ID3 (Neil Horman) [813086]
- [net] add a truesize parameter to skb_add_rx_frag() (Neil Horman) [813086]
- [net] rtnetlink: add rtnl_dereference() (Neil Horman) [813086]
- [net] rtnetlink: Add checking to rcu_dereference() primitives (Neil Horman) [813086]
- [kernel] rcu: define __rcu address space modifier for sparse (Neil Horman) [813086]
- [kernel] rcu: Add rcu_access_pointer and rcu_dereference_protected (Neil Horman) [813086]
- [kernel] rcu: Add lockdep checking to rhel (Neil Horman) [813086]
- [kernel] rcu: Make __kfree_rcu() less dependent on compiler choices (Neil Horman) [813086]
- [kernel] rcu: introduce kfree_rcu() (Neil Horman) [813086]
- [mmc] sdio: add quirk to clamp byte mode transfer (Neil Horman) [813086]
- [kernel] pm_runtime: Generic resume shouldn't set RPM_ACTIVE unconditionally (Neil Horman) [813086]
- [kernel] workqueue: unify spelling of 'freeze' + 'able' to 'freezable' (Neil Horman) [813086]
- [kernel] Allow drivers to compile with #include <linux/printk.h> (Neil Horman) [813086]
- [mmc] sdio: add new function for RAW (Read after Write) operation (Neil Horman) [813086]
- [kernel] Uset set_irq_type() to define irq_set_irq_type() (Neil Horman) [813086]
- [kernel] irq: Provide status modifier (Neil Horman) [813086]
- [kernel] Simulate pm_qos_X_reuest() using existing qos RHEL6 infrastructure (Neil Horman) [813086]
- [lib] cordic: add library module providing cordic angle calculation (Neil Horman) [813086]
- [pcmcia] add PCMCIA_DEVICE_MANF_CARD_PROD_ID3 (Neil Horman) [813086]
- [pcmcia] add pcmica_{read,write}_config_byte (Neil Horman) [813086]
- [pcmcia] Add {pccard,pcmcia}_loop_tuple (Neil Horman) [813086]
- [pcmcia] add pcmica_{read,write}_config_byte (Neil Horman) [813086]
- [pci] Add helper macro for pci_register_driver boilerplate (Neil Horman) [813086]
- [usb] Add helper macro for usb_driver boilerplate (Neil Horman) [813086]
- [kernel] device: Generalize module_platform_driver (Neil Horman) [813086]
- [kernel] dma-mapping: add dma_zalloc_coherent() (Neil Horman) [813086]
- [kernel] Empty implementation of functions to make drivers compile (Neil Horman) [813086]
- [kernel] split out the EXPORT_SYMBOL into export.h (Neil Horman) [813086]
- [kernel] pm_qos: Define pm_qos_request() as pm_qos_requirement() (Neil Horman) [813086]
- [kernel] replace USHORT_MAX, SHORT_MAX and SHORT_MIN with USHRT_MAX, SHRT_MAX and SHRT_MIN (Neil Horman) [813086]
- [net] add wireless TX status socket option (Neil Horman) [813086]
- [kernel] workqueue: implement alloc_ordered_workqueue() (Neil Horman) [813086]
- [kernel] pm_qos: Move and rename the implementation files (Neil Horman) [813086]
- [kernel] atomic: add atomic_inc_not_zero_hint() (Neil Horman) [813086]
- [fs] vfs: introduce noop_llseek() (Neil Horman) [813086]
- [net] Add net_ratelimited_function and net_<level>_ratelimited macros (Neil Horman) [813086]
- [fs] libfs: add simple_open() (Neil Horman) [813086]
- [base] core: device_rename's new_name can be const (Neil Horman) [813086]
- [net] Add a boolean function to check if 2 ethernet addresses are the same (Neil Horman) [813086]
- [net] Allow changing number of RX queues after device allocation (Neil Horman) [813086]
- [net] Introduce skb_checksum_start_offset() to replace repetitive calculation (Neil Horman) [813086]
- [netdrv] e1000e: drop check of RXCW.CW to eliminate link going up and down (Dean Nelson) [847310]
- [net] core: add unknown state to sysfs NIC duplex export (Nikolay Aleksandrov) [855062]
- [pci] read-modify-write the PCIe device control register when initiating FLR (Myron Stowe) [848358]

* Wed Sep 12 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-308.el6]
- [s390] zfcp: No automatic port_rescan on events (Hendrik Brueckner) [855131]
- [fs] xfs: push the AIL from memory reclaim and periodic sync (Dave Chinner) [855139]
- [powerpc] perf: Use perf_instruction_pointer in callchains (Steve Best) [850575]
- [powerpc] perf: Always use pt_regs for userspace samples (Steve Best) [850575]
- [powerpc] perf: Move code to select SIAR or pt_regs into perf_read_regs (Steve Best) [850575]
- [powerpc] perf: Create mmcra_sihv/mmcra_sipv helpers (Steve Best) [850575]
- [powerpc] perf: Fix instruction address sampling on 970 and Power4 (Steve Best) [850575]
- [netdrv] ehea: fix losing of NEQ events when one event occurred early (Steve Best) [822659]
- [netdrv] ehea: only register irq after setting up ports (Steve Best) [822659]
- [netdrv] ehea: make some functions and variables static (Steve Best) [822659]
- [netdrv] ehea: Use round_jiffies_relative to align workqueue (Steve Best) [822659]
- [netdrv] ehea: Reduce memory usage in buffer pools (Steve Best) [822659]
- [netdrv] ehea: Remove unused tcp_end field in send WQ (Steve Best) [822659]
- [netdrv] ehea: Add GRO support (Steve Best) [822659]
- [netdrv] ehea: Remove LRO support (Steve Best) [822659]
- [netdrv] ehea: Remove some unused definitions (Steve Best) [822659]
- [netdrv] ehea: Simplify type 3 transmit routine (Steve Best) [822659]
- [netdrv] ehea: Merge swqe2 TSO and non TSO paths (Steve Best) [822659]
- [netdrv] ehea: Simplify ehea_xmit2 and ehea_xmit3 (Steve Best) [822659]
- [netdrv] ehea: Allocate large enough skbs to avoid partial cacheline DMA writes (Steve Best) [822659]
- [netdrv] ehea: Add vlan_features (Steve Best) [822659]
- [netdrv] ehea: Dont check NETIF_F_TSO in TX path (Steve Best) [822659]
- [netdrv] ehea: Remove num_tx_qps module option (Steve Best) [822659]
- [netdrv] ehea: Remove force_irq logic in napi poll routine (Steve Best) [822659]
- [netdrv] ehea: Update multiqueue support (Steve Best) [822659]
- [netdrv] ehea: Remove NETIF_F_LLTX (Steve Best) [822659]
- [netdrv] ehea: Remove sleep at .ndo_get_stats (Steve Best) [822659]
- [netdrv] ehea: do vlan cleanup (Steve Best) [822659]
- [netdrv] ehea: Use ethtool ethtool_cmd_speed API (Steve Best) [822659]
- [netdrv] ehea: fix wrongly reported speed and port (Steve Best) [822659]
- [netdrv] ehea: Fix a DLPAR bug on ehea_rereg_mrs() (Steve Best) [822659]
- [netdrv] ehea: don't use flush_scheduled_work() (Steve Best) [822659]
- [netdrv] ehea: kill unused ehea_rereg_mr_task (Steve Best) [822659]
- [netdrv] ehea: Fixing LRO configuration (Steve Best) [822659]
- [netdrv] ehea: Fixing statistics (Steve Best) [822659]
- [netdrv] ehea: fix use after free (Steve Best) [822659]
- [netdrv] ehea: Don't check for vlan group before vlan_tx_tag_present (Steve Best) [822659]
- [netdrv] ehea: simplify conditional (Steve Best) [822659]
- [netdrv] ehea: Fix a checksum issue on the receive path (Steve Best) [822659]
- [netdrv] ehea: Allocate stats buffer with GFP_KERNEL (Steve Best) [822659]
- [net] drop_monitor: dont sleep in atomic context (Neil Horman) [817146]
- [net] drop_monitor: prevent init path from scheduling on the wrong cpu (Neil Horman) [817146]
- [net] drop_monitor: Make updating data->skb smp safe (Neil Horman) [817146]
- [net] drop_monitor: fix sleeping in invalid context warning (Neil Horman) [817146]
- [scsi] bfa: firmware image name update (Rob Evers) [830008]
- [scsi] bfa: Fix error codes and misc cleanup (Rob Evers) [830008]
- [scsi] bfa: squelch lockdep complaint (Rob Evers) [830008]
- [scsi] bfa: dereferencing freed memory in bfad_im_probe() (Rob Evers) [830008]
- [scsi] bfa: off by one in bfa_ioc_mbox_isr() (Rob Evers) [830008]
- [scsi] bfa: Fix to set vport FC host sysfs entries (Rob Evers) [830008]
- [scsi] bfa: Fix bfa logging port state change (Rob Evers) [830008]
- [scsi] bfa: defer vport delete handler till fw logo (Rob Evers) [830008]
- [scsi] bfa: Update the driver version to 3.0.23.0 (Rob Evers) [830008]
- [scsi] bfa: BSG and User interface fixes. (Rob Evers) [830008]
- [scsi] bfa: Fix to avoid vport delete hang on request queue full scenario. (Rob Evers) [830008]
- [scsi] bfa: Move service parameter programming logic into firmware. (Rob Evers) [830008]
- [scsi] bfa: Revise Fabric Assigned Address(FAA) (Rob Evers) [830008]
- [scsi] bfa: Flash controller IOC pll init fixes. (Rob Evers) [830008]
- [scsi] bfa: Serialize the IOC hw semaphore unlock (Rob Evers) [830008]
- [scsi] bfa: Modify ISR to process pending completions (Rob Evers) [830008]
- [scsi] bfa: Add fc host issue lip support (Rob Evers) [830008]
- [scsi] bfa: Fix endian bug (Rob Evers) [830008]
- [scsi] be2iscsi: Bump the driver version (Rob Evers) [827594]
- [scsi] be2iscsi: Fix panic because of TCP RST/FIN (Rob Evers) [827594]
- [scsi] be2iscsi: configure VLAN parameters (Rob Evers) [827594]
- [scsi] be2iscsi: Format the MAC_ADDR with sysfs (Rob Evers) [827594]
- [scsi] be2iscsi: Set log levels for various events (Rob Evers) [827594]
- [scsi] be2iscsi: MBX Cmd for login, crashdump mode (Rob Evers) [827594]
- [scsi] be2iscsi: Remove the iscsi_data_pdu setting (Rob Evers) [827594]
- [target] tcm_fc: Add abort flag for gracefully handling exchange timeout (Neil Horman) [829932]
- [scsi] fcoe: Ensure fcoe_recv_frame is always called in process context (Neil Horman) [829932]
- [target] Fix possible NULL pointer with __transport_execute_tasks (Neil Horman) [829932]
- [usb] usbdevfs: Add a USBDEVFS_GET_CAPABILITIES ioctl (Don Zickus) [828271]

* Fri Sep 07 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-307.el6]
- [scsi] hpsa: bump version number (Tomas Henzl) [737644]
- [scsi] hpsa: add marketing names for Gen8 controllers (Tomas Henzl) [737644]
- [scsi] hpsa: dial down lockup detection during firmware flash (Tomas Henzl) [737644]
- [scsi] hpsa: removed unused member maxQsinceinit (Tomas Henzl) [737644]
- [scsi] hpsa: add new RAID level "1(ADM)" (Tomas Henzl) [737644]
- [scsi] hpsa: factor out hpsa_free_irqs_and_disable_msix (Tomas Henzl) [737644]
- [scsi] hpsa: refine interrupt handler locking for greater concurrency (Tomas Henzl) [737644]
- [scsi] hpsa: use multiple reply queues (Tomas Henzl) [737644]
- [scsi] hpsa: factor out tail calls to next_command() in process_(non)indexed_cmd() (Tomas Henzl) [737644]
- [scsi] hpsa: do aborts two ways (Tomas Henzl) [737644]
- [scsi] hpsa: add abort error handler function (Tomas Henzl) [737644]
- [scsi] hpsa: remove unused parameter from finish_cmd (Tomas Henzl) [737644]
- [scsi] hpsa: do not give up retry of driver cmds after only 3 retries (Tomas Henzl) [737644]
- [scsi] hpsa: retry driver initiated commands on busy status (Tomas Henzl) [737644]
- [scsi] hpsa: do not read from controller unnecessarily in completion code (Tomas Henzl) [737644]
- [scsi] hpsa: suppress excessively chatty error messages (Tomas Henzl) [737644]
- [scsi] hpsa: enable bus master bit after pci_enable_device (Tomas Henzl) [737644]
- [scsi] hpsa: do not skip disabled devices (Tomas Henzl) [737644]
- [scsi] hpsa: call pci_disable_device on driver unload (Tomas Henzl) [737644]
- [scsi] hpsa: use check_signature (Tomas Henzl) [737644]
- [scsi] hpsa: use find_first_zero_bit (Tomas Henzl) [737644]
- [scsi] hpsa: factor out driver name (Tomas Henzl) [737644]
- [scsi] hpsa: removed unneeded structure member max_sg_entries and fix bad name (Tomas Henzl) [737644]
- [scsi] hpsa: fix per device memory leak on driver unload (Tomas Henzl) [737644]
- [scsi] hpsa: do not sleep in atomic context in rmmod path. (Tomas Henzl) [737644]
- [scsi] hpsa: Disable ASPM (Tomas Henzl) [737644]
- [scsi] hpsa: detect controller lockup (Tomas Henzl) [737644]
- [scsi] hpsa: fix flush cache transfer length (Tomas Henzl) [737644]
- [scsi] hpsa: remove unused busy_initializing and busy_scanning (Tomas Henzl) [737644]
- [scsi] hpsa: set max sectors instead of taking the default (Tomas Henzl) [737644]
- [scsi] hpsa: change confusing message to be more clear (Tomas Henzl) [737644]
- [scsi] hpsa: fix physical device lun and target numbering problem (Tomas Henzl) [737644]
- [scsi] hpsa: fix problem that OBDR devices are not detected (Tomas Henzl) [737644]
- [scsi] hpsa: retry commands completing with status of UNSOLICITED_ABORT (Tomas Henzl) [737644]
- [scsi] hpsa: fix potential overrun while memcpy'ing sense data (Tomas Henzl) [737644]
- [scsi] hpsa: fix dma unmap error in hpsa_passthru_ioctl (Tomas Henzl) [737644]
- [scsi] hpsa: Change memset using sizeof(ptr) to sizeof(*ptr) (Tomas Henzl) [737644]
- [x86] perf: Enable/Add IvyBridge hardware support (Prarit Bhargava) [829872]
- [x86] perf: Update SNB PEBS constraints (Prarit Bhargava) [829872]
- [x86] perf: Implement cycles:p for SNB/IVB (Prarit Bhargava) [829872]
- [x86] perf: Prettify pmu config literals (Prarit Bhargava) [829872]
- [x86] perf: Implement arch event mask as quirk (Prarit Bhargava) [829872]
- [x86] perf: Disable PEBS on SandyBridge chips (Prarit Bhargava) [829872]
- [virt] kvm: Add accessor for reading cr4 (or some bits of cr4) (Gleb Natapov) [832301]
- [kernel] sched: Create special class for stop/migrate work (Igor Mammedov) [843541]
- [net] ipv4: Add interface option to enable routing of 127.0.0.0/8 (Thomas Graf) [831623]
- [net] ipv6: Move ipv6 proc file registration to end of init order (Thomas Graf) [809297]
- [net] sctp: Don't charge for data in sndbuf again when transmitting packet (Thomas Graf) [809792]

* Thu Sep 06 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-306.el6]
- [x86] acpi: Fix use-after-free in acpi_map_lsapic (Igor Mammedov) [826067]
- [drm] ttm: use shmem_read_mapping_page (Rafael Aquini) [806049]
- [drm] i915: use shmem_read_mapping_page (Rafael Aquini) [806049]
- [drm] i915: use shmem_truncate_range (Rafael Aquini) [806049]
- [fs] udf: fix retun value on error path in udf_load_logicalvol (Nikola Pajkovsky) [843143] {CVE-2012-3400}
- [fs] udf: Improve table length check to avoid possible overflow (Nikola Pajkovsky) [843143] {CVE-2012-3400}
- [fs] udf: Fortify loading of sparing table (Nikola Pajkovsky) [843143] {CVE-2012-3400}
- [fs] udf: Avoid run away loop when partition table length is corrupted (Nikola Pajkovsky) [843143] {CVE-2012-3400}
- [fs] udf: Use 'ret' instead of abusing 'i' in udf_load_logicalvol() (Nikola Pajkovsky) [843143] {CVE-2012-3400}

* Fri Aug 31 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-305.el6]
- [virt] kvm: fix KVM_GET_MSR for PV EOI (Michael S. Tsirkin) [835095]
- [virt] kvm: update KVM_SAVE_MSRS_BEGIN to correct value (Michael S. Tsirkin) [835095]
- [virt] kvm: switch to apic_set_eoi_write, apic_write (Michael S. Tsirkin) [835095]
- [x86] apic: add apic_set_eoi_write for PV use (Michael S. Tsirkin) [835095]
- [virt] kvm: host side for eoi optimization (Michael S. Tsirkin) [835095]
- [virt] kvm: introduce kvm_read_guest_cached (Michael S. Tsirkin) [835095]
- [virt] kvm: Add memory slot versioning and use it to provide fast guest write interface (Michael S. Tsirkin) [835095]
- [virt] kvm_host: add kvm_memslots wrapper (Michael S. Tsirkin) [835095]
- [virt] kvm: only sync when attention bits set (Michael S. Tsirkin) [835095]
- [x86] bitops: note on __test_and_clear_bit atomicity (Michael S. Tsirkin) [835095]
- [virt] kvm: guest side for eoi avoidance (Michael S. Tsirkin) [835095]
- [x86] apic: make apic_probe extern (Michael S. Tsirkin) [835095]
- [x86] apic: add apic_flat to apic_probe on x86_64 (Michael S. Tsirkin) [835095]
- [virt] kvm: add paravirt cpu notifier stubs (Michael S. Tsirkin) [835095]
- [virt] kvm: optimize ISR lookups (Michael S. Tsirkin) [835095]
- [virt] kvm: document lapic regs field (Michael S. Tsirkin) [835095]
- [x86] apic: Implement EIO micro-optimization (Michael S. Tsirkin) [835095]
- [x86] apic: Add apic->eoi_write() callback (Michael S. Tsirkin) [835095]
- [x86] apic: Use symbolic APIC_EOI_ACK (Michael S. Tsirkin) [835095]
- [x86] apic: Fix typo EIO_ACK -> EOI_ACK and document it (Michael S. Tsirkin) [835095]
- [virt] kvm: Introduce bitmask for apic attention reasons (Michael S. Tsirkin) [835095]
- [virt] kvm: dont clear TMR on EOI (Michael S. Tsirkin) [835095]
- [x86] efi_ioremap may not map the entire physical address space requested (Larry Woodman) [840691]
- [netdrv] bnx2x: Add remote-fault link detection (Michal Schmidt) [814877]
- [virt] vhost: poll vq in zerocopy callback (Jason Wang) [734731]
- [virt] vhost_net, zerocopy: adding and signalling immediately when fully copied (Jason Wang) [734731]
- [virt] vhost_net: re-poll only on EAGAIN or ENOBUFS (Jason Wang) [734731]
- [net] sunrpc: svc_xprt sends on closed socket should stop immediately (J. Bruce Fields) [849702]

* Thu Aug 30 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-304.el6]
- [fs] jbd2: fix fsync() tid wraparound bug (Dave Wysochanski) [735768]
- [fs] jbd: fix fsync() tid wraparound bug (Dave Wysochanski) [735768]
- [fs] jbd, jbd2: fixed typos (Dave Wysochanski) [735768]
- [x86] perf: disable PEBS on a guest entry (Gleb Natapov) [845664]
- [fs] dlm: make dlm_recv single threaded (David Teigland) [821060]
- [fs] dlm: fix granting from recovery (David Teigland) [821824]
- [fs] dlm: fix deadlock between dlm_send and dlm_controld (David Teigland) [824964]
- [kernel] fork: fix overflow in vma length when copying mmap on clone (Anton Arapov) [815891]
- [fs] fuse: update attributes on aio_read (Brian Foster) [850642]
- [fs] fuse: invalidate inode mapping if mtime changes (Brian Foster) [850642]
- [fs] fuse: add FUSE_AUTO_INVAL_DATA init flag (Brian Foster) [850642]
- [net] cls_cgroup: Allow net_cls cgroups to have their classid reset to 0 (Neil Horman) [831456]
- [mm] clarify the radix_tree exceptional cases (Rafael Aquini) [806049]
- [mm] tmpfs, radix_tree: locate_item to speed up swapoff (Rafael Aquini) [806049]
- [mm] a few small updates for radix-swap (Rafael Aquini) [806049]
- [mm] tmpfs: convert shmem_writepage and enable swap (Rafael Aquini) [806049]
- [mm] tmpfs: convert mem_cgroup shmem to radix-swap (Rafael Aquini) [806049]
- [mm] tmpfs: convert shmem_getpage_gfp to radix-swap (Rafael Aquini) [806049]
- [mm] tmpfs: convert shmem_unuse_inode to radix-swap (Rafael Aquini) [806049]
- [mm] tmpfs: convert shmem_truncate_range to radix-swap (Rafael Aquini) [806049]
- [mm] tmpfs: copy truncate_inode_pages_range (Rafael Aquini) [806049]
- [mm] tmpfs: miscellaneous trivial cleanups (Rafael Aquini) [806049]
- [mm] tmpfs: demolish old swap vector support (Rafael Aquini) [806049]
- [mm] let swap use exceptional entries (Rafael Aquini) [806049]
- [lib] radix_tree: exceptional entries and indices (Rafael Aquini) [806049]
- [mm] tmpfs: simplify unuse and writepage (Rafael Aquini) [806049]
- [mm] tmpfs: simplify filepage/swappage (Rafael Aquini) [806049]
- [mm] tmpfs: simplify prealloc_page (Rafael Aquini) [806049]
- [mm] tmpfs: pass gfp to shmem_getpage_gfp (Rafael Aquini) [806049]
- [mm] tmpfs: no need to use i_lock (Rafael Aquini) [806049]
- [mm] pincer in truncate_inode_pages_range (Rafael Aquini) [806049]
- [mm] consistent truncate and invalidate loops (Rafael Aquini) [806049]
- [mm] tidy vmtruncate_range and related functions (Rafael Aquini) [806049]
- [mm] truncate functions are in truncate.c (Rafael Aquini) [806049]
- [mm] filemap: cleanup descriptions of filler arg (Rafael Aquini) [806049]
- [mm] tmpfs: add shmem_read_mapping_page_gfp (Rafael Aquini) [806049]
- [mm] tmpfs: take control of its truncate_range (Rafael Aquini) [806049]
- [mm] move shmem prototypes to shmem_fs.h (Rafael Aquini) [806049]
- [mm] move vmtruncate_range to truncate.c (Rafael Aquini) [806049]
- [mm] remove worrying dead code from find_get_pages() (Rafael Aquini) [806049]
- [lib] radix-tree: fix RCU bug (Rafael Aquini) [819243]

* Mon Aug 27 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-303.el6]
- [ata] libata: Add space to fix 2GB ATA Flash Disk/ADMA428M blacklist (Prarit Bhargava) [843849]
- [char] hw_random: check for errors in data_present() return value (Amit Shah) [849196]
- [char] hwrng: Revert back to older API to prevent (k)abi bugs (Amit Shah) [849196]
- [char] Revert: hw_random/virtio-rng: don't wait on host when module is going away (Amit Shah) [849196]
- [pci] add pci_pcie_cap2() check for PCIe feature capabilities >= v2 (Myron Stowe) [834700]
- [pci] use pci_pcie_cap() in pci core (Myron Stowe) [834700]
- [s390] dasd: add sanity check to detect path connection error (Hendrik Brueckner) [823015]
- [s390] kernel: Add z/VM LGR detection (Hendrik Brueckner) [823014]
- [message] mptfusion: Fix for device removed in blocked state (Tomas Henzl) [831865]
- [mm] avoid swapping out with swappiness==0 (Satoru Moriya) [787885]

* Fri Aug 24 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-302.el6]
- [pci] disable MEM decoding while updating 64-bit MEM BARs (Myron Stowe) [841973]
- [pci] leave MEM and IO decoding disabled during 64-bit BAR sizing, too (Myron Stowe) [841973]
- [pci] Use class for quirk for host bridge mmio_always_on (Myron Stowe) [841973]
- [pci] fold pci_calc_resource_flags() into decode_bar() (Myron Stowe) [841973]
- [pci] treat mem BAR type "11" (reserved) as 32-bit, not 64-bit, BAR (Myron Stowe) [841973]
- [pci] disable mmio during bar sizing (Myron Stowe) [841973]
- [fs] nfs: nfs_attr_use_mounted_on_file() missing return value. (Steve Dickson) [842312]
- [fs] gfs2: Make gfs2_write_end not dirty the inode with every write (Robert S Peterson) [844814]
- [x86] cpufeature: Add CPU features from Intel document 319433-012A (John Villalovos) [841661]
- [virt] kvm: expose latest Intel cpu new features (BMI1/BMI2/FMA/AVX2) to guest (John Villalovos) [841661]
- [tools] perf kvm: Fix segfault with report and mixed guestmount use (Jiri Olsa) [846702]
- [tools] perf kvm: Fix regression with guest machine creation (Jiri Olsa) [846702]
- [tools] perf script: Fix format regression due to libtraceevent merge (Jiri Olsa) [846702]
- [tools] perf: Fix synthesizing tracepoint names from the perf.data headers (Jiri Olsa) [846702]
- [tools] perf stat: Fix default output file (Jiri Olsa) [846702]
- [tools] perf tools: Fix endianity swapping for adds_features bitmask (Jiri Olsa) [846702]
- [tools] perf uprobes: Remove unnecessary check before strlist__delete (Jiri Olsa) [846702]
- [tools] perf symbols: Check for valid dso before creating map (Jiri Olsa) [846702]
- [tools] perf evsel: Fix 32 bit values endianity swap for sample_id_all header (Jiri Olsa) [846702]
- [tools] perf session: Handle endianity swap on sample_id_all header data (Jiri Olsa) [846702]
- [tools] perf symbols: Handle different endians properly during symbol load (Jiri Olsa) [846702]
- [tools] perf evlist: Pass third argument to ioctl explicitly (Jiri Olsa) [846702]
- [tools] perf: Update ioctl documentation for PERF_IOC_FLAG_GROUP (Jiri Olsa) [846702]
- [tools] perf: Make --version show kernel version instead of pull req tag (Jiri Olsa) [846702]
- [tools] perf: Check if callchain is corrupted (Jiri Olsa) [846702]
- [tools] perf callchain: Make callchain cursors TLS (Jiri Olsa) [846702]
- [tools] perf: Fix pager on minimal-install embedded systems (Jiri Olsa) [846702]
- [tools] perf: Fix make tarballs (Jiri Olsa) [846702]
- [tools] perf script: Fix regression in callchain dso name (Jiri Olsa) [846702]
- [tools] perf stat: Initialize default events wrt exclude_{guest, host} (Jiri Olsa) [846702]
- [tools] perf annotate browser: Fix help window entry for navigating to hottest line (Jiri Olsa) [846702]
- [tools] perf report: Use the right symbol for annotation (Jiri Olsa) [846702]
- [tools] perf probe: Detect probe target when m/x options are absent (Jiri Olsa) [846702]
- [tools] perf compat: Make a note in documentation about uprobe interface (Jiri Olsa) [846702]
- [tools] perf probe: Provide perf interface for uprobes (Jiri Olsa) [846702]
- [tools] perf ui browser: Stop using 'self' (Jiri Olsa) [846702]
- [tools] perf annotate browser: Read perf config file for settings (Jiri Olsa) [846702]
- [tools] perf config: Allow '_' in config file variable names (Jiri Olsa) [846702]
- [tools] perf annotate browser: Make feature toggles global (Jiri Olsa) [846702]
- [tools] perf annotate browser: The idx_asm field should be used in asm only view (Jiri Olsa) [846702]
- [tools] perf: Convert critical messages to ui__error() (Jiri Olsa) [846702]
- [tools] perf ui: Make --stdio default when TUI is not supported (Jiri Olsa) [846702]
- [tools] perf record: Fix branch_stack type in perf_record_opts (Jiri Olsa) [846702]
- [tools] perf: Reconstruct event with modifiers from perf_event_attr (Jiri Olsa) [846702]
- [tools] perf top: Fix counter name fixup when fallbacking to cpu-clock (Jiri Olsa) [846702]
- [tools] perf: fix thread_map__new_by_pid_str() memory leak in error path (Jiri Olsa) [846702]
- [tools] perf: Do not use _FORTIFY_SOURCE when DEBUG=1 is specified (Jiri Olsa) [846702]
- [tools] perf evlist: Explicititely initialize input_name (Jiri Olsa) [846702]
- [tools] perf compat: Disable perf branch sampling in evlist command (Jiri Olsa) [846702]
- [tools] perf evlist: Show event attribute details (Jiri Olsa) [846702]
- [tools] perf: Bump default sample freq to 4 kHz (Jiri Olsa) [846702]
- [tools] perf buildid-list: Work better with pipe mode (Jiri Olsa) [846702]
- [tools] perf: Fix piped mode read code (Jiri Olsa) [846702]
- [tools] perf inject: Fix broken perf inject -b (Jiri Olsa) [846702]
- [tools] perf: rename HEADER_TRACE_INFO to HEADER_TRACING_DATA (Jiri Olsa) [846702]
- [tools] perf: Add union u64_swap type for swapping u64 data (Jiri Olsa) [846702]
- [tools] perf: Carry perf_event_attr bitfield throught different endians (Jiri Olsa) [846702]
- [tools] perf record: Fix documentation for branch stack sampling (Jiri Olsa) [846702]
- [tools] perf target: Add cpu flag to sample_type if target has cpu (Jiri Olsa) [846702]
- [tools] perf: Add hardcoded name term for pmu events (Jiri Olsa) [846702]
- [tools] perf: Separate 'mem:' event scanner bits (Jiri Olsa) [846702]
- [tools] perf: Use allocated list for each parsed event (Jiri Olsa) [846702]
- [tools] perf: Add support for displaying event parser debug info (Jiri Olsa) [846702]
- [tools] perf test: Move parse event automated tests to separated object (Jiri Olsa) [846702]
- [tools] perf evsel: Create events initially disabled -- again (Jiri Olsa) [846702]
- [tools] perf: Split term type into value type and term type (Jiri Olsa) [846702]
- [tools] perf hists: Fix callchain ip printf format (Jiri Olsa) [846702]
- [tools] perf target: Add uses_mmap field (Jiri Olsa) [846702]
- [tools] Revert: perf evlist: Fix creation of cpu map (Jiri Olsa) [846702]
- [tools] perf target: Rename functions to avoid double negation (Jiri Olsa) [846702]
- [tools] perf annotate browser: Add key bindings help window (Jiri Olsa) [846702]
- [tools] perf annotate browser: Show 'jumpy' functions (Jiri Olsa) [846702]
- [tools] perf annotate browser: Count the numbers of jump sources to a target (Jiri Olsa) [846702]
- [tools] perf annotate: Introduce ->free() method in ins_ops (Jiri Olsa) [846702]
- [tools] perf annotate: Augment lock instruction output (Jiri Olsa) [846702]
- [tools] perf annotate: Resolve symbols using objdump comment for single op ins (Jiri Olsa) [846702]
- [tools] perf annotate: Resolve symbols using objdump comment (Jiri Olsa) [846702]
- [tools] perf annotate: Use raw form for register indirect call instructions (Jiri Olsa) [846702]
- [tools] perf hists browser: Use '/' for search/filter instead of 's' (Jiri Olsa) [846702]
- [tools] perf annotate: shorten helpline so it fits in visible space (Jiri Olsa) [846702]
- [tools] perf record: Reset event name when falling back to cpu-clock (Jiri Olsa) [846702]
- [tools] perf top: Update event name when falling back to cpu-clock (Jiri Olsa) [846702]
- [tools] perf record: Fix fallback to cpu-clock on ppc (Jiri Olsa) [846702]
- [tools] perf report: Fix format string for x86-32 compilation (Jiri Olsa) [846702]
- [tools] perf top: Default to system wide using perf_target methods (Jiri Olsa) [846702]
- [tools] perf stat: Use perf_evlist__create_maps (Jiri Olsa) [846702]
- [tools] perf target: Consolidate target task/cpu checking (Jiri Olsa) [846702]
- [tools] perf: Introduce perf_target__strerror() (Jiri Olsa) [846702]
- [tools] perf target: Introduce perf_target__parse_uid() (Jiri Olsa) [846702]
- [tools] perf target: Introduce perf_target_errno (Jiri Olsa) [846702]
- [tools] perf evlist: Fix creation of cpu map (Jiri Olsa) [846702]
- [tools] perf top: Set target.system_wide (Jiri Olsa) [846702]
- [tools] perf session: Fail on processing event with unknown size (Jiri Olsa) [846702]
- [tools] perf ui: Change fallback policy of setup_browser() (Jiri Olsa) [846702]
- [tools] perf ui: Add gtk2 support into setup_browser() (Jiri Olsa) [846702]
- [tools] perf ui gtk: Rename functions for consistency (Jiri Olsa) [846702]
- [tools] perf ui gtk: Drop arg[cv] arguments from perf_gtk_setup_browser() (Jiri Olsa) [846702]
- [tools] perf ui: Make setup_browser() generic (Jiri Olsa) [846702]
- [tools] perf target: Split out perf_target handling code (Jiri Olsa) [846702]
- [tools] perf: Check more combinations of PID/TID, UID and CPU switches (Jiri Olsa) [846702]
- [tools] perf evlist: Make create_maps() take struct perf_target (Jiri Olsa) [846702]
- [tools] perf: Introduce perf_target__validate() helper (Jiri Olsa) [846702]
- [tools] perf top: Convert to struct perf_target (Jiri Olsa) [846702]
- [tools] perf stat: Convert to struct perf_target (Jiri Olsa) [846702]
- [tools] perf: Introduce struct perf_target (Jiri Olsa) [846702]
- [tools] perf: Fix include header files in util/parse-events.h (Jiri Olsa) [846702]
- [tools] perf annotate browser: Compact 'nop' output (Jiri Olsa) [846702]
- [tools] perf annotate browser: Do raw printing in 'o'ffset in a single place (Jiri Olsa) [846702]
- [tools] perf annotate browser: Don't change the asm line color when toggling source (Jiri Olsa) [846702]
- [tools] perf annotate browser: More clearly separate columns (Jiri Olsa) [846702]
- [tools] perf ui browser: Introduce routine to draw vertical line (Jiri Olsa) [846702]
- [tools] perf annotate browser: Don't display 0.00 percentages (Jiri Olsa) [846702]
- [tools] perf annotate browser: Remove the vertical line after the percentages (Jiri Olsa) [846702]
- [tools] perf annotate browser: Show current jump, back or forward (Jiri Olsa) [846702]
- [tools] perf ui browser: Add method to draw up/down arrow line (Jiri Olsa) [846702]
- [tools] perf annotate browser: Add a right arrow before call instructions (Jiri Olsa) [846702]
- [tools] perf annotate browser: Don't draw jump connectors for out of function jumps (Jiri Olsa) [846702]
- [tools] perf annotate: Mark jump instructions with no offset (Jiri Olsa) [846702]
- [tools] perf annotate: Disambiguage offsets and addresses in operands (Jiri Olsa) [846702]
- [tools] perf annotate browser: Handle NULL jump targets (Jiri Olsa) [846702]
- [tools] perf annotate browser: Initial loop detection (Jiri Olsa) [846702]
- [tools] perf: Cleanup realloc use (Jiri Olsa) [846702]
- [tools] ui browser: Add method to write graphical characters (Jiri Olsa) [846702]
- [tools] perf annotate browser: Handle retq instructions (Jiri Olsa) [846702]
- [tools] perf annotate browser: Add visual cue for retq instruction (Jiri Olsa) [846702]
- [tools] perf annotate browser: Add visual cues on jump lines (Jiri Olsa) [846702]
- [tools] perf annotate browser: Suppress the callq address (Jiri Olsa) [846702]
- [tools] perf annotate browser: Bandaid offsets/jump label objdump ambiguity (Jiri Olsa) [846702]
- [tools] perf annotate: Group operands members (Jiri Olsa) [846702]
- [tools] perf annotate: Add missing jump variants (Jiri Olsa) [846702]
- [tools] perf annotate browser: Use a vertical line as percentage separator (Jiri Olsa) [846702]
- [tools] perf annotate browser: Make lines more compact (Jiri Olsa) [846702]
- [tools] perf annotate browser: Align jump labels (Jiri Olsa) [846702]
- [tools] perf annotate browser: Hide non jump target addresses in offset mode (Jiri Olsa) [846702]
- [tools] perf symbols: Introduce symbol__size method (Jiri Olsa) [846702]
- [tools] perf annotate browser: Rename disasm_line_rb_node (Jiri Olsa) [846702]
- [tools] perf annotate: Introduce scnprintf ins_ops method (Jiri Olsa) [846702]
- [tools] perf annotate: Parse call targets earlier (Jiri Olsa) [846702]
- [tools] perf annotate: Disassembler instruction parsing (Jiri Olsa) [846702]
- [tools] perf annotate browser: Use the disasm_line instruction name and operand fields (Jiri Olsa) [846702]
- [tools] perf annotate: Parse instruction (Jiri Olsa) [846702]
- [tools] perf annotate: Rename objdump_line to disasm_line (Jiri Olsa) [846702]
- [tools] perf record: Use sw counter only if hw pmu is not detected (Jiri Olsa) [846702]
- [tools] perf: Fix thread map that is type pid_t (Jiri Olsa) [846702]
- [tools] perf stat: Declare some references static (Jiri Olsa) [846702]
- [tools] perf: Move GTK+ bits to tools/perf/ui/gtk directory (Jiri Olsa) [846702]
- [tools] perf: Move UI bits to tools/perf/ui directory (Jiri Olsa) [846702]
- [tools] perf annotate: Fix a build error (Jiri Olsa) [846702]
- [tools] perf annotate browser: string search: /?n (Jiri Olsa) [846702]
- [tools] perf report: Correct display of samples and events in header (Jiri Olsa) [846702]
- [tools] perf annotate browser: Initial support for navigating jump instructions (Jiri Olsa) [846702]
- [tools] perf ui annotate browser: Add list based search for addr offset (Jiri Olsa) [846702]
- [tools] perf ui annotate browser: Move callq handling to separate function (Jiri Olsa) [846702]
- [tools] perf ui annotate browser: Allow toggling addr offset view (Jiri Olsa) [846702]
- [tools] perf annotate: Allow printing objdump line addr in different color (Jiri Olsa) [846702]
- [tools] perf ui browser: Return the current color when setting a new one (Jiri Olsa) [846702]
- [tools] traceevent: Ignore TRACEEVENT-CFLAGS file (Jiri Olsa) [846702]
- [tools] traceevent: Detect build environment changes (Jiri Olsa) [846702]
- [tools] traceevent: Cleanup realloc use (Jiri Olsa) [846702]
- [tools] traceevent: Add missing break in make_bprint_args (Jiri Olsa) [846702]
- [tools] traceevent: Check return value of arg_to_str() (Jiri Olsa) [846702]
- [tools] traceevent: Check result of malloc() during reading token (Jiri Olsa) [846702]
- [tools] traceevent: Fix some comments (Jiri Olsa) [846702]
- [tools] traceevent: Do not call add_event() again if allocation failed (Jiri Olsa) [846702]
- [tools] traceevent: Pass string type argument to args (Jiri Olsa) [846702]
- [tools] traceevent: Handle realloc() failure path (Jiri Olsa) [846702]
- [tools] traceevent: Handle strdup failure cases (Jiri Olsa) [846702]
- [tools] traceevent: Introduce extend_token() (Jiri Olsa) [846702]
- [tools] traceevent: Fix printk_cmp() (Jiri Olsa) [846702]
- [tools] traceevent: Fix trace_printk for long integers (Jiri Olsa) [846702]
- [tools] traceevent: Fix pM print format arg handling (Jiri Olsa) [846702]
- [tools] traceevent: Add support to show migrate disable counter (Jiri Olsa) [846702]
- [tools] traceevent: Add support for ".*s" in bprintk events (Jiri Olsa) [846702]
- [tools] traceevent: Let filtering numbers by string use function names (Jiri Olsa) [846702]
- [tools] traceevent: Replace malloc_or_die to plain malloc in alloc_event() (Jiri Olsa) [846702]
- [tools] traceevent: Add support for __print_hex() (Jiri Olsa) [846702]
- [tools] traceevent: Use local variable 'field' (Jiri Olsa) [846702]
- [tools] traceevent: Check string is really printable (Jiri Olsa) [846702]
- [tools] traceevent: Make dependency files regeneratable (Jiri Olsa) [846702]
- [tools] traceevent: Teach [ce]tags about libtraceeevent error codes (Jiri Olsa) [846702]
- [tools] traceevent: Fix clean target in Makefile (Jiri Olsa) [846702]
- [tools] traceevent: Silence compiler warning on 32bit build (Jiri Olsa) [846702]
- [tools] traceevent: Fix signature of create_arg_item() (Jiri Olsa) [846702]
- [tools] traceevent: Use proper function parameter type (Jiri Olsa) [846702]
- [tools] traceevent: Fix freeing arg on process_dynamic_array() (Jiri Olsa) [846702]
- [tools] traceevent: Fix a possibly wrong memory dereference (Jiri Olsa) [846702]
- [tools] traceevent: Fix a possible memory leak (Jiri Olsa) [846702]
- [tools] traceevent: Allow expressions in __print_symbolic() fields (Jiri Olsa) [846702]
- [tools] perf: Always try to build libtraceevent (Jiri Olsa) [846702]
- [tools] perf: Rename libparsevent to libtraceevent in Makefile (Jiri Olsa) [846702]
- [tools] parse-events: Rename struct record to struct pevent_record (Jiri Olsa) [846702]
- [tools] perf/events: Add flag to produce nsec output (Jiri Olsa) [846702]
- [tools] perf: Have perf use the new libtraceevent.a library (Jiri Olsa) [846702]
- [tools] perf: Build libtraceevent.a (Jiri Olsa) [846702]
- [tools] perf: Separate out trace-cmd parse-events from perf files (Jiri Olsa) [846702]
- [tools] perf script: Rename struct event to struct event_format in perl engine (Jiri Olsa) [846702]
- [tools] perf script: Explicitly handle known default print arg type (Jiri Olsa) [846702]
- [tools] Add Makefile.include (Jiri Olsa) [846702]
- [tools] parse-event: Fix memset pointer size bug in handle (Jiri Olsa) [846702]
- [tools] parse-events: Allow '*' and '/' operations in TP_printk (Jiri Olsa) [846702]
- [tools] parse-events: Support '+' opcode in print format (Jiri Olsa) [846702]
- [tools] parse-events: Let pevent_free() take a NULL pointer (Jiri Olsa) [846702]
- [tools] parse-events: Handle opcode parsing error (Jiri Olsa) [846702]
- [tools] parse-events: Handle invalid opcode parsing gracefully (Jiri Olsa) [846702]
- [tools] perf/events: Correct size given to memset (Jiri Olsa) [846702]
- [tools] perf/events: Add flag/symbol format_flags (Jiri Olsa) [846702]
- [tools] events: Update tools/lib/traceevent to work with perf (Jiri Olsa) [846702]
- [tools] events: Add files to create libtraceevent.a (Jiri Olsa) [846702]
- [netdrv] cxgb4: Fix (nearly-)kernel-doc comments for various functions (Jay Fenlason) [847356]
- [netdrv] cxgb4: Remove casts to same type (Jay Fenlason) [847356]
- [netdrv] cxgb4: DB Drop Recovery for RDMA and LLD queues (Jay Fenlason) [847356]
- [netdrv] cxgb4: Common platform specific changes for DB Drop Recovery (Jay Fenlason) [847356]
- [netdrv] cxgb4: Detect DB FULL events and notify RDMA ULD (Jay Fenlason) [847356]
- [netdrv] cxgb4: unify return value of .ndo_set_mac_address if address is invalid (Jay Fenlason) [847356]
- [netdrv] cxgb4: Add support for Chelsio's T480-CR and T440-LP-CR adapters (Jay Fenlason) [847356]
- [x86] mce: Disable error thresholding bank 4 on some AMD models (Frank Arnold) [823617]
- [x86] bitops: Move BIT_64 for a wider use (Frank Arnold) [823617]
- [x86] mce_amd: Hide interrupt_enable sysfs node (Frank Arnold) [823617]
- [x86] mce_amd: Make APIC LVT thresholding interrupt optional (Frank Arnold) [823617]
- [s390] kernel: incorrect task size after fork of a 31 bit process (Hendrik Brueckner) [845133]
- [net] sock: delete unnecessary call of sk_alloc_size() (Weiping Pan) [850736]

* Wed Aug 22 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-301.el6]
- [tracing] kprobes: Fix KABI break caused by new #include (Jiri Olsa) [786489]
- [tools] perf: Enable the probe command (Jiri Olsa) [786489]
- [tracing] Modify is_delete, is_return from int to bool (Jiri Olsa) [786489]
- [tracing] kprobes: Rename probe_* to trace_probe_* (Jiri Olsa) [786489]
- [tracing] ftrace, kprobes: Fix not to delete probes if in use (Jiri Olsa) [786489]
- [tracing] kprobes: Fix kprobe-tracer to support stack trace (Jiri Olsa) [786489]
- [kernel] stack_trace: Add weak save_stack_trace_regs() (Jiri Olsa) [786489]
- [x86] Swap save_stack_trace_regs parameters (Jiri Olsa) [786489]
- [tracing] kprobes: Fix kprobe selftest for gcc 4.6 (Jiri Olsa) [786489]
- [tracing] kprobes: Fix common misspellings (Jiri Olsa) [786489]
- [tracing] kprobes: Fix NULL pointer deref check (Jiri Olsa) [786489]
- [tracing] kprobes: Add bitfield type (Jiri Olsa) [786489]
- [tracing] kprobes: Support longer (>128 bytes) command (Jiri Olsa) [786489]
- [tracing] kprobes: Cleanup strict_strtol() using code (Jiri Olsa) [786489]
- [tracing] kprobes: Fix handling of C-unlike argument names (Jiri Olsa) [786489]
- [tracing] kprobes: Fix handling of argument names (Jiri Olsa) [786489]
- [tracing] kprobes: Fix a memory leak in error case (Jiri Olsa) [786489]
- [tracing] kprobes: fix printk typo 'faild' (Jiri Olsa) [786489]
- [tracing] kprobes: unregister_trace_probe needs to be called under mutex (Jiri Olsa) [786489]
- [tracing] perf, kprobes: Remove duplicate includes from many files (Jiri Olsa) [786489]
- [tracing] kprobes: Support "string" type (Jiri Olsa) [786489]
- [tracing] kprobes: Support basic types on dynamic events (Jiri Olsa) [786489]
- [tracing] Fix typo of info text in trace_kprobe.c (Jiri Olsa) [786489]
- [tracing] kprobes: Fix probe parsing (Jiri Olsa) [786489]
- [tracing] kprobes: Cleanup unused return value of tracing functions (Jiri Olsa) [786489]
- [tracing] perf: Factorize trace events raw sample buffer operations (Jiri Olsa) [786489]
- [tracing] kprobes: Update kprobe tracing self test for new syntax (Jiri Olsa) [786489]
- [tracing] kprobes: Drop function argument access syntax (Jiri Olsa) [786489]
- [tracing] kprobes: Show sign of fields in trace_kprobe format files (Jiri Olsa) [786489]
- [tracing] kprobes: Check new event/group name (Jiri Olsa) [786489]
- [tracing] kprobes: Fix field creation's bad error handling (Jiri Olsa) [786489]
- [tracing] kprobes: Support delete probe syntax (Jiri Olsa) [786489]
- [tracing] kprobes: Fix a memory leak bug and check kstrdup() return value (Jiri Olsa) [786489]
- [tracing] kprobes: Don't output zero offset (Jiri Olsa) [786489]
- [tracing] kprobes: Always show group name (Jiri Olsa) [786489]
- [tracing] kprobes: Fix memory leak (Jiri Olsa) [786489]
- [tracing] perf, kprobes: Fix lock recursion (Jiri Olsa) [786489]
- [tracing] kprobes: Rename Kprobe-tracer to kprobe-event (Jiri Olsa) [786489]
- [tracing] kprobes: Compare both of event-name and event-group to find probe (Jiri Olsa) [786489]
- [tracing] kprobes: Add failure messages for debugging (Jiri Olsa) [786489]
- [tracing] kprobes: Update kprobe-tracer selftest against new syntax (Jiri Olsa) [786489]
- [tracing] kprobes: Robustify fixed field names against variable field names conflicts (Jiri Olsa) [786489]
- [tracing] kprobes: Avoid field name confliction (Jiri Olsa) [786489]
- [tracing] kprobes: Make special variable names more self-explainable (Jiri Olsa) [786489]
- [tracing] kprobes: Remove '$ra' special variable (Jiri Olsa) [786489]
- [tracing] kprobes: Add $ prefix to special variables (Jiri Olsa) [786489]
- [tracing] kprobes: Use global event perf buffers in kprobe tracer (Jiri Olsa) [786489]
- [tracing] kprobes: Merge conflicts changes (Jiri Olsa) [786489]
- [tracing] kprobes: Disable kprobe events by default after creation (Jiri Olsa) [786489]
- [tracing] kprobes: Fix profiling alignment for perf_counter buffer (Jiri Olsa) [786489]
- [tracing] kprobes: Add probe handler dispatcher to support perf and ftrace concurrent use (Jiri Olsa) [786489]
- [tracing] kprobes: Fix trace_probe registration order (Jiri Olsa) [786489]
- [tracing] kprobes: Support custom subsystem for each kprobe event (Jiri Olsa) [786489]
- [tracing] kprobes: Show event name in trace output (Jiri Olsa) [786489]
- [tracing] kprobes: Add argument name support (Jiri Olsa) [786489]
- [tracing] kprobes: Add event profiling support (Jiri Olsa) [786489]
- [tracing] kprobes: Cleanup kprobe tracer code. (Jiri Olsa) [786489]
- [tracing] kprobes: Fix probe offset to be unsigned (Jiri Olsa) [786489]
- [tracing] kprobes: Merge conflicts changes (Jiri Olsa) [786489]
- [tracing] kprobes: Change trace_arg to probe_arg (Jiri Olsa) [786489]
- [tracing] kprobes: Fix format typo in trace_kprobes (Jiri Olsa) [786489]
- [tracing] kprobes: Add kprobes event profiling interface (Jiri Olsa) [786489]
- [tracing] kprobes: tracer assigns new event ids for each event (Jiri Olsa) [786489]
- [tracing] Generate names for each kprobe event automatically (Jiri Olsa) [786489]
- [tracing] Kprobe-tracer supports more than 6 arguments (Jiri Olsa) [786489]
- [tracing] Add kprobe-based event tracer documentation (Jiri Olsa) [786489]
- [tracing] Add kprobe-based event tracer (Jiri Olsa) [786489]
- [x86] ptrace: Fix regs_get_argument_nth() to add correct offset (Jiri Olsa) [786489]
- [x86] Add pt_regs register and stack access APIs (Jiri Olsa) [786489]
- [net] sched/act_mirred: do not drop packets when fails to mirror it (Jason Wang) [846585]
- [net] sched: fix race in mirred device removal (Jason Wang) [846585]
- [net] sched: printk message severity (Jason Wang) [846585]
- [net] sched: act_mirred cleanup (Jason Wang) [846585]
- [kernel] events: Fix double start/stop in x86_pmu_start() (Jerome Marchand) [803900]
- [kernel] events: Fix broken interrupt rate throttling (Jerome Marchand) [803900]
- [kernel] events: Avoid a useless pmu_disable() in the perf-tick (Jerome Marchand) [803900]
- [input] wacom: add support for Bamboo Pen ID 0xd4 (Aristeu Rozanski) [798796]
- [input] wacom: add Intuos5 Touch Ring/ExpressKey support (Aristeu Rozanski) [841611]
- [input] wacom: add basic Intuos5 support (Aristeu Rozanski) [841611]
- [virt] virtio: Use ida to allocate virtio index (Asias He) [844542]
- [virt] kvm: apply kvmclock offset to guest wall clock time (Marcelo Tosatti) [817243]
- [virt] kvm: Fix PCI header check on device assignment (Alex Williamson) [829031]
- [virt] kvm: Don't save/restore MSR_IA32_PERF_STATUS (Karen Noel) [816308]
- [s390] kernel: CPU idle vs CPU hotplug (Hendrik Brueckner) [845132]
- [powerpc] pseries/iommu: remove default window before attempting DDW manipulation (Steve Best) [822614]
- [char] tty: Fix possible race in n_tty_read() (Stanislaw Gruszka) [765665]
- [x86] crash: prepare for pseudo-phys pages without machine frames (Laszlo Ersek) [848766]
- [netdrv] cxgb3: Set vlan_feature on net_device (Steve Best) [841993]
- [netdrv] mlx4: Add support for EEH error recovery (Steve Best) [822654]
- [netdrv] e1000e: add missing clear of E1000_RCTL_VFE to e1000e_set_rx_mode() (Dean Nelson) [832573]
- [netdrv] e1000: Prevent reset task killing itself (Dean Nelson) [842886]
- [netdrv] r8169: fix invalid firmware for 8168d and include ones for newer chipsets (Ivan Vecera) [840591]
- [net] netconsole: disable netconsole target before releasing target_list_lock (Amerigo Wang) [849571]
- [net] netconsole: fix deadlock when removing net driver that netconsole is using (Amerigo Wang) [769734]
- [net] ethtool: Report link-down while interface is down (Ivan Vecera) [821674]

* Fri Aug 17 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-300.el6]
- [x86] mce: Replace MCM_ with MCI_MISC_ (Luming Yu) [696033]
- [x86] mce: Move MCACOD defines from mce-severity.c to <asm/mce.h> (Luming Yu) [696033]
- [x86] mce-severity: Fix check for processor context when machine check was taken (Luming Yu) [696033]
- [x86] mce-severity: Replace hard coded hex constants with symbolic defines (Luming Yu) [696033]
- [x86] mce-severity: Recognise machine check bank signature for data path error (Luming Yu) [696033]
- [x86] mce-severity: Clean up trivial coding style problems (Luming Yu) [696033]
- [x86] mce-severity: Cleanup severity table (Luming Yu) [696033]
- [x86] mce-severity: Make formatting a bit more readable (Luming Yu) [696033]
- [x86] mce-severity: Fix two severities table signatures (Luming Yu) [696033]
- [x86] mce: Handle "action required" errors (Luming Yu) [696033]
- [x86] mce: Add mechanism to safely save information in MCE handler (Luming Yu) [696033]
- [x86] mce: Create helper function to save addr/misc when needed (Luming Yu) [696033]
- [mm] HWPOISON: Add code to handle "action required" errors (Luming Yu) [696033]
- [mm] HWPOISON: Clean up memory_failure() vs. __memory_failure() (Luming Yu) [696033]
- [hwmon] fam15h_power: Fix pci_device_id array (Frank Arnold) [822277]
- [hwmon] fam15h_power: fix bogus values with current BIOSes (Frank Arnold) [822277]
- [hwmon] fam15h_power: Increase output resolution (Frank Arnold) [822277]
- [hwmon] fam15h_power: Correct sign extension of running_avg_capture (Frank Arnold) [822277]
- [hwmon] Add driver for AMD family 15h processor power information (Frank Arnold) [822277]
- [pci] amd-nb: Rename CPU PCI id define for F4 (Frank Arnold) [822277]
- [hwmon] k10temp: Add support for AMD Trinity CPUs (Frank Arnold) [822277]
- [hwmon] k10temp: Update documentation for Fam12h (Frank Arnold) [822277]
- [md] raid1: close some possible races on write errors during resync (Jes Sorensen) [817970]
- [md] avoid crash when stopping md array races with closing other open fds. (Jes Sorensen) [817970]
- [md] fix bug in handling of new_data_offset (Jes Sorensen) [817970]
- [md] raid1: fix use-after-free bug in RAID1 data-check code. (Jes Sorensen) [817970]
- [md] support re-add of recovering devices. (Jes Sorensen) [817970]
- [md] raid1: fix bug in read_balance introduced by hot-replace (Jes Sorensen) [817970]
- [md] raid5: delayed stripe fix (Jes Sorensen) [817970]
- [md] raid456: When read error cannot be recovered, record bad block (Jes Sorensen) [817970]
- [md] make 'name' arg to md_register_thread non-optional. (Jes Sorensen) [817970]
- [md] raid10: fix failure when trying to repair a read error. (Jes Sorensen) [817970]
- [md] raid5: fix refcount problem when blocked_rdev is set. (Jes Sorensen) [817970]
- [md] raid5: In ops_run_io, inc nr_pending before calling md_wait_for_blocked_rdev (Jes Sorensen) [817970]
- [md] raid5: Do not add data_offset before call to is_badblock (Jes Sorensen) [817970]
- [md] raid5: prefer replacing failed devices over want-replacement devices. (Jes Sorensen) [817970]
- [md] raid10: Don't try to recovery unmatched (and unused) chunks. (Jes Sorensen) [817970]
- [md] raid1, raid10: fix problem with merge_bvec_fn (Jes Sorensen) [817970]
- [md] bitmap: record the space available for the bitmap in the superblock. (Jes Sorensen) [817970]
- [md] raid10: Remove extras after reshape to smaller number of devices. (Jes Sorensen) [817970]
- [md] raid5: improve removal of extra devices after reshape. (Jes Sorensen) [817970]
- [md] check the return of mddev_find() (Jes Sorensen) [817970]
- [md] raid5: Allow reshape while a bitmap is present. (Jes Sorensen) [817970]
- [md] raid10: resize bitmap when required during reshape. (Jes Sorensen) [817970]
- [md] allow array to be resized while bitmap is present. (Jes Sorensen) [817970]
- [md] bitmap: make sure reshape request are reflected in superblock. (Jes Sorensen) [817970]
- [md] bitmap: add bitmap_resize function to allow bitmap resizing. (Jes Sorensen) [817970]
- [md] bitmap: use DIV_ROUND_UP instead of open-code (Jes Sorensen) [817970]
- [md] bitmap: create a 'struct bitmap_counts' substructure of 'struct bitmap' (Jes Sorensen) [817970]
- [md] bitmap: make bitmap bitops atomic. (Jes Sorensen) [817970]
- [md] bitmap: make _page_attr bitops atomic. (Jes Sorensen) [817970]
- [md] bitmap: merge bitmap_file_unmap and bitmap_file_put. (Jes Sorensen) [817970]
- [md] bitmap: remove async freeing of bitmap file. (Jes Sorensen) [817970]
- [md] bitmap: convert some spin_lock_irqsave to spin_lock_irq (Jes Sorensen) [817970]
- [md] bitmap: use set_bit, test_bit, etc for operation on bitmap->flags. (Jes Sorensen) [817970]
- [md] bitmap: remove single-bit manipulation on sb->state (Jes Sorensen) [817970]
- [md] bitmap: remove bitmap_mask_state (Jes Sorensen) [817970]
- [md] bitmap: move storage allocation from bitmap_load to bitmap_create. (Jes Sorensen) [817970]
- [md] bitmap: separate bitmap file allocation to its own function. (Jes Sorensen) [817970]
- [md] bitmap: store bytes in file rather than just in last page. (Jes Sorensen) [817970]
- [md] bitmap: move some fields of 'struct bitmap' into a 'storage' substruct. (Jes Sorensen) [817970]
- [md] bitmap: change *_page_attr() to take a page number, not a page. (Jes Sorensen) [817970]
- [md] bitmap: centralise allocation of bitmap file pages. (Jes Sorensen) [817970]
- [md] bitmap: allow a bitmap with no backing storage. (Jes Sorensen) [817970]
- [md] bitmap: add new 'space' attribute for bitmaps. (Jes Sorensen) [817970]
- [md] bitmap: disentangle two different 'pending' flags. (Jes Sorensen) [817970]
- [md] raid5: support sync request (Jes Sorensen) [817970]
- [md] raid5: remove unused variables (Jes Sorensen) [817970]
- [md] raid10: Fix memleak in r10buf_pool_alloc (Jes Sorensen) [817970]
- [md] raid1: allow fix_read_error to read from recovering device. (Jes Sorensen) [817970]
- [md] move freeing of badblocks.page into md_rdev_clear (Jes Sorensen) [817970]
- [md] dm-raid should call helper function to clear rdev. (Jes Sorensen) [817970]
- [lib] raid6: Add SSSE3 optimized recovery functions (Jes Sorensen) [817970]
- [md] raid10: add reshape support (Jes Sorensen) [817970]
- [md] raid10: split out interpretation of layout to separate function. (Jes Sorensen) [817970]
- [md] raid10: Introduce 'prev' geometry to support reshape. (Jes Sorensen) [817970]
- [md] use resync_max_sectors for reshape as well as resync. (Jes Sorensen) [817970]
- [md] teach sync_page_io about new_data_offset. (Jes Sorensen) [817970]
- [md] raid10: collect some geometry fields into a dedicated structure. (Jes Sorensen) [817970]
- [md] raid5: allow for change in data_offset while managing a reshape. (Jes Sorensen) [817970]
- [md] raid5: Use correct data_offset for all IO. (Jes Sorensen) [817970]
- [md] add possibility to change data-offset for devices. (Jes Sorensen) [817970]
- [md] allow a reshape operation to be reversed. (Jes Sorensen) [817970]
- [md] using GFP_NOIO to allocate bio for flush request (Jes Sorensen) [817970]
- [md] raid10: fix transcription error in calc_sectors conversion. (Jes Sorensen) [817970]
- [md] raid10: set dev_sectors properly when resizing devices in array. (Jes Sorensen) [817970]
- [md] bitmap: fix calculation of 'chunks' - missing shift. (Jes Sorensen) [817970]
- [md] fix possible corruption of array metadata on shutdown. (Jes Sorensen) [817970]
- [md] don't call ->add_disk unless there is good reason. (Jes Sorensen) [817970]
- [md] bitmap: prevent bitmap_daemon_work running while initialising bitmap (Jes Sorensen) [817970]
- [md] raid1, raid10: Fix calculation of 'vcnt' when processing error recovery. (Jes Sorensen) [817970]
- [md] Bitmap version cleanup (Jes Sorensen) [817970]
- [md] raid1, raid10: don't compare excess byte during consistency check. (Jes Sorensen) [817970]
- [md] raid5: Fix a bug about judging if the operation is syncing or replacing (Jes Sorensen) [817970]
- [md] raid1:Remove unnecessary rcu_dereference(conf->mirrors[i].rdev). (Jes Sorensen) [817970]
- [md] raid5: fix handling of bad blocks during recovery. (Jes Sorensen) [817970]
- [md] raid1: If md_integrity_register() failed, run() must free the mem (Jes Sorensen) [817970]
- [md] raid0: If md_integrity_register() fails, raid0_run() must free the mem. (Jes Sorensen) [817970]
- [md] linear: If md_integrity_register() fails, linear_run() must free the mem. (Jes Sorensen) [817970]
- [md] Add judgement bb->unacked_exist in function md_ack_all_badblocks(). (Jes Sorensen) [817970]
- [md] fix clearing of the 'changed' flags for the bad blocks list. (Jes Sorensen) [817970]
- [md] bitmap: discard CHUNK_BLOCK_SHIFT macro (Jes Sorensen) [817970]
- [md] bitmap: remove unnecessary indirection when allocating. (Jes Sorensen) [817970]
- [md] bitmap: remove some pointless locking. (Jes Sorensen) [817970]
- [md] bitmap: change a 'goto' to a normal 'if' construct. (Jes Sorensen) [817970]
- [md] bitmap: move printing of bitmap status to bitmap.c (Jes Sorensen) [817970]
- [md] bitmap: remove some unused noise from bitmap.h (Jes Sorensen) [817970]
- [md] raid10 - support resizing some RAID10 arrays. (Jes Sorensen) [817970]
- [md] raid1: handle merge_bvec_fn in member devices. (Jes Sorensen) [817970]
- [md] raid10: handle merge_bvec_fn in member devices. (Jes Sorensen) [817970]
- [md] add proper merge_bvec handling to RAID0 and Linear. (Jes Sorensen) [817970]
- [md] tidy up rdev_for_each usage. (Jes Sorensen) [817970]
- [md] raid1, raid10: avoid deadlock during resync/recovery. (Jes Sorensen) [817970]
- [md] don't set md arrays to readonly on shutdown. (Jes Sorensen) [817970]
- [md] allow re-add to failed arrays. (Jes Sorensen) [817970]
- [md] raid5: use atomic_dec_return() instead of atomic_dec() and atomic_read(). (Jes Sorensen) [817970]
- [md] Use existed macros instead of numbers (Jes Sorensen) [817970]
- [md] raid5: removed unused 'added_devices' variable. (Jes Sorensen) [817970]
- [md] raid10: remove unnecessary smp_mb() from end_sync_write (Jes Sorensen) [817970]
- [md] raid5: make sure reshape_position is cleared on error path. (Jes Sorensen) [817970]
- [md] raid10: fix assembling of arrays with replacement devices. (Jes Sorensen) [817970]
- [md] raid10: fix handling of error on last working device in array. (Jes Sorensen) [817970]
- [md] raid1: fix buglet in md_raid1_contested. (Jes Sorensen) [817970]
- [md] two small fixes to handling interrupt resync. (Jes Sorensen) [817970]
- [md] notify the 'degraded' sysfs attribute on failure. (Jes Sorensen) [817970]
- [md] raid1: Mark device want_replacement when we see a write error. (Jes Sorensen) [817970]
- [md] raid1: If there is a spare and a want_replacement device, start replacement. (Jes Sorensen) [817970]
- [md] raid1: recognise replacements when assembling arrays. (Jes Sorensen) [817970]
- [md] raid1: handle activation of replacement device when recovery completes. (Jes Sorensen) [817970]
- [md] raid1: Allow a failed replacement device to be removed. (Jes Sorensen) [817970]
- [md] raid1: Allocate spare to store replacement devices and their bios. (Jes Sorensen) [817970]
- [md] raid1: Replace use of mddev->raid_disks with conf->raid_disks. (Jes Sorensen) [817970]
- [md] raid10: If there is a spare and a want_replacement device, start replacement. (Jes Sorensen) [817970]
- [md] raid10: recognise replacements when assembling array. (Jes Sorensen) [817970]
- [md] raid10: Allow replacement device to be replace old drive. (Jes Sorensen) [817970]
- [md] raid10: handle recovery of replacement devices. (Jes Sorensen) [817970]
- [md] raid10: Handle replacement devices during resync. (Jes Sorensen) [817970]
- [md] raid10: writes should get directed to replacement as well as original. (Jes Sorensen) [817970]
- [md] raid10: allow removal of failed replacement devices. (Jes Sorensen) [817970]
- [md] raid10: preferentially read from replacement device if possible. (Jes Sorensen) [817970]
- [md] raid10: change read_balance to return an rdev (Jes Sorensen) [817970]
- [md] raid10: prepare data structures for handling replacement. (Jes Sorensen) [817970]
- [md] raid5: Mark device want_replacement when we see a write error. (Jes Sorensen) [817970]
- [md] raid5: If there is a spare and a want_replacement device, start replacement. (Jes Sorensen) [817970]
- [md] raid5: recognise replacements when assembling array. (Jes Sorensen) [817970]
- [md] raid5: handle activation of replacement device when recovery completes. (Jes Sorensen) [817970]
- [md] raid5: detect and handle replacements during recovery. (Jes Sorensen) [817970]
- [md] raid5: writes should get directed to replacement as well as original. (Jes Sorensen) [817970]
- [md] raid5: allow removal for failed replacement devices. (Jes Sorensen) [817970]
- [md] raid5: preferentially read from replacement device if possible. (Jes Sorensen) [817970]
- [md] raid5: remove redundant bio initialisations. (Jes Sorensen) [817970]
- [md] raid5: raid5.h cleanup (Jes Sorensen) [817970]
- [md] raid5: allow each slot to have an extra replacement device (Jes Sorensen) [817970]
- [md] create externally visible flags for supporting hot-replace. (Jes Sorensen) [817970]
- [md] change hot_remove_disk to take an rdev rather than a number (Jes Sorensen) [817970]
- [md] remove test for duplicate device when setting slot number (Jes Sorensen) [817970]
- [md] bitmap: be more consistent when setting new bits in memory bitmap (Jes Sorensen) [817970]
- [md] Fix userspace free_pages() macro (Jes Sorensen) [817970]
- [md] raid5: be more thorough in calculating 'degraded' value (Jes Sorensen) [817970]
- [md] bitmap: daemon_work cleanup (Jes Sorensen) [817970]
- [md] allow non-privileged uses to GET_*_INFO about raid arrays (Jes Sorensen) [817970]
- [md] update documentation for md/rdev/state sysfs interface (Jes Sorensen) [817970]
- [kernel] Add DIV_ROUND_UP_ULL and DIV_ROUND_UP_SECTOR_T macro usage (Jes Sorensen) [817970]
- [kernel] add roundup() code comment from akpm (Jes Sorensen) [817970]
- [kernel] Constify temporary variable in roundup() (Jes Sorensen) [817970]
- [kernel] roundup should only reference arguments once (Jes Sorensen) [817970]
- [md] raid: remove sparse warning:symbol XXX was not declared (Jes Sorensen) [817970]
- [md] convert bitmap code to use compat macros for le-bitops (Jes Sorensen) [817970]
- [md] add rhel6 compat macros for upstream le-bitops (Jes Sorensen) [817970]
- [scsi] cleanup usages of scsi_complete_async_scans (David Milburn) [839070]
- [scsi] queue async scan work to an async_schedule domain (David Milburn) [839070]
- [scsi] async: make async_synchronize_full() flush all work regardless of domain (David Milburn) [839070]
- [scsi] async: introduce 'async_domain' type (David Milburn) [839070]
- [scsi] isci: make function declaration match implementation (David Milburn) [839070]
- [scsi] cleanup ata_host flags initialization via ata_host_init (David Milburn) [839070]
- [scsi] fix hot unplug vs async scan race (David Milburn) [839070]
- [scsi] libsas: fix taskfile corruption in sas_ata_qc_fill_rtf (David Milburn) [839070]
- [scsi] sd: limit the scope of the async probe domain (David Milburn) [839070]
- [scsi] libsas: fix sas_discover_devices return code handling (David Milburn) [839070]
- [scsi] cleanup setting task state in scsi_error_handler() (David Milburn) [839070]
- [scsi] Revert: scsi_transport_sas: fix delete vs scan race (David Milburn) [839070]

* Fri Aug 17 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-299.el6]
- [kernel] sched: fix divide by zero at {thread_group,task}_times (Stanislaw Gruszka) [843771]
- [scsi] alua: backoff alua rtpg retry linearly (Rob Evers) [820567]
- [scsi] scsi_transport_fc: fix scan when devs are offline (Rob Evers) [822691]
- [scsi] alua: retry extended header for illegal response (Rob Evers) [678069]
- [scsi] alua: implement 'implied transition timeout' (Rob Evers) [678069]
- [scsi] alua: Re-enable STPG for unavailable ports (Rob Evers) [807486]
- [scsi] alua: Optimize the STPG command (Rob Evers) [807486]
- [scsi] alua: Store the PREF bit from RTPG (Rob Evers) [807486]
- [scsi] alua: Introduce set params interface (Rob Evers) [807486]
- [dm] dm-thin: add read only and fail io modes (Mike Snitzer) [814826]
- [dm] dm-thin-metadata: introduce dm_pool_abort_metadata (Mike Snitzer) [814826]
- [dm] dm-thin-metadata: introduce dm_pool_metadata_set_read_only (Mike Snitzer) [814826]
- [dm] dm-persistent-data: introduce dm_bm_set_read_only (Mike Snitzer) [814826]
- [dm] dm-thin: reduce number of metadata commits (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: add dm_thin_changed_this_transaction (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: add format option to dm_pool_metadata_open (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: tidy up open and format error paths (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: only check incompat features on open (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: remove duplicate pmd initialisation (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: remove create parameter from __create_persistent_data_objects (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: move __superblock_all_zeroes to __open_or_format_metadata (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: remove nr_blocks arg from __create_persistent_data_objects (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: split __open or format metadata (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: use struct dm_pool_metadata members in __open_or_format_metadata (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: zero unused superblock uuid (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: lift __begin_transaction out of __write_initial_superblock (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: move dm_commit_pool_metadata into __write_initial_superblock (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: factor out __write_initial_superblock (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: lift some initialisation out of __open_or_format_metadata (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: factor __destroy_persistent_data out of dm_pool_metadata_close (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: move bm creation code into create_persistent_data_objects (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: rename init_pmd to __create_persistent_data_objects (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: wrap superblock locking (Mike Snitzer) [844808]
- [dm] dm-persistent-data: stop using dm_bm_unlock_move when shadowing blocks in tm (Mike Snitzer) [844808]
- [dm] dm-persistent-data: tidy transaction manager creation fns (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: stop tracking need for commit (Mike Snitzer) [844808]
- [dm] persistent-data: create new dm_block_manager struct (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: factor __setup_btree_details out of init_pmd (Mike Snitzer) [844808]
- [dm] dm-thin: set flush_supported (Mike Snitzer) [844808]
- [dm] allow targets to request flushes regardless of underlying device support (Mike Snitzer) [844808]
- [dm] persistent-data: only commit space map if index changed (Mike Snitzer) [844808]
- [dm] persistent-data: always unlock superblock in dm_bm_flush_and_unlock (Mike Snitzer) [844808]
- [dm] dm-thin: avoid unnecessarily breaking sharing for flushes (Mike Snitzer) [844808]
- [dm] dm-thin: fix memory leak in process_prepared_mapping error paths (Mike Snitzer) [844808]
- [dm] dm-thin: split discards on block boundary (Mike Snitzer) [844808]
- [dm] introduce split_discard_requests (Mike Snitzer) [844808]
- [dm] dm-raid: move sectors_per_dev calculation (Mike Snitzer) [844808]
- [dm] dm-raid: restructure parse_raid_params (Mike Snitzer) [844808]
- [dm] dm-mpath: add retain_attached_hw_handler feature (Mike Snitzer) [818374]
- [scsi] scsi_dh: add scsi_dh_attached_handler_name (Mike Snitzer) [818374]
- [dm] dm-thin: optimize power of two block size (Mike Snitzer) [814823]
- [dm] dm-thin: support for non power of 2 pool blocksize (Mike Snitzer) [814823]
- [dm] dm-stripe: optimize chunk_size calculations (Mike Snitzer) [814820]
- [dm] dm-stripe: remove minimum stripe size (Mike Snitzer) [814820]
- [dm] dm-stripe: support for non power of 2 chunksize (Mike Snitzer) [814820]
- [dm] support non power of two target max_io_len (Mike Snitzer) [814820]
- [dm] dm-stripe: remove stripes_mask (Mike Snitzer) [814820]
- [dm] dm-snapshot: remove redundant assignment in merge fn (Mike Snitzer) [844808]
- [dm] dm-thin: provide specific errors for two table load failure cases (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: introduce THIN_MAX_CONCURRENT_LOCKS (Mike Snitzer) [844808]
- [dm] dm-thin-metadata: remove pointless label from __commit_transaction (Mike Snitzer) [844808]
- [dm] dm-persistent-data: remove debug space map checker (Mike Snitzer) [844808]
- [dm] dm-thin: clean up compiler warning (Mike Snitzer) [844808]
- [dm] dm-thin: reduce endio_hook pool size (Mike Snitzer) [844808]
- [dm] replace simple_strtoul (Mike Snitzer) [844808]
- [dm] dm-thin: convert from simple_strto* to kstrto* (Mike Snitzer) [844808]
- [dm] dm-raid1: set discard_zeroes_data_unsupported (Mike Snitzer) [844808]
- [dm] dm-thin: do not send discards to shared blocks (Mike Snitzer) [844808]
- [dm] dm-table: introduce discard_zeroes_data_unsupported (Mike Snitzer) [844808]
- [block] do not artificially constrain max_sectors for stacking drivers (Mike Snitzer) [844968]
- [dm] persistent-data: fix allocation failure in space map checker init (Mike Snitzer) [828955]
- [dm] persistent-data: handle space map checker creation failure (Mike Snitzer) [828955]
- [dm] persistent-data: fix shadow_info_leak on dm_tm_destroy (Mike Snitzer) [828955]
- [dm] dm-thin: commit metadata before creating metadata snapshot (Mike Snitzer) [828955]
- [dm] dm-thin: provide userspace access to pool metadata (Mike Snitzer) [828955]
- [dm] dm-thin: use slab mempools (Mike Snitzer) [828955]
- [dm] dm-thin: correct module description (Mike Snitzer) [828955]
- [dm] dm-thin: add pool target flags to control discard (Mike Snitzer) [828955]
- [dm] dm-thin: support discards (Mike Snitzer) [828955]
- [dm] dm-thin: prepare to support discard (Mike Snitzer) [828955]
- [dm] dm-thin: use dm_target_offset (Mike Snitzer) [828955]
- [dm] dm-thin: support read only external snapshot origins (Mike Snitzer) [828955]
- [dm] dm-thin: relax hard limit on the maximum size of a metadata device (Mike Snitzer) [828955]
- [dm] persistent-data: remove space map ref_count entries if redundant (Mike Snitzer) [828955]
- [dm] dm-thin: commit outstanding data every second (Mike Snitzer) [828955]
- [dm] dm-thin: fix stacked bi_next usage (Mike Snitzer) [828955]
- [dm] dm-bufio: there's no need to include linux/version.h (Mike Snitzer) [828955]
- [dm] dm-thin-metadata: pass correct space map to dm_sm_root_size (Mike Snitzer) [828955]
- [dm] persistent-data: remove redundant value_size arg from value_ptr (Mike Snitzer) [828955]
- [dm] dm-thin: correct comments (Mike Snitzer) [828955]
- [dm] persistent-data: fix btree rebalancing after remove (Mike Snitzer) [828955]
- [dm] dm-mpath: allow ioctls to trigger pg init (Mike Snitzer) [760438]
- [dm] dm-mpath: delay retry of bypassed pg (Mike Snitzer) [828955]
- [dm] dm-mpath: reduce size of struct multipath (Mike Snitzer) [828955]
- [dm] dm-mpath: detect invalid map_context (Mike Snitzer) [828955]
- [dm] clear bi_end_io on remapping failure (Mike Snitzer) [828955]
- [dm] reject trailing characters in sccanf input (Mike Snitzer) [828955]
- [dm] dm-table: simplify call to free_devices (Mike Snitzer) [828955]
- [dm] dm-exception-store: fix init error path (Mike Snitzer) [828955]
- [dm] dm-flakey: fix crash on read when corrupt_bio_byte not set (Mike Snitzer) [828955]
- [dm] dm-log-userspace: add log device dependency (Mike Snitzer) [828955]
- [dm] remove superfluous smp_mb (Mike Snitzer) [828955]
- [dm] use local printk ratelimit (Mike Snitzer) [828955]
- [dm] dm-ioctl: add flag to wipe buffers for secure data (Mike Snitzer) [828955]
- [dm] fix idr leak on module removal (Mike Snitzer) [828955]
- [dm] replicator: remove all related code (Mike Snitzer) [828955]
- [block] rename __make_request() to blk_queue_bio() (Mike Snitzer) [828955]
- [block] export __make_request (Mike Snitzer) [828955]

* Wed Aug 15 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-298.el6]
- [scsi] vmw_pvscsi: set max_id suggested by device (Rob Evers) [830357]
- [scsi] fix medium error problems (Rob Evers) [845135]
- [char] hw_random/virtio-rng: s3/s4 support (Amit Shah) [844579 844582 844583]
- [char] hw_random/virtio-rng: split out common code in probe / remove for s3/s4 ops (Amit Shah) [844579 844582 844583]
- [char] hw_random/virtio-rng: don't wait on host when module is going away (Amit Shah) [844579 844582 844583]
- [char] hw_random/virtio-rng: allow tasks to be killed that are waiting for rng input (Amit Shah) [844579 844582 844583]
- [char] hwrng: virtio-rng - Convert to new API (Amit Shah) [844579 844582 844583]
- [char] hwrng: core - Fix double unlock in rng_dev_read (Amit Shah) [844579 844582 844583]
- [char] hwrng: core - Replace u32 in driver API with byte array (Amit Shah) [844579 844582 844583]
- [kernel] timekeeping: Add missing update call in timekeeping_resume() (Prarit Bhargava) [836803]
- [kernel] hrtimer: Update hrtimer base offsets each hrtimer_interrupt (Prarit Bhargava) [836803]
- [kernel] timekeeping: Provide hrtimer update function (Prarit Bhargava) [836803]
- [kernel] hrtimers: Move lock held region in hrtimer_interrupt() (Prarit Bhargava) [836803]
- [kernel] timekeeping: Maintain ktime_t based offsets for hrtimers (Prarit Bhargava) [836803]
- [kernel] timekeeping: Fix leapsecond triggered load spike issue (Prarit Bhargava) [836803]
- [kernel] hrtimer: Provide clock_was_set_delayed() (Prarit Bhargava) [836803]

* Tue Aug 14 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-297.el6]
- [powerpc] pci-dma: use include/linux/pci-dma.h (Stanislaw Gruszka) [827193]
- [x86] pci-dma: use include/linux/pci-dma.h (Stanislaw Gruszka) [827193]
- [acpi] apei/ghes: Printk queued error record before panic (Myron Stowe) [816496]
- [acpi] apei/ghes: Distinguish interleaved error report in kernel log (Myron Stowe) [816496]
- [acpi] apei: Add Kconfig option IRQ_WORK for GHES (Myron Stowe) [816496]
- [acpi] apei/ghes: 32-bit buildfix (Myron Stowe) [816496]
- [acpi] apei/ghes: Add hardware memory error recovery support (Myron Stowe) [816496]
- [acpi] apei/ghes: Error records content based throttle (Myron Stowe) [816496]
- [acpi] apei/ghes: printk support for recoverable error via NMI (Myron Stowe) [816496]
- [lib] genalloc: Make gen_pool memory allocator lockless (Myron Stowe) [816496]
- [misc] Add Kconfig option ARCH_HAVE_NMI_SAFE_CMPXCHG (Myron Stowe) [816496]
- [acpi] apei/ghes: Do not ratelimit fatal error printk before panic (Myron Stowe) [816496]
- [lib] genalloc: add support for specifying the physical address (Myron Stowe) [816496]
- [lib] genalloc: add multiple-inclusion guards (Myron Stowe) [816496]
- [lib] genalloc: fix allocation from end of pool (Myron Stowe) [816496]
- [lib] genalloc: use bitmap_find_next_zero_area (Myron Stowe) [816496]
- [usb] xhci: Fix oops caused by more USB2 ports than USB3 ports (Don Zickus) [738470 813677]
- [i2c] i2c-i801: Add device IDs for Intel Lynx Point (John Villalovos) [738470]
- [watchdog] iTCO_wdt: add Intel Lynx Point DeviceIDs (John Villalovos) [738470]
- [ata] ata_piix: IDE-mode SATA patch for Intel Lynx Point DeviceIDs (John Villalovos) [738470]
- [ata] ahci: AHCI-mode SATA patch for Intel Lynx Point DeviceIDs (John Villalovos) [738470]
- [sound] alsa: Add Lynx Point HD Audio Controller DeviceIDs (John Villalovos) [738470]
- [netdrv] e1000e: prevent oops when adapter is being closed and reset simultaneously (Dean Nelson) [826375]
- [fs] cifs: possible memory leak in xattr (Sachin Prabhu) [824065]
- [fs] cifs: integer overflow in parse_dacl() (Sachin Prabhu) [824065]
- [fs] cifs: Call id to SID mapping functions to change owner/group (Sachin Prabhu) [824065]
- [fs] cifs: Add data structures and functions for uid/gid to SID mapping (Sachin Prabhu) [824065]
- [fs] cifs: Do not set cifs/ntfs acl using a file handle (Sachin Prabhu) [824065]
- [fs] cifs: Fix endian error comparing authusers when cifsacl enabled (Sachin Prabhu) [824065]
- [fs] cifs: Change key name to cifs.idmap, misc. clean-up (Sachin Prabhu) [824065]
- [fs] cifs: Invoke id mapping functions (Sachin Prabhu) [824065]
- [fs] cifs: Add idmap key and related data structures and functions (Sachin Prabhu) [824065]
- [fs] cifs: Allow to set extended attribute cifs_acl (Sachin Prabhu) [824065]
- [fs] cifs: Use mask of ACEs for SID Everyone to calculate all three permissions user, group, and other (Sachin Prabhu) [824065]
- [fs] cifs: goto out here is unnecessary (Sachin Prabhu) [823934]
- [fs] cifs: remove bogus call to cifs_cleanup_volume_info (Sachin Prabhu) [823934]
- [fs] cifs: tidy cifs_do_mount() up a bit (Sachin Prabhu) [823934]
- [fs] cifs: close sget() races (Sachin Prabhu) [823934]
- [fs] cifs: pull freeing mountdata/dropping nls/freeing cifs_sb into cifs_umount() (Sachin Prabhu) [823934]
- [fs] cifs: move cifs_umount() call into ->kill_sb() (Sachin Prabhu) [823934]
- [fs] cifs: pull cifs_mount() call up (Sachin Prabhu) [823934]
- [fs] cifs: sanitize cifs_umount() prototype (Sachin Prabhu) [823934]
- [fs] cifs: initialize ->tlink_tree in cifs_setup_cifs_sb() (Sachin Prabhu) [823934]
- [fs] cifs: allocate mountdata earlier (Sachin Prabhu) [823934]
- [fs] cifs: don't pass superblock to cifs_mount() (Sachin Prabhu) [823934]
- [fs] cifs: don't leak nls on mount failure (Sachin Prabhu) [823934]
- [fs] cifs: double free on mount failure (Sachin Prabhu) [823934]
- [fs] cifs: trivial cleanup fscache cFYI and cERROR messages (Sachin Prabhu) [823934]
- [fs] cifs: Fix memory leak in cifs_do_mount (Sachin Prabhu) [823934]
- [fs] cifs: When mandatory encryption on share, fail mount (Sachin Prabhu) [823934]
- [fs] cifs: Move smb_vol to cifsglob.h (Sachin Prabhu) [823934]
- [fs] cifs: Rename three structures to avoid camel case (Sachin Prabhu) [823934]
- [fs] cifs: Remove unused inode number while fetching root inode (Sachin Prabhu) [823934]
- [fs] cifs: Remove build warning (Sachin Prabhu) [823934]
- [fs] cifs: Fix undefined behavior when mount fails (Sachin Prabhu) [823934]
- [fs] cifs: Simplify mount code for further shared sb capability (Sachin Prabhu) [823934]
- [fs] cifs: Simplify connection structure search calls (Sachin Prabhu) [823934]
- [fs] cifs: Add rwpidforward mount option (Sachin Prabhu) [823902]
- [fs] cifs: Use pid saved from cifsFileInfo in writepages and set_file_size (Sachin Prabhu) [823902]
- [fs] cifs: clean up error handling in cifs_mknod (Sachin Prabhu) [823902]
- [fs] cifs: Fix to problem with getattr caused by invalidate simplification patch (Sachin Prabhu) [823878]
- [fs] cifs: Simplify invalidate part (Sachin Prabhu) [823878]
- [fs] cifs: Add launder_page operation (Sachin Prabhu) [823878]
- [fs] cifs: Use invalidate_inode_pages2 instead of invalidate_remote_inode (Sachin Prabhu) [823878]
- [fs] cifs: Fix oplock break handling (Sachin Prabhu) [823843]
- [fs] cifs: switch cifs_open and cifs_create to use CIFSSMBUnixSetFileInfo (Sachin Prabhu) [823630]
- [fs] cifs: Simplify cifs_open code (Sachin Prabhu) [823630]
- [fs] cifs: Simplify non-posix open stuff (Sachin Prabhu) [823630]
- [fs] cifs: fix handling of scopeid in cifs_convert_address (Sachin Prabhu) [823625]
- [fs] cifs: add attribute cache timeout (actimeo) tunable (Sachin Prabhu) [823620]
- [fs] cifs: TCP_Server_Info diet (Sachin Prabhu) [823842]
- [fs] cifs: directio read/write cleanups (Sachin Prabhu) [742314]
- [fs] cifs: Fix variable types in cifs_iovec_read/write (Sachin Prabhu) [742314]
- [fs] cifs: Add strictcache mount option (Sachin Prabhu) [742314]
- [fs] cifs: Implement cifs_strict_writev (Sachin Prabhu) [742314]
- [fs] cifs: Implement cifs_strict_readv (Sachin Prabhu) [742314]
- [fs] cifs: Implement cifs_file_strict_mmap (Sachin Prabhu) [742314]
- [fs] cifs: Implement cifs_strict_fsync (Sachin Prabhu) [742314]
- [fs] cifs: Make cifsFileInfo_put work with strict cache mode (Sachin Prabhu) [742314]
- [fs] NFS: Don:t leak in nfs_proc_symlink() (Jeff Layton) [802538]
- [fs] nfs: skip commit in releasepage if we:re freeing memory for fs-related reasons (Jeff Layton) [832434]
- [fs] gfs2: fix kernel panic with small gfs2 filesystems - 1 RG (Abhijith Das) [838638]
- [block] fix infinite loop in __getblk_slow (Jeff Moyer) [534080]
- [fs] block_dev: don't mark buffers beyond end of disk as mapped (Jeff Moyer) [534080]
- [fs] nfs4: fix referrals on mounts that use IPv6 addrs (Steve Dickson) [820734]
- [fs] nfsd: add IPv6 addr escaping to fs_location hosts (Steve Dickson) [820734]
- [fs] nfs: Enclose hostname in brackets when needed in nfs_do_root_mount (Steve Dickson) [820734]
- [fs] nfs4: serialize layoutcommit (Steve Dickson) [837871]
- [fs] pnfs: cleanup_layoutcommit (Steve Dickson) [837871]
- [fs] pnfs: encode_layoutcommit (Steve Dickson) [837871]
- [fs] pnfs: let layoutcommit handle a list of lseg (Steve Dickson) [837871]
- [fs] pnfs: save layoutcommit cred at layout header init (Steve Dickson) [837871]
- [fs] pnfs: save layoutcommit lwb at layout header (Steve Dickson) [837871]
- [block] virtio-blk: Call revalidate_disk() upon online disk resize (Jeff Moyer) [693940]
- [fs] fs/direct-io.c: dont try to allocate more than BIO_MAX_PAGES in a bio (Jeff Moyer) [832962]
- [fs] nfsd: don't fail unchecked creates of non-special files (J. Bruce Fields) [808112]
- [fs] NFS: fix return value of nfs_pagein_one/nfs_flush_one (Steve Dickson) [837871]
- [fs] pNFS: Fall back to ordinary i/o through the mds if we have no layout segment (Steve Dickson) [837871]
- [fs] pNFS: Add an initialisation callback for pNFS (Steve Dickson) [837871]
- [fs] pnfs: write: Set mds_offset in the generic layer - it is needed by all LDs (Steve Dickson) [837871]
- [fs] NFS: move pnfs layouts to nfs_server structure (Steve Dickson) [837871]
- [fs] NFS: fix umount of pnfs filesystems (Steve Dickson) [837871]

* Thu Aug 09 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-296.el6]
- [mm] check PageUnevictable in lru_deactivate() (Jan Stancek) [846253]
- [virt] virtio-blk: Use block layer provided spinlock (Asias He) [734051]
- [virt] virtio-blk: Reset device after blk_cleanup_queue() (Asias He) [734051]
- [virt] virtio-blk: Call del_gendisk() before disable guest kick (Asias He) [734051]
- [virt] virtio-blk: Fix hot-unplug race in remove method (Asias He) [734051]
- [virt] virtio_blk: Drop unused request tracking list (Asias He) [734051]
- [acpi] apei: new einj parameter to control trigger action (Myron Stowe) [816508]
- [acpi] apei: limit the range of einj_param (Myron Stowe) [816508]
- [acpi] apei: Use acpi_os_map_memory() instead of ioremap() in einj driver (Myron Stowe) [816508]
- [acpi] apei: cleanup 0 vs NULL confusion (Myron Stowe) [816508]
- [acpi] apei: Allow empty EINJ Trigger Error Action Table (Myron Stowe) [816508]
- [acpi] apei: Add extensions to EINJ from rev 5.0 of acpi spec (Myron Stowe) [816508]
- [acpi] apei: Print resource errors in conventional format (Myron Stowe) [816508]
- [net] dev: consolidate netif_needs_gso() checks (Amerigo Wang) [822737]
- [net] skbuff: add check for non-linear to warn_if_lro and needs_linearize (Amerigo Wang) [822737]
- [net] dev: Optimize non-gso test checks (Amerigo Wang) [822737]
- [powerpc] time: Fixups for powerpc timekeeping code (Prarit Bhargava) [843138]
- [mm] Eliminate kernel crash due to races in hugetlbfs (Larry Woodman) [822458]
- [net] tcp: clear hints to avoid a stale one (Andy Gospodarek) [807704]
- [net] fix rtnetlink IFF_PROMISC and IFF_ALLMULTI handling (Jiri Benc) [838450]

* Wed Aug 08 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-295.el6]
- [net] openvswitch: checking wrong variable in queue_userspace_packet() (Herbert Xu) [805656]
- [net] openvswitch: Validation of IPv6 set port action uses IPv4 header (Herbert Xu) [805656]
- [net] openvswitch: Release rtnl_lock if ovs_vport_cmd_build_info() failed (Herbert Xu) [805656]
- [net] openvswitch: Add length check when retrieving TCP flags (Herbert Xu) [805656]
- [net] openvswitch: Fix checksum update for actions on UDP packets (Herbert Xu) [805656]
- [net] openvswitch: Honor dp_ifindex, when specified, for vport lookup by name (Herbert Xu) [805656]
- [net] openvswitch: Fix multipart datapath dumps (Herbert Xu) [805656]
- [net] openvswitch: small potential memory leak in ovs_vport_alloc() (Herbert Xu) [805656]
- [net] openvswitch: Add Open vSwitch kernel components (Herbert Xu) [805656]
- [lib] flex_array: export symbols to modules (Herbert Xu) [805656]
- [net] net: Add rcu_dereference_rtnl (Herbert Xu) [805656]
- [net] Add skb_reset_mac_len helper (Herbert Xu) [805656]
- [net] rcu: add __rcu API for later sparse checking (Herbert Xu) [805656]
- [net] ipv6: Add fragment reporting to ipv6_skip_exthdr() (Herbert Xu) [805656]
- [net] vlan: Move vlan_set_encap_proto() to vlan header file (Herbert Xu) [805656]
- [net] genetlink: Add rcu_dereference_genl and genl_dereference (Herbert Xu) [805656]
- [net] genetlink: Add lockdep_genl_is_held() (Herbert Xu) [805656]
- [net] netlink: Export genl_lock() API for use by modules (Herbert Xu) [805656]
- [net] genetlink: Add genl_notify() (Herbert Xu) [805656]
- [x86] setup: Update hardware check to support Intel Haswell processors (Prarit Bhargava) [842862]
- [kernel] tracing, function tracer: Clean up strstrip() usage (Jiri Olsa) [838745]
- [kernel] tracing: Support multiple pids in set_pid_ftrace file (Jiri Olsa) [838745]
- [mm] thp: remove unnecessary tlb flush for mprotect (Andrea Arcangeli) [823994]
- [mm] thp: improve order in lru list for split huge page (Andrea Arcangeli) [823994]
- [mm] thp: Set compound tail page _count to zero (Andrea Arcangeli) [823994]
- [mm] thp: Add compound tail page _mapcount when mapped (Andrea Arcangeli) [823994]
- [mm] thp: reduce khugepaged freezing latency (Andrea Arcangeli) [823994]
- [mm] Fix slab->page flags corruption (Andrea Arcangeli) [823994]
- [powerpc] oprofile: Handle events that raise an exception without overflowing (Steve Best) [834157]
- [infiniband] cxgb3: Don't pass irq flags to flush_qp() (Steve Best) [829758]
- [usb] ehci: go back to using the system clock for QH unlinks (Gerd Hoffmann) [816576]
- [md] dm-raid1: Fix mirror crash when discard request is sent and sync is in progress (Mikulas Patocka) [837607]
- [scsi] st: increase max number of tapes configured (Rob Evers) [533469]
- [mm] Never OOM kill tasks outside of memory cgroup when memory.limit_in_bytes is exceeded by a Transparent Huge Page (Larry Woodman) [811255]
- [netdrv] bond_alb: don't disable softirq under bond_alb_xmit (Jiri Pirko) [841987]

* Tue Jul 31 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-294.el6]
- [net] ipv4: add RCU protection to inet->opt (Jiri Pirko) [829109]
- [x86] perf: Update event scheduling constraints for AMD family 15h models (Jiri Olsa) [739441]
- [x86] ioapic: Fix kdump race with migrating irq (Don Zickus) [783322]
- [net] sctp: Implement quick failover draft from tsvwg (Neil Horman) [830716]
- [net] sctp: be more restrictive in transport selection on bundled sacks (Neil Horman) [830716]
- [net] rds: set correct msg_namelen (Weiping Pan) [822731] {CVE-2012-3430}

* Wed Jul 25 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-293.el6]
- [s390] kernel: pfault task state race (Hendrik Brueckner) [831262]
- [powerpc] pseries: Support lower minimum entitlement for virtual processors (Steve Best) [822651]
- [kernel] sched: Fix signed unsigned comparison in check_preempt_tick() (Frederic Weisbecker) [835797]
- [edac] i5000_edac: Fix the fatal error channel report (Mauro Carvalho Chehab) [806796]
- [security] selinux: fix error codes in cond_read_bool() (Eric Paris) [839315]
- [mm] page-writeback: Improvement of page writeback ordering (Naoya Horiguchi) [786025]
- [mm] reduce page fragmentation in buddy allocator (Jarod Wilson) [786318]

* Wed Jul 25 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-292.el6]
- [pci] print out PCI device info along with duration (Myron Stowe) [808213]
- [pci] Move "pci reassigndev resource alignment" out of quirks.c (Myron Stowe) [808213]
- [pci] Use class for quirk for usb host controller fixup (Myron Stowe) [808213]
- [pci] Use class for quirk for netmos class fixup (Myron Stowe) [808213]
- [pci] Use class for quirk for intel e100 interrupt fixup (Myron Stowe) [808213]
- [pci] Use class for quirk for legacy ATA NO_D3 (Myron Stowe) [808213]
- [pci] Use class for quirk for cardbus_legacy (Myron Stowe) [808213]
- [pci] Use class for quirk for pci_fixup_video (Myron Stowe) [808213]
- [pci] Use class quirk for intel fix_transparent_bridge (Myron Stowe) [808213]
- [pci] Use class for quirk for via_no_dac (Myron Stowe) [808213]
- [pci] Add class support in quirk handling (Myron Stowe) [808213]
- [pci] Annotate PCI quirks in initcall_debug style (Myron Stowe) [808213]
- [kernel] async: remove redundant declaration (Myron Stowe) [808213]
- [pci] init.h: Add "extern int initcall_debug" (Myron Stowe) [808213]
- [powerpc] Make keyctl new_session work on powerpc (David Howells) [830152]
- [pci] Fix uninitialized variable 'cap_mask' (Myron Stowe) [813363]
- [s390] enable ARCH_DMA_ADDR_T_64BIT with 64BIT (Prarit Bhargava) [715410]
- [x86] Enable ARCH_DMA_ADDR_T_64BIT with X86_64 || HIGHMEM64G (Prarit Bhargava) [715410]
- [powerpc] enable ARCH_DMA_ADDR_T_64BIT with ARCH_PHYS_ADDR_T_64BIT (Prarit Bhargava) [715410]
- [kernel] add the common dma_addr_t typedef to include/linux/types.h (Prarit Bhargava) [715410]
- [pci] ahci: add pci quirk for JMB362 (Prarit Bhargava) [836880]
- [net] tun: allow tap iface in netconsole'd bridge (Jiri Benc) [838025]
- [net] netconsole: fix deadlock on network restart (Jiri Benc) [839266]
- [net] ipv4/ping: Fix recvmsg MSG_OOB error handling (Jiri Pirko) [787705]
- [net] fix some sparse errors (Jiri Pirko) [787705]
- [net] ping: dont increment ICMP_MIB_INERRORS (Jiri Pirko) [787705]
- [net] ping: remove some sparse errors (Jiri Pirko) [787705]
- [net] ping: fix the coding style (Jiri Pirko) [787705]
- [net] ping: make local functions static (Jiri Pirko) [787705]
- [net] ping: cleanups ping_v4_unhash() (Jiri Pirko) [787705]
- [net] ipv4/ping: Remove duplicate icmp.h include (Jiri Pirko) [787705]
- [net] ping: fix build failure (Jiri Pirko) [787705]
- [net] ping: dont call udp_ioctl() (Jiri Pirko) [787705]
- [net] ping: small changes (Jiri Pirko) [787705]
- [net] ipv4: add IPPROTO_ICMP socket kind (Jiri Pirko) [787705]
- [x86] amd_iommu: Fix SRIOV and hotplug devices (Stefan Assmann) [832009]
- [mm] hugetlb: fix resv_map leak in error path (Motohiro Kosaki) [824351] {CVE-2012-2390}

* Wed Jul 25 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-291.el6]
- [crypto] signature: remove module signing xtime usage (Prarit Bhargava) [836748]
- [kernel] timekeeping: Fix CLOCK_MONOTONIC inconsistency during leapsecond (Prarit Bhargava) [836748]
- [kernel] timekeeping: Fix a few minor newline issues (Prarit Bhargava) [836748]
- [kernel] time: fix s/then/than/ spelling errors (Prarit Bhargava) [836748]
- [kernel] time: Avoid scary backtraces when warning of > 11 adj (Prarit Bhargava) [836748]
- [kernel] ntp: Fix leap-second hrtimer livelock (Prarit Bhargava) [836748]
- [kernel] time: Fix change_clocksource locking (Prarit Bhargava) [836748]
- [kernel] time: Move common updates to a function (Prarit Bhargava) [836748]
- [kernel] time: Reorder so the hot data is together (Prarit Bhargava) [836748]
- [kernel] time: Remove most of xtime_lock usage in timekeeping.c (Prarit Bhargava) [836748]
- [kernel] ntp: Add ntp_lock to replace xtime_locking (Prarit Bhargava) [836748]
- [kernel] ntp: Access tick_length variable via ntp_tick_length() (Prarit Bhargava) [836748]
- [kernel] time: Add timekeeper lock (Prarit Bhargava) [836748]
- [kernel] time: Cleanup global variables and move them to the top (Prarit Bhargava) [836748]
- [kernel] time: Move raw_time into timekeeper structure (Prarit Bhargava) [836748]
- [kernel] time: Move xtime into timekeeeper structure (Prarit Bhargava) [836748]
- [kernel] time: Move wall_to_monotonic into the timekeeper structure (Prarit Bhargava) [836748]
- [kernel] time: Move total_sleep_time into the timekeeper structure (Prarit Bhargava) [836748]
- [kernel] time: Fix spelling mistakes in new comments (Prarit Bhargava) [836748]
- [kernel] time: fix bogus comment in timekeeping_get_ns_raw (Prarit Bhargava) [836748]
- [kernel] timekeeping: add arch_offset hook to ktime_get functions (Prarit Bhargava) [836748]
- [kernel] clocksource: Avoid selecting mult values that might overflow when adjusted (Prarit Bhargava) [836748]
- [kernel] time: Improve documentation of timekeeeping_adjust() (Prarit Bhargava) [836748]
- [kernel] time: Fix stupid KERN_WARN compile issue (Prarit Bhargava) [836748]
- [kernel] time: Avoid accumulating time drift in suspend/resume (Prarit Bhargava) [836748]
- [kernel] time: Catch invalid timespec sleep values in __timekeeping_inject_sleeptime (Prarit Bhargava) [836748]
- [kernel] hrtimers: Prepare for cancel on clock was set timers (Prarit Bhargava) [836748]
- [kernel] time: Add timekeeping_inject_sleeptime (Prarit Bhargava) [836748]
- [kernel] time: Extend get_xtime_and_monotonic_offset() to also return sleep (Prarit Bhargava) [836748]
- [kernel] time: Introduce get_monotonic_boottime and ktime_get_boottime (Prarit Bhargava) [836748]
- [kernel] time: Introduce timekeeping_inject_offset (Prarit Bhargava) [836748]
- [kernel] time: Correct the *settime* parameters (Prarit Bhargava) [836748]
- [kernel] time: Provide xtime_update() (Prarit Bhargava) [836748]
- [kernel] time: Remove unused __get_wall_to_monotonic() (Prarit Bhargava) [836748]
- [kernel] time: Provide get_xtime_and_monotonic_offset() (Prarit Bhargava) [836748]
- [kernel] time: Move do_timer() to kernel/time/timekeeping.c (Prarit Bhargava) [836748]
- [kernel] timekeeping: Make local variables static (Prarit Bhargava) [836748]
- [kernel] time: Compensate for rounding on odd-frequency clocksources (Prarit Bhargava) [836748]
- [kernel] time: Workaround gcc loop optimization that causes 64bit div errors (Prarit Bhargava) [836748]
- [kernel] timekeeping: Fix overflow in rawtime tv_nsec on 32 bit archs (Prarit Bhargava) [836748]
- [kernel] timekeeping: Fix update_vsyscall to provide wall_to_monotonic offset (Prarit Bhargava) [836748]
- [powerpc] kernel: RHEL6 xtime removal (Prarit Bhargava) [836748]
- [kernel] timekeeping: Make xtime and wall_to_monotonic static (Prarit Bhargava) [836748]
- [powerpc] kernel: Cleanup xtime usage (Prarit Bhargava) [836748]
- [kernel] hrtimer: Cleanup direct access to wall_to_monotonic (Prarit Bhargava) [836748]
- [kernel] time: Kill off CONFIG_GENERIC_TIME (Prarit Bhargava) [836748]
- [kernel] time: Implement timespec_add (Prarit Bhargava) [836748]
- [kernel] time: Remove xtime_cache (Prarit Bhargava) [836748]
- [kernel] time: Fix accumulation bug triggered by long delay (Prarit Bhargava) [836748]
- [kernel] time: Clean up warp_clock() (Prarit Bhargava) [836748]
- [virt] time: Clean up direct xtime usage in xen (Prarit Bhargava) [836748]
- [s390] kernel: Cleanup xtime usage (Prarit Bhargava) [836748]
- [kernel] Export the symbol of getboottime and mmonotonic_to_bootbased (Prarit Bhargava) [836748]
- [kernel] clocksource: add suspend callback (Prarit Bhargava) [836748]
- [kernel] ntp: Cleanup xtime references in ntp.c (Prarit Bhargava) [836748]
- [kernel] Revert: time: Remove xtime_cache (Prarit Bhargava) [836748]
- [kernel] timekeeping: Fix clock_gettime vsyscall time warp (Prarit Bhargava) [836748]
- [kernel] nohz: Prevent clocksource wrapping during idle (Prarit Bhargava) [836748]
- [kernel] time: Remove xtime_cache (Prarit Bhargava) [836748]
- [kernel] time: Implement logarithmic time accumulation (Prarit Bhargava) [836748]
- [kernel] Revert: time: Implement logarithmic time accumalation (Prarit Bhargava) [836748]
- [kernel] Revert: Export the symbol of getboottime and mmonotonic_to_bootbased (Prarit Bhargava) [836748]
- [s390x] Revert: timekeeping: Fix accumulation bug triggered by long delay (Prarit Bhargava) [836748]
- [s390x] Revert: timekeeping: Fix clock_gettime vsyscall time warp (Prarit Bhargava) [836748]
- [kernel] Revert: nohz: Prevent clocksource wrapping during idle (Prarit Bhargava) [836748]

* Tue Jul 24 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-290.el6]
- [netdrv] be2net: reduce gso_max_size setting to account for ethernet header (Ivan Vecera) [834185]
- [netdrv] dl2k: fix unfiltered netdev rio_ioctl access by users (Jacob Tanenbaum) [818825] {CVE-2012-2313}
- [fs] proc/stat: fix whitespace damage in use arch_idle_time patch (Steve Best) [841149]
- [virt] kvm: disable writeback for TEST in emulator (Gleb Natapov) [842211]
- [x86] lapic-timer: Increase the max_delta to 31 bits (Prarit Bhargava) [832138]
- [net] 8021q/vlan: filter device events on bonds (Neil Horman) [841983]

* Mon Jul 23 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-289.el6]
- [fs] nfs: fix EOF incorrectly set on short read for nfsv2 (Sachin Prabhu) [827126]
- [usbhid] hiddev: Consolidate device existence checks in hiddev_ioctl (Don Zickus) [839973]
- [usbhid] hiddev: Fix race between disconnect and hiddev_ioctl (Don Zickus) [839973]
- [usbhid] hiddev: protect against disconnect/NULL-dereference race (Don Zickus) [839973]
- [perf] events: Fix ring_buffer_wakeup() brown paperbag bug (Frederic Weisbecker) [839105]
- [perf] Fix loss of notification with multi-event (Frederic Weisbecker) [839105]
- [perf] Split up buffer handling from core code (Frederic Weisbecker) [839105]
- [drm] i915: fix integer overflow in i915_gem_do_execbuffer() (Jacob Tanenbaum) [824563] {CVE-2012-2384}
- [crypto] algapi: Move larval completion into algboss (Herbert Xu) [832135]
- [kernel] pm_qos: Accept ASCII values for latency (Herbert Xu) [833456]
- [x86] Use .cfi_sections for assembly code (Mark Wielaard) [823990]
- [scsi] mpt2sas: reduce lock contention (Tomas Henzl) [790506]
- [net] ipv4: fix panic while tuning accept_local (Weiping Pan) [835911]

* Thu Jul 19 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-288.el6]
- [powerpc] Fix wrong divisor in usecs_to_cputime backport (Steve Best) [821374]
- [drm] i915: fix integer overflow in i915_gem_execbuffer2() (Jacob Tanenbaum) [824555] {CVE-2012-2383}
- [fs] proc/stat: Use arch_idle_time for idle and iowait times if available (Steve Best) [841149]
- [lib] kstrto: Reduce the number of expensive division instructions done by _parse_integer() (Sachin Prabhu) [820847]
- [lib] kstrtox: common code between kstrto*() and simple_strto*() functions (Sachin Prabhu) [820847]
- [lib] make _tolower() public (Sachin Prabhu) [820847]
- [lib] vsprintf: use TOLOWER whenever possible (Sachin Prabhu) [820847]
- [lib] lib: add kstrto*_from_user() (Sachin Prabhu) [820847]
- [lib] kstrtox: simpler code in _kstrtoull() (Sachin Prabhu) [820847]
- [lib] kstrto: converting strings to integers done (hopefully) right (Sachin Prabhu) [820847]
- [lib] vsprintf: reuse almost identical simple_strtoulX() functions (Sachin Prabhu) [820847]
- [usb] core: change the memory limits in usbfs URB submission (Don Zickus) [828271]
- [usb] core: unify some error pathways in usbfs (Don Zickus) [828271]
- [base] firmware: Fix an oops on reading fw_priv->fw in sysfs loading file (Prarit Bhargava) [819877]

* Tue Jul 17 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-287.el6]
- [tools] perf, spec: Add bison and flex build BuildRequires (Jiri Olsa) [827474]
- [tools] perf, compat: Disable hw breakpoint events (Jiri Olsa) [827474]
- [tools] perf, compat: Disable branch stack feature (Jiri Olsa) [827474]
- [tools] perf, compat: Disable PMU events (Jiri Olsa) [827474]
- [tools] perf, stat: handle ENXIO error for perf_event_open (Jiri Olsa) [827474]
- [tools] perf: Turn off compiler warnings for flex and bison generated files (Jiri Olsa) [827474]
- [tools] perf, stat: Fix case where guest/host monitoring is not supported by kernel (Jiri Olsa) [827474]
- [tools] perf, build-id: Fix filename size calculation (Jiri Olsa) [827474]
- [tools] perf, symbols: Read plt symbols from proper symtab_type binary (Jiri Olsa) [827474]
- [tools] perf: Add 'G' and 'H' modifiers to event parsing (Jiri Olsa) [827474]
- [tools] perf: Drop CROSS_COMPILE from flex and bison calls (Jiri Olsa) [827474]
- [tools] perf, report: Fix crash showing warning related to kernel maps (Jiri Olsa) [827474]
- [tools] perf, archive: Correct cutting of symbolic link (Jiri Olsa) [827474]
- [tools] perf: Ignore auto-generated bison/flex files (Jiri Olsa) [827474]
- [tools] perf: Fix parsers' rules to dependencies (Jiri Olsa) [827474]
- [tools] perf: fix NO_GTK2 Makefile config error (Jiri Olsa) [827474]
- [tools] perf, session: Skip event correctly for unknown id/machine (Jiri Olsa) [827474]
- [tools] perf, kvm: Finding struct machine fails for PERF_RECORD_MMAP (Jiri Olsa) [827474]
- [tools] perf, annotate: Validate addr in symbol__inc_addr_samples (Jiri Olsa) [827474]
- [tools] perf, hists browser: Fix NULL deref in hists browsing code (Jiri Olsa) [827474]
- [tools] perf, hists: Catch and handle out-of-date hist entry maps. (Jiri Olsa) [827474]
- [tools] perf, annotate: Fix hist decay (Jiri Olsa) [827474]
- [tools] perf, top: Add intel_idle to the skip list (Jiri Olsa) [827474]
- [tools] perf: Fix getrusage() related build failure on glibc trunk (Jiri Olsa) [827474]
- [tools] perf: Remove auto-generated bison/flex files (Jiri Olsa) [827474]
- [tools] perf, annotate: Fix off by one symbol hist size allocation and hit accounting (Jiri Olsa) [827474]
- [tools] perf, annotate: addr2line wants addresses in same format as objdump (Jiri Olsa) [827474]
- [tools] perf, probe: Finder fails to resolve function name to address (Jiri Olsa) [827474]
- [tools] perf, symbols: Handle NULL dso in dso__name_len (Jiri Olsa) [827474]
- [tools] perf, symbols: Do not include libgen.h (Jiri Olsa) [827474]
- [tools] perf: Fix bug in raw sample parsing (Jiri Olsa) [827474]
- [tools] perf: Fix display of first level of callchains (Jiri Olsa) [827474]
- [tools] perf, diff: Fix to work with new hists design (Jiri Olsa) [827474]
- [tools] perf: Fix modifier to be applied on correct events (Jiri Olsa) [827474]
- [tools] perf: Fix various casting issues for 32 bits (Jiri Olsa) [827474]
- [tools] perf: Simplify event_read_id exit path (Jiri Olsa) [827474]
- [tools] perf: Use scnprintf where applicable (Jiri Olsa) [827474]
- [tools] perf: Incorrect use of snprintf results in SEGV (Jiri Olsa) [827474]
- [tools] perf, record: Fix buffer overrun bug in tracepoint_id_to_path() (Jiri Olsa) [827474]
- [tools] perf, report: Add a simple GTK2-based 'perf report' browser (Jiri Olsa) [827474]
- [tools] perf, report: Document --symbol-filter option (Jiri Olsa) [827474]
- [tools] perf, ui browser: Clean lines inside of the input window (Jiri Olsa) [827474]
- [tools] perf, report: Treat an argument as a symbol filter (Jiri Olsa) [827474]
- [tools] perf, report: Add --symbol-filter option (Jiri Olsa) [827474]
- [tools] perf, ui browser: Add 's' key to filter by symbol name (Jiri Olsa) [827474]
- [tools] perf, ui browser: Introduce ui_browser__input_window (Jiri Olsa) [827474]
- [tools] perf, hists: Add hists__filter_by_symbol (Jiri Olsa) [827474]
- [tools] perf: Do not disable members of group event (Jiri Olsa) [827474]
- [tools] perf, stat: Fix event grouping on forked task (Jiri Olsa) [827474]
- [tools] perf: Add support to specify pmu style event (Jiri Olsa) [827474]
- [tools] perf: Add perf pmu object to access pmu format definition (Jiri Olsa) [827474]
- [tools] perf: Add config options support for event parsing (Jiri Olsa) [827474]
- [tools] perf: Add parser generator for events parsing (Jiri Olsa) [827474]
- [tools] perf: Adjust make rules (Jiri Olsa) [827474]
- [tools] perf, report: Fix annotate double quit issue in branch view mode (Jiri Olsa) [827474]
- [tools] perf, report: Remove duplicate annotate choice in branch view mode (Jiri Olsa) [827474]
- [tools] perf, report: Enable TUI in branch view mode (Jiri Olsa) [827474]
- [tools] perf, report: Auto-detect branch stack sampling mode (Jiri Olsa) [827474]
- [tools] perf, record: Add HEADER_BRANCH_STACK tag (Jiri Olsa) [827474]
- [tools] perf, record: Provide default branch stack sampling mode option (Jiri Olsa) [827474]
- [tools] perf: Make perf able to read files from older ABIs (Jiri Olsa) [827474]
- [tools] perf: Fix ABI compatibility bug in print_event_desc() (Jiri Olsa) [827474]
- [tools] perf: Enable reading of perf.data files from different ABI rev (Jiri Olsa) [827474]
- [tools] perf, report: Add support for taken branch sampling (Jiri Olsa) [827474]
- [tools] perf, record: Add support for sampling taken branch (Jiri Olsa) [827474]
- [tools] perf: Add code to support PERF_SAMPLE_BRANCH_STACK (Jiri Olsa) [827474]
- [tools] perf, annotate: Add missing newline on error message (Jiri Olsa) [827474]
- [tools] perf, annotate: Fix help string on tui (Jiri Olsa) [827474]
- [tools] perf, annotate: Restore title when came back to original symbol (Jiri Olsa) [827474]
- [tools] perf, annotate: Handle lower case key code in annotate_browser__run() (Jiri Olsa) [827474]
- [tools] perf, annotate: Print asm code as blue when source code is displayed (Jiri Olsa) [827474]
- [tools] perf: Add descriptions of missing Makefile arguments (Jiri Olsa) [827474]
- [tools] perf, evlist: Restore original errno after open failed (Jiri Olsa) [827474]
- [tools] perf, probe: Ensure offset provided is not greater than function length without DWARF info too (Jiri Olsa) [827474]
- [tools] perf: Ensure comm string is properly terminated (Jiri Olsa) [827474]
- [tools] perf, probe: Ensure offset provided is not greater than function length (Jiri Olsa) [827474]
- [tools] perf, evlist: Return first evsel for non-sample event on old kernel (Jiri Olsa) [827474]
- [tools] perf: fix broken perf record -a mode (Jiri Olsa) [827474]
- [tools] perf: Remove duplicated string.h includes (Jiri Olsa) [827474]
- [tools] perf: Allow expressions in __print_symbolic() fields (Jiri Olsa) [827474]
- [tools] perf: Invert the sample_id_all logic (Jiri Olsa) [827474]
- [tools] perf: Handle kernels that don't support attr.exclude_{guest, host} (Jiri Olsa) [827474]
- [tools] perf: cleanup initialization of attr->size (Jiri Olsa) [827474]
- [tools] perf: Factor out feature op to process header sections (Jiri Olsa) [827474]
- [tools] perf: Moving code in header.c (Jiri Olsa) [827474]
- [tools] perf: Add bitmap_or function into bitmap object (Jiri Olsa) [827474]
- [tools] perf: Add sysfs mountpoint interface (Jiri Olsa) [827474]
- [tools] perf: Remove unused functions from debugfs object (Jiri Olsa) [827474]
- [tools] perf: Get rid of ctype.h in symbol.c (Jiri Olsa) [827474]
- [tools] perf: ctype.c only wants util.h (Jiri Olsa) [827474]
- [tools] perf: Implement islower/isupper macro into util.h (Jiri Olsa) [827474]
- [tools] perf: Change perf_guest default back to false (Jiri Olsa) [827474]
- [tools] perf, top: Don't process samples with no valid machine object (Jiri Olsa) [827474]
- [tools] perf: Allow multiple threads or processes in record, stat, top (Jiri Olsa) [827474]
- [tools] perf: Fix out of tree compiles (Jiri Olsa) [827474]
- [tools] perf: Fix build dependency of perf python extension (Jiri Olsa) [827474]
- [tools] perf, record: No build id option fails (Jiri Olsa) [827474]
- [tools] perf: fix endianness detection in perf.data (Jiri Olsa) [827474]
- [tools] perf, stat: Align scaled output of cpu-clock (Jiri Olsa) [827474]
- [tools] perf, stat: Adjust print unit (Jiri Olsa) [827474]
- [tools] perf, doc: Allow producing documentation in a specified output directory (Jiri Olsa) [827474]
- [tools] perf, evsel: Fix an issue where perf report fails to show the proper percentage (Jiri Olsa) [827474]
- [tools] perf, record: Make feature initialization generic (Jiri Olsa) [827474]
- [tools] perf, probe: Rename target_module to target (Jiri Olsa) [827474]
- [tools] perf: Remove distclean from Makefile help output (Jiri Olsa) [827474]
- [tools] perf, evlist: Make splice_list_tail method public (Jiri Olsa) [827474]
- [tools] perf, python: Use attr.watermark in twatch.py (Jiri Olsa) [827474]
- [tools] perf: Remove unnecessary ctype.h inclusion (Jiri Olsa) [827474]
- [tools] perf, lock: Document lock info subcommand (Jiri Olsa) [827474]
- [tools] perf, top: Fix number of samples displayed (Jiri Olsa) [827474]
- [tools] perf, script: Add option resolving vmlinux path (Jiri Olsa) [827474]
- [tools] perf, script: Add the offset field specifier (Jiri Olsa) [827474]
- [tools] perf, script: Print branch_from and branch_to of BTS events (Jiri Olsa) [827474]
- [tools] perf, script: Unify the expressions indicating "unknown" (Jiri Olsa) [827474]
- [tools] perf, evsel: Fix spelling typo (Jiri Olsa) [827474]
- [tools] perf: Fix strlen() bug in perf_event__synthesize_event_type() (Jiri Olsa) [827474]
- [tools] perf: probe usability fixes (Jiri Olsa) [827474]
- [tools] perf: Fix broken build by defining _GNU_SOURCE in Makefile (Jiri Olsa) [827474]
- [tools] perf: Introduce per user view (Jiri Olsa) [827474]
- [tools] perf: Add fprintf methods for thread_map and cpu_map classes (Jiri Olsa) [827474]
- [tools] perf: Add support for guest/host-only profiling (Jiri Olsa) [827474]
- [tools] perf, kvm: Do guest-only counting by default (Jiri Olsa) [827474]
- [fs] ext4: properly dirty split extent nodes (David Jeffery) [838640]
- [netdrv] ixgbe: BIT_APP_UPCHG not set by ixgbe_copy_dcb_cfg() (Andy Gospodarek) [814044]
- [netdrv] ixgbe: driver fix for link flap (Andy Gospodarek) [814044]
- [net] tcp: Add TCP_USER_TIMEOUT socket option (Jiri Benc) [819610]

* Sat Jul 14 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-286.el6]
- [net] bridge: Fix enforcement of multicast hash_max limit (Thomas Graf) [832575]
- [net] bluetooth: fix sco_conninfo infoleak (Jacob Tanenbaum) [681308] {CVE-2011-1078}
- [wireless] ipw2200: remove references to CFG80211_WEXT config option (John Linville) [839311]
- [virt] kvm: whitelist-based GET_SUPPORTED_CPUID (Eduardo Habkost) [832486]
- [virt] kvm: handle last_boosted_vcpu = 0 case (Rik van Riel) [827031]
- [net] ehea: fix promiscuous mode (Steve Best) [826075]
- [net] ehea: fix allmulticast support (Steve Best) [826075]
- [s390] kdump: Move early_pgm_check_handler() to text section (Hendrik Brueckner) [831288]

* Wed Jul 11 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-285.el6]
- [s390] kdump: Fix PSW restart on offline CPUs (Hendrik Brueckner) [831277]
- [s390] kdump: Use real mode for PSW restart and kexec (Hendrik Brueckner) [831278]
- [s390] kernel: clear page table for sw large page emulation (Hendrik Brueckner) [831265]
- [s390] dasd: re-prioritize partition detection message (Hendrik Brueckner) [831261]
- [s390] zfcpdump: Implement async sdias event processing (Hendrik Brueckner) [818893]
- [mm] readahead: readahead page allocations are OK to fail (Jeff Moyer) [804815]
- [base] firmware_class: fix memory leak - free allocated pages kabi fixes (Prarit Bhargava) [745657]
- [base] firmware_class: fix memory leak - free allocated pages (Prarit Bhargava) [745657]
- [fs] tmpfs: fix highmem swapoff crash regression (Rafael Aquini) [817719]
- [fs] tmpfs: fix race between truncate and writepage (Rafael Aquini) [817719]
- [fs] tmpfs: fix race between swapoff and writepage (Rafael Aquini) [817719]
- [fs] tmpfs: fix spurious ENOSPC when racing with unswap (Rafael Aquini) [817719]
- [fs] tmpfs: fix race between umount and swapoff (Rafael Aquini) [817719]
- [fs] tmpfs: fix race between umount and writepage (Rafael Aquini) [817719]

* Tue Jul 10 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-284.el6]
- [net] ipv6/netfilter: fix null pointer dereference in nf_ct_frag6_reasm() (Petr Matousek) [833412] {CVE-2012-2744}
- [x86] io-apic: IO-APIC MMIO should not fail on resource insertion (Prarit Bhargava) [790726]
- [x86] apic: Use PAGE_SIZE instead of numbers (Prarit Bhargava) [790726]
- [firmware] dmi: bail earlier if no smbios found (Jarod Wilson) [833588]
- [x86] cpu: mark hardware unsupported in single function (Prarit Bhargava) [829436]
- [net] 9p: replace p9_poll_task with a work (Prarit Bhargava) [789126]
- [net] 9p: use system_wq instead of p9_mux_wq (Prarit Bhargava) [789126]
- [bluetooth] btusb: typo in Broadcom SoftSailing id (Don Zickus) [768385]
- [bluetooth] btusb: add device entry for Broadcom SoftSailing (Don Zickus) [768385]
- [ipc] mqueue: add rbtree node caching support checkpatch fixes (Doug Ledford) [826177]
- [ipc] mqueue: add rbtree node caching support (Doug Ledford) [826177]
- [virtio] virtio_balloon: separate out common code between remove and freeze functions (Amit Shah) [813227]
- [virtio] virtio_balloon: drop restore_common() (Amit Shah) [813227]
- [virtio] virtio_balloon: let host know of updated balloon size before module removal (Amit Shah) [813227]
- [crypto] sha512: Fix byte counter overflow in SHA-512 (Jarod Wilson) [830977]
- [kernel] Prevent keyctl new_session from causing a panic (David Howells) [827424] {CVE-2012-2745}
- [mm] reclaim invalidated page ASAP (Rafael Aquini) [817659]
- [mm] memcg: move memcg reclaimable page into tail of inactive list (Rafael Aquini) [817659]
- [mm] deactivate invalidated pages (Rafael Aquini) [817659]
- [mm] filemap: find_get_pages_contig fixlet (Rafael Aquini) [819001]
- [netdrv] be2net: enable GRO by default (Ivan Vecera) [837230]
- [wireless] ath9k: fix dynamic WEP related regression (Stanislaw Gruszka) [807367]
- [net] rfs: better sizing of dev_flow_table (Jiri Pirko) [810073]
- [net] rps: fix insufficient bounds checking in store_rps_dev_flow_table_cnt() (Jiri Pirko) [810073]
- [net] ipvs: IPv6 tunnel mode fix (Jesper Brouer) [835535]
- [Documentation] networking: update the description of rp_filter in ip-sysctl.txt (Amerigo Wang) [786411]
- [net] ipv6: discard overlapping fragment (Jiri Pirko) [819952]
- [net] tcp: Fix race in tcp_poll (Jiri Pirko) [831663]
- [net] ipv6: fix incorrect TCP checksums with single-fragment packets (Jiri Benc) [759313]
- [net] ipv6: fix panic in tcp SYN processing (Jesper Brouer) [803920]
- [net] ipv4: IP_MULTICAST_IF setsockopt now recognizes struct mreq (Jiri Pirko) [803202]

* Thu Jul 05 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-283.el6]
- [net] bonding: Fix up refcounting issues with bond/vlan config (Neil Horman) [836164]
- [net] bonding: Always add vid to new slave group (Neil Horman) [834764]
- [fs] procfs: do not confuse jiffies with cputime64_t (Steve Best) [821374]
- [kernel] time: Add nsecs_to_cputime64 interface for asm-generic (Steve Best) [821374]
- [powerpc] Fix wrong divisor in usecs_to_cputime (Steve Best) [821374]

* Mon Jul 02 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-282.el6]
- [kernel] futex: Fix uninterruptible loop due to gate_area (Jerome Marchand) [834038]
- [kernel] futex: Fix regression with read only mappings (Jerome Marchand) [834038]
- [fs] pnfs: Fix an off-by-one error in pnfs_generic_pg_test (Steve Dickson) [826650]
- [fs] pnfs: Fix some issues with pnfs_generic_pg_test (Steve Dickson) [826650]
- [fs] nfs: file layout must consider pg_bsize for coalescing (Steve Dickson) [826650]
- [fs] pnfs: fix break condition in pnfs_find_lseg (Steve Dickson) [826650]
- [fs] nfs: Cleanup of the nfs_pageio code in preparation for a pnfs bugfix (Steve Dickson) [826650]
- [fs] nfs: define nfs_generic_pg_test (Steve Dickson) [826650]
- [fs] pnfs: use pnfs_generic_pg_test directly by layout driver (Steve Dickson) [826650]
- [fs] pnfs: change pg_test return type to bool (Steve Dickson) [826650]
- [fs] pnfs: unify pnfs_pageio_init functions (Steve Dickson) [826650]
- [fs] nfs/pnfs: encode_layoutreturn (Steve Dickson) [825009]
- [fs] nfs/pnfs: layoutreturn (Steve Dickson) [825009]
- [fs] nfs/pnfs: Use byte-range for cb_layoutrecall (Steve Dickson) [825009]
- [fs] nfs/pnfs: alloc and free layout_hdr layoutdriver methods (Steve Dickson) [825009]
- [fs] nfs/pnfs: support for non-rpc layout drivers (Steve Dickson) [825009]
- [fs] nfs/pnfs: align layoutget requests on page boundaries (Steve Dickson) [825009]
- [fs] nfs/pnfs: Use byte-range for layoutget (Steve Dickson) [825009]
- [fs] nfsv4.1 fix page number calculation bug for filelayout decode buffers (Steve Dickson) [758202]
- [fs] nfs: Adapt readdirplus to application usage patterns (Steve Dickson) [819891]
- [fs] nfs: Backport of upstream xdr routines to rhel6 (Steve Dickson) [784174]
- [net] sunrpc/auth_gss: the list of pseudoflavors not being parsed correctly (Steve Dickson) [784174]
- [fs] NFS: Use correct variable for page bounds checking (Steve Dickson) [784174]
- [fs] NFS: Remove secinfo knowledge out of the generic client (Steve Dickson) [784174]
- [fs] NFS: Remove unused function nfs_lookup_with_sec() (Steve Dickson) [784174]
- [fs] NFS: Honor the authflavor set in the clone mount data (Steve Dickson) [784174]
- [fs] NFS: Fix following referral mount points with different security (Steve Dickson) [784174]
- [fs] NFS: Do secinfo as part of lookup (Steve Dickson) [784174]
- [fs] NFSv4: Translate NFS4ERR_BADNAME into ENOENT when applied to a lookup (Steve Dickson) [784174]
- [fs] NFS: Handle exceptions coming out of nfs4_proc_fs_locations() (Steve Dickson) [784174]
- [fs] NFS: Remove the unused "lookupfh()" version of nfs4_proc_lookup() (Steve Dickson) [784174]
- [fs] NFS: Clean up nfs4_xdr_dec_secinfo() (Steve Dickson) [784174]
- [fs] NFS: Fix decode_secinfo_maxsz (Steve Dickson) [784174]
- [fs] NFS: Return meaningful status from decode_secinfo() (Steve Dickson) [784174]
- [fs] NFSv4: Handle NFS4ERR_WRONGSEC outside of nfs4_handle_exception() (Steve Dickson) [784174]
- [fs] NFS: don't negotiate when user specifies sec flavor (Steve Dickson) [784174]
- [fs] NFS: Attempt mount with default sec flavor first (Steve Dickson) [784174]
- [fs] NFS: Remove unused argument from nfs_find_best_sec() (Steve Dickson) [784174]
- [fs] NFS: Change initial mount authflavor only when server returns NFS4ERR_WRONGSEC (Steve Dickson) [784174]
- [fs] NFS: Fix a signed vs. unsigned secinfo bug (Steve Dickson) [784174]
- [fs] NFS: Don't leak RPC clients in NFSv4 secinfo negotiation (Steve Dickson) [784174]
- [fs] NFS: Determine initial mount security (Steve Dickson) [784174]
- [fs] NFS: use secinfo when crossing mountpoints (Steve Dickson) [784174]
- [fs] NFS: Add secinfo procedure (Steve Dickson) [784174]
- [fs] NFS: lookup supports alternate client (Steve Dickson) [784174]
- [fs] NFS: convert call_sync() to a function (Steve Dickson) [784174]
- [fs] NFSv4: Ensure continued open and lockowner name uniqueness (Steve Dickson) [784174]

* Fri Jun 29 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-281.el6]
- [fs] xfs: disable xfsaild idle mode (Brian Foster) [813137]
- [fs] xfs: fix the logspace waiting algorithm (Brian Foster) [813137]
- [fs] xfs: add AIL pushing tracepoints (Brian Foster) [813137]
- [fs] xfs: force the log if we encounter pinned buffers in .iop_pushbuf (Brian Foster) [813137]
- [fs] xfs: do not update xa_last_pushed_lsn for locked items (Brian Foster) [813137]
- [net] rpc: handle rotated gss data for Windows interoperability (Steve Dickson) [796992]
- [md] raid5: Reintroduce locking in handle_stripe() to avoid racing (Jes Sorensen) [828065]
- [virt] kvm/vmx: Fix KVM_SET_SREGS with big real mode segments (Orit Wasserman) [756044]
- [virt] virtio_console: Use wait_event_freezable instead of _interruptible (Amit Shah) [823428]
- [virt] virtio_console: Ignore port name update request if name already set (Amit Shah) [820945]
- [x86] kprobes: Fix a bug which can modify kernel code permanently (Dave Anderson) [726270]
- [x86] kprobes: Fix instruction recovery on optimized path (Dave Anderson) [726270]
- [net] bonding: show all the link status of slaves (Amerigo Wang) [826945]

* Mon Jun 18 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-280.el6]
- [fs] writeback: merge for_kupdate and !for_kupdate cases (Eric Sandeen) [818172]
- [fs] writeback: fix queue_io() ordering (Eric Sandeen) [818172]
- [fs] writeback: don't redirty tail an inode with dirty pages (Eric Sandeen) [818172]
- [fs] nfs: Map minor mismatch error to protocol not support error (Steve Dickson) [796352]
- [fs] ext4: Fix overflow caused by missing cast in ext4_fallocate() (Lukas Czerner) [830209]
- [ata] libata: Add 2GB ATA Flash Disk/ADMA428M to DMA blacklist (Prarit Bhargava) [812904]
- [netdrv] r8169: fix typo in firmware filenames (Ivan Vecera) [829211]
- [net] bonding: fix regression on vlan module removal (Neil Horman) [823822]

* Wed Jun 13 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-279.el6]
- [netdrv] mlx4: ignore old module parameters (Jay Fenlason) [830553]

* Fri Jun 01 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-278.el6]
- [kernel] sysctl: silence warning about missing strategy for file-max at boot time (Jeff Layton) [803431]
- [net] sunrpc: make new tcp_max_slot_table_entries sysctl use CTL_UNNUMBERED (Jeff Layton) [803431]
- [drm] i915: set AUD_CONFIG N_value_index for DisplayPort (Dave Airlie) [747890]
- [scsi] scsi_lib: fix scsi_io_completion's SG_IO error propagation (Mike Snitzer) [827163]
- [fs] nfs: Fix corrupt read data after short READ from server (Sachin Prabhu) [817738]

* Wed May 30 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-277.el6]
- [scsi] be2iscsi: fix dma free size mismatch regression (Mike Christie) [824287]
- [scsi] libsas: check dev->gone before submitting sata i/o (David Milburn) [824025]

* Tue May 29 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-276.el6]
- [net] ipv4/netfilter: TCP and raw fix for ip_route_me_harder (Jiri Benc) [812108]

* Fri May 25 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-275.el6]
- [net] bridge: fix broadcast flood regression (Jesper Brouer) [817157]
- [ipc] mqueue: use correct gfp flags in msg_insert (Doug Ledford) [750260]
- [security] fix compile error in commoncap.c (Eric Paris) [806726] {CVE-2012-2123}
- [security] fcaps: clear the same personality flags as suid when fcaps are used (Eric Paris) [806726] {CVE-2012-2123}
- [fs] proc: Fix vmstat crashing with trap divide error (Larry Woodman) [820507]
- [net] rds: fix rds-ping inducing kernel panic (Jay Fenlason) [803936] {CVE-2012-2372}
- [net] sock: validate data_len before allocating skb in sock_alloc_send_pskb() (Jason Wang) [814504] {CVE-2012-2136}
- [virt] kvm: Fix buffer overflow in kvm_set_irq() (Avi Kivity) [816155] {CVE-2012-2137}

* Tue May 22 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-274.el6]
- [net] sunrpc: fix loss of task->tk_status after rpc_delay call in xprt_alloc_slot (Jeff Layton) [822189]
- [net] sunrpc: suppress page allocation warnings in xprt_alloc_slot() (Jeff Layton) [822189]
- [net] netfilter: Fix ip_route_me_harder triggering ip_rt_bug (Jiri Benc) [812108]
- [net] netfilter/tproxy: do not assign timewait sockets to skb->sk (Jiri Benc) [812108]
- [usb] Don't fail USB3 probe on missing legacy PCI IRQ (Don Zickus) [812254]
- [usb] Fix handoff when BIOS disables host PCI device (Don Zickus) [812254]
- [usb] Remove duplicate USB 3.0 hub feature #defines (Don Zickus) [812254]
- [usb] Set hub depth after USB3 hub reset (Don Zickus) [812254]
- [usb] xhci: Fix encoding for HS bulk/control NAK rate (Don Zickus) [812254]
- [usb] Fix issue with USB 3.0 devices after system resume (Don Zickus) [812254]
- [virt] xenpv: avoid paravirt __pmd in read_pmd_atomic (Andrew Jones) [822697]

* Mon May 21 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-273.el6]
- [s390] qeth: remove siga retry for HiperSockets devices (Hendrik Brueckner) [817090]
- [scsi] lpfc: Changed version number to 8.3.5.68.5p (Rob Evers) [821515]
- [scsi] lpfc: Fixed system crash due to not providing SCSI error-handling host reset handler (Rob Evers) [821515]
- [scsi] lpfc: Correct handling of SLI4-port XRI resource-provisioning profile change (Rob Evers) [821515]
- [scsi] lpfc: Fix driver crash during back-to-back ramp events. (Rob Evers) [821515]
- [scsi] lpfc: Fixed system panic due to midlayer abort and driver complete race on SCSI cmd (Rob Evers) [821515]
- [scsi] sd: Fix device removal NULL pointer dereference (Rob Evers) [817853]
- [md] Add del_timer_sync to mddev_suspend, fixes a panic (Jonathan E Brassow) [818371]
- [virt] virtio_net: invoke softirqs after __napi_schedule (Michael S. Tsirkin) [819435]
- [virt] virtio_net: do not reschedule rx refill forever (Michael S. Tsirkin) [819435]

* Tue May 15 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-272.el6]
- [md] bitmap: ensure to load bitmap when creating via sysfs (Jes Sorensen) [821329]
- [infiniband] mlx4: fix RoCE oops (Doug Ledford) [749059]
- [x86] setup: Add rh_check_supported() (Prarit Bhargava) [821561]
- [mm] read_pmd_atomic: fix pmd_populate SMP race condition (Andrea Arcangeli) [820762] {CVE-2012-1179}
- [drm] i915: add Ivy Bridge GT2 Server entries (Dave Airlie) [817926]

* Tue May 15 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-271.el6]
- [scsi] qla2xxx: Update version number to 8.04.00.04.06.3-k (Chad Dupuis) [816331]
- [scsi] qla2xxx: Properly check for current state after the fabric-login request (Chad Dupuis) [816331]
- [scsi] qla2xxx: Proper completion to scsi-ml for scsi status task_set_full and busy (Chad Dupuis) [816331]
- [scsi] qla2xxx: Fix reset time out as qla2xxx not ack to reset request (Chad Dupuis) [816331]
- [scsi] qla2xxx: Block flash access from application when device is initialized for ISP82xx (Chad Dupuis) [816331]
- [scsi] qla2xxx: Remove resetting memory during device initialization for ISP82xx (Chad Dupuis) [816331]
- [scsi] qla2xxx: Proper detection of firmware abort error code for ISP82xx (Chad Dupuis) [816331]
- [scsi] qla2xxx: Additional corrections for ISP83xx support (Chad Dupuis) [816331]
- [scsi] bfa: remove tech-preview tainting (Rob Evers) [744301]
- [input] wacom: add support for Cintiq 24HD (Aristeu Rozanski) [773052]
- [netdrv] bna: remove tech-preview status (Ivan Vecera) [744302]
- [net] xfrm: impement kabi work-arounds for alg_trunc_len (Jarod Wilson) [768460]
- [net] xfrm: Add SHA384 and SHA512 HMAC authentication algorithms to XFRM (Jarod Wilson) [768460]
- [net] xfrm: Use the user specified truncation length in ESP and AH (Jarod Wilson) [768460]
- [net] xfrm: Store aalg in xfrm_state with a user specified truncation length (Jarod Wilson) [768460]
- [net] xfrm: Define new XFRM netlink auth attribute with specified truncation bits (Jarod Wilson) [768460]
- [scsi] bxn2fc: Bumped version to 1.0.11 (Mike Christie) [813065]
- [scsi] bnx2fc: cleanup task management IO when it times out. (Mike Christie) [813065]
- [scsi] bnx2fc: Decrememnt io ref count when abort times out (Mike Christie) [813065]
- [scsi] bnx2fc: Allow FLOGI to be retried when receiving bad responses. (Mike Christie) [813065]
- [netdrv] be2net: Ignore status of some ioctls during driver load (Ivan Vecera) [818561]
- [netdrv] be2net: Fix wrong status getting returned for MCC commands (Ivan Vecera) [818561]
- [netdrv] be2net: Fix traffic stall INTx mode (Ivan Vecera) [818561]
- [netdrv] be2net: Fix FW download in Lancer (Ivan Vecera) [818561]
- [netdrv] be2net: enable RSS for ipv6 pkts (Ivan Vecera) [818561]
- [s390] af_iucv: allow shutdown for HS transport sockets (Hendrik Brueckner) [815273]
- [infiniband] cxgb4: handle wake up waiters and add check for invalid endpoint (Steve Best) [811023]
- [drm] radeon: deal with errors from framebuffer init path (Dave Airlie) [736376]
- [fs] proc: restore "huge" tag for hugetlb vmas in numa_maps (Larry Woodman) [818746]
- [fs] proc: teach /proc/$pid/numa_maps about transparent hugepages (Larry Woodman) [818746]
- [fs] proc: break out numa_maps gather_pte_stats() checks (Larry Woodman) [818746]
- [fs] proc: make /proc/$pid/numa_maps gather_stats() take variable page size (Larry Woodman) [818746]
- [fs] proc: allocate storage for numa_maps statistics once (Larry Woodman) [818746]
- [fs] proc: make struct proc_maps_private truly private (Larry Woodman) [818746]
- [fs] proc: move show_numa_map() to fs/proc/task_mmu.c (Larry Woodman) [818746]
- [mm] mempolicy: declare mpol_to_str() when CONFIG_TMPFS=n (Larry Woodman) [818746]
- [mm] mempolicy: remove check_huge_range() (Larry Woodman) [818746]
- [mm] mempolicy: make gather_stats() type-safe and remove forward declaration (Larry Woodman) [818746]
- [mm] mempolicy: remove MPOL_MF_STATS (Larry Woodman) [818746]
- [mm] mempolicy: use walk_page_range() instead of custom page table walking code (Larry Woodman) [818746]
- [mm] mempolicy: export get_vma_policy() (Larry Woodman) [818746]
- [block] mtip32xx: fix missing mtip32xx.ko in installer initrd (Shyam Iyer) [819947]
- [input] wacom: add LED support for Cintiq 24HD (Aristeu Rozanski) [808315]
- [input] wacom: make LED status readable through sysfs (Aristeu Rozanski) [808315]
- [input] wacom: add LED support for Cintiq 21ux2 (Aristeu Rozanski) [808315]
- [input] wacom: add interface to control LEDs in Wacom tablets (Aristeu Rozanski) [808315]
- [vhost] net: fix possible NULL pointer dereference of vq->bufs (Jason Wang) [814288] {CVE-2012-2119}
- [net] macvtap: validate zerocopy vectors before building skb (Jason Wang) [814288] {CVE-2012-2119}
- [net] macvtap: set SKBTX_DEV_ZEROCOPY only when skb is built successfully (Jason Wang) [814288] {CVE-2012-2119}
- [net] macvtap: put zerocopy page when fail to get all requested user pages (Jason Wang) [814288] {CVE-2012-2119}
- [net] macvtap: fix zerocopy offset calculation when building skb (Jason Wang) [814288] {CVE-2012-2119}
- [netdrv] be2net: Fix EEH error reset before a flash dump completes (Ivan Vecera) [818568]
- [netdrv] be2net: cancel be_worker during EEH recovery (Ivan Vecera) [818568]
- [net] bonding: assign slaves their own vlan_groups (Neil Horman) [804232]
- [net] vlan: Add helper functions to manage vlans on bonds and slaves (Neil Horman) [804232]
- [virt] kvm: Fix kvm_arch_vcpu_put() crash with vmm_exclusive=0 (Avi Kivity) [704173]

* Tue May 08 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-270.el6]
- [netdrv] be2net: Record receive queue index in skb to aid RPS (Ivan Vecera) [818558]
- [scsi] bnx2i: Updated version and copyright year (Mike Christie) [816376]
- [scsi] bnx2i: Added the setting of target can_queue via target_alloc (Mike Christie) [816376]
- [netdrv] be2net: fix calling __vlan_put_tag() after eth_type_trans() (Ivan Vecera) [815670]
- [s390] af_iucv: detect down state of HS transport interface (Hendrik Brueckner) [815274]
- [s390] qeth: Improve OSA Express 4 blkt defaults (Hendrik Brueckner) [808486]
- [netdrv] ixgbe: Correct Adaptive Interrupt Moderation so that it will change values (Andy Gospodarek) [802837]
- [mm] x86: Move do_page_fault()'s error path under unlikely() (Motohiro Kosaki) [770376]
- [mm] x86: make pagefault killable (Motohiro Kosaki) [770376]
- [mm] x86: Handle mm_fault_error() in kernel space (Motohiro Kosaki) [770376]
- [mm] introduce wait_on_page_locked_killable() (Motohiro Kosaki) [770376]
- [mm] oom_kill: remove memcg argument from oom_kill_task() (Motohiro Kosaki) [770376]
- [mm] oom-kill: remove boost_dying_task_prio() (Motohiro Kosaki) [770376]
- [net] rds: RDS over QLogic hardware fails to work (Jay Fenlason) [797530]
- [net] netpoll: fix Allow netpoll_setup/cleanup recursion (Herbert Xu) [816034]
- [netdrv] atl1c: add workaround for issue of bit INTX-disable for MSI interrupt (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: enlarge L1 response waiting timer (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove PHY polling from atl1c_change_mtu (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Disable L0S when no cable link (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: do MAC-reset when PHY link down (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: cancel task when interface closed (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: refine mac address related code (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove code of closing register writable attribution (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: clear WoL status when reset pcie (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: add PHY link event(up/down) patch (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: refine start/enable code for MAC module (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: add function atl1c_power_saving (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove PHY reset/init for link down event (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: update PHY reset related routine (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove PHY polling from atl1c_open (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: refine SERDES-clock related code (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove PHY contrl in atl1c_reset_pcie (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: refine phy-register read/write function (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove REG_PHY_STATUS (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove MDIO_REG_ADDR_MASK in atl1c_mdio_read/write (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: fix WoL(magic) issue for l2cb 1.1 (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: refine atl1c_pcie_patch (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: refine/update ASPM configuration (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: clear bit MASTER_CTRL_CLK_SEL_DIS in atl1c_pcie_patch (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: refine reg definition of REG_MASTER_CTRL (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: clear PCIE error status in atl1c_reset_pcie (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove dmar_dly_cnt and dmaw_dly_cnt (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: update right threshold for TSO (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: add module parameter for l1c_wait_until_idle (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: threshold for ASPM is changed based on chip capability (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: restore max-read-request-size in Device Conrol Register (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: using fixed TXQ configuration for l2cb and l1c (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove dmaw_block (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: correct wrong definition of REG_DMA_CTRL (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: wrong register used to stop TXQ (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove code related to rxq 1/2/3 (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: split 2 32bit registers of TPD to 4 16bit registers (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove SMB/CMB DMA related code (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove VPD register (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove HDS register (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove multiple-RX-Q code (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: update author contact info & company/driver desciption (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: stop using net_device.{base_addr, irq} (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: set ATL1C_WORK_EVENT_RESET bit correctly (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: dont use highprio tx queue (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: set addr_assign_type if random_ether_addr() used (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: ethernet dev_alloc_skb to netdev_alloc_skb (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Remove alloc_etherdev error messages (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Sweep away N/A fw_version dustbunnies from the .get_drvinfo routine (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: add skb frag size accessors (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: use DMA_x_DEVICE and dma_mapping_error with skb_frag_dma_map (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: convert to SKB paged frag API (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Remove unneeded version.h includes from drivers/net/ (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove interrupt.h inclusion from netdevice.h (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: atl1c_resume() is only used when CONFIG_PM_SLEEP is defined (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Use ethtool's ethtool_cmd_speed API (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Use full 32 bit speed range in ethtool's set_settings (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Fix work event interrupt/task races (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Fix set-but-unused variable (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: fix sparse warnings (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Do not call device_init_wakeup() in atl1c_probe() (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Add missing PCI device ID (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove private #define (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Comment typo fixes for 'descriptor' (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Do not use legacy PCI power management (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Fix hardware type check for enabling OTP CLK (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: make functions static (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Don't check for vlan group before vlan_tx_tag_present (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: avoid some skb->ip_summed initializations (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Remove double test (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: use net_device_stats from struct net_device (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Add AR8151 v2 support and change L0s/L1 routine (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Remove unnecessary returns from void function()s (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove redundant code (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Update gfp.h and slab.h includes to prepare for breaking implicit slab.h inclusion from percpu.h (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: convert multiple drivers to use netdev_for_each_mc_addr, part3 (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: Add support for Atheros AR8152 and AR8152 (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: use DEFINE_PCI_DEVICE_TABLE() (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: fix assorted typos all over the place (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: use pM to show MAC address (Stanislaw Gruszka) [809036]
- [netdrv] atl1c:add pci map direction in atl1c_buffer flags (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: remove exceptional & on function name (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: change atl1c_buffer struct and restructure clean atl1c_buffer procedure (Stanislaw Gruszka) [809036]
- [netdrv] atl1c: duplicate atl1c_get_tpd (Stanislaw Gruszka) [809036]
- [fs] epoll: clear the tfile_check_list on -ELOOP (Jason Baron) [817140]
- [fs] epoll: Don't limit non-nested epoll paths (Jason Baron) [817137]
- [netdrv] tg3: Fix ethtool self tests (John Feeney) [808243 809036]
- [infiniband] mlx4: check return code and bail on error (Doug Ledford) [749059]
- [infiniband] mlx4: use locking when walking netdev list (Doug Ledford) [749059]
- [x86] asm: undo paravirt_patch_template kABI breakage (Rik van Riel) [813682]
- [fs] cifs: check S_AUTOMOUNT in revalidate (Ian Kent) [786149]
- [fs] vfs: fix LOOKUP_DIRECTORY not propagated to managed_dentry() (Ian Kent) [786149]
- [s390x] kdump: Change default action from reipl to stop for on_restart (Hendrik Brueckner) [806152]
- [s390x] qeth: add missing wake_up call (Hendrik Brueckner) [806151]
- [s390x] lcs: lcs offline failure (Hendrik Brueckner) [804643]
- [s390x] ctcmpc: use correct idal word list for ctcmpc (Hendrik Brueckner) [798641]
- [s390x] dasd: fix fixpoint divide exception in define_extent (Hendrik Brueckner) [798002]
- [s390x] mm: prevent memory zone interleave (Hendrik Brueckner) [797936]
- [s390x] qeth: synchronize discipline module loading (Hendrik Brueckner) [795462]
- [powerpc] perf: Check current->mm in read_user_stack_slow (Steve Best) [804569]
- [powerpc] perf: Disable pagefaults during callchain stack read (Jiri Olsa) [804569]
- [tools] selftests: mqueue mq_perf_tests checkpatch fixes (Doug Ledford) [750260]
- [ipc] mqueue: strengthen checks on mqueue creation fix (Doug Ledford) [750260]
- [misc] rbtree: backport rb_init_node() (Doug Ledford) [750260]
- [tools] selftests: add mq_perf_tests (Doug Ledford) [750260]
- [tools] selftests: add mq_open_tests (Doug Ledford) [750260]
- [ipc] mqueue: strengthen checks on mqueue creation (Doug Ledford) [750260]
- [ipc] mqueue: correct mq_attr_ok test (Doug Ledford) [750260]
- [ipc] mqueue: improve performance of send/recv (Doug Ledford) [750260]
- [watchdog] iTCO_wdt: default SMI clearing to old behaviour (Prarit Bhargava) [727875 811324]
- [watchdog] iTCO_wdt: problems with newer hardware due to SMI clearing (Prarit Bhargava) [727875 811324]
- [sound] alsa: fix Conexant CX20561 audio mute functionality (Jaroslav Kysela) [816569]
- [s390] kdump: Use 4 GiB for KEXEC_AUTO_THRESHOLD (Hendrik Brueckner) [815599]
- [net] bonding: verify for NULL when getting bridge from bond_dev->br_port (Veaceslav Falico) [816034 817145]
- [md] dm-mpath: only try to load the scsi_dh module if the scsi_dh doesn't exist (Mike Snitzer) [788591]
- [virt] kvm/svm: handle adjustment of negative tsc offsets (Marcelo Tosatti) [817236]
- [netdrv] be2net: fix programming of VLAN tags for VF (Ivan Vecera) [816013]
- [scsi] isci: End the RNC resumption wait when the RNC is destroyed. (David Milburn) [809954]
- [scsi] isci: Fixed RNC bug that lost the suspension or resumption during destroy (David Milburn) [809954]
- [scsi] isci: Fix RNC AWAIT_SUSPENSION->INVALIDATING transition. (David Milburn) [809954]
- [scsi] isci: Manage the IREQ_NO_AUTO_FREE_TAG under scic_lock. (David Milburn) [809954]
- [scsi] isci: Remove obviated host callback list. (David Milburn) [809954]
- [scsi] isci: Check IDEV_GONE before performing abort path operations. (David Milburn) [809954]
- [scsi] isci: Restore the ATAPI device RNC management code. (David Milburn) [809954]
- [scsi] isci: Don't wait for an RNC suspend if it's being destroyed. (David Milburn) [809954]
- [scsi] isci: Change the phy control and link reset interface for HW reasons. (David Milburn) [809954]
- [scsi] isci: Added timeouts to RNC suspensions in the abort path. (David Milburn) [809954]
- [scsi] isci: Add protocol indicator for TMF requests. (David Milburn) [809954]
- [scsi] isci: Directly control IREQ_ABORT_PATH_ACTIVE when completing TMFs. (David Milburn) [809954]
- [scsi] isci: Wait for RNC resumption before leaving the abort path. (David Milburn) [809954]
- [scsi] isci: Fix RNC suspend call for SCI_RESUMING state. (David Milburn) [809954]
- [scsi] isci: Manage tag releases differently when aborting tasks. (David Milburn) [809954]
- [scsi] isci: Callbacks to libsas occur under scic_lock and are synchronized. (David Milburn) [809954]
- [scsi] isci: When in the abort path, defeat other resume calls until done. (David Milburn) [809954]
- [scsi] isci: Implement waiting for suspend in the abort path. (David Milburn) [809954]
- [scsi] isci: Make sure all TCs are terminated and cleaned in LUN reset. (David Milburn) [809954]
- [scsi] isci: Manage the LLHANG timer enable/disable per-device. (David Milburn) [809954]
- [scsi] isci: Save the suspension hint for upcoming suspensions. (David Milburn) [809954]
- [scsi] isci: Fix the terminated I/O to not call sas_task_abort(). (David Milburn) [809954]
- [scsi] isci: Distinguish between remote device suspension cases (David Milburn) [809954]
- [scsi] isci: Remove isci_device reqs_in_process and dev_node from isci_device. (David Milburn) [809954]
- [scsi] isci: Only set IDEV_GONE in the device stop path. (David Milburn) [809954]
- [scsi] isci: All pending TCs are terminated when the RNC is invalidated. (David Milburn) [809954]
- [scsi] isci: Device access in the error path does not depend on IDEV_GONE. (David Milburn) [809954]
- [scsi] isci: Add suspension cases for RNC INVALIDATING, POSTING states. (David Milburn) [809954]
- [scsi] isci: Redesign device suspension, abort, cleanup. (David Milburn) [809954]
- [scsi] isci: Escalate to I_T_Nexus_Reset when the device is gone. (David Milburn) [809954]
- [scsi] isci: Remote device stop also suspends the RNC and terminates I/O. (David Milburn) [809954]
- [scsi] isci: Remote device must be suspended for NCQ cleanup. (David Milburn) [809954]
- [scsi] isci: Manage device suspensions during TC terminations. (David Milburn) [809954]
- [scsi] isci: Terminate outstanding TCs on TX/RX RNC suspensions. (David Milburn) [809954]
- [scsi] isci: Handle all suspending TC completions (David Milburn) [809954]
- [scsi] isci: Fixed bug in resumption from RNC Tx/Rx suspend state. (David Milburn) [809954]
- [scsi] isci: Manage the link layer hang detect timer for RNC suspensions. (David Milburn) [809954]

* Tue May 01 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-269.el6]
- [x86] Revert: kdump: No need to disable ioapic in crash path (Don Zickus) [815785]
- [mm] mempolicy: do_migrate_pages cleanup (Larry Woodman) [801904]
- [mm] mempolicy: do_migrate_pages fix (Larry Woodman) [801904]
- [ata] ahci: add another PCI ID for marvell (David Milburn) [813365]
- [ata] ahci: recognize Marvell 88se9125 PCIe SATA 6.0 Gb/s controller (David Milburn) [813365]
- [ata] ahci: HFLAG_YES_FBS fix legacy IDE interface (David Milburn) [813365]
- [ata] ahci: add HFLAG_YES_FBS and apply it to 88SE9128 (David Milburn) [813365]
- [sound] alsa: enable OSS emulation in rhel configuration (Jaroslav Kysela) [657291]
- [sound] alsa: add probe_mask=0x101 automatically for WinFast VP200 H (Jaroslav Kysela) [805658]
- [target] fcoe: Remove printk message from ft_dump_cmd (Neil Horman) [813678]
- [scsi] be2iscsi: fix bh use in alloc pdu path (Mike Christie) [813550]
- [scsi] libsas: fix sas port naming (David Milburn) [759210]
- [scsi] libsas: fix panic when single phy is disabled on a wide port (David Milburn) [759210]
- [scsi] isci: firmware update to latest firmware generator (David Milburn) [759210]
- [scsi] isci: enable BCN in sci_port_add_phy() (David Milburn) [759210]
- [scsi] isci: Changes in COMSAS timings enabling ISCI to detect buggy disc drives (David Milburn) [759210]
- [scsi] isci: implement suspend/resume support (David Milburn) [759210]
- [scsi] isci: kill isci_host.shost (David Milburn) [759210]
- [scsi] isci: fix interrupt disable (David Milburn) [759210]
- [scsi] isci: fix 'link-up' events occur after 'start-complete' (David Milburn) [759210]
- [scsi] isci: fix controller stop (David Milburn) [759210]
- [scsi] isci: refactor initialization for S3/S4 (David Milburn) [759210]
- [scsi] isci: kill isci_port.domain_dev_list (David Milburn) [759210]
- [scsi] isci: kill ->status, and ->state_lock in isci_host (David Milburn) [759210]
- [scsi] isci: Don't filter BROADCAST CHANGE primitives (David Milburn) [759210]
- [scsi] isci: kill sci_phy_protocol and sci_request_protocol (David Milburn) [759210]
- [scsi] isci: kill ->is_direct_attached (David Milburn) [759210]
- [scsi] isci: improve 'invalid state' warnings (David Milburn) [759210]
- [scsi] libsas: suspend / resume support (David Milburn) [759210]
- [ata] libsas: drop sata port multiplier infrastructure (David Milburn) [759210]
- [ata] libata: export ata_port suspend/resume infrastructure for sas (David Milburn) [759210]
- [net] bonding: 802.3ad - fix agg_device_up (Veaceslav Falico) [806081]
- [netdrv] mlx4_core: fix race on comm channel (Jay Fenlason) [808926]
- [scsi] libfc: cache align struct fc_fcp_pkt fields (Neil Horman) [815984]
- [scsi] libfc: cache align fc_exch_pool (Neil Horman) [815984]
- [scsi] fcoe: setup default initial value for DDP threshold (Neil Horman) [815984]
- [virt] virtio_console: tell host of open ports after resume from s3/s4 (Amit Shah) [816099]
- [scsi] st: fix memory leak with 1MB tape I/O (David Milburn) [811703]
- [drm] i915: Don't do MTRR setup if PAT is enabled (Adam Jackson) [802539]
- [scsi] device_handler: Add Netapp storage array to rdac array list (Rob Evers) [811364]
- [netdrv] cnic: Fix parity error code conflict (Mike Christie) [808619]
- [sound] alsa: Fix No sound with Conexant CX20585 / Recording fails (Jaroslav Kysela) [798923]
- [kernel] default to clocksource unstable switching off (Prarit Bhargava) [804535]
- [x86] Backout X86_FEATURE_ARAT checks in hpet initialization (Prarit Bhargava) [804535]
- [kernel] clocksource: Make watchdog robust vs. interruption (Prarit Bhargava) [804535]
- [fs] cifs: Show various mount options in /proc/mounts (Sachin Prabhu) [815751]
- [ata] libata: make ata_print_id atomic numbering fix (David Milburn) [815861]
- [md] raid1: Don't set 'fullsync' unnecessarily (Jonathan E Brassow) [813948]
- [md] dm-raid: Record and handle missing devices. (Jonathan E Brassow) [809231]
- [md] dm-raid: Set recovery flags on resume. (Jonathan E Brassow) [811669]
- [netdrv] bnx2x: changed initial dcb configuration (Michal Schmidt) [812612]
- [netdrv] tg3: Fix NVRAM writes on newer devices (John Feeney) [808617]

* Tue Apr 24 2012 Jarod Wilson <jarod@redhat.com> [2.6.32-268.el6]
- [x86] efi: Remove unnecessary error message (Matthew Garrett) [788428]
- [hid] wacom: Add serial and id reporting for Wacom Intuos4 WL (Aristeu Rozanski) [769676]
- [hid] wacom: fix proximity tool release (Aristeu Rozanski) [769676]
- [hid] wacom: report distance for Intuos4 WL (Aristeu Rozanski) [769676]
- [hid] wacom: Add pad buttons reporting on Intuos4 WL (Aristeu Rozanski) [769676]
- [hid] wacom: set ABS_MISC bit for Intuos4 WL (Aristeu Rozanski) [769676]
- [hid] wacom: introduce support for Intuos4 bluetooth (Aristeu Rozanski) [769676]
- [hid] wacom: introduce sysfs interface to control the device reporting speed (Aristeu Rozanski) [769676]
- [hid] wacom: separate mode switching function (Aristeu Rozanski) [769676]
- [hid] wacom: add missing events for pad buttons (Aristeu Rozanski) [769676]
- [bluetooth] hidp: implement raw output support for HIDP layer (Aristeu Rozanski) [769676]
- [fs] nfsd: vfs_llseek() with 32 or 64 bit offsets (hashes) (J. Bruce Fields) [813070]
- [fs] nfsd: rename 'int access' to 'int may_flags' in nfsd_open() (J. Bruce Fields) [813070]
- [fs] ext4: return 32/64-bit dir name hash according to usage type (J. Bruce Fields) [813070]
- [fs] add new FMODE flags FMODE_32bithash and FMODE_64bithash (J. Bruce Fields) [813070]
- [fs] nfsd: Remove check for a 32-bit cookie in nfsd4_readdir() (J. Bruce Fields) [813070]
- [net] bonding: remove entries for master_ip and vlan_ip and query devices instead (Andy Gospodarek) [810299]
- [net] netfilter: place conntrack in source hash after SNAT is done (Neil Horman) [740747]
- [netdrv] tg3: Fix RSS ring refill race condition (John Feeney) [808247]
- [scsi] Revert: rdac: Add dynamic match to rdac handler (Jarod Wilson) [811364]

* Sat Apr 21 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-267.el6]
- [x86] therm_throt: Don't report power limit and package level thermal throttle events in mcelog (Naoya Horiguchi) [803913]
- [x86] Use this_cpu_has for thermal_interrupt current cpu (Naoya Horiguchi) [803913]
- [x86] percpu: add this_cpu_has() macro (Naoya Horiguchi) [803913]
- [virt] KVM: lock slots_lock around device assignment (Alex Williamson) [811653]
- [virt] kvm: unmap pages from the iommu when slots are removed (Alex Williamson) [811653] {CVE-2012-2121}
- [scsi] fix eh wakeup (scsi_schedule_eh vs scsi_restart_operations) (David Milburn) [798776]
- [scsi] libsas, libata: fix start of life for a sas ata_port (David Milburn) [798776]
- [scsi] libsas: continue revalidation (David Milburn) [798776]
- [ata] libata: make ata_print_id atomic (David Milburn) [798776]
- [scsi] libsas: fix ata_eh clobbering ex_phys via smp_ata_check_ready (David Milburn) [798776]
- [scsi] libsas: fix false positive 'device attached' conditions (David Milburn) [798776]
- [scsi] libsas: unify domain_device sas_rphy lifetimes (David Milburn) [798776]
- [scsi] scsi_transport_sas: fix delete vs scan race (David Milburn) [798776]
- [ata] libata: reset once (David Milburn) [798776]
- [scsi] libsas: fix sas_get_port_device regression (David Milburn) [798776]
- [scsi] libsas: sas_rediscover_dev did not look at the SMP exec status. (David Milburn) [798776]
- [scsi] libsas: fix sas_find_bcast_phy() in the presence of 'vacant' phys (David Milburn) [798776]
- [scsi] libsas: trim sas_task of slow path infrastructure (David Milburn) [798776]
- [scsi] isci: use sas eh strategy handlers (David Milburn) [798776]
- [scsi] libsas: use ->lldd_I_T_nexus_reset for ->eh_bus_reset_handler (David Milburn) [798776]
- [scsi] libsas: add sas_eh_abort_handler (David Milburn) [798776]
- [scsi] libsas: enforce eh strategy handlers only in eh context (David Milburn) [798776]
- [scsi] libata, libsas: introduce sched_eh and end_eh port ops (David Milburn) [798776]
- [scsi] libsas: cleanup spurious calls to scsi_schedule_eh (David Milburn) [798776]
- [scsi] libsas: introduce sas_work to fix sas_drain_work vs sas_queue_work (David Milburn) [798776]
- [net] fib: fix BUG_ON in fib_nl_newrule when add new fib rule (Weiping Pan) [814059]
- [scsi] isci: fix oem parameter validation on single controller skus (David Milburn) [812415]
- [x86] tsc: Don't divide by zero if TSC kHz calibration fails (Richard W.M. Jones) [813413]
- [x86] Avoid check hlt for newer cpus (Don Zickus) [812439]

* Fri Apr 20 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-266.el6]
- [virt] kvm: Allow adjust_tsc_offset to be in host or guest cycles (Frank Arnold) [807215]
- [virt] Revert: x86: Make tsc_delta calculation a function of guest tsc (Frank Arnold) [807215]
- [scsi] lpfc: Update lpfc version for 8.3.5.68.2p driver release (Rob Evers) [810522]
- [scsi] lpfc: Fix bug with mailbox handling of REG_VFI (Rob Evers) [810522]
- [scsi] lpfc: flush PCI function reset register write (Rob Evers) [810522]
- [scsi] lpfc: Fixed system panic when extents enabled (Rob Evers) [810522]
- [scsi] lpfc: Fixed the system panic during EEH recovery (Rob Evers) [810522]
- [scsi] lpfc: Fix resource leak when acc fails (Rob Evers) [810522]
- [scsi] lpfc: Fixed SLI4 driver module load and unload test loop (Rob Evers) [810522]
- [scsi] lpfc: Fixed missing CVL event (Rob Evers) [810522]
- [scsi] lpfc: Fix deadlock during adapter offline request (Rob Evers) [810522]
- [scsi] lpfc: Fix same RPI registered multiple times (Rob Evers) [810522]
- [scsi] lpfc: Fix handling of XRI Aborted CQE response (Rob Evers) [810522]
- [scsi] lpfc: Fixed failure handling SLI4 FC port reset (Rob Evers) [810522]
- [scsi] lpfc: Fix not sending a LOGO with vport delete (Rob Evers) [810522]
- [scsi] lpfc: Fix for SLI4 Port delivery for BLS ABORT ACC (Rob Evers) [810522]
- [scsi] lpfc: Fix ndlp list not empty during unloading (Rob Evers) [810522]
- [scsi] lpfc: Fix mailbox and vpi memory leaks (Rob Evers) [810522]
- [scsi] lpfc: create char device to take a reference (Rob Evers) [810522]
- [scsi] lpfc: Fix for FDISC failures (Rob Evers) [810522]
- [scsi] lpfc: Fix for driver using duplicate RPIs (Rob Evers) [810522]
- [scsi] lpfc: Fix discovery problem when in pt2pt (Rob Evers) [810522]
- [scsi] lpfc: Fixed handling large CQ/EQ ids in an IOV env (Rob Evers) [810522]
- [scsi] lpfc: Fix Locking code raising IRQ twice (Rob Evers) [810522]
- [scsi] lpfc: Fix not returning when bad ndlp found (Rob Evers) [810522]
- [scsi] lpfc: Fix bug with driver returning the wrong ndlp (Rob Evers) [810522]
- [scsi] lpfc: Fix driver behavior when receiving an ADISC (Rob Evers) [810522]
- [scsi] lpfc: Fixed unbounded firmware revision string (Rob Evers) [810522]
- [scsi] lpfc: Fix dump command type 4 using 16Gb FC Adapter (Rob Evers) [810522]
- [scsi] lpfc: Fix port not reset when needed during fw_dump (Rob Evers) [810522]
- [scsi] lpfc: Fix ELS FDISC failing local rej./inv. RPI (Rob Evers) [810522]
- [scsi] lpfc: Fix SLI4 FC port internal loopback (Rob Evers) [810522]
- [scsi] lpfc: Fix REG_RPI fails on SLI4 HBA (Rob Evers) [810522]
- [scsi] lpfc: Fix els command using 16Gb FC Adapter (Rob Evers) [810522]
- [scsi] lpfc: Fix NMI seen due to CQE starvation (Rob Evers) [810522]
- [scsi] lpfc: Fixed SLI4 FC port obtained link-type/num (Rob Evers) [810522]
- [scsi] lpfc: Fixed SLI4 FC port int. loopback without SFP (Rob Evers) [810522]
- [scsi] lpfc: Fix incorrect fcpCdb during scsi command prep (Rob Evers) [810522]
- [drm] i915: Do not set "Enable Panel Fitter" on SNB pageflips (Adam Jackson) [731632]
- [drm] radeon: fix load detect on rn50 with hardcoded EDIDs. (Dave Airlie) [813962]
- [fs] ext4: change return value from int to ssize_t in ext4_file_write (Eric Sandeen) [814302]
- [netdrv] iwlwifi: add option to disable 5GHz band (Stanislaw Gruszka) [812259]
- [scsi] rdac: Add dynamic match to rdac handler (Rob Evers) [811364]
- [virt] xenfv: fix hangs when kdumping (Andrew Jones) [811815]
- [netdrv] mlx4: allocate just enough pages instead of always 4 pages (Steve Best) [812470]
- [mm] Prevent panic while reading /proc/vmallocinfo (Larry Woodman) [767889]

* Thu Apr 12 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-265.el6]
- [fs] GFS2: Instruct DLM to avoid queue convert slowdowns (Robert S Peterson) [799165]
- [fs] GFS2: Allow caching of rindex glock (Robert S Peterson) [799165]
- [fs] GFS2: Don't use a try lock when promoting to a higher mode (Robert S Peterson) [799165]
- [fs] GFS2: Make sure rindex is uptodate before starting transactions (Robert S Peterson) [799165]
- [netdrv] p54spi: Release GPIO lines and IRQ on error in p54spi_probe (John Linville) [808571]
- [netdrv] iwlwifi: always monitor for stuck queues (John Linville) [808571]
- [netdrv] rt2x00: Add support for D-Link DWA-127 to rt2800usb (John Linville) [808571]
- [netdrv] iwl3945: fix possible il->txq NULL pointer dereference in delayed works (John Linville) [808571]
- [netdrv] rt2x00: fix random stalls (John Linville) [808571]
- [netdrv] iwlwifi: fix key removal (John Linville) [808571]
- [netdrv] ath9k_hw: prevent writes to const data on AR9160 (John Linville) [808571]
- [net] mac80211: zero initialize count field in ieee80211_tx_rate (John Linville) [808571]
- [netdrv] ath9k: stop on rates with idx -1 in ath9k rate control's .tx_status (John Linville) [808571]
- [net] mac80211: Fix a rwlock bad magic bug (John Linville) [808571]
- [net] mac80211: timeout a single frame in the rx reorder buffer (John Linville) [808571]
- [netdrv] ath9k_hw: fix a RTS/CTS timeout regression (John Linville) [808571]
- [netdrv] ath9k: fix a WEP crypto related regression (John Linville) [808571]
- [netdrv] ath9k: Fix kernel panic during driver initilization (John Linville) [808571]
- [netdrv] bnx2x: fix memory leak in bnx2x_init_firmware() (Michal Schmidt) [811231]
- [netdrv] bnx2x: fix a crash on corrupt firmware file (Michal Schmidt) [811231]
- [netdrv] bnx2x: FCoE statistics id fixed (Michal Schmidt) [811231]
- [netdrv] bnx2x: dcb bit indices flags used as bits (Michal Schmidt) [811231]
- [netdrv] bnx2x: added cpu_to_le16 when preparing ramrod's data (Michal Schmidt) [811231]
- [netdrv] bnx2x: pfc statistics counts pfc events twice (Michal Schmidt) [811231]
- [fs] dlm: fix QUECVT when convert queue is empty (David Teigland) [809986]
- [netdrv] bnx2x: correction to firmware interface (Michal Schmidt) [810296]

* Wed Apr 11 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-264.el6]
- [net] Fix netdevice reference leak (Thomas Graf) [719600]

* Tue Apr 10 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-263.el6]
- [net] ipmr: Enable multiple multicast routing tables (Thomas Graf) [631984]
- [net] ipmr: Don't leak memory if fib lookup fails (Thomas Graf) [631984]
- [net] ipmr: dont corrupt lists (Thomas Graf) [631984]
- [net] ipmr: off by one in __ipmr_fill_mroute() (Thomas Graf) [631984]
- [net] IPv4: unresolved multicast route cleanup (Thomas Graf) [631984]
- [net] ipmr: add support for dumping routing tables over netlink (Thomas Graf) [631984]
- [net] rtnetlink: decouple rtnetlink address families from real address families (Thomas Graf) [631984]
- [net] ipv4: ipmr: fix NULL pointer deref during unres queue destruction (Thomas Graf) [631984]
- [net] ipv4: ipmr: fix invalid cache resolving when adding a non-matching entry (Thomas Graf) [631984]
- [net] ipv4: ipmr: support multiple tables (Thomas Graf) [631984]
- [net] ipv4: ipmr: move mroute data into seperate structure (Thomas Graf) [631984]
- [net] ipv4: ipmr: convert struct mfc_cache to struct list_head (Thomas Graf) [631984]
- [net] ipv4: ipmr: remove net pointer from struct mfc_cache (Thomas Graf) [631984]
- [net] ipv4: ipmr: move unres_queue and timer to per-namespace data (Thomas Graf) [631984]
- [net] fib_rules: decouple address families from real address families (Thomas Graf) [631984]
- [net] fib_rules: set family in fib_rule_hdr centrally (Thomas Graf) [631984]
- [net] fib_rules: consolidate IPv4 and DECnet ->default_pref() functions (Thomas Graf) [631984]
- [net] ipmr/ip6mr: prevent out-of-bounds vif_table access (Thomas Graf) [631984]
- [fs] direct-io.c: fix truncation error in dio_complete() return (Vivek Goyal) [783992]
- [net] add sysctl to accept packets with local source addresses (Weiping Pan) [719600]
- [scsi] Model description fixes for Brocade adapters (Rob Evers) [808558]
- [x86] kdump: No need to disable ioapic in crash path (Don Zickus) [783322]
- [kernel] uevent: send events in correct order according to seqnum (Naoya Horiguchi) [801694]
- [net] SUNRPC: We must not use list_for_each_entry_safe() in rpc_wake_up() (Steve Dickson) [809928]
- [mm] Fix race in process_vm_rw_core (Kyle McMartin) [739136]
- [mm] Backport Cross Memory Attach patch from upstream (Larry Woodman) [739136]
- [drm] enable CONFIG_VGA_SWITCHEROO (Dave Airlie) [632635]

* Sun Apr 08 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-262.el6]
- [net] bonding: send igmp report for its master (Weiping Pan) [797780]
- [net] allow to get master bridge device for bridge port (Weiping Pan) [797780]
- [s390x] zcrypt: Fix parameter checking for ZSECSENDCPRB ioctl (Hendrik Brueckner) [808487]
- [net] fix vlan gro path (Jiri Pirko) [720611]
- [net] bonding: emit event when bonding changes MAC (Veaceslav Falico) [800231]
- [net] sctp: Fix getsockopt with SCTP_EVENTS regression and allow sctp_event_subscribe to grow (Thomas Graf) [808086]
- [net] vlan: Avoid broken offload configuration when reorder_hdr is disabled (Michal Schmidt) [781652]
- [virt] xen: Revert "xen: mask MTRR feature from guest"" (Andrew Jones) [810222]

* Thu Apr 05 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-261.el6]
- [x86] Don't inject GP for non-XSAVE enabled guests (Don Dugger) [705242]
- [drm] i915: suspend fbdev device around suspend/hibernate (Dave Airlie) [746169]
- [fs] cifs: Add mount options backupuid and backugid. (Sachin Prabhu) [806336]
- [kernel] genirq: Respect NUMA node affinity in setup_affinity() (Prarit Bhargava) [788579]
- [netdrv] iwlwifi: do not nulify ctx->vif on reset (Stanislaw Gruszka) [801730]
- [virt] VMX: vmx_set_cr0 expects kvm->srcu locked (Marcelo Tosatti) [807507] {CVE-2012-1601}
- [virt] KVM: Ensure all vcpus are consistent with in-kernel irqchip settings (Marcelo Tosatti) [807507] {CVE-2012-1601}
- [virt] virtio-pci: S3 support (Amit Shah) [803187]
- [virt] virtio-pci: drop restore_common() (Amit Shah) [803187]
- [virt] virtio: drop thaw PM operation (Amit Shah) [803187]
- [virt] virtio: balloon: Allow stats update after restore from S4 (Amit Shah) [803187]

* Mon Apr 02 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-260.el6]
- [scsi] be2iscsi: fix include order (Mike Christie) [738043]
- [scsi] be2iscsi: Get Port State and Speed of the Adapter (Mike Christie) [738043]
- [scsi] be2iscsi: adding functionality to change network settings using iscsiadm (Mike Christie) [738043]
- [scsi] be2iscsi: Adding bsg interface for be2iscsi (Mike Christie) [738043]
- [scsi] be2iscsi: Get Initiator Name for the iSCSI_Host (Mike Christie) [738043]
- [scsi] be2iscsi: Return async handle of unknown opcode to free list (Mike Christie) [738043]
- [scsi] be2iscsi: Check ASYNC PDU Handle corresponds to HDR/DATA Handle (Mike Christie) [738043]
- [scsi] be2iscsi: Bump the driver Version (Mike Christie) [738043]
- [scsi] be2iscsi: Update in Copyright information (Mike Christie) [738043]
- [scsi] be2iscsi: Fix the function return values (Mike Christie) [738043]
- [scsi] be2iscsi: Code cleanup, removing the goto statement (Mike Christie) [738043]
- [scsi] be2iscsi: Fix double free of MCCQ info memory (Mike Christie) [738043]
- [scsi] be2iscsi: Set num_cpu = 1 if pci_enable_msix fails (Mike Christie) [738043]
- [scsi] be2iscsi:Fix typo function name mismatch (Mike Christie) [738043]
- [scsi] be2iscsi: Freeing of WRB and SGL Handle in cleanup task (Mike Christie) [738043]
- [scsi] be2iscsi: WRB Initialization and Failure code path change (Mike Christie) [738043]
- [scsi] be2iscsi: Fix in ASYNC PDU stitching logic (Mike Christie) [738043]
- [scsi] be2iscsi: Fix in the Asynchronous Code Path (Mike Christie) [738043]
- [net] ipv4: Constrain UFO fragment sizes to multiples of 8 bytes (Jiri Benc) [797731]
- [net] ipv4: Don't use ufo handling on later transformed packets (Jiri Benc) [797731]
- [net] udp: Add UFO to NETIF_F_GSO_SOFTWARE (Jiri Benc) [797731]
- [fs] Fix length of buffer copied in __nfs4_get_acl_uncached (Sachin Prabhu) [808036]
- [net] bond: Make LRO flag follow slave settings (Neil Horman) [794647]
- [net] make dev_disable_lro use physical device if passed a vlan dev (Andy Gospodarek) [713641]
- [net] move is_vlan_dev into public header file (Andy Gospodarek) [713641]

* Thu Mar 29 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-259.el6]
- [mm] memcg: fix coalescing uncharge during truncate (Johannes Weiner) [717803]
- [mm] thp: allow a hwpoisoned head page to be put back to LRU (Dean Nelson) [795574]
- [block] md: Avoid OOPS when reshaping raid1 to raid0 (Jes Sorensen) [805857]
- [net] bridge: fix use after free of skb in bridge when netpoll in use (Neil Horman) [769725]
- [scsi] fcoe: Move destroy_work to a private work queue (Neil Horman) [806119]
- [virt] xen: only check xen_platform_pci_unplug if hvm (Andrew Jones) [807354]

* Tue Mar 27 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-258.el6]
- [fs] epoll: kabi fixups for epoll limit wakeup paths (Jason Baron) [681689] {CVE-2011-1083}
- [fs] epoll: limit paths (Jason Baron) [681689] {CVE-2011-1083}
- [perf] tool: Fix diff command to work with new hists design (Jiri Olsa) [794689]
- [x86] call restore_sched_clock_state after gs is initialized (Marcelo Tosatti) [803132]
- [virt] virtio-scsi: fix whitespace in fix TMF use-after-free patch (Paolo Bonzini) [802127]
- [netdrv] macvtap: add ioctl to modify vnet header size (Michael S. Tsirkin) [789362]
- [netdrv] firmware: add bnx2x FW 7.2.16 (Michal Schmidt) [798316]
- [netdrv] cnic: update for FW 7.2.xx (Michal Schmidt) [798316]
- [netdrv] bnx2fc: HSI dependent changes for 7.2.xx FW (Michal Schmidt) [798316]
- [netdrv] bnx2x: use FW 7.2.16 (Michal Schmidt) [798316]
- [fs] GFS2: put glock reference in error patch of read_rindex_entry (Robert S Peterson) [803384]
- [infiniband] rdmacm: fix initialization bug (Doug Ledford) [805996]
- [pci] Don't touch ASPM at all when it's forcibly disabled (Matthew Garrett) [801877]

* Mon Mar 26 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-257.el6]
- [security] Fix negative key error handling (David Howells) [806393]
- [char] ipmi: Increase KCS timeouts (Matthew Garrett) [803378]
- [scsi] cxgb3: Add latest upstream firmware (Neil Horman) [747139]
- [scsi] cxgb3 driver update to latest upstream (Neil Horman) [747139]
- [x86] uv_mmrs.h cleanup patch (George Beshers) [737747]
- [x86] reduce clock calibration time during slave cpu startup (George Beshers) [737747]
- [x86] uv: Fix uninitialized spinlocks (George Beshers) [737747]
- [x86] uv: Fix uv_gpa_to_soc_phys_ram() shift (George Beshers) [737747]
- [x86] UV2: Add accounting for BAU strong nacks (George Beshers) [737747]
- [x86] UV2: Ack BAU interrupt earlier (George Beshers) [737747]
- [x86] UV2: Remove stale no-resources test for UV2 BAU (George Beshers) [737747]
- [x86] UV2: Work around BAU bug (George Beshers) [737747]
- [x86] UV2: Fix BAU destination timeout initialization (George Beshers) [737747]
- [x86] UV2: Fix new UV2 hardware by using native UV2 broadcast mode (George Beshers) [737747]
- [x86] UV: Update Boot messages for SGI UV2 platform (George Beshers) [737747]
- [x86] UV: Fix UV2 hub part number (George Beshers) [737747]
- [mm] vmstat.c: cache align vm_stat (George Beshers) [737747]
- [x86] uv2: Workaround for UV2 Hub bug (George Beshers) [737747]
- [x86] UV: Remove UV delay in starting slave cpus (George Beshers) [737747]
- [x86] UV: Clean up uv_mmrs.h (George Beshers) [737747]
- [net] ehash_size cleanup in tcp (George Beshers) [737748]
- [x86] print EST-capable warning message only once (George Beshers) [737748]
- [mm] Overflow computing _hash_mask (George Beshers) [737748]
- [x86] ACPI: Remove repeated cooling_device messages (George Beshers) [737748]
- [fs] vfs: fix panic in __d_lookup() (George Beshers) [737748]
- [x86] Fix bootmem allocator large bitmap (George Beshers) [737748]
- [net] Limit sysctl_tcp_mem and sysctl_udp_mem initializers (George Beshers) [737748]
- [mm] alloc_large_system_hash() printk overflow on 16TB boot (George Beshers) [737748]
- [fs] On a 16TB machine, max_user_watches has an integer overflow (George Beshers) [737748]
- [fs] allow for more than 2^31 file (George Beshers) [737748]
- [netdrv] bnx2x: consistent statistics after internal driver reload (Michal Schmidt) [747522]
- [netdrv] netxen_nic: Sysfs support for firmware dump (Veaceslav Falico) [801653]

* Thu Mar 22 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-256.el6]
- [kernel] sched: Fix ancient race in do_exit() (Motohiro Kosaki) [784758]
- [virt] xen: initialize platform_pci even if xen_emul_unplug=never (Igor Mammedov) [803239]
- [virt] virtio-scsi: fix TMF use-after-free (Paolo Bonzini) [802127]
- [virt] KVM: increase max vcpu count to 160 (Marcelo Tosatti) [748946]
- [scsi] sd: Unmap discard alignment needs to be converted to bytes (Mike Snitzer) [805519]
- [scsi] sd: Fix VPD buffer allocations (Mike Snitzer) [805519]
- [scsi] isci: improvements in driver unloading routine (David Milburn) [805530]
- [scsi] isci: improve phy event warnings (David Milburn) [805530]
- [scsi] isci: debug, provide state-enum-to-string conversions (David Milburn) [805530]
- [scsi] scsi_transport_sas: 'enable' phys on reset (David Milburn) [805530]
- [scsi] libsas: don't recover end devices attached to disabled phys (David Milburn) [805530]
- [scsi] libsas: fixup target_port_protocols for expanders that don't report sata (David Milburn) [805530]
- [scsi] libsas: set attached device type and target protocols for local phys (David Milburn) [805530]
- [scsi] isci: T10 DIF support (David Milburn) [805530]
- [scsi] isci: enable clock gating (David Milburn) [805530]
- [scsi] isci: Fix NULL ptr dereference when no firmware is being loaded (David Milburn) [805530]
- [fs] Pstore supplies a wrong header to kmsg files (Seiji Aguchi) [804789]
- [fs] nfs: Try using machine credentials for RENEW calls (Sachin Prabhu) [795441]
- [kernel] perf/x86/kvm: Fix Host-Only/Guest-Only counting with SVM disabled (Gleb Natapov) [805496]

* Thu Mar 22 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-255.el6]
- [fs] jbd2: clear BH_Delay & BH_Unwritten in journal_unmap_buffer (Eric Sandeen) [748713] {CVE-2011-4086}
- [kernel] sched: Call tick_check_idle before __irq_enter (George Beshers) [635817]
- [kernel] sched: Increment cache_nice_tries only on periodic lb (George Beshers) [635817]
- [cpuidle] menu: fixed wrapping timers at 4.294 seconds (George Beshers) [635817]
- [kernel] sched: Fix softirq time accounting (George Beshers) [635817]
- [x86] UV: Lower UV rtc clocksource rating (George Beshers) [635817]
- [infiniband] mlx4_core: fix bug in modify_cq wrapper for resize flow (Doug Ledford) [801111]
- [infiniband] mlx4_core: remove buggy sched_queue masking (Doug Ledford) [801111]
- [infiniband] mlx4_core: Fixing array indexes when setting port types (Doug Ledford) [801111]
- [infiniband] mlx4: Setting new port types after all interfaces unregistered (Doug Ledford) [801111]
- [infiniband] mlx4: Replacing pool_lock with mutex (Doug Ledford) [801111]
- [infiniband] mlx4_core: Do not map BF area if capability is 0 (Doug Ledford) [801111]
- [infiniband] mlx4: add unicast steering entries to resource_tracker (Doug Ledford) [801111]
- [infiniband] mlx4: fix QP tree trashing (Doug Ledford) [801111]
- [infiniband] mlx4: fix buffer overrun (Doug Ledford) [801111]
- [infiniband] mlx4: Fix kcalloc parameters swapped (Doug Ledford) [801111]
- [net] net_sched: qdisc_alloc_handle() can be too slow (Jiri Pirko) [785891]
- [net] RFC3069, private VLAN proxy arp support (Weiping Pan) [786544]
- [scsi] aio: fix the "too late munmap()" race (Jeff Moyer) [801528]
- [scsi] aio: fix io_setup/io_destroy race (Jeff Moyer) [801528]
- [scsi] aio: fix rcu ioctx lookup (Jeff Moyer) [801528]

* Wed Mar 21 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-254.el6]
- [fs] GFS2: Change truncate page allocation to be GFP_NOFS (Robert S Peterson) [796017]
- [fs] GFS2: Remove a __GFP_NOFAIL allocation (Robert S Peterson) [796017]
- [fs] GFS2: flush work when clearing inode (Robert S Peterson) [796017]
- [scsi] hpsa: change version string (Tomas Henzl) [785262]
- [scsi] hpsa: rename HPSA_MAX_SCSI_DEVS_PER_HBA (Tomas Henzl) [785262]
- [scsi] hpsa: update device attributes when they change (Tomas Henzl) [785262]
- [scsi] hpsa: improve naming on external target device functions (Tomas Henzl) [785262]
- [scsi] hpsa: eliminate 8 external target limitation (Tomas Henzl) [785262]
- [scsi] hpsa: fix potential array overflow in hpsa_update_scsi_devices (Tomas Henzl) [785262]
- [scsi] hpsa: refactor hpsa_figure_bus_target_lun (Tomas Henzl) [785262]
- [scsi] hpsa: make target and lun match what SCSI REPORT LUNs returns (Tomas Henzl) [785262]
- [scsi] hpsa: Fix problem with MSA2xxx devices (Tomas Henzl) [785262]
- [scsi] hpsa: add P2000 to list of shared SAS devices (Tomas Henzl) [785262]
- [virt] KVM: PMU: Fix raw event check (Gleb Natapov) [803620]
- [virt] KVM: PMU: warn when pin control is set in eventsel msr (Gleb Natapov) [803620]
- [virt] x86 emulator: correctly mask pmc index bits in RDPMC instruction emulation (Gleb Natapov) [803620]
- [powerpc] perf: Fix frequency calculation for overflowing counters (Steve Best) [804608]
- [security] keys: add a "logon" key type (David Howells) [788634]
- [security] KEYS: testing wrong bit for KEY_FLAG_REVOKED (David Howells) [788634]
- [security] KEYS: Permit key_serial() to be called with a const key pointer (David Howells) [788634]
- [security] keys: fix user_defined key sparse messages (David Howells) [788634]
- [security] keys: fix trusted/encrypted keys sparse rcu_assign_pointer messages (David Howells) [788634]
- [security] KEYS: Add missing smp_rmb() primitives to the keyring search code (David Howells) [788634]
- [security] KEYS: Make garbage collector nonreentrant under RHEL-6 (David Howells) [788634]
- [security] KEYS: Correctly destroy key payloads when their keytype is removed (David Howells) [788634]
- [security] KEYS: The dead key link reaper should be non-reentrant (David Howells) [788634]
- [security] KEYS: Make the key reaper non-reentrant (David Howells) [788634]
- [security] KEYS: Move the unreferenced key reaper to the keys garbage collector file (David Howells) [788634]
- [security] KEYS: __key_link() should use the RCU deref wrapper for keyring payloads (David Howells) [788634]
- [security] KEYS: keyctl_get_keyring_ID() should create a session keyring if create flag set (David Howells) [788634]
- [security] KEYS: If install_session_keyring() is given a keyring, it should install it (David Howells) [788634]
- [security] KEYS: Fix error handling in construct_key_and_link() (David Howells) [788634]
- [security] KEYS: Don't return EAGAIN to keyctl_assume_authority() (David Howells) [788634]
- [security] KEYS: Make request_key() and co. return an error for a negative key (David Howells) [788634]
- [security] KEYS: Improve /proc/keys (David Howells) [788634]
- [security] KEYS: Add an iovec version of KEYCTL_INSTANTIATE (David Howells) [788634]
- [security] KEYS: Add a new keyctl op to reject a key with a specified error code (David Howells) [788634]
- [security] KEYS: Add an RCU payload dereference macro (David Howells) [788634]
- [security] KEYS: Fix __key_link_end() quota fixup on error (David Howells) [788634]
- [security] KEYS: Fix up comments in key management code (David Howells) [788634]
- [security] KEYS: Do some style cleanup in the key management code (David Howells) [788634]
- [security] KEYS: Don't call up_write() if __key_link_begin() returns an error (David Howells) [788634]
- [security] Add a dummy printk function for the maintenance of unused printks (David Howells) [788634]
- [security] KEYS: request_key() should return -ENOKEY if the constructed key is negative (David Howells) [788634]
- [security] KEYS: Reinstate lost passing of process keyring ID in call_sbin_request_key() (David Howells) [788634]
- [security] KEYS: Use the variable 'key' in keyctl_describe_key() (David Howells) [788634]
- [security] KEYS: Make /proc/keys check to see if a key is possessed before security check (David Howells) [788634]
- [security] KEYS: Authorise keyctl_set_timeout() on a key if we have its authorisation key (David Howells) [788634]
- [security] KEYS: Propagate error code instead of returning -EINVAL (David Howells) [788634]
- [security] keyctl_session_to_parent(): use thread_group_empty() to check singlethreadness (David Howells) [788634]
- [security] KEYS: Do preallocation for __key_link() (David Howells) [788634]
- [security] KEYS: keyring_serialise_link_sem is only needed for keyring->keyring links (David Howells) [788634]
- [security] whitespace coding style fixes (David Howells) [788634]
- [security] key: keyring: fix some code style issues (David Howells) [788634]
- [security] Fix some coding styles in security/keys/keyring.c (David Howells) [788634]
- [x86] EFI: Only set regions uncacheable if they support it (Matthew Garrett) [767291]
- [virt] KVM: Fix fetch fault error code (Avi Kivity) [802453]
- [netdrv] add myri10ge firmware (Stanislaw Gruszka) [796099]
- [fs] xfs: fix inode lookup race (Dave Chinner) [796277]
- [x86] amd: Fix L1i and L2 cache sharing information for AMD family 15h processors (Frank Arnold) [798399]
- [x86] cache_info: Update calculation of AMD L3 cache indices (Frank Arnold) [798399]
- [x86] cache_info: Remove bogus free of amd_l3_cache data (Frank Arnold) [798399]
- [hwmon] k10temp: Add support for Fam15h Bulldozer (Frank Arnold) [798209]
- [hwmon] k10temp: add support for AMD Family 12h/14h CPUs (Frank Arnold) [798209]
- [x86] AMD, PCI: Add AMD northbridge PCI device id for CPU families 12h and 14h (Frank Arnold) [798209]
- [netdrv] pch_gbe: modify Kconfig/Makefile and config-generic (Veaceslav Falico) [728177]
- [netdrv] pch_gbe: new network driver from upstream (Veaceslav Falico) [728177]
- [x86] Ivy Bridge kernel rdrand support (Jay Fenlason) [696442]

* Mon Mar 19 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-253.el6]
- [net] gro: more generic L2 header check (Doug Ledford) [789123]
- [infiniband] IPoIB: Stop lying about hard_header_len and use skb->cb to stash LL addresses (Doug Ledford) [789123]
- [net] Make qdisc_skb_cb upper size bound explicit (Doug Ledford) [789123]
- [fs] GFS2: Invalidate directory hash table on inode deallocate (Robert S Peterson) [801171]
- [fs] GFS2: Fix a use-after-free that coverity spotted (Robert S Peterson) [801171]
- [kernel] lkdtm: avoid calling lkdtm_do_action() with spinlock held (Prarit Bhargava) [770621]
- [x86] Fix printk levels for panic, softlockups and stack dumps (Prarit Bhargava) [770621]
- [kernel] lkdtm.c: fix race when crashpoint is hit multiple times before checking count (Prarit Bhargava) [770621]
- [kernel] lkdtm: prefix enum constants (Prarit Bhargava) [770621]
- [kernel] lkdtm: use generic_file_llseek in debugfs (Prarit Bhargava) [770621]
- [kernel] param: remove unnecessary writable charp (Prarit Bhargava) [770621]
- [kernel] lktdm: add support for hardlockup, softlockup and hung task crashes (Prarit Bhargava) [770621]
- [kernel] lkdtm: add debugfs access and loosen KPROBE ties (Prarit Bhargava) [770621]
- [scsi] aacraid: Fixes kernel oops in "aac_eh_abort" (Tomas Henzl) [760396]
- [kernel] sys_poll: fix incorrect type for 'timeout' parameter (Oleg Nesterov) [794681]
- [kernel] kdump: round up total_size to 128M for crashkernel reserving threshold (Dave Young) [798727]
- [block] loop: fix partial read infomation leak (Dave Young) [761418]
- [netdrv] mlx4: Don't show RoCE interfaces if the hpn channel is not installed (Doug Ledford) [753004]
- [mm] thp: fix pmd_bad() triggering in code paths holding mmap_sem read mode (Andrea Arcangeli) [800328]
- [target] fix build on i386 (Andy Grover) [765982]
- [target] Backport from stable-3.2.6 (Andy Grover) [765982]

* Wed Mar 14 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-252.el6]
- [dm] fixing test for NULL pointer testing (Paolo Bonzini) [752380] {CVE-2011-4127}
- [dm] do not forward ioctls from logical volumes to the underlying device (Paolo Bonzini) [752380] {CVE-2011-4127}
- [block] fail SCSI passthrough ioctls on partition devices (Paolo Bonzini) [752380] {CVE-2011-4127}
- [block] add and use scsi_blk_cmd_ioctl (Paolo Bonzini) [752380] {CVE-2011-4127}
- [kernel] regset: Return -EFAULT, not -EIO, on host-side memory fault (Jerome Marchand) [799213] {CVE-2012-1097}
- [kernel] regset: Prevent null pointer reference on readonly regsets (Jerome Marchand) [799213] {CVE-2012-1097}
- [scsi] qla4xxx: update version (Mike Christie) [800664]
- [scsi] iscsi class: fix gfp use in ping compl and host event (Mike Christie) [800664]
- [scsi] iscsi if: Removed packed attr from struct iscsi_chap_rec (Mike Christie) [800664]
- [scsi] iscsi_transport: Added error status code for ping comp event (Mike Christie) [800664]
- [scsi] fix system lock up from scsi error flood (Neil Horman) [800555]
- [scsi] libcxgbi: do not print a message when memory allocation fails (Steve Best) [800114]
- [infiniband] iser: post initial receive buffers before sending the final login request (Mike Christie) [800041]
- [sound] ALSA: pcm midlevel code - add time check for (Jaroslav Kysela) [798984]
- [fs] GFS2: call gfs2_write_alloc_required for each fallocate chunk (Benjamin Marzinski) [801141]

* Fri Mar 09 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-251.el6]
- [scsi] lpfc: Update lpfc version for 8.3.5.58.1p driver release (Rob Evers) [738037]
- [virt] VMX: VMXON/VMXOFF usage changes (Avi Kivity) [704173]
- [virt] VMX: VMCLEAR/VMPTRLD usage changes (Avi Kivity) [704173]
- [virt] VMX: Some minor changes to code structure (Avi Kivity) [704173]
- [virt] VMX: Define new functions to wrapper direct call of asm code (Avi Kivity) [704173]
- [net] bonding: move dev_addr cpy to bond_enslave (Thomas Graf) [799794]
- [net] bonding: move slave MTU handling from sysfs (Thomas Graf) [799794]
- [ppc] Implement CONFIG_STRICT_DEVMEM (Steve Best) [655689]
- [scsi] fcoe: Only define ndo_fcoe_get_hbainfo if fcoe is configured (Neil Horman) [789086]
- [x86] ACPI / PM: Fix build problem for !CONFIG_ACPI related to NVS rework (Myron Stowe) [708447]
- [x86] ips: use interruptible waits in ips-monitor (Neil Horman) [727944]
- [x86] kvmclock: abstract save/restore sched_clock_state (Marcelo Tosatti) [694801]
- [virt] fix a merge problem in "KVM steal time suspend/resume bugfix" series (Aristeu Rozanski) [612320]
- [virt] reapply "KVM steal time suspend/resume bugfix" series (Aristeu Rozanski)

* Tue Mar 06 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-250.el6]
- [net] nfs: set vs_hidden on nfs4_callback_version4 (Jeff Layton) [741039]
- [net] SUNRPC: remove rpcbind clients destruction on module cleanup (Jeff Layton) [741039]
- [net] SUNRPC: remove rpcbind clients creation during service registering (Jeff Layton) [741039]
- [net] NFSd: call svc rpcbind cleanup explicitly (Jeff Layton) [741039]
- [net] SUNRPC: cleanup service destruction (Jeff Layton) [741039]
- [net] SUNRPC: setup rpcbind clients if service requires it (Jeff Layton) [741039]
- [net] SUNRPC: introduce svc helpers for prepairing rpcbind infrastructure (Jeff Layton) [741039]
- [net] SUNRPC: use rpcbind reference counting helpers (Jeff Layton) [741039]
- [net] SUNRPC: introduce helpers for reference counted rpcbind clients (Jeff Layton) [741039]
- [net] SUNRPC: Use AF_LOCAL for rpcbind upcalls (Jeff Layton) [741039]
- [fs] nfs4: Fix nfs4_init and reset_slot_table (Steve Dickson) [785823]
- [net] SUNRPC: Change the default limit to the number of TCP slots (Steve Dickson) [785823]
- [net] SUNRPC: Ensure we always bump the backlog queue in xprt_free_slot (Steve Dickson) [785823]
- [net] SUNRPC: Replace xprt->resend and xprt->sending with a priority queue (Steve Dickson) [785823]
- [net] SUNRPC: Allow caller of rpc_sleep_on() to select priority levels (Steve Dickson) [785823]
- [net] SUNRPC: Support dynamic slot allocation for TCP connections (Steve Dickson) [785823]
- [net] SUNRPC: Clean up the slot table allocation (Steve Dickson) [785823]
- [net] SUNRPC: Initalise the struct xprt upon allocation (Steve Dickson) [785823]
- [net] SUNRPC: Ensure that we grab the XPRT_LOCK before calling xprt_alloc_slot (Steve Dickson) [785823]
- [net] SUNRPC: Convert struct rpc_xprt to use atomic_t counters (Steve Dickson) [785823]
- [net] SUNRPC: Support for RPC over AF_LOCAL transports (Steve Dickson) [785823]
- [mm] memcg: fix wake up in oom wait queue (Frantisek Hrbata) [739615]
- [mm] memcg: oom kill disable and oom status (Frantisek Hrbata) [739615]
- [mm] memcg: oom notifier (Frantisek Hrbata) [739615]
- [mm] memcg: oom wakeup filter (Frantisek Hrbata) [739615]
- [mm] kabi: __GENKSYMS__ for event_list in struct cgroup (Frantisek Hrbata) [739615]
- [mm] cgroup: implement eventfd-based generic API for notifications (Frantisek Hrbata) [739615]
- [mm] cgroups: fix CONTENTS in cgroups documentation (Frantisek Hrbata) [739615]
- [virt] Revert "KVM steal time suspend/resume bugfix" series (Aristeu Rozanski)

* Tue Mar 06 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-249.el6]
- [fs] procfs: add hidepid= and gid= mount options (Jerome Marchand) [770652]
- [fs] procfs: parse mount options (Jerome Marchand) [770652]
- [scsi] qla4xxx: v5.02.00.00.06.03-k3 (Chad Dupuis) [798721]
- [scsi] qla4xxx: assign correct address for iscsi_cls_host (Chad Dupuis) [798721]
- [scsi] qla4xxx: trivial cleanup (Chad Dupuis) [798721]
- [scsi] qla4xxx: Fix sparse warning (Chad Dupuis) [798721]
- [scsi] qla4xxx: Add support for multiple session per host (Chad Dupuis) [798721]
- [scsi] qla4xxx: Export CHAP index as sysfs attribute (Chad Dupuis) [798721]
- [scsi] scsi_transport: Export CHAP index as sysfs attribute (Chad Dupuis) [798721]
- [scsi] qla4xxx: Add support to display CHAP list and delete CHAP entry (Chad Dupuis) [798721]
- [scsi] iscsi_transport: Add support to display CHAP list and delete CHAP entry (Chad Dupuis) [798721]
- [block] Fix io_context leak after failure of clone with CLONE_IO (Vivek Goyal) [791125] {CVE-2012-0879}
- [block] Fix io_context leak after clone with CLONE_IO (Vivek Goyal) [791125] {CVE-2012-0879}
- [fs] dlm: fix slow rsb search in dir recovery (David Teigland) [772376]
- [fs] GFS2: rename existing file after mount crashes (Robert S Peterson) [794839]
- [fs] GFS2: Eliminate sd_rindex_mutex (Robert S Peterson) [798763]
- [fs] cifs: fix dentry refcount leak when opening a FIFO on lookup (Sachin Prabhu) [781893]
- [fs] NFSv4: Handle expired stateids when the lease is still valid (Sachin Prabhu) [757876]
- [perf] header: Fix build on old systems (Jiri Olsa) [784888]
- [perf] hists browser: Add missing stdarg.h include (Jiri Olsa) [784888]

* Tue Mar 06 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-248.el6]
- [netdrv] bnx2: revert firmware load modifications (Neil Horman) [720428]
- [virt] virtio: balloon: leak / fill balloon across S4 (Amit Shah) [798583]
- [scsi] silencing 'killing requests for dead queue' (David Milburn) [798672]
- [scsi] sd_dif: fix setting bio flags (Jeff Moyer) [799075]
- [scsi] megaraid_sas: driver update to version 00.00.06.14-rh1 (Tomas Henzl) [749923]
- [infiniband] srp: fix include ordering issue (Doug Ledford) [791209]
- [sched] Fix Kernel divide by zero panic in find_busiest_group() (Larry Woodman) [785959]

* Mon Mar 05 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-247.el6]
- [virt] KVM steal time suspend/resume bugfix (Rik van Riel) [612320]
- [virt] guest: KVM Steal time registration (Laszlo Ersek) [612320]
- [virt] KVM guest: Steal time accounting (Rik van Riel) [612320]
- [virt] KVM guest: Add a pv_ops stub for steal time (Rik van Riel) [612320]
- [virt] KVM: Steal time implementation (Rik van Riel) [612320]
- [virt] KVM: KVM Steal time guest/host interface (Rik van Riel) [612320]
- [virt] KVM: Add constant to represent KVM MSRs enabled bit in guest/host interface (Rik van Riel) [612320]
- [kernel] perf: Fix parsing of __print_flags() in TP_printk() (Jiri Olsa) [756311]
- [x86] perf: Check that current->mm is alive before getting user callchain (Jiri Olsa) [756311]
- [fs] NFSv4: Propagate the error NFS4ERR_BADOWNER to nfs4_do_setattr (Steve Dickson) [705099]
- [kernel] ftrace: Fix hash record accounting bug (Steven Rostedt) [454694]
- [kernel] ftrace: Fix regression where ftrace breaks when modules are loaded (Steven Rostedt) [454694]
- [kernel] ftrace: Fix dynamic selftest failure on some archs (Steven Rostedt) [454694]
- [kernel] ftrace: Update filter when tracing enabled in set_ftrace_filter() (Steven Rostedt) [454694]
- [kernel] ftrace: Balance records when updating the hash (Steven Rostedt) [454694]
- [kernel] ftrace: Do not disable interrupts for modules in mcount update (Steven Rostedt) [454694]
- [kernel] ftrace: Fix regression of :mod:module function enabling (Steven Rostedt) [454694]
- [kernel] ftrace: Fix possible undefined return code (Steven Rostedt) [454694]
- [kernel] ftrace: Have ftrace_startup() return failure code (Steven Rostedt) [454694]
- [kernel] ftrace: Modify ftrace_set_filter/notrace to take ops (Steven Rostedt) [454694]
- [kernel] ftrace: Allow dynamically allocated function tracers (Steven Rostedt) [454694]
- [kernel] ftrace: Implement separate user function filtering (Steven Rostedt) [454694]
- [kernel] ftrace: Free hash with call_rcu_sched() (Steven Rostedt) [454694]
- [kernel] ftrace: Have global_ops store the functions that are to be traced (Steven Rostedt) [454694]
- [kernel] ftrace: Add ops parameter to ftrace_startup/shutdown functions (Steven Rostedt) [454694]
- [kernel] ftrace: Use counters to enable functions to trace (Steven Rostedt) [454694]
- [kernel] ftrace: Separate hash allocation and assignment (Steven Rostedt) [454694]
- [kernel] ftrace: Create a global_ops to hold the filter and notrace hashes (Steven Rostedt) [454694]
- [kernel] ftrace: Use hash instead for FTRACE_FL_FILTER (Steven Rostedt) [454694]
- [kernel] ftrace: Replace FTRACE_FL_NOTRACE flag with a hash of ignored functions (Steven Rostedt) [454694]
- [kernel] ftrace: Consolidate the function match routines for normal and mods (Steven Rostedt) [454694]
- [kernel] ftrace: Return EINVAL when writing invalid val to set_ftrace_filter (Steven Rostedt) [454694]
- [kernel] ftrace: Consolidate updating of ftrace_trace_function (Steven Rostedt) [454694]
- [kernel] ftrace: Move record update for normal and modules into a separate function (Steven Rostedt) [454694]
- [kernel] ftrace: Remove FTRACE_FL_CONVERTED flag (Steven Rostedt) [454694]
- [kernel] tracing: Enable records during the module load (Steven Rostedt) [454694]
- [kernel] ftrace: Remove FTRACE_FL_FAILED flag (Steven Rostedt) [454694]
- [kernel] ftrace: Remove failures file (Steven Rostedt) [454694]
- [kernel] ftrace: Make FTRACE_WARN_ON() work in if condition (Steven Rostedt) [454694]
- [kernel] ftrace: Only update the function code on write to filter files (Steven Rostedt) [454694]
- [kernel] tracing: Remove leftover FTRACE_ENABLE/DISABLE_MCOUNT enums (Steven Rostedt) [454694]
- [kernel] ftrace: Call trace_parser_clear() properly (Steven Rostedt) [454694]
- [fs] NFSv4: include bitmap in nfsv4 get acl data (Sachin Prabhu) [753232 767288]
- [pci] Add pcie_hp=nomsi to disable MSI/MSI-X for pciehp driver (hiro muneda) [728852]
- [netdrv] enic: enhance SR-IOV support (Stefan Assmann) [795976]

* Thu Mar 01 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-246.el6]
- [infiniband] mlx4/fw: Fix ppc64 build (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: Added missing iounmap upon releasing a device (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392 787762]
- [infiniband] mlx4: allow device removal by fixing dma unmap size (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: use correct port for steering (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: use correct flag for unicast_promisc (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: fix memory leak at multi_func_cleanup (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] RDMA/nes: Copyright update (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/mlx4: pass SMP vendor-specific attribute MADs to firmware (Doug Ledford) [737661 738491 739139 749059 751220 755741 756147 756392 787572]
- [infiniband] RDMA/nes: Fix fast memory registration opcode (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/nes: Fix fast memory registration length (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/ucma: Discard all events for new connections until accepted (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/qib: Roll back PCIe tuning change (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Use GFP_ATOMIC when locks are held (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] RDMA/nes: Fix for sending MPA reject frame (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/ipath: Calling PTR_ERR() on right variable in create_file() (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/core: Fix kernel panic by always initializing qp->usecnt (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] rds: Make rds_sock_lock BH rather than IRQ safe. (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] mlx4_core: map async events to arbitrary slave eqs (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Fix mtt profile issue (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: removed function index from vf. (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: eth statistics modification (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: VF is not allowed to perform dump stats (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: clear all eth statistics when port goes up (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] RDS: Remove some unused iWARP code (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] rdma/core: Fix sparse warnings (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cma: Fix endianness bugs (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/nes: Fix terminate during AE (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/nes: Make unnecessarily global nes_set_pau() static (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/nes: Change MDIO bus clock to 2.5MHz (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/cm: Fix layout of APR message (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/mlx4: Fix SL to 802.1Q priority-bits mapping for IBoE (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/qib: Default some module parameters optimally (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Optimize locking for get_txreq() (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Fix a possible data corruption when receiving packets (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Eliminate 64-bit jiffies use (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Fix style issues (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/uverbs: Protect QP multicast list (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] mlx4_core: Elaborating limitation on VF port options (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: fix mtt range deallocation (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: limiting VF port options (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: using array index for sense_allowed (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: Add missing include of linux/slab.h (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: FIX: Setting default_qpn before using it (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: Fixing wrong error codes in communication channel (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: not using spin_lock_irq when getting vf by resource. (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: nullify cached multicast address list after cleanup (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Changing link sensing logic (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: capability for link sensing (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: Fix compile error when driver is comiled-in (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: updated driver version to 2.0 (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: updated driver version to 1.1 (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Modify driver initialization flow to accommodate SRIOV for Ethernet (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: adjust catas operation for SRIOV mode (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: mtts resources units changed to offset (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: Allow communication between functions on same host (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: Ethernet port management modifications (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: Traffic steering management support for SRIOV (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_ib: disable SRIOV mode for IB ports (not yet supported) (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: resource tracking for HCA resources used by guests (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Add wrapper functions and comm channel and slave event support to EQs (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: mtt modifications for SRIOV (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: cq modifications for SRIOV (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: qp modifications for SRIOV (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: srq modifications for SRIOV (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Added FW commands and their wrappers for supporting SRIOV (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] net/mlx4_core: Implement the master-slave communication channel (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Reduce number of PD bits to 17 (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Add "native" argument to mlx4_cmd and its callers (where needed) (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: Extanding port_mask functionality (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: initial header-file changes for SRIOV support (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] net/mlx4_en: bug fix for the case of vlan id 0 and UP 0 (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] net/mlx4_en: fix WOL handlers were always looking at port2 capability bit (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] net/mlx4_en: using non collapsed CQ on TX (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] net/mlx4_en: fix sparse warning on a cast which truncates bits from constant value (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] net/mlx4: fix UDP RSS related settings (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: Recording rx queue for gro packets (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: Adding rxhash support (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] net/mlx4: move RSS related definitions to be global (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] net/cxgb{3, 4} - get rid of stale firmware usage technique (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB: various strlcpy conversions to make the code match upstream (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/qib: Correct sense on freectxts increment and decrement (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] RDMA/cma: Verify private data length (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/mlx4: Fix shutdown crash accessing a non-existent bitmap (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/ipoib: Prevent hung task or softlockup processing multicast response (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/qib: Fix over-scheduling of QSFP work (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] RDMA/cxgb4: Fix retry with MPAv1 logic for MPAv2 (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cxgb4: Fix iw_cxgb4 count_rcqes() logic (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] rds: drop "select LLIST" (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] IB/qib: Don't use schedule_work() (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Fix panic in RC error flushing logic (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/iser: DMA unmap TX bufs used for iSCSI/iSER headers (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/iser: Use separate buffers for the login request/response (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/mthca: Fix buddy->num_free allocation size (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] net: add moduleparam.h for users of module_param/MODULE_PARM_DESC (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] net: Fix files explicitly needing to include module.h (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] mlx4_core: Deprecate log_num_vlan module param (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/mlx4: Don't set VLAN in IBoE WQEs' control segment (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/mlx4: Enable 4K mtu for IBoE (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] RDMA/cxgb4: Mark QP in error before disabling the queue in firmware (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cxgb4: Serialize calls to CQ's comp_handler (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cxgb3: Serialize calls to CQ's comp_handler (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/qib: Fix issue with link states and QSFP cables (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/mlx4: Configure extended active speeds (Doug Ledford) [737661 738491 739139 749059 751220 755741 756147 756392]
- [infiniband] mlx4_core: Add extended port capabilities support (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/qib: Hold links until tuning data is available (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Clean up checkpatch issue (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Remove s_lock around header validation (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Use RCU for qpn lookup (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Eliminate divide/mod in converting idx to egr buf pointer (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Decode path MTU optimization (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Optimize RC/UC code by IB operation (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] mlx4_en: Controlling FCS header removal (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IPoIB: Use the right function to do DMA unmap pages (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cxgb4: Use correct QID in insert_recv_cqe() (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cxgb4: Make sure flush CQ entries are collected on connection close (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/uverbs: Export ib_open_qp() capability to user space (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/core: Export ib_open_qp() to share XRC TGT QPs (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/mlx4: Add support for XRC QPs (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/mlx4: Add support for XRC SRQs (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/mlx4: Add support for XRC domains (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/cm: Do not automatically disconnect XRC TGT QPs (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cma: Support XRC QPs (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/ucm: Allow user to specify QP type when creating id (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cm: Define new RDMA port space specific to IB (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/cm: Update XRC support based on XRC annex errata (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/cm: Update protocol to support XRC (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/uverbs: Export XRC TGT QPs to user space (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/uverbs: Export XRC INI QPs to userspace (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/uverbs: Export XRC SRQs to user space (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/uverbs: Export XRC domains to user space (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/verbs: Cleanup XRC TGT QPs when destroying XRCD (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/core: Add XRC QPs (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/core: Add XRC SRQ type (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/core: Add SRQ type field (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/core: Add XRC domain support (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IPoIB: Handle extended rates in debugfs (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB: Add new InfiniBand link speeds (Doug Ledford) [738491 739139 749059 751220 755741]
- [infiniband] IB/ipath: Add missing <linux/stat.h> in ipath_chip_init.c (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/nes: Support for Packed And Unaligned fpdus (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/nes: Print IP address for critcal errors (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/nes: Fix terminate connection (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] net: use DMA_x_DEVICE and dma_mapping_error with skb_frag_dma_map (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/nes: Add support for MPAv2 Enhanced RDMA Negotiation (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cxgb4: Add support for MPAv2 Enhanced RDMA Negotiation (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/{amso1100,cxgb3}: Minimal MPAv2 support (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/iwcm: Propagate ird/ord values upwards (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] IB/qib: Correct nfreectxts for multiple HCAs (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] RDMA/nes: Add missing calls to ib_umem_release() (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] mlx4_core: Fix buddy->num_free allocation size (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Use the right function to free eq->page_list entries (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Clean up error flow in mlx4_register_mac() (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] RDMA/ucm: Removed checks for unsigned value < 0 (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/mad: Verify mgmt class in received MADs (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cma: Check for NULL conn_param in rdma_accept (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cxgb4: Fail RDMA initialization for unsupported cards (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] RDMA/cma: Fix crash in cma_req_handler (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/amso1100: Use 'pM' format option to print MAC (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] net, rds, Replace xlist in net/rds/xlist.h with llist (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] llist: return whether list is empty before adding in llist_add fix (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] llist: Add back llist_add_batch() and llist_del_first() prototypes (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] llist: Remove cpu_relax() usage in cmpxchg loops (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] llist: Add llist_next() (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] llist: Return whether list is empty before adding in llist_add() (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] llist: Move cpu_relax() to after the cmpxchg() (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] llist: Remove the platform-dependent NMI checks (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] llist: Make some llist functions inline (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] lib, Add lock-less NULL terminated single list (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] net: Convert vmalloc/memset to vzalloc (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IPoIB: convert to SKB paged frag API. (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB: nes: convert to SKB paged frag API. (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB: amso1100: convert to SKB paged frag API. (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDSRDMA: Fix cleanup of rds_iw_mr_pool (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] IB/iser: Support iSCSI PDU padding (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IBiser: Fix wrong mask when sizeof (dma_addr_t) > sizeof (unsigned long) (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] mlx4: decreasing ref count when removing mac (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: Fixing Ethernet unicast packet steering (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/qib: Defer HCA error events to tasklet (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] mlx4_core: Bump the driver version to 1.0 (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] RDMA/cxgb4: Use printk_ratelimited() instead of printk_ratelimit() (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/mlx4: Support PMA counters for IBoE (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/mlx4: Use flow counters on IBoE ports (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/pma: Add include file for IBA performance counters definitions (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] Revert "[infiniband] qib: add thresholds to VendorPortCounters PMA operation" (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] mlx4_core: Add network flow counters (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Fix location of counter index in QP context struct (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Read extended capabilities into the flags field (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_core: Extend capability flags to 64 bits (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/mlx4: Generate GID change events in IBoE code (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] IB/core: Add GID change event (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cma: Don't allow IPoIB port space for IBoE (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA: Allow for NULL .modify_device() and .modify_port() methods (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/qib: Update active link width (Doug Ledford) [722308 726127 738491 739139 749059 755741]
- [infiniband] IB/qib: Add sysfs interface to read free contexts (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/mthca: Remove unnecessary read of PCI_CAP_ID_EXP (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/qib: Remove double define (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/qib: Remove unnecessary read of PCI_CAP_ID_EXP (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] IB/ipath: Convert old cpumask api into new one (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/qib: Convert old cpumask api into new one (Doug Ledford) [722308 738491 739139 749059 755741]
- [infiniband] cpumask: rename tsk_cpumask to tsk_cpus_allowed (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] RDMA/cma: Avoid assigning an IS_ERR value to cm_id pointer in CMA id object (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] IB/mthca: Stop returning separate error and status from FW commands (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] net: rds: fix const array syntax (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] mlx4: remove unnecessary read of PCI_CAP_ID_EXP (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: use pci_dev->revision (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] net/rds: use prink_ratelimited() instead of printk_ratelimit() (Doug Ledford) [683318 689657 738491 739139 749059 755741]
- [infiniband] net: remove interrupt.h inclusion from netdevice.h (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] ethtool: cosmetic: Use ethtool ethtool_cmd_speed API (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] ethtool: Use full 32 bit speed range in ethtool's set_settings (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] mlx4: fix kfree on error path in new_steering_entry() (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] Fix common misspellings (Doug Ledford) [738491 739139 749059 755741]
- [infiniband] mlx4: Fixing use after free (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: Enabling new steering (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: Add support for promiscuous mode in the new steering model. (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4: generalization of multicast steering. (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [infiniband] mlx4_en: UDP RSS support (Doug Ledford) [737661 738491 739139 749059 755741 756147 756392]
- [fs] GFS2: fix NULL pointer dereference on mkdir/symlink/mknod (Abhijith Das) [797305]
- [net] implement IP_RECVTOS for IP_PKTOPTIONS (Jiri Benc) [677351]
- [scsi] mptsas: Added check for the LU type is SSC (Tomas Henzl) [735895]
- [dm] raid: add flush support (Mike Snitzer) [797967]

* Wed Feb 29 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-245.el6]
- [build] update RHEL_MINOR to '3' (Aristeu Rozanski)
- [fs] keyring: allow special keyrings to be cleared (Steve Dickson) [772495]
- [fs] NFS: Update idmapper documentation (Steve Dickson) [772495]
- [fs] NFS: Keep idmapper include files in one place (Steve Dickson) [772495]
- [fs] NFS: Fall back on old idmapper if request_key() fails (Steve Dickson) [772495]
- [virt] KVM: do not #GP on perf MSR writes when vPMU is disabled (Gleb Natapov) [645365]
- [virt] KVM: Expose the architectural performance monitoring CPUID leaf (Gleb Natapov) [645365]
- [kernel] perf, x86: expose perf capability to other modules (Gleb Natapov) [645365]
- [kernel] x86, perf: disable non available architectural events (Gleb Natapov) [645365]
- [virt] KVM: VMX: Intercept RDPMC (Gleb Natapov) [645365]
- [virt] KVM: SVM: Intercept RDPMC (Gleb Natapov) [645365]
- [virt] KVM: Add generic RDPMC support (Gleb Natapov) [645365]
- [virt] KVM: Expose a version 2 architectural PMU to a guests (Gleb Natapov) [645365]
- [virt] KVM: Expose kvm_lapic_local_deliver() (Gleb Natapov) [645365]
- [virt] KVM: VMX: Check for automatic switch msr table overflow (Gleb Natapov) [645365]
- [virt] KVM: VMX: Add support for guest/host-only profiling (Gleb Natapov) [645365]
- [virt] KVM: VMX: add support for switching of PERF_GLOBAL_CTRL (Gleb Natapov) [645365]
- [virt] perf, intel: Use GO/HO bits in perf-ctr (Gleb Natapov) [645365]
- [kernel] perf, amd: Use GO/HO bits in perf-ctr (Gleb Natapov) [645365]
- [kernel] perf, core: Introduce attrs to count in either host or guest mode (Gleb Natapov) [645365]
- [virt] KVM: VMX: Add definitions for more vm entry/exit control bits (Gleb Natapov) [645365]
- [virt] KVM: VMX: Add facility to atomically switch MSRs on guest entry/exit (Gleb Natapov) [645365]
- [virt] KVM: VMX: Add definition for msr autoload entry (Gleb Natapov) [645365]
- [virt] KVM: Let vcpu structure alignment be determined at runtime (Gleb Natapov) [645365]
- [kernel] perf: Add context field to perf_event (Gleb Natapov) [645365]
- [virt] irq_work: Add generic hardirq context callbacks (Gleb Natapov) [645365]
- [kernel] perf: Fix perf_event_do_pending() fallback callsite (Gleb Natapov) [645365]
- [netdrv] bnx2: update firmware to latest upstream (Neil Horman)
- [netdrv] bnx2: update to latest upstream (Neil Horman) [720428]
- [netdrv] mii.c: Add ethtool advertisement functions (John Feeney) [787753]
- [scsi] dcb: add DCBX mode to event notifier attributes (Neil Horman) [789086]
- [scsi] fcoe: use real dev in case of HW vlan acceleration (Neil Horman) [789086]
- [netdrv] netdev: FCoE: Add new ndo_get_fcoe_hbainfo() call (Neil Horman) [789086]
- [scsi] libfc: Handle discovery failure during ctlr link down (Neil Horman) [789086]
- [scsi] scsi_transport_fc: Getting FC Port Speed in sync with FC-GS (Neil Horman) [789086]
- [scsi] scsi_transport_fc: Add FDMI host attributes (Neil Horman) [789086]
- [scsi] libfc: Fix panic in fc_exch_recv (Neil Horman) [789086]
- [scsi] fcoe: Remove reference counting on 'stuct fcoe_interface' (Neil Horman) [789086]
- [scsi] fcoe: Do not switch context in vport_delete callback (Neil Horman) [789086]
- [scsi] fcoe: Rename out_nomod label to out_putmod (Neil Horman) [789086]
- [scsi] fcoe: Allow exposing FDMI attributes via sysfs (Neil Horman) [789086]
- [scsi] fcoe: Add support for FDMI in fcoe (Neil Horman) [789086]
- [scsi] libfc: Add support for FDMI (Neil Horman) [789086]
- [scsi] libfc: Make the libfc Common Transport(CT) code generic (Neil Horman) [789086]
- [scsi] libfcoe: Don't KERN_ERR on netdev notification (Neil Horman) [789086]
- [scsi] libfc: remove redundant timer init for fcp (Neil Horman) [789086]
- [scsi] fcoe: Move fcoe_debug_logging from fcoe.h to fcoe.c (Neil Horman) [789086]
- [scsi] libfc: Declare local functions static (Neil Horman) [789086]
- [scsi] fcoe: fix regression on offload em matching function for initiator/target (Neil Horman) [789086]
- [scsi] fcoe: remove double check if skb is nonlinear (Neil Horman) [789086]
- [scsi] fcoe: fix fcoe in a DCB environment by adding DCB notifiers to set skb priority (Neil Horman) [789086]
- [scsi] fcoe: Fix preempt count leak in fcoe_filter_frames() (Neil Horman) [789086]
- [scsi] Fix up files implicitly depending on module.h inclusion (Neil Horman) [789086]
- [x86] efivars: add missing parameter to efi_pstore_read() (Seiji Aguchi) [696383]
- [x86] pstore: gracefully handle NULL pstore_info functions (Seiji Aguchi) [696383]
- [x86] pstore: pass reason to backend write callback (Seiji Aguchi) [696383]
- [x86] pstore: pass allocated memory region back to caller (Seiji Aguchi) [696383]
- [x86] pstore: make pstore write function return normal success/fail value (Seiji Aguchi) [696383]
- [x86] pstore: change mutex locking to spin_locks (Seiji Aguchi) [696383]
- [x86] pstore: defer inserting OOPS entries into pstore for RHEL (Seiji Aguchi) [696383]
- [x86] efivars: fix warnings when CONFIG_PSTORE=n (Seiji Aguchi) [696383]
- [x86] efivars: Introduce PSTORE_EFI_ATTRIBUTES (Seiji Aguchi) [696383]
- [x86] efivars: Use string functions in pstore_write (Seiji Aguchi) [696383]
- [x86] efivars: introduce utf16_strncmp (Seiji Aguchi) [696383]
- [x86] efivars: String functions (Seiji Aguchi) [696383]
- [x86] efi: Add support for using efivars as a pstore backend (Seiji Aguchi) [696383]
- [x86] include cleanup: Update gfp.h and slab.h includes to prepare for breaking implicit slab.h inclusion from percpu.h (Seiji Aguchi) [696383]
- [x86] pstore: Make "part" unsigned (Seiji Aguchi) [696383]
- [x86] pstore: Add extra context for writes and erases (Seiji Aguchi) [696383]
- [x86] Fix argument types for SetVariable() for RHEL (Seiji Aguchi) [696383]
- [x86] pstore: Extend API for more flexibility in new backends (Seiji Aguchi) [696383]
- [x86] efi: Fix argument types for SetVariable() (Seiji Aguchi) [696383]
- [x86] treewide: fix a few typos in comments (Seiji Aguchi) [696383]
- [x86] efivars: prevent oops on unload when efi is not enabled (Seiji Aguchi) [696383]
- [x86] efivars: handle errors from register_efivars() (Seiji Aguchi) [696383]
- [x86] efivars: memory leak on error in create_efivars_bin_attributes() (Seiji Aguchi) [696383]
- [x86] Fix common misspellings (Seiji Aguchi) [696383]
- [x86] efivars: Expose efivars functionality to external drivers (Seiji Aguchi) [696383]
- [x86] efivars: Parameterize operations (Seiji Aguchi) [696383]
- [x86] efivars: Split out variable registration (Seiji Aguchi) [696383]
- [x86] efivars: parameterize efivars (Seiji Aguchi) [696383]
- [x86] efivars: Make efivars bin_attributes dynamic (Seiji Aguchi) [696383]
- [x86] sysfs: Use one lockdep class per sysfs attribute (Seiji Aguchi) [696383]
- [x86] efivars: move efivars globals into struct efivars (Seiji Aguchi) [696383]
- [netdrv] iwlwifi: make "Tx aggregation enabled on ra =" be at DEBUG level (John Linville) [788055]
- [netdrv] Add firmware blobs required by the integrated compat-wireless build (John Linville)
- [netdrv] Add/modify config settings as appropriate for the wireless rebase (John Linville) [766952]
- [netdrv] b44: replace the ssb_dma API with the generic DMA API (John Linville) [766952]
- [netdrv] orinoco: minimal changes to build with wireless rebase from 3.2.6 (John Linville) [766952]
- [netdrv] ar9170: minor fixups to get it building with 3.2.6-based mac80211 (John Linville) [766952]
- [netdrv] Revert "ar9170: fix for driver-core ABI change" (John Linville) [766952]
- [netdrv] Revert "ath5k: use kstrtoint() to parse numbers coming from sysfs" (John Linville) [766952]
- [netdrv] libertas_tf: Revert bits of "param: simple locking for sysfs-writable..." (John Linville) [766952]
- [netdrv] ipw2100: Revert "PM QOS update" (John Linville) [766952]
- [netdrv] Revert "ipw2100: mark ipw2100_pm_qos_req static" (John Linville) [766952]
- [netdrv] Revert "ipw2100: register pm_qos request before registering pci driver" (John Linville) [766952]
- [netdrv] ipw2100: Revert "pm_qos: Get rid of the allocation in pm_qos_add_request()" (John Linville) [766952]
- [netdrv] rndis_wlan: minor build fixups for wireless rebase from 3.2.6 (John Linville) [766952]
- [netdrv] at76c50x-usb: undo "lib: rename pack_hex_byte()..." (John Linville) [766952]
- [netdrv] wl12xx: reduce frame usage of driver_state_read (John Linville) [766952]
- [netdrv] wl12xx: convert a few more kstrtoul back to strict_strtoul (John Linville) [766952]
- [netdrv] wl1251: revert change from "drivers: Final irq namespace conversion" (John Linville) [766952]
- [netdrv] wl12xx: Revert "wl1251: fix ELP_CTRL register reads" (John Linville) [766952]
- [netdrv] wl12xx: Revert "wl12xx: use kstrtoul functions" (John Linville) [766952]
- [netdrv] wl12xx: Revert "wl12xx: strict_stroul introduced converted to kstrtoul" (John Linville) [766952]
- [netdrv] wl12xx: Revert "wl12xx: use kstrtoul_from_user" (John Linville) [766952]
- [netdrv] wl12xx: Revert "wl12xx: use freezable workqueue for netstack_work" (John Linville) [766952]
- [netdrv] rt2x00: switch to use the kfifo-new.h header file (John Linville) [766952]
- [netdrv] rt2x00: Revert "rt2x00: Move TX/RX work into dedicated workqueue" (John Linville) [766952]
- [netdrv] rt2x00: Revert "rt2x00: simplify txstatus_fifo handling" (John Linville) [766952]
- [netdrv] b43: don't include bcma header files (John Linville) [766952]
- [netdrv] b43: Revert relevant portion of "pcmcia: Convert pcmcia_device_id..." (John Linville) [766952]
- [netdrv] b43: Revert relevant portions of "pcmcia: move driver name to..." (John Linville) [766952]
- [netdrv] b43: Revert relevant portions of "pcmcia: re-work..." commit eb14120f (John Linville) [766952]
- [netdrv] b43: Revert bits of "pcmcia: do not use win_req_t when..." (John Linville) [766952]
- [netdrv] b43: Revert bits of "pcmcia: convert pcmcia_request..." commit 1ac71e5a (John Linville) [766952]
- [ssb] b43-pci-bridge: Add new vendor for BCM4318 (John Linville) [766952]
- [ssb] Revert "pcmcia: convert ssb pcmcia driver to use new CIS helpers" (John Linville) [766952]
- [ssb] Implement pcmcia_{read, write}_config_byte for drivers/ssb/pcmcia.c (John Linville) [766952]
- [ssb] Revert relevant portion of "pcmcia: re-work pcmcia..." commit eb14120f (John Linville) [766952]
- [ssb] Revert relevant portions of "pcmcia: remove cs_types.h" commit ac8b4228 (John Linville) [766952]
- [net] mac80211/debugfs_netdev.c: convert kstrtoull to strict_strtoull (John Linville) [766952]
- [net] mac80211: remove reference to lockdep_rtnl_is_held (John Linville) [766952]
- [net] mac80211: continue using USHORT_MAX (John Linville) [766952]
- [net] mac80211: Revert "net/mac80211/debugfs: Convert to kstrou8_from_user" (John Linville) [766952]
- [net] mac80211: Revert mac80211 bits of "param: simple locking for sysfs-writable..." (John Linville) [766952]
- [net] mac80211: Revert "mac80211: Speedup ieee80211_remove_interfaces()" (John Linville) [766952]
- [net] mac80211: Revert "net/mac80211, rcu: convert call_rcu(work_free_rcu) to kfree_rcu()" (John Linville) [766952]
- [net] mac80211: Revert "net, rcu: convert call_rcu(kfree_tid_tx) to kfree_rcu()" (John Linville) [766952]
- [net] mac80211: Revert mac80211 bits of "PM QOS update" upstream commit ed77134b (John Linville) [766952]
- [net] mac80211: Revert mac80211 bits of "rcu: convert uses of rcu_assign_pointer..." (John Linville) [766952]
- [net] mac80211: Revert "mac80211: fix race condition between assoc_done and first EAP packet" (John Linville) [766952]
- [net] mac80211: Revert "mac80211: annotate station rcu dereferences" (John Linville) [766952]
- [net] mac80211: Revert "mac80211: cancel restart_work explicitly instead of depending on flush_scheduled_work()" (John Linville) [766952]
- [net] mac80211: Revert "mac80211: sparse RCU annotations" (John Linville) [766952]
- [netdrv] wireless: Revert "nl80211: use netlink consistent dump feature for BSS dumps" (John Linville) [766952]
- [net] wireless rebase: Revert bits of "cfg80211: support sysfs namespaces" (John Linville) [766952]
- [net] wireless rebase: Revert "wext: refactor" (John Linville) [766952]
- [net] mac80211: borrow leds compat implementation from compat project (John Linville) [766952]
- [netdrv] wireless: borrow genetlink compat implementation from compat project (John Linville) [766952]
- [netdrv] wireless rebase: remove references to noop_llseek (John Linville) [766952]
- [netdrv] wireless rebase: Revert bits of "PM QoS: Move and rename the implementation..." (John Linville) [766952]
- [netdrv] wireless rebase: accomodate lack of "net: convert multicast list to list_head" (John Linville) [766952]
- [netdrv] wireless rebase: undo bits of "USB: rename usb_buffer_alloc()..." (John Linville) [766952]
- [netdrv] wireless rebase: Revert bits of "net: Add export.h..." (John Linville) [766952]
- [netdrv] wireless rebase: Revert bits of "atomic: use <linux/atomic.h>" (John Linville) [766952]
- [netdrv] drivers/net/wireless/ath: remove references to ath6kl (John Linville) [766952]
- [netdrv] drivers/net/wireless/ath: remove references to carl9170 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/ath/ar9170 from commit 7bb45683 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/libertas_tf from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/iwmc3200wifi from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/ipw2x00 from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/rndis_wlan.c from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/mwl8k.c from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/mac80211_hwsim.* from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/at76c50x-usb.* from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/adm8211.* from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/zd1211rw from linux 3.2.6 (John Linville) [766952]
- [netdrv] Add drivers/net/wireless/wl1251 from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/wl12xx from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/rtl818x from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/rt2x00 from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/p54 from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/b43legacy from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/b43 from linux 3.2.6 (John Linville) [766952]
- [ssb] Rebase drivers/ssb from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/ath/ath5k from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/ath/ath9k from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/ath from linux 3.2.6 (John Linville) [766952]
- [netdrv] Add drivers/net/wireless/iwlegacy from linux 3.2.6 (John Linville) [766952]
- [netdrv] Rebase drivers/net/wireless/iwlwifi from linux 3.2.6 (John Linville) [735934 735936 735939 766952 770780]
- [net] Rebase net/mac80211 from linux 3.2.6 (John Linville) [766952]
- [net] Rebase net/wireless from linux 3.2.6 (John Linville) [766952]
- [net] introduce NETDEV_POST_INIT notifier (John Linville) [766952]
- [net] bridge: support IFF_DONT_BRIDGE (John Linville) [766952]
- [usb] Add a usb_pipe_endpoint() convenience function (John Linville) [766952]
- [kernel] compiler: Introduce __always_unused (John Linville) [766952]
- [netdrv] eeprom_93cx6: Add support for 93c86 EEPROMs (John Linville) [766952]
- [netdrv] if_ether.h: add definition of ETH_P_TDLS (John Linville) [766952]
- [kernel] Cherry-pick core bits of "bitops: rename for_each_bit() to for_each_set_bit()" (John Linville) [766952]
- [kernel] Cherry-pick the core bits of "bitops: Provide generic sign_extend32 function" (John Linville) [766952]
- [dma] dma-mapping.h: add the dma_unmap state API (John Linville) [766952]
- [pci] pci-dma: add include/linux/pci-dma.h (John Linville) [766952]
- [kernel] lib: Improve EWMA efficiency by using bitshifts (John Linville) [766952]
- [kernel] lib: Add generic exponentially weighted moving average (EWMA) function (John Linville) [766952]

* Tue Feb 28 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-244.el6]
- [virt] virtio-scsi: add power management (Paolo Bonzini) [782027]
- [virt] virtio-scsi: add driver (Paolo Bonzini) [782027]
- [fs] CIFS: Fix DFS handling in cifs_get_file_info (Jarod Wilson) [786989]
- [fs] CIFS: fix automount for DFS shares (Jarod Wilson) [786989]
- [fs] cifs: don't overwrite dentry name in d_revalidate (Jarod Wilson) [786989]
- [fs] cifs: demote DFS referral lookup errors to cFYI (Jarod Wilson) [786989]
- [fs] cifs: Unconditionally copy mount options to superblock info (Jarod Wilson) [786989]
- [fs] cifs: Use kstrndup for cifs_sb->mountdata (Jarod Wilson) [786989]
- [fs] cifs: Simplify handling of submount options in cifs_mount (Jarod Wilson) [786989]
- [fs] cifs: do not tokenize mount options in-place (Jarod Wilson) [786989]
- [fs] cifs: Add support for mounting Windows 2008 DFS shares (Jarod Wilson) [786989]
- [fs] cifs: Extract DFS referral expansion logic to separate function (Jarod Wilson) [786989]
- [drm] rebase upstream fixes (Dave Airlie) [797142]
- [drm] rebase for RHEL 6.3 (Dave Airlie) [786494]
- [kernel] swiotlb: export swiotlb_nr_tbl backport (Dave Airlie) [786494]
- [pci] msi: fix imbalanced refcount of msi irq sysfs objects (Prarit Bhargava) [794767]
- [pci] sysfs: add per pci device msi[x] irq listing (Prarit Bhargava) [794767]
- [mm] vmscan: immediately reclaim end-of-LRU dirty pages when writeback completes (Satoru Moriya) [788536]
- [mm] vmscan: throttle reclaim if encountering too many dirty pages under writeback (Satoru Moriya) [788536]
- [mm] vmscan: do not writeback filesystem pages in kswapd except in high priority (Satoru Moriya) [788536]
- [fs] ext4: warn if direct reclaim tries to writeback pages (Satoru Moriya) [788536]
- [fs] xfs: warn if direct reclaim tries to writeback pages (Satoru Moriya) [788536]
- [mm] vmscan: remove dead code related to lumpy reclaim waiting on pages under writeback (Satoru Moriya) [788536]
- [mm] vmscan: do not writeback filesystem pages in direct reclaim (Satoru Moriya) [788536]
- [security] audit: fix signedness bug in audit_log_execve_info() (Eric Paris) [661765]
- [security] audit: comparison on interprocess fields (Eric Paris) [661765]
- [security] audit: implement all object interfield comparisons (Eric Paris) [661765]
- [security] audit: allow interfield comparison between gid and ogid (Eric Paris) [661765]
- [security] audit: complex interfield comparison helper (Eric Paris) [661765]
- [security] audit: allow interfield comparison in audit rules (Eric Paris) [661765]
- [security] audit: allow audit matching on inode gid (Eric Paris) [661765]
- [audit] allow matching on obj_uid (Eric Paris) [661765]
- [security] audit: check current inode and containing object when filtering on major and minor (Eric Paris) [661765]
- [security] audit: make filetype matching consistent with other filters (Eric Paris) [661765]
- [ppc] Reserve iommu page 0 (Steve Best) [784088]
- [fs] fuse: add O_DIRECT support (Josef Bacik) [753798]
- [bluetooth] Add support for Broadcom BCM20702A0 (Don Zickus) [746041]
- [kernel] sysctl: restrict write access to dmesg_restrict (Phillip Lougher) [749251]

* Tue Feb 28 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-243.el6]
- [pci] RH backport changes for MaxPayload patchset (Shyam Iyer) [692531]
- [pci] Clean-up MPS debug output (Shyam Iyer) [692531]
- [pci] Clamp pcie_set_readrq() when using "performance" settings (Shyam Iyer) [692531]
- [pci] enable MPS "performance" setting to properly handle bridge MPS (Shyam Iyer) [692531]
- [pci] Workaround for Intel MPS errata (Shyam Iyer) [692531]
- [pci] Disable MPS configuration by default (Shyam Iyer) [692531]
- [pci] Don't crash when reading mpss from root complex (Shyam Iyer) [692531]
- [pci] Remove MRRS modification from MPS setting code (Shyam Iyer) [692531]
- [pci] Fix pointer dereference before call to pcie_bus_configure_settings (Shyam Iyer) [692531]
- [pci] set PCI-E Max Payload Size on fabric (Shyam Iyer) [692531]
- [pci] correct pcie_set_readrq write size (Shyam Iyer) [692531]
- [pci] Set PCIE maxpayload for card during hotplug insertion (Shyam Iyer) [692531]
- [netdrv] cxgb4: add latest upstream firmware (Neil Horman) [747141]
- [netdrv] cxgb4: Update to latest upstream version (Neil Horman) [747141]
- [block] dm io: fix discard support (Mike Snitzer) [758404]
- [block] dm thin: add call to mark_tech_preview (Mike Snitzer) [790618]
- [block] dm raid: remove call to mark_tech_preview (Mike Snitzer) [790618]
- [block] dm thin metadata: decrement counter after removing mapped block (Mike Snitzer) [790618]
- [block] dm thin metadata: unlock superblock in init_pmd error path (Mike Snitzer) [790618]
- [block] dm thin metadata: remove incorrect close_device on creation error paths (Mike Snitzer) [790618]
- [block] dm ioctl: do not leak argv if target message only-contains whitespace (Mike Snitzer) [790618]
- [fs] ext3: fix start and len arguments handling in ext3_trim_fs() (Lukas Czerner) [767219]
- [fs] ext3: Add fixed tracepoints - batched_discard (Lukas Czerner) [786987]
- [fs] ext3/ioctl.c: silence sparse warnings about different address spaces (Lukas Czerner) [786987]
- [fs] ext3/balloc.c: local functions should be static (Lukas Czerner) [786987]
- [fs] ext3: Return -EINVAL when start is beyond the end of fs in ext3_trim_fs() (Lukas Czerner) [786987]
- [fs] ext3: Fix an overflow in ext3_trim_fs (Lukas Czerner) [786987]
- [fs] ext3: speed up group trim with the right free block count (Lukas Czerner) [786987]
- [fs] ext3: Adjust trim start with first_data_block (Lukas Czerner) [786987]
- [fs] ext3: Add FITRIM handling (Lukas Czerner) [786987]
- [fs] ext3: Add batched discard support for ext3 (Lukas Czerner) [786987]
- [fs] NFS: Optimise away unnecessary setattrs for open(O_TRUNC) (J. Bruce Fields) [636590]
- [s390x] kdump: Add s390 description to kernel documentation (Hendrik Brueckner) [738862]
- [net] bridge: Reset IPCB when entering IP stack (Herbert Xu) [717407]
- [net] netlink: wrong size was calculated for vfinfo list blob (Andy Gospodarek) [772136]
- [net] sctp: implement event notification SCTP_SENDER_DRY_EVENT (Thomas Graf) [787652]
- [net] ipv6: fix default multicast hops setting (Jiri Benc) [767435]
- [scsi] libfcoe: Do not sends FDISCs before FLOGI during CVL (Neil Horman) [790942]
- [misc] hpilo: Increase number of channels (Tony Camuso) [737920]
- [fs] dlm: fix kmalloc args (David Teigland) [752539]
- [block] cciss: add some older controllers to the kdump blacklist (Tomas Henzl) [738930]
- [netdrv] 8139cp: properly config rx mode after resuming (Jason Wang) [665515]
- [netdrv] mlx4_en: fix endianness with blue frame support (Steve Best) [750166]
- [mm] remove debug printk's from memory_hotplug.c (Hendrik Brueckner) [738862]

* Mon Feb 27 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-242.el6]
- [kernel] kmsg_dump: Don't run on non-error paths by default (Seiji Aguchi) [696394]
- [kernel] kmsg_dump: add kmsg_dump() calls to the reboot, halt, poweroff and emergency_restart paths (Seiji Aguchi) [696394]
- [net] af_iucv: offer new getsockopt SO_MSGSIZE (Hendrik Brueckner) [786997]
- [net] af_iucv: performance improvements for new HS transport (Hendrik Brueckner) [786996]
- [s390x] qeth: Fix recovery in case of concurrent asynchronous deliveries (Hendrik Brueckner) [786958]
- [s390x] af_iucv: remove IUCV-pathes completely (Hendrik Brueckner) [786960]
- [kdump] Define KEXEC_NOTE_BYTES arch specific for s390x (Hendrik Brueckner) [786959]
- [s390x] dasd: fix expiration handling for recovery requests (Hendrik Brueckner) [768890]
- [kernel] console interrupts vs. panic (Hendrik Brueckner) [768891]
- [fs] ext4: fix start and len arguments handling in ext4_trim_fs() (Lukas Czerner) [767219]
- [block] blkdev: Do not return -EOPNOTSUPP if discard is supported (Lukas Czerner) [767219]
- [block] blkdev: Submit discard bio in batches in blkdev_issue_discard() (Lukas Czerner) [767219]
- [fs] ext4: Adjust minlen with discard_granularity in the FITRIM ioctl (Lukas Czerner) [767219]
- [fs] ext4: add FITRIM to compat_ioctl (Lukas Czerner) [767219]
- [fs] ext4: check if device support discard in FITRIM ioctl (Lukas Czerner) [767219]
- [fs] ext4: Change the wrong param comment for ext4_trim_all_free (Lukas Czerner) [767219]
- [fs] ext4: Speed up FITRIM by recording flags in ext4_group_info (Lukas Czerner) [767219]
- [fs] ext4: Add new ext4 trim tracepoints (Lukas Czerner) [767219]
- [fs] ext4: speed up group trim with the right free block count (Lukas Czerner) [767219]
- [fs] ext4: fix trim length underflow with small trim length (Lukas Czerner) [767219]
- [fs] ext4: protect bb_first_free in ext4_trim_all_free() with group lock (Lukas Czerner) [767219]
- [fs] ext4: only load buddy bitmap in ext4_trim_fs() when it is needed (Lukas Czerner) [767219]
- [fs] ext4: ignore errors when issuing discards (Lukas Czerner) [767219]
- [fs] ext4: fix a BUG in mb_mark_used during trim (Lukas Czerner) [767219]
- [s390x] config: Add kdump kernel config options for s390 (Hendrik Brueckner) [738862]
- [s390x] kdump: Add KEXEC_AUTO_RESERVE for s390 (Hendrik Brueckner) [738862]
- [s390x] zfcpdump: Do not initialize zfcpdump in kdump mode (Hendrik Brueckner) [738862]
- [s390x] crashkernel: Add arch code for unmapping crashkernel memory (Hendrik Brueckner) [738862]
- [s390x] kernel: kdump backend code (Hendrik Brueckner) [738862]
- [s390x] zcore: Add real memory access functions (Hendrik Brueckner) [738862]
- [s390x] Add PSW restart shutdown trigger (Hendrik Brueckner) [738862]
- [s390x] kernel: Use diagnose 308 for system reset (Hendrik Brueckner) [738862]
- [mm] Replace diag10() with diag10_range() function (Hendrik Brueckner) [738862]
- [kexec] reipl: Export do_store_status() function (Hendrik Brueckner) [738862]
- [kexec] crashk_res init check for /sys/kernel/kexec_crash_size (Hendrik Brueckner) [738862]
- [kexec] Add missing RAM resource in crash_shrink_memory() (Hendrik Brueckner) [738862]
- [kernel] Create udev events for memory hotplug (Hendrik Brueckner) [738862]
- [kexec] fix crash_kexec()/smp_send_stop() race in panic (Hendrik Brueckner) [738862]
- [kexec] Add infrastructure for unmapping crashkernel memory (Hendrik Brueckner) [738862]
- [kexec] Initialize vmcoreinfo note at startup (Hendrik Brueckner) [738862]
- [kexec] Add KEXEC_CRASH_CONTROL_MEMORY_LIMIT (Hendrik Brueckner) [738862]
- [pci] Disable this patch set's SRIOV reallocation unless booted with pci=realloc (James Takahashi) [587729]
- [pci] update bridge resources to get more big ranges (James Takahashi) [587729]
- [pci] PCI-Clear-bridge-resource-flags-if-requested (James Takahashi) [587729]
- [pci] bus allocation alignment handling (James Takahashi) [587729]
- [pci] pre-allocate additional resources to devices only after successful allocation of essential resources (James Takahashi) [587729]
- [pci] introduce reset_resource (James Takahashi) [587729]
- [pci] data structure agnostic free list function (James Takahashi) [587729]
- [pci] refactor io size calculation code (James Takahashi) [587729]
- [pci] don't shrink bridge resources (James Takahashi) [587729]
- [sound] ALSA: enable OSS emulation layer for PCM and mixer (Jaroslav Kysela) [657291]
- [fs] Stable page cache to better support T10/DIF (Data Integrity storage) (Steve Best) [706189]
- [char] ipmi: Decrease the IPMI message transaction time in interrupt mode (Shyam Iyer) [739359]
- [security] IMA: fix audit res field to indicate 1 for success and 0 for failure (Eric Paris) [784351]
- [mm] fix nrpages assertion (Josef Bacik) [766861]
- [mm] Eliminate possible panic in page compaction code (Larry Woodman) [714902 755885]
- [mm] Prevent panic on 2-node x3850 X5 w/2 MAX5 memory drawers panics while running certification tests caused by page list corruption (Larry Woodman) [755885]

* Sat Feb 25 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-241.el6]
- [netdrv] netdev: ethernet dev_alloc_skb to netdev_alloc_skb (Veaceslav Falico) [722304]
- [netdrv] netxen_nic: signedness bug in netxen_md_entry_err_chk() (Veaceslav Falico) [722304]
- [netdrv] netxen: report valid speed and duplex status when link is down (Veaceslav Falico) [722304]
- [netdrv] netxen: Fix a panic during driver unload in device_remove_file (Veaceslav Falico) [722304]
- [netdrv] netxen_nic: Error logging on firmware hang (Veaceslav Falico) [722304]
- [netdrv] netxen_nic: Fix phy link status (Veaceslav Falico) [722304]
- [netdrv] netxen_nic: fw dump support (Veaceslav Falico) [722304]
- [netdrv] netxen_nic: fix cdrp race condition (Veaceslav Falico) [722304]
- [netdrv] netxen: Remove alloc_etherdev error messages (Veaceslav Falico) [722304]
- [netdrv] netxen: convert .get_drvinfo routine to strlcpy (Veaceslav Falico) [722304]
- [netdrv] netxen: Remove unnecessary driver assignments of ethtool_ringparam fields to zero (Veaceslav Falico) [722304]
- [mm] thp: fix BUG on mm->nr_ptes (Andrea Arcangeli) [794497]
- [x86] ACPI, APEI, ERST, Fix erst-dbg long record reading issue (Don Zickus) [728993]
- [x86] ACPI, APEI, ERST, Prevent erst_dbg from loading if ERST is disabled (Don Zickus) [728993]
- [netdrv] cnic: update for RHEL6.3, part 2 (Michal Schmidt) [740048]
- [netdrv] bnx2x: update for RHEL6.3 (Michal Schmidt) [741676]
- [netdrv] cnic, bnx2fc: update for RHEL6.3, part 1 (Michal Schmidt) [740048]
- [net] introduce build_skb() (Michal Schmidt) [741676]
- [net] more accurate skb truesize (Michal Schmidt) [741676]
- [net] skbuff: add skb frag size accessors (Michal Schmidt) [741676]
- [netdrv] bnx2x, cnic: update to current upstream (Michal Schmidt)
- [s390x] qeth: improve recovery during resource shortage (Hendrik Brueckner) [766785]
- [s390x] qeth: support ipv6 query arp cache for HiperSockets (Hendrik Brueckner) [738874]
- [s390x] qeth: add OSA concurrent hardware trap (Hendrik Brueckner) [738861]
- [s390x] dasd: add enhanced DASD statistics interface (Hendrik Brueckner) [738871]
- [kernel] mutex: Introduce arch_mutex_cpu_relax() (Hendrik Brueckner) [738872]
- [s390x] ap: Setup timer for sending messages after reset (Hendrik Brueckner) [760544]
- [s390x] cio: disallow driver io for known to be broken paths (Hendrik Brueckner) [765810]
- [netdrv] qeth: forbid recovery during shutdown (Hendrik Brueckner) [765809]
- [netdrv] qeth: reduce SIGA-r to avoid CPU cost implications (Hendrik Brueckner) [765808]
- [kernel] cpu hotplug vs missing pfault completion interrupts (Hendrik Brueckner) [753080]
- [scsi] aacraid: fix return value (Tomas Henzl) [741724]
- [scsi] aacraid: Add new code for PMC-Sierra's SRC based controller family (Tomas Henzl) [741724]
- [scsi] aacraid: fix File System going into read-only mode (Tomas Henzl) [640011]
- [scsi] mpt2sas: add missing allocation check (Tomas Henzl) [736229]
- [scsi] mpt2sas: Remove unused duplicate diag_buffer_enable param (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fix possible integer truncation of cpu_count (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fix leak on mpt2sas_base_attach() error path (Tomas Henzl) [736229]
- [scsi] mpt2sas: Removed redundant calling of _scsih_probe_devices() from _scsih_probe (Tomas Henzl) [736229]
- [scsi] mpt2sas: Bump driver vesion to 12.101.00.00 (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fix for memory allocation error for large host credits (Tomas Henzl) [736229]
- [scsi] mpt2sas: Do not retry a timed out direct IO for warpdrive (Tomas Henzl) [736229]
- [scsi] mpt2sas: Release spinlock for the raid device list before blocking it (Tomas Henzl) [736229]
- [scsi] mpt2sas: MPI next revision header update (Tomas Henzl) [736229]
- [scsi] mpt2sas: Added support for customer specific branding (Tomas Henzl) [736229]
- [scsi] mpt2sas: Increase max transfer support from 4MB to 16MB (Tomas Henzl) [736229]
- [scsi] mpt2sas: Support for greater than 2TB capacity WarpDrive (Tomas Henzl) [736229]
- [scsi] mpt2sas: Rearrange the the code so that the completion queues are initialized prior to sending the request to controller firmware (Tomas Henzl) [736229]
- [scsi] mpt2sas: Do not set sas_device->starget to NULL from the slave_destroy callback when all the LUNS have been deleted (Tomas Henzl) [736229]
- [scsi] mpt2sas: MPI next revision header update (Tomas Henzl) [736229]
- [scsi] mpt2sas: Added support for customer specific branding (Tomas Henzl) [736229]
- [scsi] mpt2sas: When IOs are terminated, update the result to DID_SOFT_ERROR to avoid infinite resets (Tomas Henzl) [736229]
- [scsi] mpt2sas: Better handling DEAD IOC (PCI-E LInk down) error condition (Tomas Henzl) [736229]
- [scsi] mpt2sas: _scsih_smart_predicted_fault uses GFP_KERNEL in interrupt context (Tomas Henzl) [736229]
- [scsi] mpt2sas: add missing allocation (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fix for issue - Panic when inactive volume is tried deleting (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fix for issue Port Reset is taking long time to complete while issued during creating a volume (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fix for issue deadlock between hot plug worker threads and host reset context (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fix for dead lock occurring between host_lock and sas_device_lock (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fix drives not getting properly deleted if sas cable is removed while host reset is active (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fix failure message displayed during diag reset (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fix for system hang when discovery in progress (Tomas Henzl) [736229]
- [scsi] mpt2sas: Fast Load Support (Tomas Henzl) [736229]
- [scsi] mpt2sas : MPI next revision header update (Tomas Henzl) [736229]
- [scsi] mpt2sas: take size of pointed value, not pointer (Tomas Henzl) [736229]
- [scsi] mpt2sas: Added NUNA IO support in driver which uses multi-reply queue support of the HBA (Tomas Henzl) [736229]
- [scsi] mptsas: Add device ID for SAS1068_820XELP (Tomas Henzl) [735895]
- [scsi] mptsas: ensure NUL-termination of MptCallbacksName elements (Tomas Henzl) [735895]
- [scsi] mptfusion: Fix for device offline while doing aggressive HBA reset (Tomas Henzl) [735895]
- [scsi] mptfusion: Bump version 3.4.20 (Tomas Henzl) [735895]
- [scsi] mptfusion: Avoid out of order Event processing due to cpu migration (Tomas Henzl) [735895]
- [scsi] mptfusion: Set max sector count module parameter (Tomas Henzl) [735895]
- [scsi] mptfusion: Added check for SILI bit in READ_6 CDB for DATA UNDERRUN ERRATA (Tomas Henzl) [735895]
- [scsi] mptsas: Fix annoying warning (Tomas Henzl) [735895]
- [input] ALPS: add support for protocol versions 3 and 4 (John Feeney) [637229]
- [input] ALPS: remove assumptions about packet size (John Feeney) [637229]
- [input] ALPS: add protocol version field in alps_model_info (John Feeney) [637229]
- [input] ALPS: fix stuck buttons on some touchpads (John Feeney) [637229]
- [input] ALPS: do not set REL_X/REL_Y capabilities on the touchpad (John Feeney) [637229]
- [input] ALPS: add support for touchpads with 4-directional button (John Feeney) [637229]
- [input] ALPS: move protocol information to Documentation (John Feeney) [637229]
- [ppc] mpic: Fix problem that affinity is not updated (Steve Best) [738451]
- [sound] alsa: enable snd-cmipci driver (Jaroslav Kysela) [661316]
- [fs] procfs: return ENOENT on opening a being-removed proc entry (Neil Horman) [735881]
- [fs] pnfs: simplify pnfs files module autoloading (Steve Dickson) [790961]
- [fs] GFS2: panic during glock reclaim, ref count 0 (Steven Whitehouse) [781468]
- [s390x] ap: Setup timer for processing messages in request queue (Hendrik Brueckner) [753085]
- [kernel] ulimit: raise default hard ulimit on number of files to 4096 (Jarod Wilson) [786307]
- [kernel] time: cast jiffies_to_clock_t() argument to unsigned long (Prarit Bhargava) [783401]
- [kernel] watchdog: softdog.c: enhancement to optionally invoke panic instead of reboot on timer expiry (Don Zickus) [738894]
- [kernel] Prevent system hang and eventual crash when using CPU cgroups (Larry Woodman) [790945]
- [usb] Fix deadlock in hid_reset when Dell iDRAC is reset (Shyam Iyer) [782374]
- [dm] RAID: Print correct status characters (Jonathan E Brassow) [749684]
- [virt] vmxnet3: Cap the length of the pskb_may_pull on transmit (bz 790673) (Neil Horman) [790673]
- [mm] shmem: reduce pagefault lock contention (Jarod Wilson) [786320]
- [x86] Fix i386 debug kernel fails to boot on some systems (Larry Woodman) [773138]
- [mm] memcg: add memcg sanity checks at allocating and freeing pages (Johannes Weiner) [752137]

* Fri Feb 24 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-240.el6]
- [pci] use security_capable() when checking capablities during config space read (Eric Paris) [596419]
- [security] add cred argument to security_capable() (Eric Paris) [596419]
- [scsi] qla2xxx: Update LICENSE.qla2xxx (Chad Dupuis) [722295]
- [scsi] qla2xxx: Update version number to 8.04.00.02.06.3-k. (Chad Dupuis) [722295]
- [scsi] qla2xxx: Avoid invalid request queue dereference for bad response packets (Chad Dupuis) [722295]
- [scsi] qla2xxx: Stop iteration after first failure in *_id functions (Chad Dupuis) [722295]
- [scsi] qla2xxx: Fix incorrect register access in qla2x00_start_iocbs() (Chad Dupuis) [722295]
- [scsi] qla2xxx: Handle device mapping changes due to device logout (Chad Dupuis) [722295]
- [scsi] qla2xxx: Complete mailbox command timedout to avoid initialization failures during next reset cycle (Chad Dupuis) [722295]
- [scsi] qla2xxx: Add ha->max_fibre_devices to keep track of the maximum number of targets (Chad Dupuis) [722295]
- [scsi] qla2xxx: Cache swl during fabric discovery (Chad Dupuis) [722295]
- [scsi] qla2xxx: Remove EDC sysfs interface (Chad Dupuis) [722295]
- [scsi] qla2xxx: Perform firmware dump procedure on mailbox command timeout (Chad Dupuis) [722295]
- [scsi] qla2xxx: Change the log message when previous dump is available to retrieve for ISP82xx (Chad Dupuis) [722295]
- [scsi] qla2xxx: Log messages to use correct vha (Chad Dupuis) [722295]
- [scsi] qla2xxx: Add new message when a new loopid is assigned (Chad Dupuis) [722295]
- [scsi] qla2xxx: Fix ql_dbg arguments (Chad Dupuis) [722295]
- [scsi] qla2xxx: Use ql_log* (Chad Dupuis) [722295]
- [scsi] qla2xxx: Convert remaining printk's to ql_log format (Chad Dupuis) [722295]
- [scsi] qla2xxx: Print mailbox command opcode and return code when a command times out (Chad Dupuis) [722295]
- [scsi] qla2xxx: Correct out of bounds read of ISP2200 mailbox registers (Chad Dupuis) [722295]
- [scsi] qla2xxx: Remove errant clearing of MBX_INTERRUPT flag during CT-IOCB processing (Chad Dupuis) [722295]
- [scsi] qla2xxx: Reduce mbx-command timeout for Login/Logout requests (Chad Dupuis) [722295]
- [scsi] qla2xxx: Clear options-flags while issuing stop-firmware mbx command (Chad Dupuis) [722295]
- [scsi] qla2xxx: Add an "is reset active" helper (Chad Dupuis) [722295]
- [scsi] qla2xxx: Prep zero-length BSG data-transfer requests (Chad Dupuis) [722295]
- [scsi] qla2xxx: Fix byte swapping in IPE print statement (Chad Dupuis) [722295]
- [scsi] qla2xxx: Handle failure cases during fabric_login (Chad Dupuis) [722295]
- [scsi] qla2xxx: Increase speed of flash access in ISP82xx adapters to improve firmware load speed (Chad Dupuis) [722295]
- [scsi] qla2xxx: Add check for null fcport references in qla2xxx_queuecommand (Chad Dupuis) [722295]
- [scsi] qla2xxx: Handle change notifications based on switch scan results (Chad Dupuis) [722295]
- [scsi] qla2xxx: Correct print format for edc ql_log() calls (Chad Dupuis) [722295]
- [scsi] qla2xxx: Use consistent DL mask for ELS/CT passthru requests (Chad Dupuis) [722295]
- [scsi] qla2xxx: Consolidation of SRB processing (Chad Dupuis) [722295]
- [scsi] qla2xxx: Use a valid enode-mac if none defined (Chad Dupuis) [722295]
- [scsi] qla2xxx: Propagate up abort failures (Chad Dupuis) [722295]
- [scsi] qla2xxx: Add vmalloc.h include to qla_nx.c (Chad Dupuis) [722295]
- [scsi] qla2xxx: Enhancements to support ISP83xx (Chad Dupuis) [722295]
- [scsi] qla2xxx: Enhanced the dump routines to capture multiple request and response queues (Chad Dupuis) [722295]
- [scsi] qla2xxx: Disable generating pause frames when firmware hang detected for ISP82xx (Chad Dupuis) [722295]
- [scsi] qla2xxx: Do not check for minidump when device state is QLA82XX_DEV_READY (Chad Dupuis) [722295]
- [scsi] qla2xxx: Clear mailbox busy flag during premature mailbox completion for ISP82xx (Chad Dupuis) [722295]
- [scsi] qla2xxx: Encapsulate prematurely completing mailbox commands during ISP82xx firmware hang (Chad Dupuis) [722295]
- [scsi] qla2xxx: Display IPE error message for ISP82xx (Chad Dupuis) [722295]
- [scsi] qla2xxx: Return the correct value for a mailbox command if 82xx is in reset recovery (Chad Dupuis) [722295]
- [scsi] qla2xxx: Fix "active_mask" may be used uninitialized warning (Chad Dupuis) [722295]
- [scsi] qla2xxx: Correct fc_host port_state display (Chad Dupuis) [722295]
- [scsi] qla2xxx: Move initialization of some variables before iospace_config (Chad Dupuis) [722295]
- [scsi] qla2xxx: Enable Minidump by default with default capture mask 0x1f (Chad Dupuis) [722295]
- [scsi] qla2xxx: Stop unconditional completion of mailbox commands issued in interrupt mode during firmware hang (Chad Dupuis) [722295]
- [scsi] fix qla2xxx printk format warning (Chad Dupuis) [722295]
- [scsi] qla2xxx: Ensure there's enough request-queue space for passthru IOCBs (Chad Dupuis) [722295]
- [scsi] qla2xxx: Fix crash in qla2x00_abort_all_cmds() on unload (Chad Dupuis) [722295]
- [scsi] qla2xxx: Implement FCP priority tagging for 82xx adapters (Chad Dupuis) [722295]
- [scsi] qla2xxx: Revert back the request queue mapping to request queue 0 (Chad Dupuis) [722295]
- [scsi] qla2xxx: Consolidated IOCB processing routines (Chad Dupuis) [722295]
- [scsi] qla2xxx: Process marker IOCB request on request queue 0 (Chad Dupuis) [722295]
- [scsi] qla2xxx: Added a new entry to ISP specific function pointers structure (Chad Dupuis) [722295]
- [scsi] qla2xxx: Submit all chained IOCBs for passthrough commands on Request queue 0 (Chad Dupuis) [722295]
- [scsi] qla2xxx: Corrected the display of firmware dump availability for ISP82xx (Chad Dupuis) [722295]
- [scsi] qla2xxx: Corrected the default setting of the help text of Minidump capture mask (Chad Dupuis) [722295]
- [scsi] qla2xxx: Corrections to returned sysfs error codes (Chad Dupuis) [722295]
- [scsi] qla2xxx: Correct report-id acquisiton check (Chad Dupuis) [722295]
- [scsi] qla2xxx: Fix to include FCE data as part of dump (Chad Dupuis) [722295]
- [scsi] qla2xxx: Limit excessive DPC cycles (Chad Dupuis) [722295]
- [scsi] qla2xxx: Fix race that could hang kthread_stop() (Chad Dupuis) [722295]
- [scsi] qla2xxx: Only read requested mailbox registers (Chad Dupuis) [722295]
- [scsi] qla2xxx: Proper cleanup of pass through commands when firmware returns error (Chad Dupuis) [722295]
- [scsi] qla2xxx: Update to dynamic logging (Chad Dupuis) [722295]
- [scsi] qla2xxx: Add dynamic logging (Chad Dupuis) [722295]
- [scsi] qla2xxx: Queue depth ramp up/down modification changes (Chad Dupuis) [722295]
- [scsi] qla2xxx: Check for SCSI status on underruns (Chad Dupuis) [722295]
- [scsi] qla2xxx: Display FCP_CMND priority on update (Chad Dupuis) [722295]
- [scsi] qla2xxx: Remove qla2x00_wait_for_loop_ready function (Chad Dupuis) [722295]
- [scsi] qla2xxx: Don't call alloc_fw_dump for ISP82XX (Chad Dupuis) [722295]
- [scsi] qla2xxx: Issue mailbox command only when firmware hung bit is reset for ISP82xx (Chad Dupuis) [722295]
- [scsi] qla2xxx: Return sysfs error codes appropriate to conditions (Chad Dupuis) [722295]
- [scsi] qla2xxx: Correct inadvertent loop state transitions during port-update handling (Chad Dupuis) [722295]
- [scsi] qla2xxx: Set the task attributes after memsetting fcp cmnd (Chad Dupuis) [722295]
- [scsi] qla2xxx: Provide method for updating I2C attached VPD (Chad Dupuis) [722295]
- [scsi] qla2xxx: Enable write permission to some debug related module parameters to be changed dynamically (Chad Dupuis) [722295]
- [scsi] qla2xxx: Add support for ISP82xx to capture dump (minidump) on failure (Chad Dupuis) [722295]
- [scsi] qla2xxx: T10 DIF - Fix incorrect error reporting (Chad Dupuis) [722295]
- [scsi] qla2xxx: T10 DIF - Handle uninitalized sectors (Chad Dupuis) [722295]
- [scsi] qla2xxx: Double check for command completion if abort mailbox command fails (Chad Dupuis) [722295]
- [scsi] qla2xxx: Implemeted beacon on/off for ISP82XX (Chad Dupuis) [722295]
- [scsi] qla2xxx: Fix qla24xx revision check while enabling interrupts (Chad Dupuis) [722295]
- [scsi] qla2xxx: check for marker IOCB during response queue processing (Chad Dupuis) [722295]
- [scsi] qla2xxx: Acquire hardware lock while manipulating dsd list (Chad Dupuis) [722295]
- [scsi] qla2xxx: Fix array out of bound warning (Chad Dupuis) [722295]
- [scsi] qla2xxx: Prevent CPU lockups when "ql2xdontresethba" module param is set (Chad Dupuis) [722295]
- [scsi] qla2xxx: Save and restore irq in the response queue interrupt handler (Chad Dupuis) [722295]
- [scsi] qla2xxx: During loopdown perform Diagnostic loopback (Chad Dupuis) [722295]

* Fri Feb 24 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-239.el6]
- [scsi] libsas: convert to standard kernel debugging (David Milburn) [782929]
- [scsi] libsas: dynamic queue depth (David Milburn) [782929]
- [scsi] libsas, libata: fix ->change_queue_{depth|type} for sata devices (David Milburn) [782929]
- [scsi] libsas: fix panic when single phy is disabled on a wide port (David Milburn) [782929]
- [scsi] libsas: fix failure to revalidate domain for anything but the first expander child (David Milburn) [782929]
- [scsi] libsas: async ata scanning (David Milburn) [782929]
- [scsi] mvsas: remove mvs_slave_{alloc|configure} (David Milburn) [782929]
- [scsi] libsas: revert ata srst (David Milburn) [782929]
- [scsi] libsas: fix lifetime of SAS_HA_FROZEN (David Milburn) [782929]
- [scsi] libsas: restore scan order (David Milburn) [782929]
- [scsi] libsas: delete device on sas address changed (David Milburn) [782929]
- [scsi] libsas: let libata recover links that fail to transmit initial sig-fis (David Milburn) [782929]
- [scsi] libsas: set sas_address and device type of rphy (David Milburn) [782929]
- [scsi] libsas: fix sas port naming (David Milburn) [782929]
- [scsi] libsas: improve debug statements (David Milburn) [782929]
- [scsi] libsas: kill spurious sas_put_device (David Milburn) [782929]
- [scsi] libsas: fix sas_unregister_ports vs sas_drain_work (David Milburn) [782929]
- [scsi] libsas: route local link resets through ata-eh (David Milburn) [782929]
- [scsi] libsas: fix mixed topology recovery (David Milburn) [782929]
- [scsi] libsas: close scsi_remove_target() vs libata-eh race (David Milburn) [782929]
- [scsi] libsas: mark all domain devices gone if root port disappears (David Milburn) [782929]
- [scsi] libsas: pre-clean commands that won the eh vs completion race (David Milburn) [782929]
- [scsi] isci: remove IDEV_EH hack to disable "discovery-time" ata resets (David Milburn) [782929]
- [scsi] isci: remove bus and reset handlers (David Milburn) [782929]
- [scsi] isci: ->lldd_ata_check_ready handler (David Milburn) [782929]
- [scsi] isci: stop interpreting ->lldd_lu_reset() as an ata soft-reset (David Milburn) [782929]
- [scsi] isci: fix interpretation of "hard" reset (David Milburn) [782929]
- [scsi] isci: kill isci_port->status (David Milburn) [782929]
- [scsi] libsas: don't recover 'gone' devices in sas_ata_hard_reset() (David Milburn) [782929]
- [scsi] libsas: fix sas_find_local_phy(), take phy references (David Milburn) [782929]
- [scsi] libsas: check for 'gone' expanders in smp_execute_task() (David Milburn) [782929]
- [scsi] libsas: don't mark expanders as gone when a child device is removed (David Milburn) [782929]
- [scsi] libsas: poll for ata device readiness after reset (David Milburn) [782929]
- [scsi] libsas: async ata-eh (David Milburn) [782929]
- [scsi] libsas: add mutex for SMP task execution (David Milburn) [782929]
- [scsi] libsas: Remove redundant phy state notification calls (David Milburn) [782929]
- [scsi] libsas: sas_phy_enable via transport_sas_phy_reset (David Milburn) [782929]
- [scsi] libsas: execute transport link resets with libata-eh via host workqueue (David Milburn) [782929]
- [scsi] libsas: perform sas-transport resets in shost->workq context (David Milburn) [782929]
- [scsi] libsas: use libata-eh-reset for sata rediscovery fis transmit failures (David Milburn) [782929]
- [scsi] libsas: defer SAS_TASK_NEED_DEV_RESET commands to libata (David Milburn) [782929]
- [scsi] libsas: let libata handle command timeouts (David Milburn) [782929]
- [scsi] libsas: fix timeout vs completion race (David Milburn) [782929]
- [scsi] libsas: prevent double completion of scmds from eh (David Milburn) [782929]
- [scsi] libsas: close error handling vs sas_ata_task_done() race (David Milburn) [782929]
- [scsi] libsas: kill invocation of scsi_eh_finish_cmd from sas_ata_task_done (David Milburn) [782929]
- [scsi] libsas: use ->set_dmamode to notify lldds of NCQ parameters (David Milburn) [782929]
- [scsi] libsas: prevent domain rediscovery competing with ata error handling (David Milburn) [782929]
- [scsi] libsas: convert dev->gone to flags (David Milburn) [782929]
- [scsi] libsas: remove ata_port.lock management duties from lldds (David Milburn) [782929]
- [scsi] libsas: introduce sas_drain_work() (David Milburn) [782929]
- [scsi] libsas: convert ha->state to flags (David Milburn) [782929]
- [scsi] libsas: replace event locks with atomic bitops (David Milburn) [782929]
- [scsi] libsas: fix leak of dev->sata_dev.identify_[packet_]device (David Milburn) [782929]
- [scsi] libsas: fix domain_device leak (David Milburn) [782929]
- [scsi] libsas: kill sas_slave_destroy (David Milburn) [782929]
- [scsi] libsas: remove unused ata_task_resp fields (David Milburn) [782929]
- [scsi] libsas: fix port->dev_list locking (David Milburn) [782929]
- [scsi] libsas: remove expander from dev list on error (David Milburn) [782929]
- [block] export blk_{get,put}_queue() (Jeff Moyer) [757362]
- [block] floppy: fix a crash during rmmod() (Jeff Moyer) [757362]
- [block] floppy: Cleanup disk->queue before calling put_disk() if add_disk() was never called (Jeff Moyer) [757362]
- [block] add missing blk_queue_dead() checks (Jeff Moyer) [757362]
- [block] fix drain_all condition in blk_drain_queue() (Jeff Moyer) [757362]
- [block] add blk_queue_dead() (Jeff Moyer) [757362]
- [block] don't call blk_drain_queue() if elevator is not up (Jeff Moyer) [757362]
- [block] blk-throttle: use queue_is_locked() instead of lockdep_is_held() (Jeff Moyer) [757362]
- [block] fix request_queue lifetime handling by making blk_queue_cleanup() properly shutdown (Jeff Moyer) [757362]
- [block] make get_request[_wait]() fail if queue is dead (Jeff Moyer) [757362]
- [block] reorganize throtl_get_tg() and blk_throtl_bio() (Jeff Moyer) [757362]
- [block] reorganize queue draining (Jeff Moyer) [757362]
- [block] drop unnecessary blk_get/put_queue() in scsi_cmd_ioctl() and blk_get_tg() (Jeff Moyer) [757362]
- [block] pass around REQ_* flags instead of broken down booleans during request alloc/free (Jeff Moyer) [757362]
- [block] move blk_throtl prototypes to block/blk.h (Jeff Moyer) [757362]
- [block] fix genhd refcounting in blkio_policy_parse_and_set() (Jeff Moyer) [757362]
- [block] make gendisk hold a reference to its queue (Jeff Moyer) [757362]
- [block] Free queue resources at blk_release_queue() (Jeff Moyer) [757362]
- [block] fix crash in scsi_dispatch_cmd() (Jeff Moyer) [757362]
- [block] Fix oops caused by queue refcounting failure (Jeff Moyer) [757362]
- [block] add proper state guards to __elv_next_request (Jeff Moyer) [757362]
- [block] fix oops in scsi_run_queue() (Jeff Moyer) [757362]
- [block] put stricter guards on queue dead checks (Jeff Moyer) [757362]
- [scsi] lpfc: Fix warning on i386 system (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.58 driver release (Rob Evers) [738037]
- [scsi] lpfc: Fixed FCP EQ memory check prevent initialize to single interrupt vector case (Rob Evers) [738037]
- [scsi] lpfc: Fixed SLI4 16Gbit FC port internal and external diagnostic loopback tests (Rob Evers) [738037]
- [scsi] lpfc: Fixed system panic during EEH recovery on SLI4 FC port (Rob Evers) [738037]
- [scsi] lpfc: Fix FLOGI fails with invalid RPI (0x04) after connecting to a arbitrated loop (Rob Evers) [738037]
- [scsi] lpfc: Fix ELS SCR failing with local reject / invalid RPI (Rob Evers) [738037]
- [scsi] lpfc: Fix SLI4 port failures after firmware reset or dump (Rob Evers) [738037]
- [scsi] lpfc: Fix port reset log messages indicate error when no error is seen (Rob Evers) [738037]
- [scsi] lpfc: HBQ buffers are uninitialized in the base driver (Rob Evers) [738037]
- [scsi] lpfc: Fixed missing shost lock protection on setting/clearing bit in vport->fc_flag (Rob Evers) [738037]
- [scsi] lpfc: Fixed missing hbalock protection on setting/clearing bit in phba->link_flag (Rob Evers) [738037]
- [scsi] lpfc: Fixed illegal state transition during driver unload (Rob Evers) [738037]
- [scsi] lpfc: Fixed system crash on SLI4 FC port looopback diagnostic test with large buffers (Rob Evers) [738037]
- [scsi] lpfc: Fixed a potential error path that might try to free DMA memory not allocated (Rob Evers) [738037]
- [scsi] lpfc: Fixed SLI4 FC port Internal and External loopback diagnostic tests (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.57 driver release (Rob Evers) [738037]
- [scsi] lpfc: Fix a crash while deleting 256 vports (Rob Evers) [738037]
- [scsi] lpfc: Fix vport never finished discovery if switch runs out of resources (Rob Evers) [738037]
- [scsi] lpfc: Fix kernel build warnings (Rob Evers) [738037]
- [scsi] lpfc: Fix kernel panic when putting board in offline state twice (Rob Evers) [738037]
- [scsi] lpfc: Fix memory leak when running hba resets to SLI-4 board (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.56 driver release (Rob Evers) [738037]
- [scsi] lpfc: Fix driver message 3092 and 3116 to KERN_WARNING (Rob Evers) [738037]
- [scsi] lpfc: Fix PCI read failure looks like a over temperature event (Rob Evers) [738037]
- [scsi] lpfc: Fixed driver event reporting to mgmt on error attention due to forced dump (Rob Evers) [738037]
- [scsi] lpfc: Fix not displaying firmware rev for BE boards (Rob Evers) [738037]
- [scsi] lpfc: Add asynchronous ABTS notification event feature to driver (Rob Evers) [738037]
- [scsi] lpfc: Fix bug with driver not byte swapping extended mailbox data (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.55 driver release (Rob Evers) [738037]
- [scsi] lpfc: Fix premature ndlp cleanup after second target LOGO (Rob Evers) [738037]
- [scsi] lpfc: Add loop support for sli4 fc (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.54 driver release (Rob Evers) [738037]
- [scsi] lpfc: Fixed OCM failing COMN_READ_OBJECT and COMN_WRITE_OBJECT mailbox pass-through (Rob Evers) [738037]
- [scsi] lpfc: No longer read fcoe parameters if board is not fcoe (Rob Evers) [738037]
- [scsi] lpfc: Fix bug with driver passing a wrong count value (Rob Evers) [738037]
- [scsi] lpfc: Added restore state and error log when sysfs board_mode attribute access failed (Rob Evers) [738037]
- [scsi] lpfc: Added support for SLI4_CONFIG non-embedded COMN_GET_CNTL_ADDL_ATTR pass-through (Rob Evers) [738037]
- [scsi] lpfc: Added support for SLI4 FC port persistent linkdown through config region 23 (Rob Evers) [738037]
- [scsi] lpfc: Fix for ABTS. Do not free original IOCB whenever ABTS fails (Rob Evers) [738037]
- [scsi] lpfc: Fixed Linux driver inconsistency in reporting FC host port-state through OCM (Rob Evers) [738037]
- [scsi] lpfc: Return an error if the mbox sysfs is called (Rob Evers) [738037]
- [scsi] lpfc: Fix firmware upgrade attempt on unsupported adapter (Rob Evers) [738037]
- [scsi] lpfc: Fix incomplete message number 2889 (Rob Evers) [738037]
- [scsi] lpfc: Fix system crash when LPe16000 fails to initialize (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.53 driver release (Rob Evers) [738037]
- [scsi] lpfc: Fix multiple non-functional discrepancies with upstream (Rob Evers) [738037]
- [scsi] lpfc: Fix virtual fabrics bit set in FLOGI incorrectly (Rob Evers) [738037]
- [scsi] lpfc: Merge from upstream: remove cmd->serial_number litter (Rob Evers) [738037]
- [scsi] lpfc: Merge from upstream: Fix common misspellings (Rob Evers) [738037]
- [scsi] lpfc: Fix bug with driver not returning extended mailbox data (Rob Evers) [738037]
- [scsi] lpfc: Fix unsupported link speed accepted by SLI4 port (Rob Evers) [738037]
- [scsi] lpfc: Increment mix-and-match minor number by 1 for added "protocol" sysfs attribute (Rob Evers) [738037]
- [scsi] lpfc: Fix kernel build warnings (Rob Evers) [738037]
- [scsi] lpfc: Modify WQ handling to use entry_repost (Rob Evers) [738037]
- [scsi] lpfc: Moved macro definition to a location proper location in lpfc_hw4.h file (Rob Evers) [738037]
- [scsi] lpfc: Added a sysfs attribute "protocol" to report SLI4 port link protocol type (Rob Evers) [738037]
- [scsi] lpfc: Added SLI4 INTF_TYPE and SLI_FAMILY as sub-fieled to the fwrev sysfs attribute (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.52 driver release (Rob Evers) [738037]
- [scsi] lpfc: Adding structure to support T10 DIF in SLI4 (Rob Evers) [738037]
- [scsi] lpfc: Fix performance slowed due to too many register accesses (Rob Evers) [738037]
- [scsi] lpfc: Fixed a warning when converting from simple_strtoul to strict_strtoul (Rob Evers) [738037]
- [scsi] lpfc: Add Initial code to inject T10 DIF errors (Rob Evers) [738037]
- [scsi] lpfc: Fixed non-embedded COMMON_GET_CNTL_ATTR mbox command failed with status 0x4 (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.51 driver release (Rob Evers) [738037]
- [scsi] lpfc: Changed the way of SLI4 device detecting physical port name (Rob Evers) [738037]
- [scsi] lpfc: Add new check to lpfc_decode_firmware_rev to handle releases that have an 'X' (Rob Evers) [738037]
- [scsi] lpfc: Fixed RPI leaks in ELS protocol handling (Rob Evers) [738037]
- [scsi] lpfc: Fixed NPIV FDISC failure on SLI4 if-type 2 ports (Rob Evers) [738037]
- [scsi] lpfc: Fixed driver failed to follow IP reset procedure in SLI4 error attention handler (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.50 driver release (Rob Evers) [738037]
- [scsi] lpfc: Fix sysfs lists fabric name for port that has been disconnected from fabric (Rob Evers) [738037]
- [scsi] lpfc: Changed the timeout to 300 seconds for SLI_CONFIG (0x9B) mailbox command (Rob Evers) [738037]
- [scsi] lpfc: Fixed fcp underrun reporting (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.49 driver release (Rob Evers) [738037]
- [scsi] lpfc: Fixed a driver handling IP reset issue when PCI read return error (Rob Evers) [738037]
- [scsi] lpfc: Fixed casting problem (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.48 driver release (Rob Evers) [738037]
- [scsi] lpfc: Added proper error code return for management API to make proper decisions (Rob Evers) [738037]
- [scsi] lpfc: Fix sli4 mailbox status code. Management software has dependancies (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.47 driver release (Rob Evers) [738037]
- [scsi] lpfc: Made error log include PCI BAR bitmap from kernel when enable PCI device failed (Rob Evers) [738037]
- [scsi] lpfc: Fixed incomplete scsi messages displayed (Rob Evers) [738037]
- [scsi] lpfc: Fix enable_bg config parameter for SLI4 (Rob Evers) [738037]
- [scsi] lpfc: fix potentially dangerous trailing ';' (Rob Evers) [738037]
- [scsi] lpfc: Fix driver firmware update to match new firmware image format (Rob Evers) [738037]
- [scsi] lpfc: Merge from upstream: Silence DEBUG_STRICT_USER_COPY_CHECKS=y warning (Rob Evers) [738037]
- [scsi] lpfc: Merge from upstream: treewide: fix a few typos in comments (Rob Evers) [738037]
- [scsi] lpfc: Merge from upstream: treewide: remove extra semicolons (Rob Evers) [738037]
- [scsi] lpfc: Fix SLI4 CT handling for sequences > 4K (Rob Evers) [738037]
- [scsi] lpfc: Fixed handling of unsolicited frames for vports (Rob Evers) [738037]
- [scsi] lpfc: Fixed handling of CVL for vports (Rob Evers) [738037]
- [scsi] lpfc: Fixed crash when aborting els IOs (Rob Evers) [738037]
- [scsi] lpfc: Fix up CT and oxid/rxid for unsol rcv frames (Rob Evers) [738037]
- [scsi] lpfc: Added fcf priority record selection for fcf failover (Rob Evers) [738037]
- [scsi] lpfc: Fixed mailbox double free panic (Rob Evers) [738037]
- [scsi] lpfc: Update lpfc version for 8.3.5.46 driver release (Rob Evers) [738037]
- [scsi] lpfc: Removed unused argument passing to the lpfc_bsg_diag_mode_enter routine (Rob Evers) [738037]
- [scsi] lpfc: Add sysfs logging when writeable parameters are changed (Rob Evers) [738037]
- [scsi] lpfc: iDiag added SLI4 device PCI BAR memory mapped reigster access methods (Rob Evers) [738037]
- [scsi] lpfc: Consolidated duplicating macro definitions (Rob Evers) [738037]
- [scsi] lpfc: Fixed cosmetic issues with T10 DIF (Rob Evers) [738037]
- [scsi] lpfc: iDiag fixed mailbox capture and dump overlapping bitmap macro definition (Rob Evers) [738037]
- [scsi] lpfc: iDiag changed command structure data array indexing by using macro defines (Rob Evers) [738037]
- [scsi] lpfc: iDiag extended debugfs setting up inline mailbox capture and dump capability (Rob Evers) [738037]
- [scsi] lpfc: Fix the case where the SCSI host supplies the CRC, only support T10 DIF type 1 (Rob Evers) [738037]
- [scsi] lpfc: Fixed failure to show 16 Gbit from FC host supported_speeds sysfs entry (Rob Evers) [738037]
- [fs] ext4: fix the deadlock in mpage_da_map_and_submit() (Lukas Czerner) [737780]
- [fs] ext4: fix deadlock in ext4_ordered_write_end() (Lukas Czerner) [737780]
- [fs] ext4: mark multi-page IO complete on mapping failure (Lukas Czerner) [737780]
- [fs] ext4: fix ext4_da_block_invalidatepages() to handle page range properly (Lukas Czerner) [737780]
- [fs] ext4: call mpage_da_submit_io() from mpage_da_map_blocks() (Lukas Czerner) [737780]

* Thu Feb 23 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-238.el6]
- [virt] blkfront: don't change to closing if we're busy (Andrew Jones) [773219]
- [virt] blkfront: don't put bdev right after getting it (Andrew Jones) [773219]
- [virt] blkfront: Remove obsolete info->users (Andrew Jones) [773219]
- [virt] blkfront: Lock blockfront_info during xbdev removal (Andrew Jones) [773219]
- [virt] blkfront: Fix blkfront backend switch race (bdev release) (Andrew Jones) [773219]
- [virt] blkfront: Fix blkfront backend switch race (bdev open) (Andrew Jones) [773219]
- [virt] blkfront: Lock blkfront_info when closing (Andrew Jones) [773219]
- [virt] blkfront: Clean up vbd release (Andrew Jones) [773219]
- [virt] blkfront: Fix gendisk leak (Andrew Jones) [773219]
- [virt] blkfront: Fix backtrace in del_gendisk (Andrew Jones) [773219]
- [virt] blkfront: fixes for 'xm block-detach ... --force' (Andrew Jones) [773219]
- [virt] xen: use less generic names in blkfront driver (Andrew Jones) [773219]
- [scsi] qla4xxx: v5.02.00.00.06.03-k2 (Chad Dupuis) [725502]
- [scsi] qla4xxx: Added ping support (Chad Dupuis) [725502]
- [scsi] iscsi_transport: Added Ping support (Chad Dupuis) [725502]
- [scsi] qla4xxx: added support for host event (Chad Dupuis) [725502]
- [scsi] scsi_transport_iscsi: added support for host event (Chad Dupuis) [725502]
- [scsi] qla4xxx: Proper detection of firmware abort error code for ISP82xx (Chad Dupuis) [725502]
- [scsi] qla4xxx: Remove un-necessary print statment (Chad Dupuis) [725502]
- [scsi] qla4xxx: Modified debug log messages for boot info (Chad Dupuis) [725502]
- [scsi] qla4xxx: Fix verify boot idx correctly (Chad Dupuis) [725502]
- [scsi] qla4xxx: Fix un-necessary delay on invalid DDB (Chad Dupuis) [725502]
- [scsi] qla4xxx: Remove unused code (Chad Dupuis) [725502]
- [scsi] scsi_error: classify some ILLEGAL_REQUEST sense as a permanent TARGET_ERROR (Mike Snitzer) [789021]
- [scsi] Make sure provisioning mode is reported correctly (Mike Snitzer) [789021]
- [scsi] Ensure discard failure gets treated as a target problem (Mike Snitzer) [789021]
- [x86] iommu/amd: Fix wrong shift direction (Don Dutile) [781531]
- [x86] iommu/amd: Don't use MSI address range for DMA addresses (Don Dutile) [781524]
- [pci] kabi: fix potential use of older pci_[un]block_user_cfg_access (Don Dutile) [786610]
- [uio] Convert uio_generic_pci to new intx masking API (Don Dutile) [786610]
- [pci] Introduce INTx check & mask API (Don Dutile) [786610]
- [pci] Rework config space blocking services (Don Dutile) [786610]
- [uio] uio_pci_generic: Remove useless spin_lock (Don Dutile) [786610]
- [fs] autofs4: autofs4_wait() vs. autofs4_catatonic_mode() race (Ian Kent) [786693]
- [fs] autofs4: catatonic_mode vs. notify_daemon race (Ian Kent) [786693]
- [fs] autofs4: deal with autofs4_write/autofs4_write races (Ian Kent) [786693]
- [block] md/raid1: perform bad-block tests for WriteMostly devices too (Jes Sorensen) [789570]
- [fs] GFS2: Sort the ordered write list (Robert S Peterson) [788627]
- [fs] GFS2: combine duplicated block freeing routines (Robert S Peterson) [788627]
- [fs] GFS2: Fix multi-block allocation (Robert S Peterson) [788627]
- [fs] GFS2: decouple quota allocations from block allocations (Robert S Peterson) [788627]
- [fs] GFS2: split function rgblk_search (Robert S Peterson) [788627]
- [fs] GFS2: Fix up "off by one" in the previous patch (Robert S Peterson) [788627]
- [fs] GFS2: move toward a generic multi-block allocator (Robert S Peterson) [788627]
- [fs] vfs: Provide function to get superblock and wait for it to thaw (Eric Sandeen) [747740]
- [fs] quota: Fix deadlock with suspend and quotas (Eric Sandeen) [747740]
- [fs] vfs: In get_super() and user_get_super() restarts are unconditional (Eric Sandeen) [747740]
- [fs] vfs: remove LOOKUP_NO_AUTOMOUNT flag (Ian Kent) [745775]
- [fs] VFS: Fix the remaining automounter semantics regressions (Ian Kent) [745775]
- [fs] vfs pathname lookup: Add LOOKUP_AUTOMOUNT flag (Ian Kent) [745775]
- [fs] vfs: automount should ignore LOOKUP_FOLLOW (Ian Kent) [745775]

* Thu Feb 23 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-237.el6]
- [netdrv] tg3: fix ipv6 header length computation (John Feeney) [740052]
- [netdrv] tg3: Add 57766 ASIC rev support (John Feeney) [740052]
- [netdrv] tg3: Update version to 3.122 (John Feeney) [740052]
- [netdrv] tg3: Return flowctrl config through ethtool (John Feeney) [740052]
- [netdrv] tg3: Save stats across chip resets (John Feeney) [740052]
- [netdrv] tg3: Remove ethtool stats member from dev struct (John Feeney) [740052]
- [netdrv] tg3: Scale back code that modifies MRRS (John Feeney) [740052]
- [netdrv] tg3: Fix TSO CAP for 5704 devs w / ASF enabled (John Feeney) [740052]
- [netdrv] tg3: Add MDI-X reporting (John Feeney) [740052]
- [netdrv] tg3: Restrict large prod ring cap devices (John Feeney) [740052]
- [netdrv] tg3: Adjust BD replenish thresholds (John Feeney) [740052]
- [netdrv] tg3: Make 1000Base-X FC resolution look like 1000T (John Feeney) [740052]
- [netdrv] convert .get_drvinfo routines to strlcpy (John Feeney) [740052]
- [netdrv] tg3: Update version to 3.121 (John Feeney) [740052]
- [netdrv] tg3: Eliminate timer race with reset_task (John Feeney) [740052]
- [netdrv] tg3: Schedule at most one tg3_reset_task run (John Feeney) [740052]
- [netdrv] tg3: Obtain PCI function number from device (John Feeney) [740052]
- [netdrv] tg3: Fix irq alloc error cleanup path (John Feeney) [740052]
- [netdrv] tg3: Fix 4k skb error recovery path (John Feeney) [740052]
- [netdrv] tg3: Fix 4k tx bd segmentation code (John Feeney) [740052]
- [netdrv] tg3: Fix APE mutex init and use (John Feeney) [740052]
- [netdrv] tg3: add tx_dropped counter (John Feeney) [740052]
- [netdrv] tg3: fix tigon3_dma_hwbug_workaround() (John Feeney) [740052]
- [netdrv] tg3: Remove unnecessary driver assignments of ethtool_ringparam fields to zero (John Feeney) [740052]
- [netdrv] tg3: Fix VLAN tagging regression (John Feeney) [740052]
- [netdrv] tg3: Code movement (John Feeney) [740052]
- [netdrv] tg3: Eliminate tg3_halt_cpu() prototype (John Feeney) [740052]
- [netdrv] tg3: Eliminate tg3_write_sig_post_reset() prototype (John Feeney) [740052]
- [netdrv] tg3: Eliminate tg3_stop_fw() prototype (John Feeney) [740052]
- [netdrv] tg3: Add ability to turn off 1shot MSI (John Feeney) [740052]
- [netdrv] tg3: Remove tp->rx_offset term when unneeded (John Feeney) [740052]
- [netdrv] tg3: Fix missed MSI workaround (John Feeney) [740052]
- [netdrv] tg3: Check all adv bits when checking config (John Feeney) [740052]
- [netdrv] tg3: Update version to 3.120 (John Feeney) [740052]
- [netdrv] tg3: Add external loopback support to selftest (John Feeney) [740052]
- [net] add external loopback test in ethtool self test (John Feeney) [740052]
- [netdrv] tg3: Restructure tg3_test_loopback (John Feeney) [740052]
- [netdrv] tg3: Pull phy int lpbk setup into separate function (John Feeney) [740052]
- [netdrv] tg3: Remove dead code (John Feeney) [740052]
- [netdrv] tg3: Remove 5719 jumbo frames and TSO blocks (John Feeney) [740052]
- [netdrv] tg3: Break larger frags into 4k chunks for 5719 (John Feeney) [740052]
- [netdrv] tg3: Add tx BD budgeting code (John Feeney) [740052]
- [netdrv] tg3: Consolidate code that calls tg3_tx_set_bd() (John Feeney) [740052]
- [netdrv] tg3: Add partial fragment unmapping code (John Feeney) [740052]
- [netdrv] tg3: Generalize tg3_skb_error_unmap() (John Feeney) [740052]
- [netdrv] tg3: Remove short DMA check for 1st fragment (John Feeney) [740052]
- [netdrv] tg3: Simplify tx bd assignments (John Feeney) [740052]
- [netdrv] tg3: Reintroduce tg3_tx_ring_info (John Feeney) [740052]
- [netdrv] tg3: Fix NVRAM selftest failures for 5720 devs (John Feeney) [740052]
- [netdrv] tg3: Return size from tg3_vpd_readblock() (John Feeney) [740052]
- [netdrv] tg3: Fix int selftest for recent devices (John Feeney) [740052]
- [netdrv] tg3: Fix RSS indirection table distribution (John Feeney) [740052]
- [netdrv] tg3: Add 5719 and 5720 to EEE_CAP list (John Feeney) [740052]
- [netdrv] tg3: Fix link down notify failure when EEE disabled (John Feeney) [740052]
- [netdrv] tg3: Fix link flap at 100Mbps with EEE enabled (John Feeney) [740052]
- [netdrv] tg3: Fix io failures after chip reset (John Feeney) [740052]
- [netdrv] tg3: Match power source to driver state (John Feeney) [740052]
- [netdrv] tg3: Add function status reporting (John Feeney) [740052]
- [netdrv] tg3: Create critical section around GPIO toggling (John Feeney) [740052]
- [netdrv] tg3: Determine PCI function number in one place (John Feeney) [740052]
- [netdrv] tg3: Check transitions to D0 power state (John Feeney) [740052]
- [netdrv] tg3: Move power state transitions to init_one (John Feeney) [740052]
- [netdrv] tg3: Detect APE enabled devs earlier (John Feeney) [740052]
- [netdrv] tg3: remove unnecessary read of PCI_CAP_ID_EXP (John Feeney) [740052]
- [netdrv] tg3: Migrate phy preprocessor defs to system defs (John Feeney) [740052]
- [netdrv] tg3: Show flowctrl settings through get_settings() (John Feeney) [740052]
- [netdrv] tg3: Remove 4G_DMA_BNDRY_BUG flag (John Feeney) [740052]
- [netdrv] tg3: Remove 40BIT_DMA_LIMIT_BUG (John Feeney) [740052]
- [net] remove interrupt.h inclusion from netdevice.h (John Feeney) [740052]
- [netdrv] tg3: Fix tg3_skb_error_unmap() (John Feeney) [740052]
- [netdrv] Add Fujitsu 1000base-SX PCI ID to tg3 (John Feeney) [740052]
- [netdrv] tg3: Add braces around 5906 workaround (John Feeney) [740052]
- [netdrv] tg3: Add TSO loopback test (John Feeney) [740052]
- [netdrv] tg3: Add jumbo frame loopback tests to selftest (John Feeney) [740052]
- [netdrv] tg3: Cleanup transmit error path (John Feeney) [740052]
- [scsi] iscsi: don't hang in endless loop if no targets present (Mike Christie) [747846]
- [scsi] libiscsi: fix cmd timeout/completion race (Mike Christie) [747846]
- [scsi] libiscsi_tcp: fix max_r2t manipulation (Mike Christie) [747846]
- [scsi] iscsi: fix setting of pid from netlink skb (Mike Christie) [747846]
- [kernel] sched: Cure nr_iowait_cpu() users (Larry Woodman) [760479]
- [kernel] proc: Consider NO_HZ when printing idle and iowait times (Larry Woodman) [760479]
- [kernel] nohz: Make idle/iowait counter update conditional (Larry Woodman) [760479]
- [kernel] nohz: Fix update_ts_time_stat idle accounting (Larry Woodman) [760479]
- [kernel] cputime: Clean up cputime_to_usecs and usecs_to_cputime macros (Larry Woodman) [760479]
- [mm] memcg: avoid css_get() (Johannes Weiner) [717803]
- [mm] memcg: coalesce charging via percpu storage (Johannes Weiner) [717803]
- [mm] memcg: coalesce uncharge during unmap/truncate (Johannes Weiner) [717803]
- [kernel] tracing: send_sigqueue() needs trace_signal_generate() too (Oleg Nesterov) [738720]
- [kernel] tracing: let trace_signal_generate() report more info, kill overflow_fail/lose_info (Oleg Nesterov) [738720]
- [tracing] latency: Fix header output for latency tracers (Jiri Olsa) [734757]
- [kernel] tracing: Fixing wakeup tracer function for disabled function trace (Jiri Olsa) [734757]
- [kernel] tracing: Convert nop macros to static inlines (Jiri Olsa) [734757]
- [sched] Fix cgroup movement of waking process (Larry Woodman) [773517]
- [sched] Fix cgroup movement of forking process (Larry Woodman) [773517]
- [sched] Fix cgroup movement of newly created process (Larry Woodman) [773517]
- [sched] Fix ->min_vruntime calculation in dequeue_entity() (Larry Woodman) [773517]
- [sched] cgroup: Fixup broken cgroup movement (Larry Woodman) [773517]
- [fs] GFS2: Read in rindex if necessary during unlink (Robert S Peterson) [790997]
- [fs] GFS2: More automated code analysis fixes (Robert S Peterson) [790997]
- [usb] serial: use port endpoint size to determine if ep is available (Don Zickus) [744113]
- [ppc] pseries: Cancel RTAS event scan before firmware flash (Steve Best) [718252]
- [ppc] Fix device tree claim code (Steve Best) [740544]
- [ppc] Fix accounting of softirq time when idle (Steve Best) [740550]
- [fs] GFS2: panic in gfs2_rindex_update during gfs2_grow (Robert S Peterson) [791010]
- [fs] GFS2: Implement FITRIM ioctl (Steven Whitehouse) [656959]
- [x86] ACPI: Fix possible alignment issues with GAS 'address' references (Myron Stowe) [708447]
- [x86] ACPI / PM: Use existing ACPI iomaps for NVS save/restore (Myron Stowe) [708447]
- [x86] ACPI: Introduce acpi_os_get_iomem() (Myron Stowe) [708447]
- [x86] ACPI: Do not use krefs under a mutex in osl.c (Myron Stowe) [708447]
- [x86] ACPI: Make acpi_os_map_memory() avoid creating unnecessary mappings (Myron Stowe) [708447]
- [x86] ACPI: Avoid walking the list of memory mappings in osl.c twice in a row (Myron Stowe) [708447]
- [x86] ACPI: Change acpi_ioremap_lock into a mutex (Myron Stowe) [708447]
- [x86] ACPI: Do not export functions that are only used in osl.c (Myron Stowe) [708447]
- [x86] ACPI: Fix acpi_os_read_memory() and acpi_os_write_memory() (Myron Stowe) [708447]
- [x86] ACPI: Introduce acpi_os_ioremap() (Myron Stowe) [708447]
- [x86] ACPI: fix resource check message (Myron Stowe) [708447]
- [x86] ACPI: Use ioremap_cache() (Myron Stowe) [708447]
- [x86] ACPI: Page based coalescing of I/O remappings optimization (Myron Stowe) [708447]
- [x86] ACPI: Convert simple locking to RCU based locking (Myron Stowe) [708447]
- [x86] ACPI: Pre-map 'system event' related register blocks (Myron Stowe) [708447]
- [x86] ACPI: Add interfaces for ioremapping/iounmapping ACPI registers (Myron Stowe) [708447]
- [x86] ACPI: Maintain a list of ACPI memory mapped I/O remappings (Myron Stowe) [708447]
- [x86] ACPI: fix unused but set variables in ACPI (Myron Stowe) [708447]
- [net] make bonding slaves honour master's skb->priority (Andy Gospodarek) [749416]
- [net] ipv6: Allow inet6_dump_addr() to handle more than 64 addresses (Jiri Pirko) [742588]
- [scsi] hpsa: add some older controllers to the kdump blacklist (Tomas Henzl) [738930]
- [kernel] perf: add examples.txt file (Jason Baron) [569502]
- [tracing] Fix returning of duplicate data after EOF in trace_pipe_raw (Jason Baron) [746009]
- [block] Fix sysctl check failure update (James Paradis) [714021]
- [pci] Workaround hard-wired bus number (Myron Stowe) [790557]
- [x86] APEI: Avoid resource conflict errors (Matthew Garrett) [696521]
- [netdrv] igbvf driver update (Stefan Assmann) [737716]
- [netdrv] enic driver update (Stefan Assmann) [747384]
- [scsi] revert remove tech_preview tag for mpt2sas lockless mode (Tomas Henzl) [559393]

* Mon Feb 20 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-236.el6]
- [block] md: Fix sysctl check failure (James Paradis) [714021]
- [netdrv] mlx4: fix DMA mapping leak when allocation fails (Steve Best) [787771]
- [kernel] perf, tool: Fix scripts dependent on upstream raw_syscall event (Jiri Olsa) [726600]
- [kernel] perf, tool: Fix prefix matching for kernel maps (Jiri Olsa) [755873]
- [fs] NFSv4: Further reduce the footprint of the idmapper (Steve Dickson) [730045]
- [fs] NFSv4: Reduce the footprint of the idmapper (Steve Dickson) [730045]
- [netdrv] be2net: bump version (Ivan Vecera) [738041]
- [netdrv] be2net: Use new implementation of get mac list command (Ivan Vecera) [738041]
- [netdrv] be2net: Fix link status query command (Ivan Vecera) [738041]
- [netdrv] be2net: add descriptions for stat counters reported via ethtool (Ivan Vecera) [738041]
- [netdrv] be2net: create RSS rings even in multi-channel configs (Ivan Vecera) [738041]
- [netdrv] be2net: query link status in be_open() (Ivan Vecera) [738041]
- [netdrv] be2net: fix range check for set_qos for a VF (Ivan Vecera) [738041]
- [netdrv] be2net: fix be_vlan_add/rem_vid (Ivan Vecera) [738041]
- [netdrv] be2net: Fix INTx processing for Lancer (Ivan Vecera) [738041]
- [netdrv] be2net: Add support for Skyhawk cards (Ivan Vecera) [738041]
- [netdrv] be2net: refactor/cleanup vf configuration code (Ivan Vecera) [738041]
- [netdrv] be2net: fix ethtool ringparam reporting (Ivan Vecera) [738041]
- [netdrv] be2net: workaround to fix a bug in BE (Ivan Vecera) [738041]
- [netdrv] be2net: update some counters to display via ethtool (Ivan Vecera) [738041]
- [netdrv] be2net: netpoll support (Ivan Vecera) [738041]
- [netdrv] be2net: Fix non utilization of RX queues (Ivan Vecera) [738041]
- [netdrv] be2net: Use new hash key (Ivan Vecera) [738041]
- [netdrv] be2net: Add error handling for Lancer (Ivan Vecera) [738041]
- [netdrv] be2net: Fix error recovery paths (Ivan Vecera) [738041]
- [netdrv] be2net: Move to new SR-IOV implementation in Lancer (Ivan Vecera) [738041]
- [netdrv] be2net: Use V1 query link status command for lancer (Ivan Vecera) [738041]
- [netdrv] be2net: Fix VLAN promiscous mode for Lancer (Ivan Vecera) [738041]
- [netdrv] be2net: Add EEPROM dump feature for Lancer (Ivan Vecera) [738041]
- [netdrv] be2net: add register dump feature for Lancer (Ivan Vecera) [738041]
- [netdrv] be2net: Fix TX queue create for Lancer (Ivan Vecera) [738041]
- [netdrv] be2net: stop issuing FW cmds if any cmd times out (Ivan Vecera) [738041]
- [netdrv] be2net: don't log more than one error on detecting EEH/UE errors (Ivan Vecera) [738041]
- [netdrv] be2net: stop checking the UE registers after an EEH error (Ivan Vecera) [738041]
- [netdrv] be2net: init (vf)_if_handle/vf_pmac_id to handle failure scenarios (Ivan Vecera) [738041]
- [netdrv] sweep the floors and convert some .get_drvinfo routines to strlcpy (Ivan Vecera) [738041]
- [netdrv] be2net: Add detect UE feature for Lancer (Ivan Vecera) [738041]
- [netdrv] be2net: Prevent CQ full condition for Lancer (Ivan Vecera) [738041]
- [netdrv] be2net: Fix disabling multicast promiscous mode (Ivan Vecera) [738041]
- [netdrv] be2net: Fix endian issue in RX filter command (Ivan Vecera) [738041]
- [netdrv] be2net: Changing MAC Address of a VF was broken (Ivan Vecera) [738041]
- [netdrv] be2net: Refactored be_cmds.c file (Ivan Vecera) [738041]
- [netdrv] be2net: don't create multiple RX/TX rings in multi channel mode (Ivan Vecera) [738041]
- [netdrv] be2net: don't create multiple TXQs in BE2 (Ivan Vecera) [738041]
- [netdrv] be2net: refactor VF setup/teardown code into be_vf_setup/clear() (Ivan Vecera) [738041]
- [netdrv] be2net: fix truesize errors (Ivan Vecera) [738041]
- [netdrv] be2net: Making die temperature ioctl call async (Ivan Vecera) [738041]
- [netdrv] be2net: Modified PCI MaxReadReq size to 4096 bytes (Ivan Vecera) [738041]
- [netdrv] be2net: Change the data type of the 'on die temperature' stat (Ivan Vecera) [738041]
- [netdrv] be2net: Add 60 second delay to allow FAT dump completion on recovery from EEH (Ivan Vecera) [738041]
- [netdrv] be2net: Show newly flashed FW ver in ethtool (Ivan Vecera) [738041]
- [netdrv] be2net: fix multicast filter programming (Ivan Vecera) [738041]
- [netdrv] be2net: remove unused variable (Ivan Vecera) [738041]
- [netdrv] be2net: increase FW update completion timeout (Ivan Vecera) [738041]
- [netdrv] be2net: fix erx->rx_drops_no_frags wrap around (Ivan Vecera) [738041]
- [netdrv] be2net: get rid of memory mapped pci-cfg space address (Ivan Vecera) [738041]
- [netdrv] be2net: Fix race in posting rx buffers (Ivan Vecera) [738041]
- [netdrv] be2net: Storing the 'vid' got by the grp5 event instead of storing the vlan_tag (Ivan Vecera) [738041]
- [netdrv] benet: fix build error on 32bit arch (Ivan Vecera) [738041]
- [netdrv] be2net: fix cmd-rx-filter not notifying MCC (Ivan Vecera) [738041]
- [netdrv] be2net: drop pkts that do not belong to the port (Ivan Vecera) [738041]
- [netdrv] be2net: add support for flashing Teranetics PHY firmware (Ivan Vecera) [738041]
- [netdrv] be2net: use RX_FILTER cmd to program multicast addresses (Ivan Vecera) [738041]
- [netdrv] be2net: no need to query link status (Ivan Vecera) [738041]
- [netdrv] be2net: remove wrong and unnecessary calls to netif_carrier_off() (Ivan Vecera) [738041]
- [netdrv] be2net: use stats-sync to read/write 64-bit stats (Ivan Vecera) [738041]
- [netdrv] be2net: cleanup and refactor stats code (Ivan Vecera) [738041]

* Fri Feb 17 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-235.el6]
- [netdrv] e1000: update DRV_VERSION to match upstream (Dean Nelson) [737719]
- [netdrv] e1000: add dropped DMA receive enable back in for WoL (Dean Nelson) [737719]
- [netdrv] e1000: Adding e1000_dump function (Dean Nelson) [737719]
- [netdrv] e1000: Remove unnecessary k.alloc/v.alloc OOM messages (Dean Nelson) [737719]
- [netdrv] e1000: cleanup CE4100 MDIO registers access (Dean Nelson) [737719]
- [netdrv] e1000: unmap ce4100_gbe_mdio_base_virt in e1000_remove (Dean Nelson) [737719]
- [netdrv] e1000: fix lockdep splat in shutdown handler (Dean Nelson) [737719]
- [netdrv] e1000: fix assignment of 0/1 to bool variables (Dean Nelson) [737719]
- [netdrv] e1000: remove not used fw_version from .get_drvinfo (Dean Nelson) [737719]
- [netdrv] e1000: Convert <FOO>_LENGTH_OF_ADDRESS to ETH_ALEN (Dean Nelson) [737719]
- [netdrv] e1000: cleanup .get_drvinfo (Dean Nelson) [737719]
- [netdrv] e1000: fix skb truesize underestimation (Dean Nelson) [737719]
- [netdrv] net: Remove unnecessary driver assignments of ethtool_ringparam fields to zero (Dean Nelson) [737719]
- [netdrv] e1000: convert to private mutex from rtnl (Dean Nelson) [737719]
- [netdrv] e1000: convert mdelay to msleep (Dean Nelson) [737719]
- [netdrv] e1000: convert hardware management from timers to threads (Dean Nelson) [737719]
- [netdrv] e1000: Fix driver to be used on PA RISC C8000 workstations (Dean Nelson) [737719]
- [netdrv] e1000: convert to SKB paged frag API (Dean Nelson) [737719]
- [netdrv] e1000: repair missing flush operations (Dean Nelson) [737719]
- [netdrv] e1000: always call e1000_check_for_link() on e1000_ce4100 MACs (Dean Nelson) [737719]
- [netdrv] Fix common misspellings (Dean Nelson) [737719]
- [netdrv] e1000: fix comment/printk typos (Dean Nelson) [737719]
- [netdrv] bnx2i: Fixed kernel panic caused by unprotected task->sc->request deref (Mike Christie) [740051]
- [netdrv] BNX2I: Update version (Mike Christie) [740051]
- [netdrv] BNX2I: Fixed the override of the error_mask module param (Mike Christie) [740051]
- [netdrv] BNX2I: Fixed kernel panic due to illegal usage of sc->request->cpu (Mike Christie) [740051]
- [netdrv] BNX2I: Added the use of kthreads to handle SCSI cmd completion (Mike Christie) [740051]
- [netdrv] e1000e: minor whitespace and indentation cleanup (Dean Nelson) [737713]
- [netdrv] e1000e: fix sparse warnings with -D__CHECK_ENDIAN__ (Dean Nelson) [737713]
- [netdrv] e1000e: fix checkpatch warning from MINMAX test (Dean Nelson) [737713]
- [netdrv] e1000e: cleanup - use braces in both branches of a conditional statement (Dean Nelson) [737713]
- [netdrv] e1000e: cleanup e1000_init_mac_params_82571() (Dean Nelson) [737713]
- [netdrv] e1000e: cleanup e1000_init_mac_params_80003es2lan() (Dean Nelson) [737713]
- [netdrv] e1000e: cleanup - check return values consistently (Dean Nelson) [737713]
- [netdrv] e1000e: add missing initializers reported when compiling with W=1 (Dean Nelson) [737713]
- [netdrv] e1000e: update copyright year (Dean Nelson) [737713]
- [netdrv] e1000e: split lib.c into three more-appropriate files (Dean Nelson) [737713]
- [netdrv] e1000e: call er16flash() instead of __er16flash() (Dean Nelson) [737713]
- [netdrv] e1000e: increase version number (Dean Nelson) [737713]
- [netdrv] e1000e: convert final strncpy() to strlcpy() (Dean Nelson) [737713]
- [netdrv] e1000e: concatenate long debug strings which span multiple lines (Dean Nelson) [737713]
- [netdrv] e1000e: conditionally restart autoneg on 82577/8/9 when setting LPLU state (Dean Nelson) [737713]
- [netdrv] e1000e: increase Rx PBA to prevent dropping received packets on 82566/82567 (Dean Nelson) [737713]
- [netdrv] e1000e: ICHx/PCHx LOMs should use LPLU setting in NVM when going to Sx (Dean Nelson) [737713]
- [netdrv] e1000e: update workaround for 82579 intermittently disabled during S0->Sx (Dean Nelson) [737713]
- [netdrv] e1000e: disable Early Receive DMA on ICH LOMs (Dean Nelson) [737713]
- [netdrv] e1000e: Need to include vmalloc.h (Dean Nelson) [737713]
- [netdrv] e1000e: 82574/82583 Tx hang workaround (Dean Nelson) [737713]
- [netdrv] e1000e: use hardware default values for Transmit Control register (Dean Nelson) [737713]
- [netdrv] e1000e: use default settings for Tx Inter Packet Gap timer (Dean Nelson) [737713]
- [netdrv] e1000e: 82579: workaround for link drop issue (Dean Nelson) [737713]
- [netdrv] e1000e: always set transmit descriptor control registers the same (Dean Nelson) [737713]
- [netdrv] e1000e: re-factor ethtool get/set ring parameter (Dean Nelson) [737713]
- [netdrv] e1000e: pass pointer to ring struct instead of adapter struct (Dean Nelson) [737713]
- [netdrv] e1000e: convert head, tail and itr_register offsets to __iomem pointers (Dean Nelson) [737713]
- [netdrv] e1000e: re-enable alternate MAC address for all devices which support it (Dean Nelson) [737713]
- [netdrv] e1000e: default IntMode based on kernel config & available hardware support (Dean Nelson) [737713]
- [netdrv] e1000e: fix assignment of 0/1 to bool variables (Dean Nelson) [737713]
- [netdrv] e1000e: hitting BUG_ON() from napi_enable (Dean Nelson) [737713]
- [netdrv] e1000e: cleanup strlcpy conversion of .get_drvinfo routines (Dean Nelson) [737713]
- [netdrv] e1000e: cleanup .get_drvinfo on strncpy usage (Dean Nelson) [737713]
- [netdrv] e1000e: convert to real ndo_set_rx_mode (Dean Nelson) [737713]
- [netdrv] e1000e: Convert printks to pr_<level> (Dean Nelson) [737713]
- [netdrv] e1000e: demote a debugging WARN to a debug log message (Dean Nelson) [737713]
- [netdrv] e1000e: fix skb truesize underestimation (Dean Nelson) [737713]
- [netdrv] e1000e: Remove unnecessary driver assignments of ethtool_ringparam fields to zero (Dean Nelson) [737713]
- [netdrv] e1000e: locking bug introduced by commit 67fd4fcb (Dean Nelson) [737713]
- [netdrv] e1000e: bad short packets received when jumbos enabled on 82579 (Dean Nelson) [737713]
- [netdrv] e1000e: make function tables const (Dean Nelson) [737713]
- [netdrv] intel: convert to SKB paged frag API (Dean Nelson) [737713]
- [netdrv] e1000e: workaround for packet drop on 82579 at 100Mbps (Dean Nelson) [737713]
- [netdrv] 1000e: Spurious interrupts and dropped packets with 82577/8/9 in half-duplex (Dean Nelson) [737713]
- [netdrv] e1000e: convert driver to use extended descriptors (Dean Nelson) [737713]
- [netdrv] e1000e: workaround invalid Tx/Rx tail descriptor register write (Dean Nelson) [737713]
- [netdrv] e1000e: remove e1000_queue_stats (Dean Nelson) [737713]
- [netdrv] e1000e: Add module.h to drivers who were implicitly using it (Dean Nelson) [737713]
- [netdrv] e1000e: convert short duration msleep() to usleep_range() (Dean Nelson) [737713]
- [netdrv] e100: Remove alloc_etherdev error messages (Dean Nelson) [737718]
- [netdrv] e100: remove unused fw_version from .get_drvinfo routine (Dean Nelson) [737718]
- [netdrv] e100: use strcpy in .get_drvinfo routines (Dean Nelson) [737718]
- [netdrv] e100: make sure vlan support isn't advertised on old adapters (Dean Nelson) [737718]
- [netdrv] e100: Remove unnecessary driver assignments of ethtool_ringparam fields to zero (Dean Nelson) [737718]
- [mmc] sd: Fix SDR12 timing regression (Don Zickus) [671335]
- [mmc] sdhci: Fix tuning timer incorrect setting when suspending host (Don Zickus) [671335]
- [mmc] sd: Macro name cleanup for high speed dtr (Don Zickus) [671335]
- [mmc] sd: Handle SD3.0 cards not supporting UHS-I bus speed mode (Don Zickus) [671335]
- [mmc] sd: UHS-I bus speed should be set last in UHS initialization (Don Zickus) [671335]
- [mmc] sdhci: fix retuning timer wrongly deleted in sdhci_tasklet_finish (Don Zickus) [671335]
- [mmc] sdhci: change CONFIG_MMC_RICOH_MMC to y (Don Zickus) [738180 757948]
- [pci] quirk: Always check for lower base frequency quirk for Ricoh 1180:e823 (Don Zickus) [738180 757948]
- [mmc] sdhci: Add Ricoh e823 PCI ID (Don Zickus) [738180 757948]
- [mmc] Added quirks for Ricoh 1180:e823 lower base clock frequency (Don Zickus) [738180 757948]
- [mmc] Add PCI fixup quirks for Ricoh 1180:e823 reader (Don Zickus) [738180 757948]
- [mmc] ricoh_mmc: port from driver to pci quirk (Don Zickus) [738180 757948]
- [mmc] sdhci: add support for retuning mode 1 (Don Zickus) [671335]
- [mmc] sdhci: add support for programmable clock mode (Don Zickus) [671335]
- [mmc] sdhci: enable preset value after uhs initialization (Don Zickus) [671335]
- [mmc] sd: add support for tuning during uhs initialization (Don Zickus) [671335]
- [mmc] sd: report correct speed and capacity of uhs cards (Don Zickus) [671335]
- [mmc] sd: set current limit for uhs cards (Don Zickus) [671335]
- [mmc] sd: add support for uhs bus speed mode selection (Don Zickus) [671335]
- [mmc] sdhci: reset sdclk before setting high speed enable (Don Zickus) [671335]
- [mmc] sd: add support for driver type selection (Don Zickus) [671335]
- [mmc] sd: query function modes for uhs cards (Don Zickus) [671335]
- [mmc] sd: add support for signal voltage switch procedure (Don Zickus) [671335]
- [mmc] sdhci: print SD Command and CAPABILITY_1 when dumping registers (Don Zickus) [671335]
- [mmc] implement SD-combo (IO+mem) support (Don Zickus) [671335]
- [mmc] split mmc_sd_init_card() (Don Zickus) [671335]
- [mmc] SDHC 3.0: correct f_min calculation for SD 3.0 spec (Don Zickus) [671335]
- [mmc] SDHC 3.0: Base clock frequency change in spec 3.0 (Don Zickus) [671335]
- [mmc] SDHC 3.0: support 10-bit divided clock mode (Don Zickus) [671335]
- [mmc] Test bus-width for old MMC devices (Don Zickus) [671335]
- [virt] x86: Update last_guest_tsc in vcpu_put (Frank Arnold) [634293]
- [virt] x86: Implement userspace interface to set virtual_tsc_khz (Frank Arnold) [634293]
- [virt] x86: Delegate tsc-offset calculation to architecture code (Frank Arnold) [634293]
- [virt] x86: Implement call-back to propagate virtual_tsc_khz (Frank Arnold) [634293]
- [virt] x86: Make tsc_delta calculation a function of guest tsc (Frank Arnold) [634293]
- [virt] x86: Let kvm-clock report the right tsc frequency (Frank Arnold) [634293]
- [virt] SVM: Implement infrastructure for TSC_RATE_MSR (Frank Arnold) [634293]
- [scsi] megaraid_sas: Fix instance access in megasas_reset_timer (Tomas Henzl) [759318]
- [scsi] fcoe: Make fcoe_transport_destroy a synchronous operation (Neil Horman) [771251]
- [dm] RAID: Prevent DM RAID from loading bitmap twice (Jonathan E Brassow) [789409]
- [x86] APEI: Add some upstream updates (Matthew Garrett) [728987]
- [netdrv] bnx2x: remove the 'poll' module option (Michal Schmidt) [690070]
- [netdrv] ixgbevf: update to upstream version 2.2.0-k (Andy Gospodarek) [737717]
- [netdrv] ixgbe: update to upstream version 3.6.7-k (Andy Gospodarek) [737715]
- [netdrv] macvtap: Fix the minor device number allocation (Steve Best) [786518]

* Thu Feb 16 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-234.el6]
- [x86] microcode_amd: Add support for CPU family specific container files (Frank Arnold) [787698]
- [mm] HWPOISON: convert pr_debug()s to pr_info() (Dean Nelson) [789789]
- [mm] mm/memory-failure.c: fix page isolated count mismatch (Dean Nelson) [789789]
- [mm] mem-hwpoison: fix page refcount around isolate_lru_page() (Dean Nelson) [789789]
- [mm] include cleanup: Update gfp.h and slab.h includes to prepare for breaking implicit slab.h inclusion from percpu.h (Dean Nelson) [789789]
- [mm] thp: fix unsuitable behavior for hwpoisoned tail page (Dean Nelson) [789789]
- [mm] thp: fix the wrong reported address of hwpoisoned hugepages (Dean Nelson) [789789]
- [mm] thp: fix splitting of hwpoisoned hugepages (Dean Nelson) [789789]
- [mm] thp: compound_trans_order (Dean Nelson) [789789]
- [mm] memcontrol: move if-statement to reflect upstream in prep for next patch (Dean Nelson) [789789]
- [block] DM RAID: Handle failure to read superblock (Jonathan E Brassow) [759567]
- [block] DM RAID: Set MD_CHANGE_DEVS on device rebuild (Jonathan E Brassow) [754271]
- [netdrv] qlcnic: Updated License file (Chad Dupuis) [722299]
- [netdrv] netdev: ethernet dev_alloc_skb to netdev_alloc_skb (Chad Dupuis) [722299]
- [netdrv] qlcnic: Fix API unlock (Chad Dupuis) [722299]
- [netdrv] qlcnic: Fix firmware abort code check (Chad Dupuis) [722299]
- [netdrv] qlcnic: report valid speed and duplex status when link is down (Chad Dupuis) [722299]
- [netdrv] qlcnic: Stop pause ctrl frames on fw hang (Chad Dupuis) [722299]
- [netdrv] qlcnic: Remove alloc_etherdev error messages (Chad Dupuis) [722299]
- [netdrv] sweep the floors and convert some .get_drvinfo routines to strlcpy (Chad Dupuis) [722299]
- [netdrv] net: Remove unnecessary driver assignments of ethtool_ringparam fields to zero (Chad Dupuis) [722299]
- [netdrv] qlcnic: fix beacon and LED test (Chad Dupuis) [722299]
- [netdrv] qlcnic: updated reset sequence (Chad Dupuis) [722299]
- [netdrv] qlcnic: skip IDC ack check in fw reset path (Chad Dupuis) [722299]
- [netdrv] qlcnic: reset loopback mode if promiscous mode setting fails (Chad Dupuis) [722299]
- [netdrv] qlcnic: fix external loopback test (Chad Dupuis) [722299]
- [netdrv] qlcnic: Change CDRP function (Chad Dupuis) [722299]
- [netdrv] qlcnic: Added error logging for firmware abort (Chad Dupuis) [722299]
- [netdrv] qlcnic: add beacon test support (Chad Dupuis) [722299]
- [netdrv] qlcnic: fix cdrp race condition (Chad Dupuis) [722299]
- [netdrv] qlcnic: Add FLT entry for CO cards FW image region (Chad Dupuis) [722299]
- [netdrv] qlcnic: Change debug messages in loopback path (Chad Dupuis) [722299]
- [netdrv] qlcnic: detect fan failure (Chad Dupuis) [722299]
- [netdrv] qlcnic: fix ethtool link status (Chad Dupuis) [722299]
- [netdrv] qlcnic: Added debug info (Chad Dupuis) [722299]
- [netdrv] qlcnic: Move get template from probe to start fw (Chad Dupuis) [722299]
- [netdrv] qlcnic: Fix delay in reset path (Chad Dupuis) [722299]
- [netdrv] qlcnic: FW dump related changes (Chad Dupuis) [722299]
- [netdrv] qlcnic: Fix enviroment variable for udev event generation during FW dump (Chad Dupuis) [722299]
- [netdrv] qlcnic: change capture mask for FW dump (Chad Dupuis) [722299]
- [netdrv] qlcnic: define error code for loopback test (Chad Dupuis) [722299]
- [netdrv] qlcnic: fix race in skb->len access (Chad Dupuis) [722299]
- [netdrv] qlcnic: enable mac-learning in promiscous mode (Chad Dupuis) [722299]
- [netdrv] qlcnic: updated supported cards information (Chad Dupuis) [722299]
- [netdrv] qlcnic: fix chip reset logic (Chad Dupuis) [722299]
- [netdrv] qlcnic: add external loopback support through sysfs (Chad Dupuis) [722299]
- [netdrv] qlcnic: multi protocol internal loopback support added (Chad Dupuis) [722299]
- [netdrv] qlcnic: Add support to enable/disable FW dump capability (Chad Dupuis) [722299]
- [netdrv] qlcnic: fix default operating state of interface (Chad Dupuis) [722299]
- [netdrv] qlcnic: fix initial number of msix entries in adapter (Chad Dupuis) [722299]
- [netdrv] qlcnic: Add code to tune FW dump (Chad Dupuis) [722299]
- [netdrv] qlcnic: Remove holding api lock while taking the dump (Chad Dupuis) [722299]
- [netdrv] qlcnic: Add capability to take FW dump deterministically (Chad Dupuis) [722299]
- [netdrv] qlcnic: Remove casts of void * (Chad Dupuis) [722299]
- [netdrv] qlcnic: Added sysfs node support (Chad Dupuis) [722299]
- [netdrv] qlcnic: Avoid double free of skb in tx path (Chad Dupuis) [722299]
- [netdrv] qlcnic: Fix bug in FW queue dump (Chad Dupuis) [722299]
- [netdrv] qlcnic: Bumped up version number to 5.0.18 (Chad Dupuis) [722299]
- [netdrv] qlcnic: FW dump support (Chad Dupuis) [722299]
- [netdrv] ethtool: cosmetic: Use ethtool ethtool_cmd_speed API (Chad Dupuis) [722299]
- [virt] xen/events: BUG() when we can't allocate our event->irq array (Igor Mammedov) [772981]
- [virt] xen: Populate xenbus device attributes (Igor Mammedov) [772981]
- [virt] xen: use static initializers in xen-balloon.c (Igor Mammedov) [772981]
- [virt] xen-netfront: correct MAX_TX_TARGET calculation (Igor Mammedov) [772981]
- [virt] xen/irq: Alter the locking to use a mutex instead of a spinlock (Igor Mammedov) [772981]
- [virt] xen-blkfront: Fix one off warning about name clash (Igor Mammedov) [772981]
- [virt] xen: set max_pfn_mapped to the last pfn mapped + partial revert (Igor Mammedov) [772981]
- [scsi] qla4xxx: v5.02.00.00.06.03-k1 (Chad Dupuis) [722297]
- [scsi] qla4xxx: Added support to show port_state and port_speed in sysfs (Chad Dupuis) [722297]
- [scsi] scsi_transport_iscsi: Added support to show port_state and port_speed in sysfs (Chad Dupuis) [722297]
- [scsi] qla4xxx: Added support to show targetalias in sysfs (Chad Dupuis) [722297]
- [scsi] libiscsi: Added support to show targetalias in sysfs (Chad Dupuis) [722297]
- [scsi] qla4xxx: trivial cleanup (Chad Dupuis) [722297]
- [scsi] qla4xxx: Update license (Chad Dupuis) [722297]
- [scsi] qla4xxx: Added error logging for firmware abort (Chad Dupuis) [722297]
- [scsi] qla4xxx: Cleanup modinfo display (Chad Dupuis) [722297]
- [scsi] qla4xxx: Clear the RISC interrupt bit during FW init (Chad Dupuis) [722297]
- [scsi] qla4xxx: Disable generating pause frames in case of FW hung (Chad Dupuis) [722297]
- [scsi] qla4xxx: Temperature monitoring for ISP82XX core (Chad Dupuis) [722297]
- [scsi] qla4xxx: Break the loop if the sendtargets list was empty (Chad Dupuis) [722297]
- [scsi] qla4xxx: Limit the ACB Default Timeout value to 12s (Chad Dupuis) [722297]
- [scsi] qla4xxx: cleanup, make qla4xxx_build_ddb_list short (Chad Dupuis) [722297]
- [scsi] qla4xxx: check for FW alive before calling chip_reset (Chad Dupuis) [722297]
- [scsi] qla4xxx: Fix qla4xxx_dump_buffer to dump buffer correctly (Chad Dupuis) [722297]
- [scsi] qla4xxx: Fix the IDC locking mechanism (Chad Dupuis) [722297]
- [scsi] qla4xxx: Wait for disable_acb before doing set_acb (Chad Dupuis) [722297]
- [scsi] qla4xxx: Don't recover adapter if device state is FAILED (Chad Dupuis) [722297]
- [scsi] qla4xxx: fix call trace on rmmod with ql4xdontresethba=1 (Chad Dupuis) [722297]
- [scsi] qla4xxx: Fix CPU lockups when ql4xdontresethba set (Chad Dupuis) [722297]
- [scsi] qla4xxx: Perform context resets in case of context failures (Chad Dupuis) [722297]
- [scsi] treewide: Fix typos in various parts of the kernel, and fix some comments (Chad Dupuis) [722297]
- [scsi] qla4xxx: select iscsi boot sysfs attrs (Chad Dupuis) [722297]
- [scsi] scsi: qla4xxx driver depends on NET (Chad Dupuis) [722297]
- [scsi] qla4xxx: v5.02.00.00.06.02-k14 (Chad Dupuis) [722297]
- [scsi] qla4xxx: Fixed BFS with sendtargets as boot index (Chad Dupuis) [722297]
- [scsi] qlge: Bumped driver version to 1.00.00.30 (Chad Dupuis) [722307]
- [scsi] qlge: Fix memory leak in the process of refill (Chad Dupuis) [722307]
- [scsi] qlge: Removing needless print's which are not (Chad Dupuis) [722307]
- [scsi] qlge: Fixed invalid reference to ip header (Chad Dupuis) [722307]
- [scsi] qlge: Updating Schultz LICENSE.qlge file (Chad Dupuis) [722307]

* Wed Feb 15 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-233.el6]
- [usb] xHCI: set USB2 hardware LPM (Don Zickus) [738877]
- [usb] xHCI: Check host USB2 LPM capability (Don Zickus) [738877]
- [usb] Add a strtobool function matching semantics of existing in kernel equivalents (Don Zickus) [738877]
- [usb] xhci: Fix USB 3.0 device restart on resume (Don Zickus) [738877]
- [usb] usb3.0 ch9 definitions (Don Zickus) [738877]
- [usb] xhci: Clean up 32-bit build warnings (Don Zickus) [738877]
- [usb] xhci: Properly handle COMP_2ND_BW_ERR (Don Zickus) [738877]
- [usb] xhci: Better debugging for critical host errors (Don Zickus) [787110]
- [usb] xhci: Be less verbose during URB cancellation (Don Zickus) [787110]
- [usb] xhci: Remove debugging about ring structure allocation (Don Zickus) [787110]
- [usb] xhci: Remove debugging about toggling cycle bits (Don Zickus) [787110]
- [usb] xhci: Remove debugging for individual transfers (Don Zickus) [787110]
- [usb] xhci: Remove useless sg-list debugging (Don Zickus) [787110]
- [usb] xhci: Remove warnings about MSI and MSI-X capabilities (Don Zickus) [787110]
- [usb] xhci: Remove scary warnings about transfer issues (Don Zickus) [770571 787110]
- [usb] Trivial: xhci: Fix copy-paste error (Don Zickus) [738877]
- [usb] xHCI: fix bug in xhci_clear_command_ring() (Don Zickus) [773109]
- [usb] xHCI: Adding #define values used for hub descriptor (Don Zickus) [738877]
- [usb] XHCI: resume root hubs when the controller resumes (Don Zickus) [738877 747531]
- [usb] xhci: Set slot and ep0 flags for address command (Don Zickus) [738877]
- [usb] xhci: fix lockdep warning on endpoint timeout (Don Zickus) [738877]
- [usb] fix implicit usage of gfp.h in host/xhci-hub.c (Don Zickus) [738877]
- [usb] xHCI: Make xHCI driver have a BOS descriptor (Don Zickus) [738877]
- [usb] xhci: remove CONFIG_PCI in xhci.c's probe function (Don Zickus) [738877]
- [usb] xhci: move xhci_gen_setup() away from -pci (Don Zickus) [738877]
- [usb] xhci: refactor xhci_pci_setup() (Don Zickus) [738877]
- [usb] xhci: replace pci_*_consistent() with dma_*_coherent() (Don Zickus) [738877]
- [usb] xhci: hide MSI code behind PCI bars (Don Zickus) [683681]
- [usb] xhci: group MSI interrupt registration into its own function (Don Zickus) [683681]
- [usb] host: introduce USB_ARCH_HAS_XHCI (Don Zickus) [738877]
- [usb] xHCI: fix debug message (Don Zickus) [738877]
- [usb] xHCI: AMD isoc link TRB chain bit quirk (Don Zickus) [742100]
- [usb] usbcore: add sysfs support to xHCI usb2 hardware LPM (Don Zickus) [738877]
- [usb] xHCI: test USB2 software LPM (Don Zickus) [738877]
- [usb] xHCI: Clear PLC for USB2 root hub ports (Don Zickus) [754045]
- [usb] xHCI: test and clear RWC bit (Don Zickus) [738147 754045]
- [usb] xHCI: set link state (Don Zickus) [738877]
- [usb] usbcore: check device's LPM capability (Don Zickus) [738877]
- [usb] usbcore: get BOS descriptor set (Don Zickus) [738877]
- [usb] xhci-mem.c: xhci_segment_free: No need for checking seg argument (Don Zickus) [738877]
- [usb] xhci-mem.c: Check for ring->first_seg != NULL (Don Zickus) [738877]
- [usb] xhci: USB 3.0 BW checking (Don Zickus) [735951]
- [usb] xhci: Fix mult base in endpoint bandwidth info (Don Zickus) [735951]
- [usb] xhci: ignore xhci version while checking for the link quirk (Don Zickus) [738877]
- [usb] xHCI: prevent infinite loop when processing MSE event (Don Zickus) [738877]
- [usb] xhci: Redundant check in xhci_check_args for xhci->devs (Don Zickus) [738877]
- [usb] xHCI: refine td allocation (Don Zickus) [738877]
- [usb] xhci: Don't print short isoc packets. (Don Zickus) [738877]
- [usb] xhci: Add software BW checking quirk to Intel PPT xHCI (Don Zickus) [735951]
- [usb] xhci: Implement HS/FS/LS bandwidth checking (Don Zickus) [735951]
- [usb] xhci: Track interval bandwidth tables per port/TT (Don Zickus) [738877]
- [usb] xhci: Store endpoint bandwidth information (Don Zickus) [738877]
- [usb] xhci: Store information about roothubs and TTs (Don Zickus) [738877]
- [usb] xhci: Store the "real" root port number (Don Zickus) [738877]
- [usb] xhci: Refactor endpoint limit checking (Don Zickus) [738877]
- [usb] xhci: Rename virt_dev->port to fake_port (Don Zickus) [738877]
- [usb] xhci: If no endpoints changed, don't issue BW command (Don Zickus) [738877]
- [usb] xhci: Handle zero-length isochronous packets (Don Zickus) [738877]
- [usb] xhci: Remove TDs from TD lists when URBs are canceled (Don Zickus) [738877]
- [usb] xhci: Fix failed enqueue in the middle of isoch TD (Don Zickus) [738877]
- [usb] xhci: Fix memory leak during failed enqueue (Don Zickus) [738877]
- [usb] xHCI: report USB2 port in resuming as suspend (Don Zickus) [768238]
- [usb] xHCI: fix port U3 status check condition (Don Zickus) [768238]
- [usb] rename USB_SPEED_VARIABLE to USB_SPEED_WIRELESS (Don Zickus) [738877]
- [usb] Mark EHCI LPM functions as __maybe_unused (Don Zickus) [738877]
- [usb] ehci: disable LPM and PPCD for nVidia MCP89 chips (Don Zickus) [738877]
- [usb] EHCI: Disable langwell/penwell LPM capability (Don Zickus) [738877]
- [usb] EHCI: EHCI 1.1 addendum: Enable Per-port change detect bits (Don Zickus) [738877]
- [usb] EHCI: EHCI 1.1 addendum: Basic LPM feature support (Don Zickus) [738877]
- [usb] EHCI: EHCI 1.1 addendum: preparation (Don Zickus) [738877]
- [net] ipvs: RHEL6: Enable SCTP transport loadbalancing (Thomas Graf) [786953]
- [net] ipvs: Use frag walker helper in SCTP proto support (Thomas Graf) [786953]
- [net] ipvs: provide default ip_vs_conn_{in, out}_get_proto (Thomas Graf) [786953]
- [net] ipvs: lvs sctp protocol handler is incorrectly invoked ip_vs_app_pkt_out (Thomas Graf) [786953]
- [net] ipvs: SCTP Transport Loadbalancing Support (Thomas Graf) [786953]
- [block] mtip32xx: removed the irrelevant argument of mtip_hw_submit_io() and the unused member of struct driver_data (Shyam Iyer) [658388]
- [block] mtip32xx: do rebuild monitoring asynchronously (Shyam Iyer) [658388]
- [block] mtip32xx: uninitialized variable in mtip_quiesce_io() (Shyam Iyer) [658388]
- [block] mtip32xx: updates based on feedback (Shyam Iyer) [658388]
- [block] mtip32xx: add module.h include to avoid conflict with moduleh tree (Shyam Iyer) [658388]
- [block] mtip32xx: mark a few more items static (Shyam Iyer) [658388]
- [block] mtip32xx: ensure that all local functions are static (Shyam Iyer) [658388]
- [block] mtip32xx: cleanup compat ioctl handling (Shyam Iyer) [658388]
- [block] mtip32xx: fix warnings/errors on 32-bit compiles (Shyam Iyer) [658388]
- [block] mtip32xx: RHEL specific config changes (Shyam Iyer) [658388]
- [ata] Split ahci.c to ahci.h (Shyam Iyer) [658388]
- [block] Add driver for Micron RealSSD pcie flash cards (Shyam Iyer) [658388]
- [usb] When hot reset for USB3 fails, try warm reset (Don Zickus) [734699 738151 742146 784430]
- [usb] usbcore: refine warm reset logic (Don Zickus) [734699 738151 742146 784430]
- [usb] xhci: Set change bit when warm reset change is set (Don Zickus) [734699 738151 742146 784430]
- [usb] xhci: Clear warm reset change event during init (Don Zickus) [734699 738151 742146 784430]
- [usb] Reset USB 3.0 devices on (re)discovery (Don Zickus) [734699 738151 742146 784430]
- [usb] use "device number" instead of "address" (Don Zickus) [734699 738151 742146 784430]
- [fs] nfs: Additional readdir cookie loop information (Steve Dickson) [770250]
- [fs] NFS: Fix spurious readdir cookie loop messages (Steve Dickson) [770250]
- [fs] NFSv4: Save the owner/group name string when doing open (Jeff Layton) [739797]
- [fs] tracepoint: add drop_transaction/update_superblock_end to jbd2 (Lukas Czerner) [738726]
- [scsi] Fix block queue and elevator memory leak in scsi_alloc_sdev (Jeff Moyer) [769652]
- [scsi] Make scsi_free_queue() kill pending SCSI commands (David Milburn) [784117]
- [scsi] isci: kill iphy->isci_port lookups (David Milburn) [718264]
- [scsi] scsi_dh_rdac: Fix for unbalanced reference count (Mike Snitzer) [749265]
- [x86] tsc: Fix SMI induced variation in quick_pit_calibrate() (John Villalovos) [787332]
- [virt] kvm: introduce x86_cpuinit.early_percpu_clock_init hook (Igor Mammedov) [788562]
- [netdrv] igb driver update (Stefan Assmann) [737714]

* Mon Feb 13 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-232.el6]
- [kernel] mm-tracepoint: fix documentation and examples (Jiri Olsa) [788156]
- [kernel] perf tools: Fix compile error on x86_64 Ubuntu (Jiri Olsa) [788156]
- [kernel] perf report: Fix --stdio output alignment when --showcpuutilization used (Jiri Olsa) [788156]
- [kernel] perf annotate: Get rid of field_sep check (Jiri Olsa) [788156]
- [kernel] perf annotate: Fix usage string (Jiri Olsa) [788156]
- [kernel] perf kmem: Fix a memory leak (Jiri Olsa) [788156]
- [kernel] perf kmem: Add missing closedir() calls (Jiri Olsa) [788156]
- [kernel] perf top: Add error message for EMFILE (Jiri Olsa) [788156]
- [kernel] perf test: Change type of '-v' option to INCR (Jiri Olsa) [788156]
- [kernel] perf script: Add missing closedir() calls (Jiri Olsa) [788156]
- [kernel] perf tools: Add const.h to MANIFEST to make perf-tar-src-pkg work again (Jiri Olsa) [788156]
- [kernel] perf top: Don't update total_period on process_sample (Jiri Olsa) [788156]
- [kernel] perf hists: Stop using 'self' for struct hist_entry (Jiri Olsa) [788156]
- [kernel] perf hists: Rename total_session to total_period (Jiri Olsa) [788156]
- [kernel] perf kvm: Fix copy & paste error in description (Jiri Olsa) [788156]
- [kernel] perf script: Kill script_spec__delete (Jiri Olsa) [788156]
- [kernel] perf top: Fix a memory leak (Jiri Olsa) [788156]
- [kernel] perf stat: Introduce get_ratio_color() helper (Jiri Olsa) [788156]
- [kernel] perf session: Remove impossible condition check (Jiri Olsa) [788156]
- [kernel] perf tools: Fix feature-bits rework fallout, remove unused variable (Jiri Olsa) [788156]
- [kernel] perf script: Add generic perl handler to process events (Jiri Olsa) [788156]
- [kernel] perf tools: Use for_each_set_bit() to iterate over feature flags (Jiri Olsa) [788156]
- [kernel] perf tools: Unify handling of features when writing feature section (Jiri Olsa) [788156]
- [kernel] perf report: Accept fifos as input file (Jiri Olsa) [788156]
- [kernel] perf tools: Moving code in some files (Jiri Olsa) [788156]
- [kernel] perf tools: Fix out-of-bound access to struct perf_session (Jiri Olsa) [788156]
- [kernel] perf tools: Continue processing header on unknown features (Jiri Olsa) [788156]
- [kernel] perf tools: Improve macros for struct feature_ops (Jiri Olsa) [788156]
- [kernel] perf: builtin-record: Document and check that mmap_pages must be a power of two (Jiri Olsa) [788156]
- [kernel] perf: builtin-record: Provide advice if mmap'ing fails with EPERM (Jiri Olsa) [788156]
- [kernel] perf tools: Fix truncated annotation (Jiri Olsa) [788156]
- [kernel] perf script: look up thread using tid instead of pid (Jiri Olsa) [788156]
- [kernel] perf tools: Look up thread names for system wide profiling (Jiri Olsa) [788156]
- [kernel] perf tools: Fix comm for processes with named threads (Jiri Olsa) [788156]
- [kernel] perf report: Fix usage string (Jiri Olsa) [788156]
- [kernel] perf test: Add more automated tests for event parsing (Jiri Olsa) [788156]
- [kernel] perf events: Tidy up perf_event__preprocess_sample (Jiri Olsa) [788156]
- [kernel] perf tools: Remove stale git headlines from top comment (Jiri Olsa) [788156]
- [kernel] perf tools: Fix a memory leak on perf_read_values_destroy (Jiri Olsa) [788156]
- [kernel] perf symbols: Fix error path on symbol__init() (Jiri Olsa) [788156]
- [kernel] perf symbols: Get rid of duplicated snprintf() (Jiri Olsa) [788156]
- [kernel] perf evlist: Fix errno value reporting on failed mmap (Jiri Olsa) [788156]
- [kernel] perf report: Document '--call-graph' for optional print_limit argument (Jiri Olsa) [788156]
- [kernel] perf evsel: Fix uninitialized memory access to struct perf_sample (Jiri Olsa) [788156]
- [kernel] perf record: Add ability to record event period (Jiri Olsa) [788156]
- [kernel] perf tools: Add ability to synthesize event according to a sample (Jiri Olsa) [788156]
- [kernel] perf script: Implement option for system-wide profiling (Jiri Olsa) [788156]
- [kernel] perf script: Fix mem leaks and NULL pointer checks around strdup()s (Jiri Olsa) [788156]
- [kernel] perf test: Soft errors shouldn't stop the "Validate PERF_RECORD_" test (Jiri Olsa) [788156]
- [kernel] perf test: Validate PERF_RECORD_ events and perf_sample fields (Jiri Olsa) [788156]
- [kernel] perf event: Introduce perf_event__fprintf (Jiri Olsa) [788156]
- [kernel] perf test: Allow running just a subset of the available tests (Jiri Olsa) [788156]
- [kernel] perf evlist: Always do automatic allocation of pollfd and mmap structures (Jiri Olsa) [788156]
- [kernel] perf tools: Save some loops using perf_evlist__id2evsel (Jiri Olsa) [788156]
- [kernel] perf script: Add comm filtering option (Jiri Olsa) [788156]
- [kernel] perf tools: make -C consistent across commands (for cpu list arg) (Jiri Olsa) [788156]
- [kernel] perf top: Stop using globals for tool state (Jiri Olsa) [788156]
- [kernel] perf tools: Rename perf_event_ops to perf_tool (Jiri Olsa) [788156]
- [kernel] perf tools: Resolve machine earlier and pass it to perf_event_ops (Jiri Olsa) [788156]
- [kernel] perf tools: Pass tool context in the the perf_event_ops functions (Jiri Olsa) [788156]
- [kernel] perf annotate: Group options in a struct (Jiri Olsa) [788156]
- [kernel] perf report: Group options in a struct (Jiri Olsa) [788156]
- [kernel] perf tools: Use evsel->attr.sample_type instead of session->sample_type (Jiri Olsa) [788156]
- [kernel] perf session: Remove superfluous callchain_cursor member (Jiri Olsa) [788156]
- [kernel] perf event: perf_event_ops->attr() manipulates only an evlist (Jiri Olsa) [788156]
- [kernel] perf evlist: Introduce id_hdr_size method out of perf_session (Jiri Olsa) [788156]
- [kernel] perf symbols: Add nr_events to symbol_conf (Jiri Olsa) [788156]
- [kernel] perf ui progress: Fix divide by zero (Jiri Olsa) [788156]
- [kernel] perf record: Move 'group' to perf_event_ops (Jiri Olsa) [788156]
- [kernel] perf session: Move threads to struct machine (Jiri Olsa) [788156]
- [kernel] perf record: Move mmap_pages to perf_record_opts (Jiri Olsa) [788156]
- [kernel] perf evlist: Handle default value for 'pages' on mmap method (Jiri Olsa) [788156]
- [kernel] perf evlist: Introduce {prepare, start}_workload refactored from 'perf record' (Jiri Olsa) [788156]
- [kernel] perf evsel: Introduce config attr method (Jiri Olsa) [788156]
- [kernel] perf evlist: Introduce add_tracepoints method (Jiri Olsa) [788156]
- [kernel] perf evlist: Introduce perf_evlist__add_attrs (Jiri Olsa) [788156]
- [kernel] perf tools: Simplify debugfs mountpoint handling code (Jiri Olsa) [788156]
- [kernel] perf tools: Eliminate duplicate code and use PATH_MAX consistently (Jiri Olsa) [788156]
- [kernel] perf/powerpc: Fix build for PowerPC with uclibc toolchains (Jiri Olsa) [788156]
- [fs] epoll: fix compiler warning and optimize the non-blocking path (Jason Baron) [709197]
- [fs] epoll: move ready event check into proper inline (Jason Baron) [709197]
- [fs] epoll: epoll_wait() should not use timespec_add_ns() (Jason Baron) [709197]
- [fs] epoll: make epoll_wait() use the hrtimer range feature (Jason Baron) [709197]
- [fs] select: rename estimate_accuracy() to select_estimate_accuracy() (Jason Baron) [709197]
- [fs] ext4: don't dereference null pointer when make_indexed_dir() fails (Lukas Czerner) [773342]
- [fs] ext4: Fix fs corruption when make_indexed_dir() fails (Lukas Czerner) [773342]
- [fs] ext4: ext4_mkdir should dirty dir_block with newly created directory inode (Lukas Czerner) [773342]
- [scsi] bnx2fc: Bumped version to 1.0.10 (Mike Christie) [740059]
- [scsi] bnx2fc: NPIV ports go offline when interface is brought down & up (Mike Christie) [740059]
- [scsi] bnx2fc: Handle LOGO flooding from the target (Mike Christie) [740059]
- [scsi] bnx2fc: fix panic in bnx2fc_post_io_req (Mike Christie) [740059]
- [scsi] bnx2fc: Handle SRR LS_ACC drop scenario (Mike Christie) [740059]
- [scsi] bnx2fc: Handle ABTS timeout during ulp timeout (Mike Christie) [740059]
- [fs] ext4: ignore EXT4_INODE_JOURNAL_DATA flag with delalloc (Lukas Czerner) [767199]
- [fs] tmpfs: fix off-by-one in max_blocks checks (Eric Sandeen) [783497]
- [s390x] kernel: fix 3215 console deadlock (Hendrik Brueckner) [753578]
- [net] sctp: implement socket option SCTP_GET_ASSOC_ID_LIST (Thomas Graf) [787622]
- [net] tcp: bind() fix autoselection to share ports (Flavio Leitner) [784671]
- [fs] xfs: Fix missing xfs_iunlock() on error recovery path in xfs_readlink() (Carlos Maiolino) [694702]
- [net] sch_qfq: Enable as module (Thomas Graf) [787637]
- [net] sch_qfq: accurate wsum handling (Thomas Graf) [787637]
- [net] sch_qfq: fix overflow in qfq_update_start() (Thomas Graf) [787637]
- [net] pkt_sched: QFQ - quick fair queue scheduler (Thomas Graf) [787637]
- [x86] Add hpet_mmap kernel parameter (Prarit Bhargava) [785667]
- [x86] Configure HPET_MMAP on (Prarit Bhargava) [785667]
- [net] tcp: fix undo after RTO for CUBIC (Thomas Graf) [786956]
- [net] tcp: fix undo after RTO for BIC (Thomas Graf) [786956]
- [net] tcp: drop SYN+FIN messages (Thomas Graf) [786956]
- [net] tcp: skip cwnd moderation in TCP_CA_Open in tcp_try_to_open (Thomas Graf) [786956]
- [net] tcp: allow undo from reordered DSACKs (Thomas Graf) [786956]
- [net] tcp: use SACKs and DSACKs that arrive on ACKs below snd_una (Thomas Graf) [786956]
- [net] tcp: use DSACKs that arrive when packets_out is 0 (Thomas Graf) [786956]
- [net] tcp: make is_dupack a parameter to tcp_fastretrans_alert() (Thomas Graf) [786956]
- [net] tcp: use TCP_DEFAULT_INIT_RCVWND in tcp_fixup_rcvbuf() (Thomas Graf) [786956]
- [net] tcp: use TCP_INIT_CWND in tcp_fixup_sndbuf() (Thomas Graf) [786956]
- [net] tcp: properly update lost_cnt_hint during shifting (Thomas Graf) [786956]
- [net] tcp: ECN blackhole should not force quickack mode (Thomas Graf) [786956]
- [net] tcp: fix validation of D-SACK (Thomas Graf) [786956]
- [net] tcp: Proportional Rate Reduction for TCP (Thomas Graf) [786956]
- [net] tcp: RFC2988bis + taking RTT sample from 3WHS for the passive open side (Thomas Graf) [786956]
- [net] tcp_cubic: limit delayed_ack ratio to prevent divide error (Thomas Graf) [786956]
- [net] tcp: Make undo_ssthresh arg to tcp_undo_cwr() a bool (Thomas Graf) [786956]
- [net] tcp: avoid cwnd moderation in undo (Thomas Graf) [786956]
- [net] tcp: undo_retrans counter fixes (Thomas Graf) [786956]
- [net] tcp: fix a bug that triggers large number of TCP RST by mistake (Thomas Graf) [786956]
- [net] tcp: cleanup of cwnd initialization in tcp_init_metrics() (Thomas Graf) [786956]
- [virt] x86, cpu: add FMA4 and TBM to allowed CPUID bits (Eduardo Habkost) [784856]
- [fs] cifs: change oplock break slow work to very slow work (Jeff Layton) [772874]

* Fri Feb 10 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-231.el6]
- [kernel] timer: add the usleep_range() timer (Dean Nelson) [786458]
- [net] SUNRPC: Add trace events to the sunrpc subsystem (Steve Dickson) [784103]
- [scsi] qla2xxx: Module parameter to control use of async or sync port login (Chad Dupuis) [769007]
- [x86] powernow-k8: Fix indexing issue (Frank Arnold) [781566]
- [x86] powernow-k8: Avoid Pstate MSR accesses on systems supporting CPB (Frank Arnold) [781566]
- [x86] hpet: Immediately disable HPET timer 1 if rtc irq is masked (Frank Arnold) [787695]
- [x86] rtc: disable hpet emulation on suspend (Frank Arnold) [787695]
- [x86] Report cpb and eff_freq_ro flags correctly (Frank Arnold) [787687]
- [x86] cpuinfo: Add feature flags for AMD fam15h model 10h-1fh processors (Frank Arnold) [787687]
- [net] ipv6: Generic TTL Security Mechanism (Weiping Pan) [786948]
- [net] ipv4: Generalized TTL Security Mechanism (Weiping Pan) [787311]
- [scsi] fix the new host byte settings (DID_TARGET_FAILURE and DID_NEXUS_FAILURE) (Mike Snitzer) [787282]
- [scsi] Correctly set the scsi host/msg/status bytes (Mike Snitzer) [787282]
- [scsi] Add all the definitions of host bytes to hostbyte_table (Mike Snitzer) [787282]
- [virt] virtio: balloon: Add freeze, restore handlers to support S4 (Amit Shah) [624189]
- [virt] virtio: balloon: Move vq initialization into separate function (Amit Shah) [624189]
- [virt] virtio: net: Add freeze, restore handlers to support S4 (Amit Shah) [582178]
- [virt] virtio: net: Move vq and vq buf removal into separate function (Amit Shah) [582178]
- [virt] virtio: net: Move vq initialization into separate function (Amit Shah) [582178]
- [virt] virtio: blk: Add freeze, restore handlers to support S4 (Amit Shah) [542378]
- [virt] virtio: blk: Move vq initialization to separate function (Amit Shah) [542378]
- [virt] virtio: console: Disable callbacks for virtqueues at start of S4 freeze (Amit Shah) [623913]
- [virt] virtio: console: Add freeze and restore handlers to support S4 (Amit Shah) [623913]
- [virt] virtio: console: Move vq and vq buf removal into separate functions (Amit Shah) [623913]
- [virt] virtio: pci: add PM notification handlers for restore, freeze, thaw, poweroff (Amit Shah) [542378 582178 623913 624189]
- [virt] virtio: pci: switch to new PM API (Amit Shah) [542378 582178 623913 624189]
- [virt] virtio_blk: fix config handler race (Amit Shah) [542378]
- [virt] virtio_net: use singlethread workqueue (Amit Shah) [582178]
- [virt] virtio_net: set/cancel work on ndo_open/ndo_stop (Amit Shah) [582178]
- [serial] jsm: Fixed EEH recovery error (Steve Best) [742551]
- [serial] jsm: adding EEH handlers (Steve Best) [742551]
- [scsi] isci: fix, prevent port from getting stuck in the 'configuring' state (David Milburn) [747533]
- [scsi] isci: fix start OOB (David Milburn) [747533]
- [scsi] isci: fix io failures while wide port links are coming up (David Milburn) [747533]
- [scsi] isci: allow more time for wide port targets (David Milburn) [747533]
- [scsi] isci: enable wide port targets (David Milburn) [747533]
- [scsi] isci: Fix IO fails when pull cable from phy in x4 wideport in MPC mode (David Milburn) [747533]
- [scsi] isci: update version to 1.1 (David Milburn) [747533]
- [scsi] isci: remove unused 'isci_tmf->device' field (David Milburn) [747533]
- [scsi] isci: performance-fix, shorten default "no outbound task" timeout (David Milburn) [747533]
- [scsi] isci: oem parameter format v1.3 (David Milburn) [747533]
- [scsi] isci: oem parameter format v1.1 (David Milburn) [747533]
- [scsi] isci: update afe (analog-front-end) recipe for C1 (David Milburn) [747533]
- [scsi] isci: Cleanup oem parameter and recipe handling (David Milburn) [747533]
- [net] skbuf.h: Fix parameter documentation (Dean Nelson) [786639]
- [net] add APIs for manipulating skb page fragments (Dean Nelson) [786639]
- [scsi] scsi_dh_alua: Retry the check-condition in case Mode Parameters Changed (Mike Snitzer) [772305]
- [scsi] scsi_dh_alua: Add one more check-condition for alua handler (Mike Snitzer) [772305]
- [scsi] scsi_dh_rdac: Adding NetApp as a brand name for rdac (Mike Snitzer) [772305]
- [net] config: Adding generic config option to enable netprio cgroups (Neil Horman) [772974]
- [net] add documentation for net_prio cgroups (Neil Horman) [772974]
- [net] add network priority cgroup infrastructure (Neil Horman) [772974]
- [s390x] dasd: wait for terminated request (Hendrik Brueckner) [745999]
- [sound] Update the ALSA HDA audio driver from upstream (Jaroslav Kysela) [760490]
- [kernel] perf header: Use event_name() to get an event name (Jiri Olsa) [784888]
- [kernel] perf stat: Failure with "Operation not supported" (Jiri Olsa) [784888]
- [kernel] perf: Fix parsing of __print_flags() in TP_printk() (Jiri Olsa) [784888]
- [kernel] perf session: Fix crash with invalid CPU list (Jiri Olsa) [784888]
- [kernel] perf python: Fix undefined symbol problem (Jiri Olsa) [784888]
- [kernel] perf top: Fix live annotation in the --stdio interface (Jiri Olsa) [784888]
- [kernel] perf top tui: Don't recalc column widths considering just the first page (Jiri Olsa) [784888]
- [kernel] perf report: Add progress bar when processing time ordered events (Jiri Olsa) [784888]
- [kernel] perf hists browser: Warn about lost events (Jiri Olsa) [784888]
- [kernel] perf tools: Fix a typo of command name as trace-cmd (Jiri Olsa) [784888]
- [kernel] perf hists: Fix recalculation of total_period when sorting entries (Jiri Olsa) [784888]
- [kernel] perf ui browser: Handle K_RESIZE in dialog windows (Jiri Olsa) [784888]
- [kernel] perf ui browser: No need to switch char sets that often (Jiri Olsa) [784888]
- [kernel] perf hists browser: Use K_TIMER (Jiri Olsa) [784888]
- [kernel] perf ui: Rename ui__warning_paranoid to ui__error_paranoid (Jiri Olsa) [784888]
- [kernel] perf ui: Reimplement the popup windows using libslang (Jiri Olsa) [784888]
- [kernel] perf ui: Reimplement ui__popup_menu using ui__browser (Jiri Olsa) [784888]
- [kernel] perf ui: Reimplement ui_helpline using libslang (Jiri Olsa) [784888]
- [kernel] perf ui: Improve handling sigwinch a bit (Jiri Olsa) [784888]
- [kernel] perf ui progress: Reimplement using slang (Jiri Olsa) [784888]
- [kernel] perf evlist: Fix grouping of multiple events (Jiri Olsa) [784888]
- [kernel] perf symbols: Increase symbol KSYM_NAME_LEN size (Jiri Olsa) [784888]
- [kernel] perf hists browser: Refuse 'a' hotkey on non symbolic views (Jiri Olsa) [784888]
- [kernel] perf ui browser: Use libslang to read keys (Jiri Olsa) [784888]
- [kernel] perf tools: Fix tracing info recording (Jiri Olsa) [784888]
- [kernel] perf hists browser: Elide DSO column when it is set to just one DSO, ditto for threads (Jiri Olsa) [784888]
- [kernel] perf hists: Don't consider filtered entries when calculating column widths (Jiri Olsa) [784888]
- [kernel] perf hists: Don't decay total_period for filtered entries (Jiri Olsa) [784888]
- [kernel] perf hists browser: Honour symbol_conf.show_nr_samples, total_period (Jiri Olsa) [784888]
- [kernel] perf hists browser: Do not exit on tab key with single event (Jiri Olsa) [784888]
- [kernel] perf annotate browser: Don't change selection line when returning from callq (Jiri Olsa) [784888]
- [kernel] perf tools: handle endianness of feature bitmap (Jiri Olsa) [784888]
- [kernel] perf tools: Add prelink suggestion to dso update message (Jiri Olsa) [784888]
- [kernel] perf script: Fix unknown feature comment (Jiri Olsa) [784888]
- [kernel] perf hists browser: Apply the dso and thread filters when merging new batches (Jiri Olsa) [784888]
- [kernel] perf hists: Move the dso and thread filters from hist_browser (Jiri Olsa) [784888]
- [kernel] perf ui browser: Honour the xterm colors (Jiri Olsa) [784888]
- [kernel] perf top tui: Give color hints just on the percentage, like on --stdio (Jiri Olsa) [784888]
- [kernel] perf ui browser: Make the colors configurable and change the defaults (Jiri Olsa) [784888]
- [kernel] perf tui: Remove unneeded call to newtCls on startup (Jiri Olsa) [784888]
- [kernel] perf hists: Don't format the percentage on hist_entry__snprintf (Jiri Olsa) [784888]
- [kernel] perf ui browser: Allow initial use without navigation UI elements (Jiri Olsa) [784888]
- [kernel] perf tui: Catch signals to exit gracefully (Jiri Olsa) [784888]
- [kernel] perf hists browser: Add missing hotkeys to the help window (Jiri Olsa) [784888]
- [kernel] perf top: Fix the 'E' hotkey, select among multiple events (Jiri Olsa) [784888]
- [kernel] perf top: Honour --hide_{user, kernel}_symbols and the 'U' hotkey (Jiri Olsa) [784888]
- [kernel] perf buildid: Fix possible unterminated readlink() result buffer (Jiri Olsa) [784888]
- [kernel] perf annotate browser: Allow toggling the visualization of source code lines (Jiri Olsa) [784888]
- [kernel] perf ui browser: Add filter method (Jiri Olsa) [784888]
- [kernel] perf annotate browser: Exit when pressing ESC or the left arrow (Jiri Olsa) [784888]
- [kernel] perf hists browser: Invalidate ui_browser->top after timer calls (Jiri Olsa) [784888]
- [kernel] perf hists browser: Fix handling of TAB/UNTAB for multiple events (Jiri Olsa) [784888]
- [kernel] perf top: Remove entries from entries_collapsed on decay (Jiri Olsa) [784888]
- [kernel] perf ui browser: Remove ui_browser__add_exit_keys (Jiri Olsa) [784888]
- [kernel] perf ui browser: Handle SIGWINCH (Jiri Olsa) [784888]
- [kernel] perf hists: Fix compilation when NO_NEWT_SUPPORT is set (Jiri Olsa) [784888]
- [kernel] perf hists: Don't free decayed entries if in the annotation browser (Jiri Olsa) [784888]
- [kernel] perf hists browser: Recalculate browser pointers after resort/decay (Jiri Olsa) [784888]
- [kernel] perf probe: Fix to show correct error string (Jiri Olsa) [784888]
- [kernel] perf tools: Make --no-asm-raw the default (Jiri Olsa) [784888]
- [kernel] perf tools: Make perf.data more self-descriptive (Jiri Olsa) [784888]
- [kernel] perf: Move arch specific code into separate arch directory (Jiri Olsa) [784888]
- [kernel] perf hists browser: Update the browser.nr_entries after the timer (Jiri Olsa) [784888]
- [kernel] perf hists browser: Fix TAB/UNTAB use with multiple events (Jiri Olsa) [784888]
- [kernel] perf hists browser: Don't offer symbol actions when symbols not on --sort (Jiri Olsa) [784888]
- [kernel] perf annotate browser: Use -> to navigate on assembly lines (Jiri Olsa) [784888]
- [kernel] perf tools: Fix broken number of samples for perf report -n (Jiri Olsa) [784888]
- [kernel] perf top: Use the TUI interface by default (Jiri Olsa) [784888]
- [kernel] perf annotate browser: Allow navigation to called functions (Jiri Olsa) [784888]
- [kernel] perf top: Add callgraph support (Jiri Olsa) [784888]
- [kernel] perf top: Reuse the 'report' hist_entry/hists classes (Jiri Olsa) [784888]
- [kernel] perf browsers: Add live mode to the hists, annotate browsers (Jiri Olsa) [784888]
- [kernel] perf hists: Threaded addition and sorting of entries (Jiri Olsa) [784888]
- [kernel] perf report: Add option to show total period (Jiri Olsa) [784888]
- [kernel] perf hists: Allow limiting the number of rows and columns in fprintf (Jiri Olsa) [784888]
- [kernel] perf hists: Stop using 'self' for struct hists (Jiri Olsa) [784888]
- [kernel] perf report: Fix stdio event name header printing (Jiri Olsa) [784888]
- [kernel] perf: Support setting the disassembler style (Jiri Olsa) [784888]
- [kernel] perf tools: Make stat/record print fatal signals of the target program (Jiri Olsa) [784888]
- [kernel] perf stat: Fix spelling in comment (Jiri Olsa) [784888]
- [kernel] perf stat: Allow tab as cvs delimiter (Jiri Olsa) [784888]
- [kernel] perf stat: Suppress printing std-dev when its 0 (Jiri Olsa) [784888]
- [kernel] perf stat: Fix +- nan in --no-aggr runs (Jiri Olsa) [784888]
- [kernel] perf stat: Add --log-fd <N> option to redirect stderr elsewhere (Jiri Olsa) [784888]
- [kernel] perf top: Improve lost events warning (Jiri Olsa) [784888]
- [kernel] perf, tool: Leftover from latest util/event.[ch] 3.1 sync (Jiri Olsa) [784888]
- [kernel] perf top browser: Fix up line width calculation (Jiri Olsa) [784888]
- [kernel] perf buildid-list: Support showing the build id in an ELF file (Jiri Olsa) [784888]
- [kernel] perf buildid-list: Add option to show the running kernel build id (Jiri Olsa) [784888]
- [kernel] perf script: Add drop monitor script (Jiri Olsa) [784888]
- [kernel] perf symbols: Stop using 'self' in map_groups__ methods (Jiri Olsa) [784888]
- [kernel] perf stat: Add -o and --append options (Jiri Olsa) [784888]
- [kernel] perf annotate: Add --symfs option (Jiri Olsa) [784888]
- [kernel] perf annotate: Make output more readable (Jiri Olsa) [784888]
- [kernel] doc: fix broken references (Jiri Olsa) [784888]
- [fs] ecryptfs: fix regression that prevents umount of underlying filesystem (Brian Foster) [766554]
- [scsi] ipr: fix eeh recovery for 64-bit adapters (Steve Best) [783875]
- [kernel] ipc: introduce shm_rmid_forced sysctl (Rafael Aquini) [781600]
- [pm] sleep: Fix race between CPU hotplug and freezer (Prarit Bhargava) [747224]
- [kernel] Prevent system deadlock when moving tasks between cgroups (Larry Woodman) [773522]
- [kernel] sched: Fix rt_rq runtime leakage bug (Steve Best) [736931]
- [x86] Remove AMD microcode warning (Prarit Bhargava) [786961]
- [netdrv] tg3: Fix single-vector MSI-X code (John Feeney) [703555]
- [netdrv] netxen: suppress false lro warning messages (Veaceslav Falico) [699382]
- [netdrv] cxgb4: remove forgotten real_num_tx_queues inicialization (Jiri Pirko) [745952]
- [mm] export remove_from_page_cache() to modules (Jerome Marchand) [751419]
- [fs] GFS2: Corrections to directory read-ahead (Robert S Peterson) [681906]
- [fs] GFS2: Corrections to cache dir hash table in a contiguous buffer (Robert S Peterson) [681906]

* Thu Feb 09 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-230.el6]
- [scsi] bfa: fix enidan and bit field check bug (Rob Evers) [737727]
- [scsi] bfa: fix formating and checkpatch issues (Rob Evers) [737727]
- [netdrv] ixgbe: Reconfigure SR-IOV Init (Don Dutile) [769499]
- [netdrv] igb: Check if subordinate VFs are assigned to virtual machines (Don Dutile) [769499]
- [pci] Add flag indicating device has been assigned by KVM (Don Dutile) [769499]
- [scsi] st: fix race in st_scsi_execute_end (Tomas Henzl) [716593]
- [scsi] st: Increase success probability in driver buffer allocation (Tomas Henzl) [716593]
- [scsi] st: Store page order before driver buffer allocation (Tomas Henzl) [716593]
- [fs] GFS2: remove vestigial al_alloced (Steven Whitehouse) [747896]
- [fs] GFS2: combine gfs2_alloc_block and gfs2_alloc_di (Steven Whitehouse) [747896]
- [fs] GFS2: Resource group related fixes (Steven Whitehouse) [747896]
- [fs] Use cached rgrp in gfs2_rlist_add() (Steven Whitehouse) [747896]
- [fs] GFS2: Call do_strip() directly from recursive_scan() (Steven Whitehouse) [747896]
- [fs] GFS2: Remove obsolete assert patch (Steven Whitehouse) [747896]
- [fs] GFS2: Cache the most recently used resource group in the inode (Steven Whitehouse) [747896]
- [fs] GFS2: Make resource groups "append only" during lifetime of fs (Steven Whitehouse) [747896]
- [fs] GFS2: Use rbtree for resource groups and clean up bitmap buffer ref count scheme (Steven Whitehouse) [747896]
- [virt] SVM: Add support for perf-kvm (Gleb Natapov) [632768]
- [virt] KVM: Implement perf callbacks for guest sampling (Gleb Natapov) [632768]
- [net] mqprio: Enable as module (Thomas Graf) [695553]
- [net] mqprio: RHEL6 modifications (Thomas Graf) [695553]
- [net] mqprio: Avoid panic if no options are provided (Thomas Graf) [695553]
- [net] mqprio: cleanups (Thomas Graf) [695553]
- [net] mqprio: Always set num_tc to 0 in mqprio_destroy() (Thomas Graf) [695553]
- [net] mqprio: dont leak kernel memory (Thomas Graf) [695553]
- [net] mqprio: implement a root container qdisc sch_mqprio (Thomas Graf) [695553]
- [fs] NFSv4: Change the default setting of the nfs4_disable_idmapping parameter (Steve Dickson) [705099]
- [fs] NFSv4: Send unmapped uid/gids to the server when using auth_sys (Steve Dickson) [705099]
- [fs] NFSv4: cleanup idmapper functions to take an nfs_server argument (Steve Dickson) [705099]
- [fs] NFSv4: Send unmapped uid/gids to the server if the idmapper fails (Steve Dickson) [705099]
- [fs] NFSv4: If the server sends us a numeric uid/gid then accept it (Steve Dickson) [705099]
- [block] cfq-iosched: fix cfq_cic_link() race confition (Vivek Goyal) [765673]
- [ata] ahci: AHCI mode SATA patch for Intel DH89xxCC DeviceIDs (Jes Sorensen) [773295]
- [fs] autofs4: fix expire race (Ian Kent) [766818]
- [fs] cifs: lower default wsize when unix extensions are not used (Jeff Layton) [773705]
- [fs] wake up s_wait_unfrozen when ->freeze_fs fails (Eric Sandeen) [759942]
- [net] bonding: Allow Bonding driver to disable/enable LRO on slaves (Neil Horman) [772317]
- [net] Fix RFS backport error (Neil Horman) [757040]
- [kexec] kdump: lower KEXEC_AUTO_THRESHOLD to 2G (Dave Young) [772311]
- [kernel] sched: fix {s,u}time values decrease (Stanislaw Gruszka) [748559]
- [block] Add missing config option ASYNC_RAID6_TEST (Jes Sorensen) [704003]
- [block] Introduce blk_set_stacking_limits function (Mike Snitzer) [755046]
- [netdrv] bna: clear some statistics before filling them (Ivan Vecera) [756931]
- [x86] Fix c-state transitions when !NOHZ (Prarit Bhargava) [767753]
- [x86] tsc: Skip TSC synchronization checks for tsc=reliable (Prarit Bhargava) [767753]
- [mm] Backport upstream vmalloc fix to verify address is valid before dereferencing pointer (Larry Woodman) [767889]

* Wed Feb 08 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-229.el6]
- [scsi] remove tech_preview tag for mpt2sas lockless mode (Luming Yu) [559393]
- [dm] thinp: port to RHEL6 (Mike Snitzer) [723018]
- [dm] thinp: use simple_strtox rather than kstrtox (Mike Snitzer) [723018]
- [dm] thinp: enable on all supported RHEL6 architectures (Mike Snitzer) [723018]
- [dm] add thin provisioning target (Mike Snitzer) [723018]
- [dm] add persistent data library (Mike Snitzer) [723018]
- [dm] add bufio (Mike Snitzer) [723018]
- [md] bitmap: It is OK to clear bits during recovery (Jes Sorensen) [747574]
- [md] don't give up looking for spares on first failure-to-add (Jes Sorensen) [747574]
- [md] raid5: ensure correct assessment of drives during degraded reshape (Jes Sorensen) [747574]
- [md] linear: fix hot-add of devices to linear arrays (Jes Sorensen) [747574]
- [md] raid5 crash during degradation (Jes Sorensen) [747574]
- [md] raid5: never wait for bad-block acks on failed device (Jes Sorensen) [747574]
- [md] ensure new badblocks are handled promptly (Jes Sorensen) [747574]
- [md] bad blocks shouldn't cause a Blocked status on a Faulty device (Jes Sorensen) [747574]
- [md] take a reference to mddev during sysfs access (Jes Sorensen) [747574]
- [md] refine interpretation of "hold_active == UNTIL_IOCTL" (Jes Sorensen) [747574]
- [md] lock: ensure updates to page_attrs are properly locked (Jes Sorensen) [747574]
- [md] raid5: STRIPE_ACTIVE has lock semantics, add barriers (Jes Sorensen) [747574]
- [md] raid5: abort any pending parity operations when array fails (Jes Sorensen) [747574]
- [md] Add module.h to all files using it implicitly (Jes Sorensen) [747574]
- [md] raid10: Fix bug when activating a hot-spare (Jes Sorensen) [747574]
- [md] Fix some bugs in recovery_disabled handling (Jes Sorensen) [747574]
- [md] raid5: fix bug that could result in reads from a failed device (Jes Sorensen) [747574]
- [md] trivial comment fix (Jes Sorensen) [747574]
- [md] Allow restarting an interrupted incremental recovery (Jes Sorensen) [747574]
- [md] clear In_sync bit on devices added to an active array (Jes Sorensen) [747574]
- [md] add proper write-congestion reporting to RAID1 and RAID10 (Jes Sorensen) [747574]
- [md] rename "mdk_personality" to "md_personality" (Jes Sorensen) [747574]
- [md] bitmap remove fault injection options (Jes Sorensen) [747574]
- [md] raid5: typedef removal: raid5_conf_t -> struct r5conf (Jes Sorensen) [747574]
- [md] raid1: typedef removal: conf_t -> struct r1conf (Jes Sorensen) [747574]
- [md] raid10: typedef removal: conf_t -> struct r10conf (Jes Sorensen) [747574]
- [md] raid0: typedef removal: raid0_conf_t -> struct r0conf (Jes Sorensen) [747574]
- [md] multipath: typedef removal: multipath_conf_t -> struct mpconf (Jes Sorensen) [747574]
- [md] linear: typedef removal: linear_conf_t -> struct linear_conf (Jes Sorensen) [747574]
- [md] faulty: remove typedef: conf_t -> struct faulty_conf (Jes Sorensen) [747574]
- [md] linear: remove typedefs: dev_info_t -> struct dev_info (Jes Sorensen) [747574]
- [md] remove typedefs: mirror_info_t -> struct mirror_info (Jes Sorensen) [747574]
- [md] remove typedefs: r10bio_t -> struct r10bio and r1bio_t -> struct r1bio (Jes Sorensen) [747574]
- [md] remove typedefs: mdk_thread_t -> struct md_thread (Jes Sorensen) [747574]
- [md] remove typedefs: mddev_t -> struct mddev (Jes Sorensen) [747574]
- [md] removing typedefs: mdk_rdev_t -> struct md_rdev (Jes Sorensen) [747574]
- [md] raid0: convert some printks to pr_debug (Jes Sorensen) [747574]
- [md] remove PRINTK and dprintk debugging and use pr_debug (Jes Sorensen) [747574]
- [md] remove some old DEBUGging code (Jes Sorensen) [747574]
- [md] raid5: convert to macros into inline functions (Jes Sorensen) [747574]
- [md] raid1: avoid bio search in end_sync_read() (Jes Sorensen) [747574]
- [md] raid1: factor out common bio handling code (Jes Sorensen) [747574]
- [md] raid5: remove pointless NULL test (Jes Sorensen) [747574]
- [md] raid1: add documentation to r1_private_data_s data structure (Jes Sorensen) [747574]
- [md] don't delay reboot by 1 second if no MD devices exist (Jes Sorensen) [747574]
- [md] trival: md_k.h should be md.h in the beginning comment of file md.h (Jes Sorensen) [747574]
- [md] bitmap: improve handling of 'allclean' (Jes Sorensen) [747574]
- [md] bitmap: rename and tidy up BITMAP_PAGE_CLEAN (Jes Sorensen) [747574]
- [md] Fix handling for devices from 2TB to 4TB in 0.90 metadata (Jes Sorensen) [747574]
- [md] raid1, raid10: Remove use-after-free bug in make_request (Jes Sorensen) [747574]
- [md] raid10: unify handling of write completion (Jes Sorensen) [747574]
- [md] raid5: fix a hang on device failure (Jes Sorensen) [747574]
- [md] fix clearing of 'blocked' flag in the presence of bad blocks (Jes Sorensen) [747574]
- [md] linear: avoid corrupting structure while waiting for rcu_free to complete (Jes Sorensen) [747574]
- [md] ensure changes to 'write-mostly' are reflected in metadata (Jes Sorensen) [747574]
- [md] report failure if a 'set faulty' request doesn't (Jes Sorensen) [747574]
- [md] raid10: handle further errors during fix_read_error better (Jes Sorensen) [747574]
- [md] raid10: Handle read errors during recovery better (Jes Sorensen) [747574]
- [md] raid10: simplify read error handling during recovery (Jes Sorensen) [747574]
- [md] raid10: record bad blocks due to write errors during resync/recovery (Jes Sorensen) [747574]
- [md] raid10: attempt to fix read errors during resync/check (Jes Sorensen) [747574]
- [md] raid10: Handle write errors by updating badblock log (Jes Sorensen) [747574]
- [md] raid10: clear bad-block record when write succeeds (Jes Sorensen) [747574]
- [md] raid10: avoid writing to known bad blocks on known bad drives (Jes Sorensen) [747574]
- [md] raid10 record bad blocks as needed during recovery (Jes Sorensen) [747574]
- [md] raid10: avoid reading known bad blocks during resync/recovery (Jes Sorensen) [747574]
- [md] raid10: avoid reading from known bad blocks (Jes Sorensen) [747574]
- [md] raid10: avoid reading from known bad blocks (Jes Sorensen) [747574]
- [md] raid10: avoid reading from known bad blocks (Jes Sorensen) [747574]
- [md] raid10: Split handle_read_error out from raid10d (Jes Sorensen) [747574]
- [md] raid10: simplify/reindent some loops (Jes Sorensen) [747574]
- [md] raid5: Clear bad blocks on successful write (Jes Sorensen) [747574]
- [md] raid5: Don't write to known bad block on doubtful devices (Jes Sorensen) [747574]
- [md] raid5: write errors should be recorded as bad blocks if possible (Jes Sorensen) [747574]
- [md] raid5: use bad-block log to improve handling of uncorrectable read errors (Jes Sorensen) [747574]
- [md] raid5: avoid reading from known bad blocks (Jes Sorensen) [747574]
- [md] raid1: factor several functions out or raid1d() (Jes Sorensen) [747574]
- [md] raid1: improve handling of read failure during recovery (Jes Sorensen) [747574]
- [md] raid1: record badblocks found during resync (Jes Sorensen) [747574]
- [md] raid1: Handle write errors by updating badblock log (Jes Sorensen) [747574]
- [md] raid1: store behind-write pages in bi_vecs (Jes Sorensen) [747574]
- [md] raid1: clear bad-block record when write succeeds (Jes Sorensen) [747574]
- [md] raid1: avoid writing to known-bad blocks on known-bad drives (Jes Sorensen) [747574]
- [md] raid1: avoid reading from known bad blocks (Jes Sorensen) [747574]
- [md] add 'write_error' flag to component devices (Jes Sorensen) [747574]
- [md] raid1: avoid reading known bad blocks during resync (Jes Sorensen) [747574]
- [md] raid1: avoid reading from known bad blocks (Jes Sorensen) [747574]
- [md] Disable bad blocks and v0.90 metadata (Jes Sorensen) [747574]
- [md] load/store badblock list from v1.x metadata (Jes Sorensen) [747574]
- [md] don't allow arrays to contain devices with bad blocks (Jes Sorensen) [747574]
- [md] bad-block-log: add sysfs interface for accessing bad-block-log (Jes Sorensen) [747574]
- [md] beginnings of bad block management (Jes Sorensen) [747574]
- [md] remove suspicious size_of() (Jes Sorensen) [747574]
- [md] bitmap: Revert DM dirty log hooks (Jes Sorensen) [747574]
- [md] raid5: Avoid BUG caused by multiple failures (Jes Sorensen) [747574]
- [md] raid10: move rdev->corrected_errors counting (Jes Sorensen) [747574]
- [md] raid5: move rdev->corrected_errors counting (Jes Sorensen) [747574]
- [md] raid1: move rdev->corrected_errors counting (Jes Sorensen) [747574]
- [md] get rid of unnecessary casts on page_address() (Jes Sorensen) [747574]
- [md] raid10: Improve decision on whether to fail a device with a read error (Jes Sorensen) [747574]
- [md] raid10: Make use of new recovery_disabled handling (Jes Sorensen) [747574]
- [md] change managed of recovery_disabled (Jes Sorensen) [747574]
- [md] remove ro check in md_check_recovery() (Jes Sorensen) [747574]
- [md] introduce link/unlink_rdev() helpers (Jes Sorensen) [747574]
- [md] raid: use printk_ratelimited instead of printk_ratelimit (Jes Sorensen) [747574]
- [md] raid5: finalise new merged handle_stripe (Jes Sorensen) [747574]
- [md] raid5: move some more common code into handle_stripe (Jes Sorensen) [747574]
- [md] raid5: move more common code into handle_stripe (Jes Sorensen) [747574]
- [md] raid5: unite handle_stripe_dirtying5 and handle_stripe_dirtying6 (Jes Sorensen) [747574]
- [md] raid5: unite fetch_block5 and fetch_block6 (Jes Sorensen) [747574]
- [md] raid5: rearrange a test in fetch_block6 (Jes Sorensen) [747574]
- [md] raid5: move more code into common handle_stripe (Jes Sorensen) [747574]
- [md] raid5: Move code for finishing a reconstruction into handle_stripe (Jes Sorensen) [747574]
- [md] raid5: Remove stripe_head_state arg from handle_stripe_expansion (Jes Sorensen) [747574]
- [md] raid5: move stripe_head_state and more code into handle_stripe (Jes Sorensen) [747574]
- [md] raid5: add some more fields to stripe_head_state (Jes Sorensen) [747574]
- [md] raid5: unify stripe_head_state and r6_state (Jes Sorensen) [747574]
- [md] raid5: move common code into handle_stripe (Jes Sorensen) [747574]
- [md] raid5: replace sh->lock with an 'active' flag (Jes Sorensen) [747574]
- [md] raid5: Protect some more code with ->device_lock (Jes Sorensen) [747574]
- [md] raid5: Remove use of sh->lock in sync_request (Jes Sorensen) [747574]
- [md] raid5: remove some sparse warnings (Jes Sorensen) [747574]

* Wed Jan 25 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-228.el6]
- [fs] Revert "proc: enable writing to /proc/pid/mem" (Johannes Weiner) [782650] {CVE-2012-0056}
- [fs] nfs: fix regression in handling of context= option in NFSv4 (Jeff Layton) [757896]
- [kernel] panic: call console_verbose() in panic (Alexander Gordeev) [771521]
- [net] igmp: Avoid zero delay when receiving odd mixture of IGMP queries (Jiri Pirko) [772871] {CVE-2012-0207}
- [fs] cifs/nfs: don't allow TASK_KILLABLE sleeps to block the freezer (Jeff Layton) [702630]
- [fs] xfs: validate acl count (Eric Sandeen) [773283]
- [ppc] POWER7 optimised copy_to_user/copy_from_user using VMX (Steve Best) [739137]
- [fs] GFS2: Update fallocate to match upstream (Steven Whitehouse) [732744]
- [pci] portdrv: cleanup pcie_device registration (Myron Stowe) [742460]
- [tpm] NSC driver X86 dependency fix (Steve Best) [741557]
- [net] sunrpc: remove xpt_pool (J. Bruce Fields) [753301]
- [fs] Fix sendfile write-side file position (Steven Whitehouse) [770023]
- [mm] Make task in balance_dirty_pages() killable (Lukas Czerner) [769115]
- [virt] kvm: x86: fix missing checks in syscall emulation (Marcelo Tosatti) [773391] {CVE-2012-0045}
- [virt] kvm: x86: extend "struct x86_emulate_ops" with "get_cpuid" (Marcelo Tosatti) [773391] {CVE-2012-0045}
- [net] svcrpc: fix double-free on shutdown of nfsd after changing pool mode (J. Bruce Fields) [753030]
- [net] svcrpc: avoid memory-corruption on pool shutdown (J. Bruce Fields) [753030]
- [net] svcrpc: destroy server sockets all at once (J. Bruce Fields) [753030]
- [net] svcrpc: simplify svc_close_all (J. Bruce Fields) [753030]
- [net] svcrpc: fix list-corrupting race on nfsd shutdown (J. Bruce Fields) [753030]

* Tue Jan 17 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-227.el6]
- [virt] virtio: console: add port stats for bytes received, sent and discarded (Amit Shah) [772194]
- [virt] virtio: console: make discard_port_data() use get_inbuf() (Amit Shah) [772194]
- [virt] virtio: console: rename variable (Amit Shah) [772194]
- [virt] virtio: console: make get_inbuf() return port->inbuf if present (Amit Shah) [772194]
- [virt] virtio: console: Fix return type for get_inbuf() (Amit Shah) [772194]
- [virt] virtio: console: Fix indentation (Amit Shah) [772194]
- [netdrv] r8169: fix Config2 MSIEnable bit setting (Ivan Vecera) [772565]
- [netdrv] r8169: fix Rx index race between FIFO overflow recovery and NAPI handler (Ivan Vecera) [772565]
- [netdrv] r8169: Rx FIFO overflow fixes (Ivan Vecera) [772565]
- [netdrv] r8169: corral some wayward N/A fw_version dust bunnies (Ivan Vecera) [772565]
- [netdrv] r8169: Convert MAC_ADDR_LEN uses to ETH_ALEN (Ivan Vecera) [772565]
- [netdrv] r8169: sweep the floors and convert some .get_drvinfo routines to strlcpy (Ivan Vecera) [772565]
- [netdrv] r8169: jumbo fixes (Ivan Vecera) [772565]
- [netdrv] r8169: expand received packet length indication (Ivan Vecera) [772565]
- [netdrv] r8169: support new chips of RTL8111F (Ivan Vecera) [772565]
- [netdrv] r8169: define the early size for 8111evl (Ivan Vecera) [772565]
- [netdrv] r8169: remove use of ndo_set_multicast_list in drivers (Ivan Vecera) [772565]
- [netdrv] r8169: MAC address change fix for the 8168e-vl (Ivan Vecera) [772565]
- [netdrv] r8169: Add support for D-Link 530T rev C1 (Ivan Vecera) [772565]
- [netdrv] r8169: use pci_dev->subsystem_{vendor|device} (Ivan Vecera) [772565]
- [netdrv] r8169: fix sticky accepts packet bits in RxConfig (Ivan Vecera) [772565]
- [netdrv] r8169: adjust the RxConfig settings (Ivan Vecera) [772565]
- [netdrv] r8169: don't enable rx when shutdown (Ivan Vecera) [772565]
- [netdrv] r8169: fix wake on lan setting for non-8111E (Ivan Vecera) [772565]
- [netdrv] r8169: support RTL8111E-VL (Ivan Vecera) [772565]
- [netdrv] r8169: add ERI functions (Ivan Vecera) [772565]
- [netdrv] r8169: modify the flow of the hw reset (Ivan Vecera) [772565]
- [netdrv] r8169: adjust some registers (Ivan Vecera) [772565]
- [netdrv] r8169: remove unnecessary read of PCI_CAP_ID_EXP (Ivan Vecera) [772565]
- [netdrv] r8169: fix wrong register use (Ivan Vecera) [772565]
- [netdrv] r8169: check firmware content sooner (Ivan Vecera) [772565]
- [netdrv] r8169: support new firmware format (Ivan Vecera) [772565]
- [netdrv] r8169: explicit firmware format check (Ivan Vecera) [772565]
- [netdrv] r8169: move the firmware down into the device private data (Ivan Vecera) [772565]
- [netdrv] r8169: fix static initializers (Ivan Vecera) [772565]
- [netdrv] r8169: avoid late chip identifier initialisation (Ivan Vecera) [772565]
- [netdrv] r8169: merge firmware information into the chipset description data (Ivan Vecera) [772565]
- [netdrv] r8169: provide some firmware information via ethtool (Ivan Vecera) [772565]
- [netdrv] r8169: remove non-NAPI context invocation of rtl8169_rx_interrupt (Ivan Vecera) [772565]
- [netdrv] r8169: link speed selection timer rework (Ivan Vecera) [772565]
- [netdrv] r8169: rtl8169_set_speed_xmii cleanup (Ivan Vecera) [772565]
- [netdrv] r8169: remove some code duplication (Ivan Vecera) [772565]
- [netdrv] r8169: style cleanups (Ivan Vecera) [772565]
- [netdrv] r8169: Use ethtool ethtool_cmd_speed API (Ivan Vecera) [772565]
- [netdrv] r8169: Use full 32 bit speed range in ethtool's set_settings (Ivan Vecera) [772565]
- [netdrv] r8169: fix merge conflict fix (Ivan Vecera) [772565]
- [netdrv] r8169: don't request firmware when there's no userspace (Ivan Vecera) [772565]
- [netdrv] r8169: TSO fixes (Ivan Vecera) [772565]
- [netdrv] r8169: convert to hw_features (Ivan Vecera) [772565]
- [netdrv] r8169: support RTL8168E (Ivan Vecera) [772565]
- [netdrv] r8169: add a new chip for RTL8168DP (Ivan Vecera) [772565]
- [netdrv] r8169: add a new chip for RTL8105 (Ivan Vecera) [772565]
- [netdrv] r8169: fix a bug in rtl8169_init_phy() (Ivan Vecera) [772565]
- [netdrv] r8169: support control of advertising (Ivan Vecera) [772565]
- [netdrv] r8169: support the new chips for RTL8105E (Ivan Vecera) [772565]
- [netdrv] r8169: disable ASPM (Ivan Vecera) [772565]
- [netdrv] r8169: adjust rtl8169_set_speed_xmii function (Ivan Vecera) [772565]
- [netdrv] r8169: fix RTL8168DP power off issue (Ivan Vecera) [772565]
- [netdrv] r8169: correct settings of rtl8102e (Ivan Vecera) [772565]
- [netdrv] r8169: fix incorrect args to oob notify (Ivan Vecera) [772565]
- [netdrv] r8169: Call netif_carrier_off at the end of the probe (Ivan Vecera) [772565]
- [netdrv] r8169: prevent RxFIFO induced loops in the irq handler (Ivan Vecera) [772565]
- [netdrv] r8169: keep firmware in memory (Ivan Vecera) [772565]
- [netdrv] r8169: Update the function of parsing firmware (Ivan Vecera) [772565]
- [netdrv] r8169: delay phy init until device opens (Ivan Vecera) [772565]
- [netdrv] r8169: more 8168dp support (Ivan Vecera) [772565]
- [netdrv] r8169: rtl_csi_access_enable rename (Ivan Vecera) [772565]
- [netdrv] r8169: magic (Ivan Vecera) [772565]
- [netdrv] r8169: phy power ops (Ivan Vecera) [772565]
- [netdrv] r8169: 8168DP specific MII registers access methods (Ivan Vecera) [772565]
- [netdrv] r8169: use device dependent methods to access the MII registers (Ivan Vecera) [772565]
- [netdrv] r8169: identify different registers (Ivan Vecera) [772565]
- [netdrv] r8169: remove the firmware of RTL8111D (Ivan Vecera) [772565]
- [netdrv] r8169: Use static const (Ivan Vecera) [772565]
- [netdrv] r8169: move PHY regs tables to .rodata (Ivan Vecera) [772565]
- [netdrv] r8169: don't use flush_scheduled_work() (Ivan Vecera) [772565]
- [netdrv] r8169: fix sleeping while holding spinlock (Ivan Vecera) [772565]
- [netdrv] r8169: print errors when dma mapping fail (Ivan Vecera) [772565]
- [netdrv] r8169: (re)init phy on resume (Ivan Vecera) [772565]
- [netdrv] r8169: changing mtu clean up (Ivan Vecera) [772565]
- [netdrv] r8169: do not account fragments as packets (Ivan Vecera) [772565]
- [netdrv] r8169: use pointer to struct device as local variable (Ivan Vecera) [772565]
- [netdrv] r8169: replace PCI_DMA_{TO, FROM}DEVICE to DMA_{TO, FROM}_DEVICE (Ivan Vecera) [772565]
- [netdrv] r8169: init rx ring cleanup (Ivan Vecera) [772565]
- [netdrv] r8169: check dma mapping failures (Ivan Vecera) [772565]
- [netdrv] r8169: Don't check for vlan group before vlan_tx_tag_present (Ivan Vecera) [772565]
- [netdrv] r8169: use 50 less ram for RX ring (Ivan Vecera) [772565]
- [netdrv] r8169: use device model DMA API (Ivan Vecera) [772565]
- [netdrv] r8169: allocate with GFP_KERNEL flag when able to sleep (Ivan Vecera) [772565]
- [netdrv] r8169: add gro support (Ivan Vecera) [772565]
- [netdrv] r8169: avoid some skb->ip_summed initializations (Ivan Vecera) [772565]
- [netdrv] r8169: incorrect identifier for a 8168dp (Ivan Vecera) [772565]
- [netdrv] r8169: fix mdio_read and update mdio_write according to hw specs (Ivan Vecera) [772565]
- [netdrv] r8169: fix random mdio_write failures (Ivan Vecera) [772565]
- [netdrv] r8169: remove unnecessary cast of readl()'s return value (Ivan Vecera) [772565]
- [netdrv] r8169: failure to enable mwi should not be fatal (Ivan Vecera) [772565]
- [netdrv] r8169: Fix rtl8169_rx_interrupt() (Ivan Vecera) [772565]
- [netdrv] r8169: convert multiple drivers to use netdev_for_each_mc_addr (Ivan Vecera) [772565]
- [netdrv] r8169: Use netif_printk macros (Ivan Vecera) [772565]
- [netdrv] r8169: use netdev_mc_count and netdev_mc_empty when appropriate (Ivan Vecera) [772565]
- [netdrv] r8169: use DEFINE_PCI_DEVICE_TABLE() (Ivan Vecera) [772565]
- [netdrv] r8169: use pM to shown MAC address (Ivan Vecera) [772565]
- [netdrv] r8169: Move && and || to end of previous line (Ivan Vecera) [772565]
- [fs] nfsd4: name->id mapping should fail with BADOWNER not BADNAME (J. Bruce Fields) [754834]
- [net] Potential null skb->dev dereference (Flavio Leitner) [769590]
- [mm] mempolicy.c: refix mbind_range() vma issue (Motohiro Kosaki) [697996 727700]
- [mm] mempolicy.c: fix pgoff in mbind vma merge (Motohiro Kosaki) [697996 727700]

* Fri Jan 13 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-226.el6]
- [scsi] hpsa: add the Smart Array 5i to the kdump blacklist (Tomas Henzl) [758675]
- [scsi] cciss: add Smart Array 5i to the kdump blacklist (Tomas Henzl) [758675]
- [powerpc] perf_event: Skip updating kernel counters if register value shrinks (Steve Best) [706528]
- [ppc] pseries: Fix kexec on recent firmware versions (Steve Best) [741586]
- [ppc] hvc_console: Improve tty/console put_chars handling (Steve Best) [740543]
- [ppc] pseries/hvconsole: Fix dropped console output (Steve Best) [740551]
- [ppc] pseries: Do not search for dma-window property on dlpar remove (Steve Best) [738483]
- [ppc] pseries: Fix kexec on machines with more than 4TB of RAM (Steve Best) [741581]
- [ppc] Fix oops when echoing bad values to /sys/devices/system/memory/probe (Steve Best) [739161]
- [fs] ext2, ext3, ext4: don't inherit APPEND_FL or IMMUTABLE_FL for new inodes (Eric Sandeen) [749117]
- [fs] ext4: fix race in xattr block allocation path (Eric Sandeen) [735105]
- [fs] nfs: when attempting to open a directory, fall back on normal lookup (Jeff Layton) [755380]
- [fs] nfs: don't try to migrate pages with active requests (Jeff Layton) [739811 741241]
- [fs] nfs: don't redirty inode when ncommit == 0 in nfs_commit_unstable_pages (Jeff Layton) [746541]
- [kernel] crypto: ghash - Avoid null pointer dereference if no key is set (Jiri Benc) [749482] {CVE-2011-4081}
- [fs] jbd2: validate sb->s_first in journal_get_superblock() (Eryu Guan) [693981]
- [fs] xfs: Fix memory corruption in xfs_readlink (Carlos Maiolino) [694702]
- [net] rds_rdma: don't assume infiniband device is PCI (Jes Sorensen) [740149]
- [net] ipv4: correct description for tcp_max_syn_backlog (Weiping Pan) [738796]
- [net] ipv6: tcp: fix tcp_v6_conn_request() (Jiri Benc) [742099]
- [net] netfilter: use __aligned_be64 in nfnetlink_log.h (Weiping Pan) [767992]
- [net] sctp: Do not account for sizeof(struct sk_buff) in estimated rwnd (Thomas Graf) [698119]
- [net] fib: fix fib_nl_newrule() (Neil Horman) [743459]
- [net] fix unsafe pointer access in sendmmsg (Jiri Benc) [760798] {CVE-2011-4594}
- [net] vlan: should take into account needed_headroom (Weiping Pan) [692013]
- [net] tcp: tcp_syn_retries sysctl is not honored (Jiri Benc) [692024]
- [net] pkt_sched: Fix sch_sfq vs tcf_bind_filter oops (Jiri Pirko) [667925]
- [net] ipv6: check for IPv4 mapped addresses when connecting IPv6 sockets (Jiri Benc) [728123]
- [net] mac80211: cancel auth retries when deauthenticating (John Linville) [754356]
- [net] bonding: Don't allow mode change via sysfs with slaves present (Veaceslav Falico) [747282]
- [net] bonding: update speed/duplex for NETDEV_CHANGE (Weiping Pan) [747546]
- [scsi] isci: link speed default to gen2 (David Milburn) [769376]
- [scsi] scsi_dh_rdac: Fix error path in rdac_init (Mike Snitzer) [690523]
- [scsi] hpsa: add small delay when using PCI Power Management to reset for kdump (Dave Young) [746267]
- [block] cciss: add small delay when using PCI Power Management to reset for kdump (Dave Young) [746317]
- [scsi] increase qla2xxx firmware ready time-out (Mark Goodwin) [731917]
- [usb] ch9: use proper endianess for wBytesPerInterval (Steve Best) [738578]
- [perf] powerpc: Handle events that raise an exception without overflowing (Steve Best) [755737]
- [kernel] clocksource: Install completely before selecting (Paolo Bonzini) [745713]
- [md] Avoid waking up a thread after it has been freed (Jes Sorensen) [754424]
- [pci] Fix unbootable HP DL385G6 on 2.6.32-220 by properly disabling pcie aspm (Dave Wysochanski) [769626]
- [virt] virtio-pci: fix use after free (Michael S. Tsirkin) [751805 772194]
- [pci] hotplug: shpchp: don't blindly claim non-AMD 0x7450 (Myron Stowe) [735218]
- [sched] x86: Avoid unnecessary overflow in sched_clock (Prarit Bhargava) [765720]
- [x86] binutils, xen: Fix another wrong size directive (Igor Mammedov) [720982]
- [x86] ACPI atomicio: Convert width in bits to bytes in __acpi_ioremap_fast() (Myron Stowe) [754341]
- [x86] x2apic_optout: Change WARN to printk (Prarit Bhargava) [755061]
- [x86] cpufreq: handle CPUs with different capabilities in acpi-cpufreq (Prarit Bhargava) [749056]
- [x86] mtrr: Kill over the top warn (Prarit Bhargava) [746232]
- [x86] setup: Set ax register in boot vga query (Prarit Bhargava) [742441]
- [virt] x86: Prevent starting PIT timers in the absence of irqchip support (Marcelo Tosatti) [769550]
- [virt] vmxnet3: revert hw features change (Neil Horman) [759613]
- [virt] xen: mask MTRR feature from guest BZ#750758 (Igor Mammedov) [750758]
- [virt] fix broken build if xen is disabled in config (Igor Mammedov) [729488]
- [netdrv] qlge: fix size of external list for TX address descriptors (Steve Best) [772237]
- [kernel] script to create symlinks for new network driver layout (Andy Gospodarek)
- [netdrv] e1000e: Avoid wrong check on TX hang (Dean Nelson) [751087]
- [netdrv] igb: Loopback functionality supports for i350 devices (Stefan Assmann) [756601]
- [netdrv] be2net: Fixed Endianness issues in the response read log length field while retrieving FAT (Steve Best) [743226]
- [netdrv] cxgb4: Fix EEH on IBM P7IOC (Steve Best) [721074]
- [x86] kdump, ioapic: Reset remote-IRR in clear_IO_APIC (Prarit Bhargava) [754335]
- [x86] ioapic: Move trigger defines to io_apic.h (Prarit Bhargava) [754335]
- [scsi] ipr: add definitions for additional adapter (Steve Best) [738891]
- [scsi] ipr: Add support to flash FPGA and flash back DRAM images (Steve Best) [738891]
- [scsi] ipr: Fix BUG on adapter dump timeout (Steve Best) [738891]
- [scsi] ipr: Stop reading adapter dump prematurely (Steve Best) [738891]
- [x86] hpet: Disable per-cpu hpet timer if ARAT is supported (Prarit Bhargava) [750201]
- [x86] Improve TSC calibration using a delayed workqueue (Prarit Bhargava) [750201]
- [kernel] clocksource: Add clocksource_register_hz/khz interface (Prarit Bhargava) [750201]
- [kernel] clocksource: Provide a generic mult/shift factor calculation (Prarit Bhargava) [750201]
- [ppc] gup_huge_pmd() return 0 if pte changes (Andrea Arcangeli) [751493]
- [mm] thp: share get_huge_page_tail() (Andrea Arcangeli) [751493]
- [ppc] gup_hugepte() support THP based tail recounting (Andrea Arcangeli) [751493]
- [ppc] gup_hugepte() avoid to free the head page too many times (Andrea Arcangeli) [751493]
- [ppc] get_hugepte() don't put_page() the wrong page (Andrea Arcangeli) [751493]
- [ppc] remove superflous PageTail checks on the pte gup_fast (Andrea Arcangeli) [751493]
- [virt] KVM: Device assignment permission checks (Alex Williamson) [756093]
- [virt] KVM: Remove ability to assign a device without iommu support (Alex Williamson) [756093]
- [virt] kvm: device-assignment: revert Disable the option to skip iommu setup (Alex Williamson) [756093]
- [scsi] hpsa: Add IRQF_SHARED back in for the non-MSI(X) interrupt handler (Tomas Henzl) [758707]
- [block] cciss: Add IRQF_SHARED back in for the non-MSI(X) interrupt handler (Tomas Henzl) [758707]
- [fs] Make write(2) interruptible by a fatal signal (Lukas Czerner) [769115]
- [block] cfq-iosched: fix a kbuild regression (Vivek Goyal) [705698]
- [block] cfq-iosched: rethink seeky detection for SSDs (Vivek Goyal) [705698]
- [block] cfq-iosched: rework seeky detection (Vivek Goyal) [705698]
- [block] cfq-iosched: don't regard requests with long distance as close (Vivek Goyal) [705698]
- [scsi] isci: Adding documentation to API change and fixup sysfs registration (David Milburn) [751434]
- [scsi] isci: change sas phy timeouts from 54us to 59us (David Milburn) [751434]
- [scsi] isci: fix 32-bit operation when CONFIG_HIGHMEM64G=n (David Milburn) [751434]
- [scsi] isci: overriding max_concurr_spinup oem parameter by max(oem, user) (David Milburn) [751434]
- [scsi] isci: revert bcn filtering (David Milburn) [751434]
- [scsi] libsas: export sas_alloc_task() (David Milburn) [751434]
- [scsi] isci: Fix hard reset timeout conditions (David Milburn) [751434]
- [scsi] isci: No need to manage the pending reset bit on pending requests (David Milburn) [751434]
- [scsi] isci: Remove redundant isci_request.ttype field (David Milburn) [751434]
- [scsi] isci: Fix task management for SMP, SATA and on dev remove (David Milburn) [751434]
- [scsi] isci: No task_done callbacks in error handler paths (David Milburn) [751434]
- [scsi] isci: Handle task request timeouts correctly (David Milburn) [751434]
- [scsi] isci: Fix tag leak in tasks and terminated requests (David Milburn) [751434]
- [scsi] isci: Immediately fail I/O to removed devices (David Milburn) [751434]
- [scsi] isci: Lookup device references through requests in completions (David Milburn) [751434]
- [virt] xen-blkfront: conditionally drop name and minor adjustments for emulated scsi devs (Laszlo Ersek) [729586]
- [virt] xen-blk: plug device number leak on error path in xlblk_init (Laszlo Ersek) [729586]
- [virt] xen-blkfront: more informative message when resizing vbd (Laszlo Ersek) [654982]
- [virt] xen-blkfront: pick up vbd size change through xenstore (Laszlo Ersek) [654982]

* Wed Jan 04 2012 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-225.el6]
- [kernel] Remove "WARNING: at kernel/sched.c:5915" (Larry Woodman) [766051]
- [x86] kernel: Fix memory corruption in module load (Prarit Bhargava) [767140]

* Wed Dec 14 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-224.el6]
- [virt] xen: Find an unbound irq number in reverse order high to low (Igor Mammedov) [756307]
- [virt] xen: add get_nr_hw_irqs req for finding an unbound irq number in reverse order (Igor Mammedov) [756307]
- [x86] io_apic: add get_nr_irqs_gsi() (Igor Mammedov) [756307]
- [virt] Do not init xen platform pci if xen_emul_unplug=never (Igor Mammedov) [756307]
- [fs] GFS2: Add readahead to sequential directory traversal (Robert S Peterson) [681906]
- [fs] GFS2: Cache dir hash table in a contiguous buffer (Robert S Peterson) [681906]
- [scsi] scsi_dh: move .match to an auxiliary structure (Mike Snitzer) [690523]
- [scsi] scsi_dh: code cleanup and remove the references to scsi_dev_info (Mike Snitzer) [690523]
- [scsi] scsi_dh_hp_sw: Adding the match function for hp_sw device handler (Mike Snitzer) [690523]
- [scsi] scsi_dh_rdac: Adding the match function for rdac device handler (Mike Snitzer) [690523]
- [scsi] scsi_dh_emc: Adding the match function for emc device handler (Mike Snitzer) [690523]
- [scsi] scsi_dh: Implement match callback function (Mike Snitzer) [690523]
- [scsi] scsi_dh_alua: Evaluate TPGS setting from inquiry data (Mike Snitzer) [690523]
- [scsi] scsi_dh: Use scsi_devinfo functions to do matching of device_handler tables (Mike Snitzer) [690523]
- [scsi] scsi_dh: check queuedata pointer before proceeding further (Mike Snitzer) [690523]
- [scsi] scsi_dh_alua: Fix the time inteval for alua rtpg commands (Mike Snitzer) [690523]
- [scsi] scsi_dh_alua: Decrease retry interval (Mike Snitzer) [690523]
- [scsi] scsi_dh: Check for sdev state in store_dh_state() (Mike Snitzer) [690523]
- [scsi] scsi_dh_alua: always update TPGS status on activate (Mike Snitzer) [690523]
- [scsi] scsi_dh: Fixup kernel-doc comments (Mike Snitzer) [690523]
- [block] Don't check QUEUE_FLAG_SAME_COMP in __blk_commplete_request (David Milburn) [724055]
- [block] Fix queue_flag update when rq_affinity goes from 2 to 1 (David Milburn) [724055]
- [block] improve rq_affinity placement (David Milburn) [724055]
- [block] Make rq_affinity = 1 work as expected (David Milburn) [724055]
- [block] fix warning with calling smp_processor_id() in preemptible section (David Milburn) [724055]
- [block] strict rq_affinity (David Milburn) [724055]
- [x86] mtrr: use stop_machine APIs for doing MTRR rendezvous (Prarit Bhargava) [729223]
- [x86] stop_machine: implement stop_machine_from_inactive_cpu() (Prarit Bhargava) [729223]
- [x86] stop_machine: reorganize stop_cpus() implementation (Prarit Bhargava) [729223]
- [x86] mtrr: lock stop machine during MTRR rendezvous sequence (Prarit Bhargava) [729223]
- [virt] KVM: fix guest SMEP support (Chris Wright) [703053]
- [x86] cpu: fix CPUID leaf 7 detection (Chris Wright) [703053]
- [perf] tools: Fix raw sample reading (Jiri Olsa) [752353]
- [perf] python: Add missing perf_event__parse_sample 'swapped' parm (Jiri Olsa) [752353]
- [perf] tools: Add support for disabling -Werror via WERROR=0 (Jiri Olsa) [752353]
- [perf] top: Fix userspace sample addr map offset (Jiri Olsa) [752353]
- [perf] symbols: Fix issue with binaries using 16-bytes buildids (Jiri Olsa) [752353]
- [perf] tool: Fix endianness handling of u32 data in samples (Jiri Olsa) [752353]
- [perf] sort: Fix symbol sort output by separating unresolved samples by type (Jiri Olsa) [752353]
- [perf] symbols: Synthesize anonymous mmap events (Jiri Olsa) [752353]
- [perf] record: Create events initially disabled and enable after init (Jiri Olsa) [752353]
- [perf] symbols: Add some heuristics for choosing the best duplicate symbol (Jiri Olsa) [752353]
- [perf] symbols: Preserve symbol scope when parsing /proc/kallsyms (Jiri Olsa) [752353]
- [perf] symbols: /proc/kallsyms does not sort module symbols (Jiri Olsa) [752353]
- [perf] symbols: Fix ppc64 SEGV in dso__load_sym with debuginfo files (Jiri Olsa) [752353]
- [perf] probe: Fix regression of variable finder (Jiri Olsa) [752353]
- [perf] tools: Add group event scheduling option to perf record/stat (Jiri Olsa) [752353]
- [perf] tools: Fix build against newer glibc (Jiri Olsa) [752353]
- [perf] tools: Fix error handling of unknown events (Jiri Olsa) [752353]
- [perf] evlist: Fix missing event name init for default event (Jiri Olsa) [752353]
- [perf] list: Fix exit value (Jiri Olsa) [752353]
- [perf] probe: Filter out redundant inline-instances (Jiri Olsa) [752353]
- [perf] probe: Search concrete out-of-line instances (Jiri Olsa) [752353]
- [perf] probe: Avoid searching variables in intermediate scopes (Jiri Olsa) [752353]
- [perf] probe: Fix to search local variables in appropriate scope (Jiri Olsa) [752353]
- [perf] probe: Warn when more than one line are given (Jiri Olsa) [752353]
- [perf] probe: Fix to walk all inline instances (Jiri Olsa) [752353]
- [perf] probe: Fix to search nested inlined functions in CU (Jiri Olsa) [752353]
- [perf] probe: Fix line walker to check CU correctly (Jiri Olsa) [752353]
- [perf] probe: Fix a memory leak for scopes array (Jiri Olsa) [752353]
- [perf] fix temporary file ownership check (Jiri Olsa) [752353]
- [perf] top browser: Remove spurious helpline update (Jiri Olsa) [752353]
- [perf] symbols: Check '/tmp/perf-' symbol file ownership (Jiri Olsa) [752353]
- [perf] tools: Check $HOME/.perfconfig ownership (Jiri Olsa) [752353]
- [perf] tools: Make clean leaves some files (Jiri Olsa) [752353]
- [perf] lock: Dropping unsupported ':r' modifier (Jiri Olsa) [752353]
- [perf] probe: Fix coredump introduced by probe module option (Jiri Olsa) [752353]
- [perf] report: Use ui__warning in some more places (Jiri Olsa) [752353]
- [perf] python: Add PERF_RECORD_{LOST, READ, SAMPLE} routine tables (Jiri Olsa) [752353]
- [perf] evlist: Introduce 'disable' method (Jiri Olsa) [752353]
- [perf] tools: Make test use the preset debugfs path (Jiri Olsa) [752353]
- [perf] tools: Add automated tests for events parsing (Jiri Olsa) [752353]
- [perf] tools: De-opt the parse_events function (Jiri Olsa) [752353]
- [perf] script: Fix display of IP address for non-callchain path (Jiri Olsa) [752353]
- [perf] tools: Fix endian conversion reading event attr from file header (Jiri Olsa) [752353]
- [perf] probe: Support adding probes on offline kernel modules (Jiri Olsa) [752353]
- [perf] probe: Add probed module in front of function (Jiri Olsa) [752353]
- [perf] probe: Introduce debuginfo to encapsulate dwarf information (Jiri Olsa) [752353]
- [perf] perf-probe: Move dwarf library routines to dwarf-aux.{c, h} (Jiri Olsa) [752353]
- [perf] probe: Remove redundant dwarf functions (Jiri Olsa) [752353]
- [perf] probe: Move strtailcmp to string.c (Jiri Olsa) [752353]
- [perf] probe: Rename DIE_FIND_CB_FOUND to DIE_FIND_CB_END (Jiri Olsa) [752353]
- [perf] Robustify proc and debugfs file recording (Jiri Olsa) [752353]
- [perf] report/annotate/script: Add option to specify a CPU range (Jiri Olsa) [752353]
- [perf] stat: Add noise output for csv mode (Jiri Olsa) [752353]
- [perf] tools: Only display parent field if explictly sorted (Jiri Olsa) [752353]
- [perf] tools: Allow sort dimensions to be registered more than once (Jiri Olsa) [752353]
- [perf] tools: Don't display ignored entries on stdio ui (Jiri Olsa) [752353]
- [perf] tools: Remove sort print helpers declarations (Jiri Olsa) [752353]
- [perf] tools: Make sort operations static (Jiri Olsa) [752353]
- [perf] tools: Add inverted call graph report support (Jiri Olsa) [752353]
- [perf] script: Add printing of sample address (Jiri Olsa) [752353]
- [perf] script: Make printing of dso a separate field option (Jiri Olsa) [752353]
- [perf] script: "sym" field really means show IP data (Jiri Olsa) [752353]
- [perf] stat: clarify unsupported events from uncounted events (Jiri Olsa) [752353]
- [perf] Cleanup useless double NULL termination in method arg names (Jiri Olsa) [752353]
- [pci] x86: reduce severity of host bridge window conflict warnings (Myron Stowe) [567487]
- [pci] x86: avoid high BIOS area when allocating address space (Myron Stowe) [567487]
- [pci] x86: avoid E820 regions when allocating address space (Myron Stowe) [567487]
- [pci] x86: avoid low BIOS area when allocating address space (Myron Stowe) [567487]
- [pci] resources: add arch hook for preventing allocation in reserved areas (Myron Stowe) [567487]
- [pci] x86: coalesce overlapping host bridge windows (Myron Stowe) [567487]
- [pci] x86: update iomem_resource end based on CPU physical address capabilities (Myron Stowe) [567487]
- [pci] resources: handle overflow when aligning start of available area (Myron Stowe) [567487]
- [pci] resources: ensure callback doesn't allocate outside available space (Myron Stowe) [567487]
- [pci] resources: factor out resource_clip() to simplify find_resource() (Myron Stowe) [567487]
- [pci] resources: add a default alignf to simplify find_resource() (Myron Stowe) [567487]
- [pci] PNP: log PNP resources, as we do for PCI (Myron Stowe) [567487]
- [pci] x86: use host bridge _CRS info on ASRock ALiveSATA2-GLAN (Myron Stowe) [567487]
- [pci] fall back to original BIOS BAR addresses (Myron Stowe) [567487]
- [pci] change resource collision messages from KERN_ERR to KERN_INFO (Myron Stowe) [567487]
- [pci] x86: compute Address Space length rather than using _LEN (Myron Stowe) [567487]
- [pci] x86: never allocate PCI MMIO resources below BIOS_END (Myron Stowe) [567487]
- [pci] x86: parse additional host bridge window resource types (Myron Stowe) [567487]
- [pci] x86: ignore Consumer/Producer bit in ACPI window descriptions (Myron Stowe) [567487]
- [acpi] pci_root: pass acpi_pci_root to arch-specific scan (Myron Stowe) [567487]
- [acpi] pci_root: save downstream bus range (Myron Stowe) [567487]
- [pci] x86: truncate _CRS windows with _LEN > _MAX - _MIN + 1 (Myron Stowe) [567487]
- [pci] x86: for host bridge address space collisions, show conflicting resource (Myron Stowe) [567487]
- [pci] don't say we claimed a resource if we failed (Myron Stowe) [567487]
- [pci] print resources consistently with pR (Myron Stowe) [567487]
- [pci] make disabled window printk style match the enabled ones (Myron Stowe) [567487]
- [pci] reject mmio ranges starting at 0 on pci_bridge read (Myron Stowe) [567487]
- [pci] break out primary/secondary/subordinate for readability (Myron Stowe) [567487]
- [pci] for address space collisions, show conflicting resource (Myron Stowe) [567487]
- [pci] resources: add interfaces that return conflict information (Myron Stowe) [567487]
- [pci] resource: add window support (Myron Stowe) [567487]
- [pci] resource: add bus number support (Myron Stowe) [567487]
- [pci] resource: expand IORESOURCE_TYPE_BITS to make room for bus resource type (Myron Stowe) [567487]
- [pci] vsprintf: move pR resource printf_specs off the stack (Myron Stowe) [567487]
- [pci] vsprintf: clarify comments for printf_spec flags (Myron Stowe) [567487]
- [pci] x86: use host bridge _CRS info by default on 2008 and newer machines (Myron Stowe) [567487]
- [pci] augment bus resource table with a list (Myron Stowe) [567487]
- [pci] add pci_bus_for_each_resource(), remove direct bus->resource[] refs (Myron Stowe) [567487]
- [pci] read bridge windows before filling in subtractive decode resources (Myron Stowe) [567487]
- [pci] split up pci_read_bridge_bases() (Myron Stowe) [567487]
- [pci] don't dump resource when bus resource flags indicates unused (Myron Stowe) [567487]
- [pci] x86: remove 64-bit division (Myron Stowe) [567487]
- [pci] x86/PCI: fix bogus host bridge window start/end alignment from _CRS (Myron Stowe) [567487]
- [pci] x86: for debuggability, show host bridge windows even when ignoring _CRS (Myron Stowe) [567487]
- [pci] improve discovery/configuration messages (Myron Stowe) [567487]
- [pci] replace pr_debug with dev_dbg (Myron Stowe) [567487]
- [pci] x86: print domain:bus in conventional format (Myron Stowe) [567487]
- [pci] vsprintf: use pR, pr instead of pRt, pRf (Myron Stowe) [567487]
- [pci] x86: use -DDEBUG when CONFIG_PCI_DEBUG set (Myron Stowe) [567487]
- [pci] PNP: print resources consistently with pRt (Myron Stowe) [567487]
- [pci] x86: print resources consistently with pRt (Myron Stowe) [567487]
- [pci] print resources consistently with pRt (Myron Stowe) [567487]
- [pci] vsprintf: add pRt, pRf to print struct resource details (Myron Stowe) [567487]
- [pci] vsprintf: add pR support for IRQ and DMA resources (Myron Stowe) [567487]
- [pci] vsprintf: fix io/mem resource width (Myron Stowe) [567487]
- [pci] reverting "[Fedora] [pci] silence some PCI resource allocation errors" (Myron Stowe) [567487]

* Tue Nov 29 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-223.el6]
- [x86] amd: Fix align_va_addr kernel parameter (Frank Arnold) [753237]
- [md] RAID1: Do not call md_raid1_unplug_device while holding spinlock (Jonathan E Brassow) [752528]
- [pci] intel-iommu: Default to non-coherent for domains unattached to iommus (Don Dutile) [746484]
- [x86] initialize min_delta_ns in one_hpet_msi_clockevent() (Prarit Bhargava) [728315]
- [x86] Update hpet_next_event() (Prarit Bhargava) [728315]

* Tue Nov 29 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-222.el6]
- [net] Restrict pktgen from using shared skbs on bridge interfaces (Neil Horman) [750777]
- [kernel] sched: Use resched IPI to kick off the nohz idle balance (Vivek Goyal) [717179]
- [virt] xenfv: mask smep, even if the HV doesn't (Andrew Jones) [752382]
- [drm] i915: enable ring freq scaling, RC6 and graphics turbo on Ivy Bridge (Prarit Bhargava) [752163]
- [drm] i915: load a ring frequency scaling table (Prarit Bhargava) [752163]
- [x86] cpufreq: expose a cpufreq_quick_get_max routine (Prarit Bhargava) [752163]
- [scsi] qla4xxx: Make sure we discover targets if the cable is plugged in after the driver is loaded (Chad Dupuis) [751509]
- [sched] Cleanup/optimize clock updates (Larry Woodman) [750237]
- [sched] fix skip_clock_update optimization (Larry Woodman) [750237]
- [kernel] Reset clocksource watchdog after sysrq-t (Prarit Bhargava) [742890]
- [x86] AMD: Make tsc=reliable override boot time stability checks (Prarit Bhargava) [742890]
- [block] virtio-blk: Use ida to allocate disk index (Michael S. Tsirkin) [692767]
- [virt] virtio_blk: Replace cryptic number with the macro (Michael S. Tsirkin) [692767]
- [kernel] ida: simplified functions for id allocation (Michael S. Tsirkin) [692767]
- [virt] revert virtio-blk: Use ida to allocate disk index (Aristeu Rozanski) [692767]

* Tue Nov 15 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-221.el6]
- [scsi] qla4xxx: v5.02.00.00.06.02-k13 (Chad Dupuis) [751286]
- [scsi] qla4xxx: set ql4xdisablesysfsboot=1 by default (Chad Dupuis) [751286]
- [scsi] qla4xxx: Correct ipaddress match check (Chad Dupuis) [751286]

* Tue Nov 08 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-220.el6]
- [drm] i915: fix unmap race condition introduced with VT-d fix (Dave Airlie) [750583]
- [scsi] iscsi: revert lockless queuecommand dispatch (Rob Evers) [751426]

* Tue Nov 08 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-219.el6]
- [kernel] KEYS: Fix a NULL pointer deref in the user-defined key type (David Howells) [751190] {CVE-2011-4110}
- [scsi] fc class: fix building of Fibre Channel DUP drivers in 6.2 (Mike Christie) [750268]
- [fs] nfs: don't call __mark_inode_dirty while holding i_lock (Steve Dickson) [747391]
- [netdrv] vxge: allow rebinding the driver with a different number of SR-IOV VFs (Michal Schmidt) [694742]
- [netdrv] vxge: fix crash of VF when unloading PF (Michal Schmidt) [694742]
- [ata] revert libata: remove SCSI host lock (David Milburn) [751426]
- [crypto] ansi_cprng: enforce key != seed in fips mode (Jarod Wilson) [751198]
- [net] mac80211: Fix reassociation processing within ESS roaming (John Linville) [750350]
- [net] nl80211: Allow association to change channels during reassociation (John Linville) [750350]
- [net] mac80211: let cfg80211 manage auth state (John Linville) [750350]
- [net] cfg80211: avoid sending spurious deauth to userspace (John Linville) [750350]
- [net] mac80211: recalculate idle later in MLME (John Linville) [750350]
- [net] mac80211: avoid spurious deauth frames/messages (John Linville) [750350]
- [net] cfg80211: Allow reassociation in associated state (John Linville) [750350]
- [net] cfg80211: remove warning in deauth case (John Linville) [750350]
- [net] netfilter: fix nf_conntrack refcount leak in l4proto->error() (Thomas Graf) [745472]
- [scsi] qla2xxx: Remove check for null fcport from host reset handler (Chad Dupuis) [744741]
- [scsi] qla2xxx: Perform implicit logout during rport tear-down (Chad Dupuis) [744741]
- [scsi] Revert "qla2xxx: Remove host_lock in queuecommand function" (Chad Dupuis) [744741]
- [drm] nv50/disp: shutdown display on suspend/hibernate (Ben Skeggs) [740857]
- [edac] Add sb_edac driver into the Red Hat Building system (Mauro Carvalho Chehab) [647700]
- [edac] Fix incorrect edac mode reporting in sb_edac (Mauro Carvalho Chehab) [647700]
- [edac] Add an experimental new driver to support Sandy Bridge CPU's (Mauro Carvalho Chehab) [647700]

* Sun Nov 06 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-218.el6]
- [netdrv] benet: remove bogus "unlikely" on vlan check (Ivan Vecera) [736429] {CVE-2011-3347}
- [netdrv] be2net: non-member vlan pkts not received in promiscous mode (Ivan Vecera) [736429] {CVE-2011-3347}
- [netdrv] be2net: fix crash receiving non-member VLAN packets (Ivan Vecera) [736429] {CVE-2011-3347}
- [mm] fix race between mremap and removing migration entry (Andrea Arcangeli) [751084]

* Fri Nov 04 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-217.el6]
- [fs] GFS2: rewrite fallocate code to write blocks directly (Benjamin Marzinski) [750208] {CVE-2011-4098}
- [netdrv] bnx2x: link fixes for 57810 (Andy Gospodarek) [749421]
- [netdrv] enic: fix accidental GRO off by default (Stefan Assmann) [749390]
- [scsi] qla2xxx: Correct inadvertent clearing of RISC_INTR status (Chad Dupuis) [748978]
- [debug] lockdep: double MAX_LOCKDEP_ENTRIES (Kyle McMartin) [748941]
- [x86] Add missing KERN_DEBUG to x86 module printk (Prarit Bhargava) [747837]
- [x86] Update module alternatives message (Prarit Bhargava) [745596]
- [x86] UV: KABI breakage in uv_blade_info (George Beshers) [745253]
- [net] vlan: fix panic when handling priority tagged frames (Andy Gospodarek) [714936] {CVE-2011-3593}
- [scsi] qla4xxx: Autologin persisted target entries update (Mike Christie) [747696]
- [mm] oom: fix integer overflow of points in oom_badness (Frantisek Hrbata) [741207] {CVE-2011-4097}

* Tue Nov 01 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-216.el6]
- [scsi] lockless queuecommand dispatch fixup (Rob Evers) [749018]
- [scsi] iscsi class: export pid of process that created session (Mike Christie) [747696]
- [scsi] qla4xxx: Autologin persisted target entries (Mike Christie) [747696]
- [netdrv] iwlagn: enable 11n aggregation without checking traffic load (John Linville) [744361]
- [s390x] qdio: EQBS retry after CCQ 96 (Hendrik Brueckner) [747578]
- [s390x] dasd: fix UID readout for z/VM (Hendrik Brueckner) [746000]
- [x86] PCI: irq and pci_ids patch for Intel Panther Point DeviceIDs (Prarit Bhargava) [747638]
- [netdrv] Help 6.1 out of tree drivers cope with ABI breakage (Thomas Graf) [746570]
- [mm] shmem: let shared anonymous be nonlinear again (Larry Woodman) [690129]
- [fs] ext4: fix BUG_ON() in ext4_ext_insert_extent() (Lukas Czerner) [742091] {CVE-2011-3638}
- [ipc] mqueue: separate mqueue default value from maximum value (Motohiro Kosaki) [746606]
- [ipc] mqueue: don't use kmalloc with KMALLOC_MAX_SIZE (Motohiro Kosaki) [746606]
- [ipc] mqueue: revert bump up DFLT_*MAX (Motohiro Kosaki) [746606]
- [kernel] ipc/mqueue: Up the hard limit on message queues per namespace (Doug Ledford) [746606]
- [kernel] ipc/mqueue: update maximums for the mqueue subsystem (Doug Ledford) [746606]
- [kernel] ipc/mqueue: enforce hard limits (Doug Ledford) [746606]
- [kernel] ipc/mqueue: switch back to using non-max values on create (Doug Ledford) [746606 746898]
- [kernel] ipc/mqueue: cleanup definition names and locations (Doug Ledford) [746606]
- [kernel] Revert "Restore max mqueue message size to its previous RHEL 5 value" (Doug Ledford) [746606]

* Fri Oct 28 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-215.el6]
- [virt] index of virtio disk is not decremented when removed (Mark Wu) [692767]
- [edac] i7core_edac: Initialize memory name with cpu, channel, bank (Mauro Carvalho Chehab) [712957]
- [kernel] perf: Optimize event scheduling locking (Steve Best) [744986]
- [drm] i915: set the right SDVO transcoder for CPT (Adam Jackson) [735122]
- [scsi] libfc: Prevent race that causes panic during FCoE port destroy (Neil Horman) [735959]
- [scsi] qla4xxx: Update driver version to 5.02.00-k8 (Mike Christie) [732622]
- [scsi] qla4xxx: updated device id check for BFS (Mike Christie) [732622]
- [scsi] qla4xxx: Fixed target discovery failed issue (Mike Christie) [732622]
- [scsi] qla4xxx: Fixed active session re-open issue (Mike Christie) [732622]
- [scsi] qla4xxx: Fixed device blocked issue on link up-down (Mike Christie) [732622]
- [scsi] qla4xxx: Fixed session destroy issue on link up-down (Mike Christie) [732622]
- [scsi] qla4xxx: Clear DDB map index on the basis of AEN (Mike Christie) [732622]
- [scsi] qla4xxx: Free Device Database (DDB) reserved by FW (Mike Christie) [732622]
- [scsi] qla4xxx: Fix getting BIDI CHAP for boot targets (Mike Christie) [732622]
- [scsi] qla4xxx: Fix exporting boot targets to sysfs (Mike Christie) [732622]
- [scsi] qla4xxx: Do not add duplicate CHAP entry in FLASH (Mike Christie) [732622]
- [scsi] qla4xxx: Fix bidirectional CHAP (Mike Christie) [732622]
- [scsi] qla4xxx: Add new FLT firmware region (Mike Christie) [732622]
- [scsi] qla4xxx: Update license (Mike Christie) [732622]
- [scsi] iscsi class: fix vlan configuration (Mike Christie) [732622]
- [scsi] qla4xxx: fix data alignment and use nl helpers (Mike Christie) [732622]
- [scsi] iscsi class: fix link local mispelling (Mike Christie) [732622]
- [scsi] qla4xxx: Added Get ACB support using BSG (Mike Christie) [732622]
- [scsi] qla4xxx: Added restore factory defaults support using BSG (Mike Christie) [732622]
- [scsi] qla4xxx: added support to update initiator iscsi port (Mike Christie) [732622]
- [scsi] scsi_transport_iscsi: Added support to update initiator iscsi port (Mike Christie) [732622]
- [scsi] qla4xxx: Added vendor specific sysfs attributes (Mike Christie) [732622]
- [scsi] qla4xxx: Add read/update NVRAM support for 40xx adapters using BSG (Mike Christie) [732622]
- [scsi] qla4xxx: Add get ACB state support using BSG (Mike Christie) [732622]
- [scsi] qla4xxx: Code cleanup for read/update flash using BSG (Mike Christie) [732622]
- [scsi] qla4xxx: Added support to update mtu (Mike Christie) [732622]
- [scsi] scsi_transport_iscsi: Added support to update mtu (Mike Christie) [732622]
- [scsi] libfc: improve flogi retries to avoid lport stuck (Mike Christie) [745667]
- [scsi] libfc: avoid exchanges collision during lport reset (Mike Christie) [745667]
- [scsi] libfc: fix checking FC_TYPE_BLS (Mike Christie) [745667]
- [scsi] libfc: revert fix deadlock bug in fc_exch_abort_locked (Mike Christie) [745667]
- [dm] log userspace: Allow for 'log device name' response in CTR msg exchange (Jonathan E Brassow) [746254]
- [dm] kcopyd: fix job_pool leak (Mike Snitzer) [748441]
- [netdrv] igb: Fix for Alt MAC Address feature on 82580 and later (Andy Gospodarek) [748503]

* Tue Oct 25 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-214.el6]
- [dm] table: add immutable feature (Mike Snitzer) [747438]
- [mm] reduce overhead on paravirt functions (Larry Woodman) [743554]

* Mon Oct 24 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-213.el6]
- [netdrv] Fixing use of netif_set_real_num_tx_queues in niu.c (Neil Horman) [742117]
- [netdrv] Fixing use of netif_set_real_num_tx_queues in myri10ge.c (Neil Horman) [742117]
- [netdrv] Fixing use of netif_set_real_num_tx_queues in igb_main.c (Neil Horman) [742117]
- [netdrv] Fixing use of netif_set_real_num_tx_queues in cxgb4_main.c (Neil Horman) [742117]
- [netdrv] Fixing use of netif_set_real_num_tx_queues in cxgb3_main.c (Neil Horman) [742117]
- [netdrv] Fixing use of netif_set_real_num_tx_queues in bnx2.c (Neil Horman) [742117]
- [ppc] kabi: add symbol 'paca' to ppc KABI (Jiri Olsa) [737466]
- [fs] proc: fix oops on invalid /proc/pid/maps access (Johannes Weiner) [746613] {CVE-2011-3637}
- [nfs] fix pNFS hang and oops on umounts (Steve Dickson) [746861]
- [scsi] qla4xxx: export address/port of connection (Mike Christie) [728156]
- [netdrv] Fix pktgen to not oops on unsupported drivers (Neil Horman) [678794]
- [kernel] tracing: Update the comm field in the right variable in update_max_tr (Jiri Olsa) [736955]
- [kernel] kabi: Add missing compat_alloc_user_space symbol to kABI (Jiri Olsa) [747047]
- [kernel] fix taskstats io infoleak (Jerome Marchand) [716848] {CVE-2011-2494}
- [x86] ACPI, APEI, HEST: Detect duplicated hardware error source ID (Don Zickus) [737189]
- [netdrv] Add latest cxgb3 firmware (Neil Horman) [742011]

* Fri Oct 21 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-212.el6]
- [net] bridge: fix use after free in __br_deliver() (Amerigo Wang) [730756] {CVE-2011-2942}
- [scsi] Update lpfc version for 8.3.5.45.4p driver release (Rob Evers) [746668]
- [scsi] Fix crash when cfg_fcp_eq_count is zero (Rob Evers) [746668]
- [scsi] Fix kernel crash during boot with SLI4 card installed (Rob Evers) [746668]
- [scsi] Properly clean up EQ and CQ child lists to prevent kernel crash (Rob Evers) [746668]
- [kabi] add missing symbols for Emulex be2net driver (Jiri Olsa) [745712]
- [netdrv] netxen-firmware: Install the 4.0.579 firmware (Kyle McMartin) [741776]
- [perf] symbols: Treat all memory maps without dso file as loaded (Jiri Olsa) [726582]
- [debug] increase MAX_STACK_TRACE_ENTRIES (Kyle McMartin) [645777]
- [fs] cifs: add fallback in is_path_accessible for old servers (Jeff Layton) [692709] {CVE-2011-3363}
- [tpm] Zero buffer after copying to userspace (Jiri Benc) [732633] {CVE-2011-1161 CVE-2011-1162}
- [pci] intel-iommu: IOTLB hang workaround (Dave Airlie) [728476]
- [drm] i915: Fix hang on Ironlake mobile GPU with VT-d (Dave Airlie) [728476]
- [drm] i915: Remove early exit on i915_gpu_idle (Dave Airlie) [728476]
- [drm] nv50/bios: fixup mpll programming from the init table parser (Ben Skeggs) [744992]
- [drm] nv50/vram: fix incorrect detection of bank count on newer chipsets (Ben Skeggs) [744992]
- [drm] radeon: fix llano output setup + memory corruption (Dave Airlie) [747292]
- [drm] radeon caicos enablement fixes (Dave Airlie) [747291]
- [pci] Disable SRIOV on powerpc (Prarit Bhargava) [742089]
- [pci] Add pci=nosriov to disable SRIOV (Prarit Bhargava) [742089]
- [x86] apic: ack all pending irqs when crashed/on kexec (Takao Indoh) [704142]

* Tue Oct 18 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-211.el6]
- [scsi] libsas: fix warnings when checking sata/stp protocol (David Milburn) [695950]
- [scsi] libsas: disable scanning lun > 0 on ata devices (David Milburn) [695950]
- [scsi] libsas: Allow expander T-T attachments (David Milburn) [695950]
- [usb] xhci: Make xHCI driver endian-safe (Don Zickus) [745967]
- [infiniband] RDMA/cxgb3: Don't post zero-byte read if endpoint is going away (Neil Horman) [717379]
- [scsi] isci: atapi support (David Milburn) [743692]
- [x86] amd: Move BSP code to cpu_dev helper (Larry Woodman) [739456]
- [x86] Add a BSP cpu_dev helper (Larry Woodman) [739456]
- [x86] amd: Avoid cache aliasing penalties on AMD family 15h (Larry Woodman) [739456]
- [net] ipv6: fix NULL dereference in udp6_ufo_fragment() (Jason Wang) [740465]
- [netdrv] cxgb4: Updating NIC driver firmware (Neil Horman) [717806]
- [netdrv] cxgb3: Fix NULL pointer dereference in t3_l2t_get (Neil Horman) [729737]
- [netdrv] bnx2x: remaining fixes from upstream 3.1 (Michal Schmidt) [743917]
- [netdrv] e1000e: fix WoL on 82578DM and 82567V3 (Andy Gospodarek) [699042]
- [netdrv] tg3: Use netif_set_real_num_tx_queues() (Jiri Pirko) [740477]
- [netdrv] bnx2x: critical fixes (Veaceslav Falico) [745211]
- [netdrv] bonding: properly stop queuing work when requested (Andy Gospodarek) [736904]
- [netdrv] tg3: negate USE_PHYLIB flag check (Jiri Pirko) [746006]
- [x86] Add new cpu capabilities to /proc/cpuinfo (Prarit Bhargava) [745799]
- [kabi] add missing multipath symbols for s390x (Aristeu Rozanski) [714992]
- [perf] sched: Fix script command documentation (Jiri Olsa) [726589]
- [pm] hibernate: Fix memory corruption related to swap (Stanislaw Gruszka) [701857]
- [scsi] hpsa: add heartbeat sysfs host attribute (Tomas Henzl) [730027]
- [scsi] Revert megaraid_sas: Driver only report tape drive, JBOD and logic drives (Tomas Henzl) [736667]
- [fs] GFS2: Fix ->page_mkwrite() races (Steven Whitehouse) [725091]
- [scsi] scsi_transport_fc: Fix deadlock during fc_remove_host (Mike Christie) [714320]
- [kernel] workqueue: Fix workqueue deadlock during destroy_workqueue (Mike Christie) [714320]
- [sched] Avoid expensive initial update_cfs_load() (Larry Woodman) [741569 742414]
- [sched] Simplify update_cfs_shares parameters (Larry Woodman) [741569 742414]
- [sched] Fix/remove redundant cfs_rq checks (Larry Woodman) [741569 742414]
- [sched] Fix sign under-flows in wake_affine (Larry Woodman) [741569 742414]
- [sched] Update effective_load() to use global share weights (Larry Woodman) [741569 742414]
- [sched] Fix interactivity bug by charging unaccounted run-time on entity re-weight (Larry Woodman) [741569 742414]
- [sched] Move periodic share updates to entity_tick() (Larry Woodman) [741569 742414]
- [sched] Fix UP build breakage (Larry Woodman) [741569 742414]
- [sched] Update tg->shares after cpu.shares write (Larry Woodman) [741569 742414]

* Sun Oct 16 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-210.el6]
- [drm] i915: fix IVB cursor support (Adam Jackson) [741780]
- [drm] i915: always set FDI composite sync bit (Adam Jackson) [745564]
- [netdrv] bnx2i: Fixed the endian on TTT for NOP out transmission (Mike Christie) [745676]
- [scsi] megaraid_sas: Add driver workaround for PERC5/1068 kdump kernel panic (Tomas Henzl) [723218]
- [ata] AHCI: Add new Panther Point RAID DeviceID (Prarit Bhargava) [745484]
- [scsi] isci: export phy events via ->lldd_control_phy() (David Milburn) [743654]
- [scsi] isci: The port state should be set to stopping on the last phy (David Milburn) [743654]
- [scsi] isci: fix decode of DONE_CRC_ERR TC completion status (David Milburn) [743654]
- [scsi] isci: SATA/STP I/O is only returned in the normal path to libsas (David Milburn) [743654]
- [scsi] isci: fix support for large smp requests (David Milburn) [743654]
- [scsi] isci: fix missed unlock in apc_agent_timeout() (David Milburn) [743654]
- [scsi] isci: fix event-get pointer increment (David Milburn) [743654]
- [scsi] isci: add version number (David Milburn) [743654]
- [scsi] isci: dynamic interrupt coalescing (David Milburn) [743654]
- [scsi] isci: fix sata response handling (David Milburn) [743654]
- [scsi] isci: Leave requests alone if already terminating (David Milburn) [743654]
- [fs] jbd: Fix forever sleeping process in do_get_write_access() (Harshula Jayasuriya) [744979]
- [fs] jbd2: Fix forever sleeping process in do_get_write_access() (Harshula Jayasuriya) [744979]
- [net] ipv6: fix refcnt problem related to POSTDAD state (Weiping Pan) [709280 731608]
- [x86] paravirt: PTE updates in k(un)map_atomic need to be synchronous, regardless of lazy_mmu mode (Igor Mammedov) [632802]
- [s390x] qdio: 2nd stage retry on SIGA-W busy conditions (Hendrik Brueckner) [732708]
- [s390x] kernel: NSS creation with initrd fails (Hendrik Brueckner) [730780]
- [s390x] qeth: wrong number of output queues for HiperSockets (Hendrik Brueckner) [730701]
- [s390x] qeth: l3 ipv6 vlan not working on shared OSA chpid (Hendrik Brueckner) [727850]
- [x86] Intel pci: Provide option to enable 64-bit IOMMU pass through mode (George Beshers) [696420]
- [x86] intel-iommu: Remove Host Bridge devices from identity mapping (George Beshers) [696420]
- [x86] intel-iommu: Add domain check in domain_remove_one_dev_info (George Beshers) [696420]
- [x86] intel-iommu: Use coherent DMA mask when requested (George Beshers) [696420]
- [x86] intel-iommu: Dont cache iova above 32bit (George Beshers) [696420]
- [x86] intel-iommu: Speed up processing of the identity_mapping function (George Beshers) [696420]
- [x86] intel-iommu: Check for identity mapping candidate using system dma mask (George Beshers) [696420]
- [scsi] tcm_fc: Fix to activate non-offload path for FCoE target (Andy Grover) [638007]

* Wed Oct 12 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-209.el6]
- [pci] edd: Treat "XPRS" host bus type the same as "PCI" (Mike Christie) [742059]
- [scsi] be2iscsi: Move driver Version (Mike Christie) [738163 738934]
- [scsi] be2iscsi: memset wrb for ring create (Mike Christie) [738163 738934]
- [scsi] be2iscsi: Fix for case where task->sc was cleanedup earlier (Mike Christie) [738163 738934]
- [scsi] be2iscsi: Fix for wrong dmsg setting in wrb (Mike Christie) [738163 738934]
- [scsi] be2iscsi: Fix for kdump failure (Mike Christie) [738163 738934]
- [sched] wait_for_completion_interruptible_timeout() should return signed long (J. Bruce Fields) [738379]

* Tue Oct 11 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-208.el6]
- [net] fix net_dev_xmit tracepoint use of freed skb (Jiri Pirko) [705253]
- [block] kabi: symbols missing for FusionIO iomemory-vsl driver (Jiri Olsa) [735227]
- [netdrv] kabi: symbols missing for Emulex be2net driver (Jiri Olsa) [735229]
- [virt] xen: use maximum reservation to limit amount of usable RAM (Igor Mammedov) [743590]
- [usb] additional regression fix for device removal (Don Zickus) [744154]
- [usb] fix regression occurring during device removal (Don Zickus) [744154]
- [usb] Lower USB storage settling delay to something more reasonable (Don Zickus) [743959]

* Mon Oct 10 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-207.el6]
- [netdrv] bna: Multiple Definition and Interface Setup Fix (Ivan Vecera) [743347]
- [netdrv] bna: Driver Version changed to 3.0.2.2 (Ivan Vecera) [743347]
- [netdrv] bna: Add Callback to Fix RXQ Stop (Ivan Vecera) [743347]
- [netdrv] bna: PLL Init Fix and Add Stats Attributes (Ivan Vecera) [743347]
- [netdrv] bna: Brocade 1860 HW Enablement (Ivan Vecera) [743347]
- [netdrv] bna: Implement FW Download for New HW (Ivan Vecera) [743347]
- [netdrv] bna: Capability Map and MFG Block Changes for New HW (Ivan Vecera) [743347]
- [netdrv] bna: PCI Probe Conf Lock Fix (Ivan Vecera) [743347]
- [netdrv] bna: Eliminate Small Race Condition Window in RX Path (Ivan Vecera) [743347]
- [netdrv] bna: Set Ring Param Fix (Ivan Vecera) [743347]
- [netdrv] bna: Semaphore Lock Fix (Ivan Vecera) [743347]
- [netdrv] bna: make function tables cont (Ivan Vecera) [743347]
- [netdrv] bna: Driver Version changed to 3.0.2.1 (Ivan Vecera) [743347]
- [netdrv] bna: SKB PCI UNMAP Fix (Ivan Vecera) [743347]
- [netdrv] bna: TX Queue Depth Fix (Ivan Vecera) [743347]
- [netdrv] bna: MBOX IRQ Flag Check after Locking (Ivan Vecera) [743347]
- [netdrv] bna: Async Mode Tx Rx Init Fix (Ivan Vecera) [743347]
- [netdrv] bna: Ethtool Enhancements and Fix (Ivan Vecera) [743347]
- [netdrv] bna: Initialization and Locking Fix (Ivan Vecera) [743347]
- [netdrv] bna: Formatting and Code Cleanup (Ivan Vecera) [743347]
- [netdrv] bna: TX Path and RX Path Changes (Ivan Vecera) [743347]
- [netdrv] bna: Interrupt Polling and NAPI Init Changes (Ivan Vecera) [743347]
- [netdrv] bna: PCI Probe Fix (Ivan Vecera) [743347]
- [netdrv] bna: Naming Change and Minor Macro Fix (Ivan Vecera) [743347]
- [netdrv] bna: off by one in bfa_msgq_rspq_pi_update() (Ivan Vecera) [743347]
- [netdrv] bna: unlock on error path in pnad_pci_probe() (Ivan Vecera) [743347]
- [scsi] libfc: fix deadlock bug in fc_exch_abort_locked (Mike Christie) [740096]
- [scsi] bnx2fc: Bumped version to 1.0.8 (Mike Christie) [740096]
- [scsi] bnx2fc: Return error statistics of remote peer (Mike Christie) [740096]
- [scsi] fcoe/libfcoe: Move common code for fcoe_get_lesb to fcoe_transport (Mike Christie) [740096]
- [scsi] bnx2fc: call ctlr_link_up only when the interface is enabled (Mike Christie) [740096]
- [scsi] bnx2fc: Add driver documentation (Mike Christie) [740096]
- [scsi] bnx2fc: Bumped version to 1.0.7 (Mike Christie) [740096]
- [scsi] bnx2fc: Handle bnx2fc_map_sg failure (Mike Christie) [740096]
- [scsi] bnx2fc: Replace scsi_dma_map() with dma_map_sg() (Mike Christie) [740096]
- [x86] acpi: Prevent acpiphp from deadlocking on PCI-to-PCI bridge remove (Prarit Bhargava) [732706]
- [x86] UV2: add missing kABI bits (George Beshers) [741432]
- [ppc] pci: Check devices status property when scanning OF tree (Steve Best) [738450]
- [drm] radeon/kms: reject video mode that would go over bandwidth limit on RN50 (Jerome Glisse) [729976]
- [fs] deal with races in /proc/*/syscall, stack, personality (Johannes Weiner) [692039]
- [fs] proc: enable writing to /proc/pid/mem (Johannes Weiner) [692039]
- [fs] proc: make check_mem_permission() return an mm_struct on success (Johannes Weiner) [692039]
- [fs] proc: hold cred_guard_mutex in check_mem_permission() (Johannes Weiner) [692039]
- [fs] proc: disable mem_write after exec (Johannes Weiner) [692039]
- [mm] implement access_remote_vm (Johannes Weiner) [692039]
- [mm] factor out main logic of access_process_vm (Johannes Weiner) [692039]
- [mm] use mm_struct to resolve gate vma's in __get_user_pages (Johannes Weiner) [692039]
- [mm] rename in_gate_area_no_task to in_gate_area_no_mm (Johannes Weiner) [692039]
- [mm] make in_gate_area take an mm_struct instead of a task_struct (Johannes Weiner) [692039]
- [mm] make get_gate_vma take an mm_struct instead of a task_struct (Johannes Weiner) [692039]
- [x86] mark associated mm when running a task in 32 bit compatibility mode (Johannes Weiner) [692039]
- [x86] add context tag to mark mm when running a task in 32-bit compatibility mode (Johannes Weiner) [692039]
- [fs] auxv: require the target to be tracable (or yourself) (Johannes Weiner) [692039]
- [fs] close race in /proc/*/environ (Johannes Weiner) [692039]
- [fs] report errors in /proc/*/*map* sanely (Johannes Weiner) [692039]
- [fs] pagemap: close races with suid execve (Johannes Weiner) [692039]
- [fs] make sessionid permissions in /proc/*/task/* match those in /proc/* (Johannes Weiner) [692039] {CVE-2011-1020}

* Tue Oct 04 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-206.el6]
- [ppc] ibmveth: Fix leak when recycling skb and hypervisor returns error (Steve Best) [740548]
- [fs] nfs: Do not allow multiple mounts on same mountpoint when using -o noac (Sachin Prabhu) [584768]
- [scsi] megaraid: fix FastPath and update to v5.40 (Tomas Henzl) [726225]
- [acpi] APEI: set enable bit for OSC call (Matthew Garrett) [734509]
- [block] Whitelist symbols for dm-switch multipathing driver (Shyam Iyer) [714992]
- [x86] Missing "unregister_cpu_notifier" in powernow-k8.c (Prarit Bhargava) [741302]
- [virt] xen-netfront: fix MTU reset after migration (Paolo Bonzini) [733651]

* Mon Oct 03 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-205.el6]
- [mm] add extra free kbytes tunable (Rik van Riel) [696395]
- [build] Makefile: include RHEL_RELEASE in version.h (Aristeu Rozanski)
- [ppc] Fix bogus it_blocksize in VIO iommu code (Steve Best) [738449]
- [ppc] hvcs: Ensure page aligned partner info buffer (Steve Best) [739749]
- [virt] KVM: Enable RDRAND feature support for KVM (Don Dugger) [721131]
- [virt] x86, cpu: Add CPU flags for F16C and RDRND (Don Dugger) [721131]
- [mm] zram: prevent accessing an unallocated table when init fails early (Jerome Marchand) [732707]
- [mm] zram: fix zram locking (Jerome Marchand) [732707]
- [ppc] eeh: Display eeh error location for bus and device (Steve Best) [707843]
- [ppc] pseries/eeh: Handle functional reset on non-PCIe device (Steve Best) [707843]
- [ppc] pseries/eeh: Propagate needs_freset flag to device at PE (Steve Best) [707843]
- [ppc] eeh: Add support for ibm, configure-pe RTAS call (Steve Best) [707843]
- [scsi] isci: initial sgpio write support (David Milburn) [735318]
- [scsi] isci: fix sgpio register definitions (David Milburn) [735318]
- [scsi] libsas: sgpio write support (David Milburn) [735318]
- [drm] i915: set GFX_MODE to pre-Ivybridge default value even on Ivybridge (Adam Jackson) [695793]

* Mon Oct 03 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-204.el6]
- [netdrv] firmware: add bnx2x FW 7.0.23 (Michal Schmidt) [733693]
- [netdrv] bnx2x: Add new PHY BCM54616 (Michal Schmidt) [733888]
- [netdrv] bnx2x: fixes from upstream 3.1-rc (Michal Schmidt) [733693]
- [netdrv] bnx2x: driver-side changes for firmware 7.0.23 (Michal Schmidt) [733693]
- [netdrv] bnx2x: add missing DCB callbacks (Michal Schmidt) [733693]
- [scsi] scan: don't fail scans when host is in recovery (Mike Christie) [713682]
- [usb] don't let errors prevent system sleep (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] don't let the hub driver prevent system sleep (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] xhci: Reject double add of active endpoints (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] Free bandwidth when usb_disable_device is called (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] disable endpoints after unbinding interfaces, not before (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] xhci: Don't warn about zeroed bMaxBurst descriptor field (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] xHCI 1.0: Force Stopped Event(FSE) (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] xHCI 1.0: introduce Incompatible Device Error (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] xhci: Add reset on resume quirk for asrock p67 host (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] xhci: Always set urb->status to zero for isoc endpoints (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] Fix up URB error codes to reflect implementation (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] config: use proper endian access for wMaxPacketSize (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] xhci: fix OS want to own HC (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] xhci: Don't submit commands or URBs to halted hosts (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] usbcore: warm reset USB3 port in SS.Inactive state (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] Refine USB3.0 device suspend and resume (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] fix system suspend with USB3.0 device connected to USB3.0 hub (Don Zickus) [732457 732909 735048 735050 735263]
- [usb] Clear "warm" port reset change (Don Zickus) [732457 732909 735048 735050 735263]
- [netdrv] b43: allocate receive buffers big enough for max frame len + offset (RuiRui Yang) [738205] {CVE-2011-3359}
- [netdrv] tg3: call netif_carrier_off to initialize operstate value (John Feeney) [727330]
- [fs] fuse: check size of FUSE_NOTIFY_INVAL_ENTRY message (RuiRui Yang) [736765] {CVE-2011-3353}
- [fs] cifs: fix possible memory corruption in CIFSFindNext (Jeff Layton) [730354] {CVE-2011-3191}
- [fs] nfsd4: fix open downgrade, again (J. Bruce Fields) [729176]
- [fs] jbd[2]: Use WRITE_SYNC_PLUG in journal_commit_transaction (Jeff Moyer) [720918]
- [fs] mbcache: Limit the maximum number of cache entries (Eric Sandeen) [731585]
- [netdrv] netxen: Add firmware version 4.0.557[579]. (Chad Dupuis) [741776]
- [netdrv] netxen: Add pcie workaround (Chad Dupuis) [741774]
- [netdrv] netxen: add vlan LRO support (Chad Dupuis) [741774]
- [netdrv] netxen: add fw version compatibility check (Chad Dupuis) [741774]
- [netdrv] netxen: drivers/net: Remove casts of void * (Chad Dupuis) [741774]
- [netdrv] netxen: fix race in skb->len access (Chad Dupuis) [741774]
- [netdrv] netxen: drivers/net: Remove unnecessary semicolons (Chad Dupuis) [741774]
- [netdrv] netxen: ethtool: cosmetic: Use ethtool ethtool_cmd_speed API (Chad Dupuis) [741774]
- [netdrv] netxen: ethtool: Use full 32 bit speed range in ethtool's set_settings (Chad Dupuis) [741774]

* Tue Sep 27 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-203.el6]
- [fs] xfs: avoid direct I/O write vs buffered I/O race (Dave Chinner) [732976]
- [fs] xfs: don't serialise adjacent concurrent direct IO appending writes (Dave Chinner) [732976]
- [fs] xfs: don't serialise direct IO reads on page cache checks (Dave Chinner) [732976]
- [fs] gfs2: Ignore buffers with wrong state during fsync (Abhijith Das) [740066]
- [fs] GFS2: balance pages on gfs2_fallocate. (Benjamin Marzinski) [737989]
- [fs] xfs: avoid synchronous transactions when deleting attr blocks (Dave Chinner) [740312]
- [fs] GFS2: large file delete/unlink is slow (Robert S Peterson) [739987]
- [fs] ext4: optimize ext4_check_dir_entry() (Eric Sandeen) [714007]
- [fs] Fix do_lookup false negative. (David Howells) [693841]
- [netdrv] tg3: Fix VLAN creation problem (John Feeney) [731268 732769]
- [netdrv] ixgbe: fix improper check of dma address for NULL (Neil Horman) [683611]
- [netdrv] e1000: don't enable dma receives until after dma address has been setup (Dean Nelson) [703357]
- [net] sctp: deal with multiple COOKIE_ECHO chunks (Max Matveev) [729220]

* Wed Sep 21 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-202.el6]
- [net] br_multicast: Ensure to initialize BR_INPUT_SKB_CB(skb)->mrouters_only. (Herbert Xu) [738110]

* Tue Sep 20 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-201.el6]
- [x86] Add rh_kabi.c and protect struct alt_instr under KABI (Prarit Bhargava) [737753]
- [x86] Fix module alt_instr KABI breakage (Prarit Bhargava) [737753]

* Mon Sep 19 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-200.el6]
- [build] Makefile: update RHEL_MINOR to 2 (Aristeu Rozanski)
- [scsi] scsi_lib: pause between error retries (Rob Evers) [736812]
- [kernel] perf tools: do not look at ./config for configuration (Jiri Benc) [730204] {CVE-2011-2905}
- [scsi] Fix out of spec CD-ROM problem with media change (Rob Evers) [703366]
- [netdrv] bna: Driver Version changed to 3.0.2.0 (Ivan Vecera) [701486]
- [netdrv] bna: Remove Obsolete Files (Ivan Vecera) [701486]
- [netdrv] bna: Remove Unused Code (Ivan Vecera) [701486]
- [netdrv] bna: ENET and Tx Rx Redesign Enablement (Ivan Vecera) [701486]
- [netdrv] bna: Add New HW Defs (Ivan Vecera) [701486]
- [netdrv] bna: Tx and Rx Redesign (Ivan Vecera) [701486]
- [netdrv] bna: Introduce ENET as New Driver and FW Interface (Ivan Vecera) [701486]
- [netdrv] bna: MSGQ Implementation (Ivan Vecera) [701486]
- [netdrv] bna: Remove Obsolete File bfi_ctreg.h (Ivan Vecera) [701486]
- [netdrv] bna: Consolidated HW Registers for Supported HWs (Ivan Vecera) [701486]
- [netdrv] bna: Remove get_regs Ethtool Support (Ivan Vecera) [701486]
- [netdrv] bna: HW Interface Init Update (Ivan Vecera) [701486]
- [netdrv] bna: Remove Unnecessary CNA Check (Ivan Vecera) [701486]
- [netdrv] bna: Header File Consolidation (Ivan Vecera) [701486]
- [netdrv] bna: HW Error Counter Fix (Ivan Vecera) [701486]
- [netdrv] bna: Add HW Semaphore Unlock Logic (Ivan Vecera) [701486]
- [netdrv] bna: IOC Event Name Change (Ivan Vecera) [701486]
- [netdrv] bna: Mboxq Flush When IOC Disabled (Ivan Vecera) [701486]
- [netdrv] bna: Minor IRQ Index and Definition Change (Ivan Vecera) [701486]
- [netdrv] bna: State Machine Fault Handling Cleanup (Ivan Vecera) [701486]
- [netdrv] bna: IOC Event Notification Enhancement (Ivan Vecera) [701486]
- [netdrv] bna: CheckPatch Cleanup (Ivan Vecera) [701486]
- [netdrv] bna: Print Driver Version (Ivan Vecera) [701486]
- [netdrv] bna: use netdev_alloc_skb_ip_align() (Ivan Vecera) [701486]
- [netdrv] bna: ethtool: cosmetic: Use ethtool ethtool_cmd_speed API (Ivan Vecera) [701486]
- [netdrv] bna: ethtool: Use full 32 bit speed range in ethtool's set_settings (Ivan Vecera) [701486]
- [net] bna: fix compile warning of bfa_ioc_smem_pgoff defined but not used (Ivan Vecera) [701486]
- [netdrv] bna: Fix set-but-unused variables. (Ivan Vecera) [701486]
- [netdrv] bna: use device model DMA API (Ivan Vecera) [701486]
- [netdrv] bna: Remove unnecessary memset(,0,) (Ivan Vecera) [701486]

* Mon Sep 19 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-199.el6]
- [scsi] libfcoe: fix compilation when fcoe.ko is not used (Mike Christie) [727304]
- [scsi] bnx2fc: Bumped version to 1.0.6 (Mike Christie) [727304]
- [scsi] bnx2fc: Fix FW assert during RSCN stress tests (Mike Christie) [727304]
- [scsi] bnx2fc: Fix panic caused because of incorrect errror handling in create() (Mike Christie) [727304]
- [scsi] bnx2fc: Avoid calling bnx2fc_if_destroy with unnecessary locks (Mike Christie) [727304]
- [scsi] bnx2fc: Validate vlan id in NETDEV_UNREGISTER handler (Mike Christie) [727304]
- [scsi] bnx2fc: No abort issued for REC when it times out (Mike Christie) [727304]
- [scsi] bnx2fc: Send solicitation only after vlan discovery is complete (Mike Christie) [727304]
- [scsi] bnx2fc: Reset max receive frame size during link up (Mike Christie) [727304]
- [scsi] bnx2fc: Do not use HBA_DBG macro when lport is not available (Mike Christie) [727304]
- [scsi] bnx2fc: increase cleanup wait time (Mike Christie) [727304]
- [scsi] bnx2fc: Bump version to 1.0.5 (Mike Christie) [727304]
- [scsi] bnx2fc: Prevent creating of NPIV port with duplicate WWN (Mike Christie) [727304]
- [scsi] bnx2fc: Obtain WWNN/WWPN from the shared memory (Mike Christie) [727304]
- [scsi] fcoe: Move common functions to fcoe_transport library (Mike Christie) [727304]
- [scsi] bnx2fc: Drop incoming ABTS (Mike Christie) [727304]
- [scsi] bnx2fc: code cleanup in bnx2fc_offload_session (Mike Christie) [727304]
- [scsi] bnx2fc: Fix NULL pointer deref during arm_cq (Mike Christie) [727304]
- [scsi] bnx2fc: Do not reuse the fcoe connection id immediately (Mike Christie) [727304]
- [scsi] bnx2fc: Clear DESTROY_CMPL flag after firmware destroy (Mike Christie) [727304]
- [scsi] bnx2fc: Handle NETDEV_UNREGISTER for vlan devices (Mike Christie) [727304]
- [scsi] bnx2fc: Reorganize cleanup code between interface_cleanup and if_destroy (Mike Christie) [727304]
- [scsi] bnx2fc: Change function names of bnx2fc_netdev_setup/bnx2fc_netdev_cleanup (Mike Christie) [727304]
- [scsi] bnx2fc: Do not attempt destroying NPIV port twice (Mike Christie) [727304]
- [scsi] bnx2fc: Remove erroneous kref_get on IO request (Mike Christie) [727304]
- [scsi] bnx2fc: Enable bsg_request support for bnx2fc (Mike Christie) [727304]
- [scsi] bnx2fc: Bug fixes in percpu_thread_create/destroy (Mike Christie) [727304]
- [scsi] bnx2fc: Reset the max receive frame size (Mike Christie) [727304]
- [netdrv] cnic: Wait for all Context IDs to be deleted before sending FCOE_DESTROY_FUNC (Mike Christie) [727304]
- [netdrv] cnic: Fix Context ID space calculation (Mike Christie) [727304]
- [netdrv] cnic: Return proper error code if we fail to send netlink message (Mike Christie) [727304]
- [netdrv] cnic: Fix ring setup/shutdown code (Mike Christie) [727304]
- [netdrv] cnic: Fix port_mode setting (Mike Christie) [727304]
- [netdrv] cnic: Replace get_random_bytes() with random32() (Mike Christie) [727304]
- [scsi] cnic, bnx2i: Add support for new devices - 57800, 57810, and 57840 (Mike Christie) [727304]
- [netdrv] cnic: Add VLAN ID as a parameter during netevent upcall (Mike Christie) [727304]
- [x86] mm: Fix pgd_lock deadlock (Andrew Jones) [691310]
- [mm] pdpte registers are not flushed when PGD entry is changed in x86 PAE mode (Andrew Jones) [691310]
- [mm] Revert "fix pgd_lock deadlock" (Andrew Jones) [691310]
- [scsi] libfc: fix referencing to fc_fcp_pkt from the frame pointer via fr_fsp() (Mike Christie) [734961]
- [scsi] libfc: block SCSI eh thread for blocked rports (Mike Christie) [734961]
- [scsi] libfc: fix fc_eh_host_reset (Mike Christie) [734961]
- [scsi] fcoe: Fix deadlock between fip's recv_work and rtnl (Mike Christie) [734961]
- [scsi] fcoe: add fip retry to avoid missing critical keep alive (Mike Christie) [734961]
- [scsi] libfc: fix warn on in lport retry (Mike Christie) [734961]
- [scsi] libfc: Remove the reference to FCP packet from scsi_cmnd in case of error (Mike Christie) [734961]
- [scsi] libfc: cleanup sending SRR request (Mike Christie) [734961]
- [scsi] libfc: two minor changes in comments (Mike Christie) [734961]
- [scsi] libfc, fcoe: ignore rx frame with wrong xid info (Mike Christie) [734961]
- [scsi] libfc: release exchg cache (Mike Christie) [734961]
- [scsi] libfc: use FC_MAX_ERROR_CNT (Mike Christie) [734961]
- [scsi] fcoe: remove unused ptype field in fcoe_rcv_info (Mike Christie) [734961]
- [scsi] fcoe: Rearrange fcoe port and NPIV port cleanup (Mike Christie) [734961]
- [x86] intel_idle: Fix mismerge (Matthew Garrett) [733730]
- [x86] x2apic: enable the bios request for x2apic optout (Prarit Bhargava) [696902]
- [x86] ACPI: fix ioremap failure regression (Stanislaw Gruszka) [731546]

* Fri Sep 16 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-198.el6]
- [fs] corrupted GUID partition tables can cause kernel oops (Jerome Marchand) [695982] {CVE-2011-1577}
- [x86] perf: Fix Intel fixed counters base initialization (Don Zickus) [736284] {CVE-2011-2521}
- [netdrv] iwlagn: use 6000g2b uCode for 130 series devices (Stanislaw Gruszka) [737185]
- [block] Missing portions of DM/MD RAID1 plugging patch (Jonathan E Brassow) [735124]
- [net] Compute protocol sequence numbers and fragment IDs using MD5. (Jiri Pirko) [732665] {CVE-2011-3188}
- [crypto] Move md5_transform to lib/md5.c (Jiri Pirko) [732665] {CVE-2011-3188}

* Mon Sep 12 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-197.el6]
- [block] blktrace: fix handling of requests with SYNC and META flags (Mike Snitzer) [726437]
- [block] blktrace: add FLUSH/FUA support (Mike Snitzer) [726437]
- [kernel] Restore max mqueue message size to its previous RHEL 5 value (Doug Ledford) [730632]

* Wed Sep 07 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-196.el6]
- [scsi] qla4xxx: updated device id check for BFS (Chad Dupuis) [732622]
- [fs] nfsd4: return nfserr_symlink on v4 OPEN of non-regular file (J. Bruce Fields) [697659]
- [netdrv] bnx2: Fix some late breaking bnx2 bugs (Neil Horman) [728328]
- [netdrv] e1000: save skb counts in TX to avoid cache misses (Dean Nelson) [690780]
- [netdrv] bonding: reset queue mapping prior to transmission (Neil Horman) [726688]
- [netdrv] e1000e: update to upstream version 1.4.4 (Andy Gospodarek) [730607]
- [netdrv] bonding: add missing xmit_hash_policy=layer2+3 info (Weiping Pan) [706018]
- [net] vlan: do not transfer real_num_tx_queues (Weiping Pan) [735015]
- [mm] thp: tail page refcounting fix (Andrea Arcangeli) [732986]
- [virt] xen: x86_32: do not enable iterrupts when returning from exception in interrupt context (Igor Mammedov) [713399]
- [mm] oom: task->mm == NULL doesn't mean the memory was freed (Frantisek Hrbata) [734732]
- [scsi] scsi_dh_rdac: Associate HBA and storage in rdac_controller to support partitions in storage (Mike Snitzer) [733763]
- [scsi] scsi_dh_rdac: Use WWID from C8 page instead of Subsystem id from C4 page to identify storage (Mike Snitzer) [733763]
- [scsi] lpfc: Update lpfc version for 8.3.5.45.3p driver release (Rob Evers) [733500]
- [scsi] lpfc: Fix compiler warning due to uninitialized local variable (Rob Evers) [733500]
- [scsi] lpfc: Fix bus reset handler fails with bad failure code (Rob Evers) [733500]
- [scsi] lpfc: Fix proper error code return value for management API (Rob Evers) [733500]
- [scsi] lpfc: Fixed ctlreg write bug (Rob Evers) [733500]
- [scsi] lpfc: Fix default adapter name for the OCe15100 (Rob Evers) [733500]
- [scsi] lpfc: Fix cable pull failure on interface type 2 SLI-4 adapters (Rob Evers) [733500]
- [scsi] lpfc: Fixed not able to perform firmware reset through sysfs board_mode attribute (Rob Evers) [733500]
- [scsi] lpfc: Fixed SLI4 device firmware reset with SR-IOV virtual functions (Rob Evers) [733500]
- [scsi] lpfc: Fixed not recovering SLI port in handling error attention with RN bit set (Rob Evers) [733500]
- [scsi] lpfc: Fix two crashes when unsolicted ELS ECHO_CMD is received (Rob Evers) [733500]
- [scsi] lpfc: Fix direct connect does not come up for SLI4 FC ports (Rob Evers) [733500]
- [scsi] lpfc: Fixed long wait when firmware reset to a SLI port without required privilege (Rob Evers) [733500]
- [scsi] lpfc: Fix request firmware support for little endian systems (Rob Evers) [733500]

* Sun Sep 04 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-195.el6]
- [drm] radeon/kms: set a default max_pixel_clock (Dave Airlie) [729545]
- [pci] pciehp: change wait time for valid configuration access (Myron Stowe) [727720]
- [pci] ACPI: Report ASPM support to BIOS if not disabled from command line (Myron Stowe) [732501]
- [ppc] pci: Add calls to set_pcie_port_type() and set_pcie_hotplug_bridge() (Steve Best) [734192]
- [ppc] pci: Add missing hookup to pci_slot (Steve Best) [734192]
- [ppc] pci: Add missing call to header fixup (Steve Best) [734192]
- [virt] xen events: implement mask_ack (Andrew Jones) [733672]
- [virt] Revert "[virt] xen/events: change to using fasteoi" (Andrew Jones) [733672]
- [scsi] be2iscsi: Add pci_disable device (Mike Christie) [688076]
- [scsi] be2iscsi: Adding a shutdown Routine (Mike Christie) [688076]
- [net] ipv6: make fragment identifications less predictable (Jiri Pirko) [723433] {CVE-2011-2699}
- [fs] Ecryptfs: Add mount option to check uid of device being mounted = expect uid (Eric Sandeen) [731176] {CVE-2011-1833}

* Thu Sep 01 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-194.el6]
- [md] raid5: fix FUA request handling in ops_run_io() (Mike Snitzer) [733527]
- [md] raid5: fix errant REQ_FUA that should be BIO_FUA (Mike Snitzer) [733527]
- [perf] report: Use properly build_id kernel binaries (Jiri Olsa) [691343]
- [ppc] pseries/xics: Use cpu_possible_mask rather than cpu_all_mask (Steve Best) [732357]
- [drm] i915: Post-3.0 updates from drm-intel-fixes (Adam Jackson) [720702]
- [scsi] bfa: Update the driver version to 3.0.2.2 (Rob Evers) [725913]
- [scsi] bfa: Add support to store driver configuration in flash (Rob Evers) [725913]
- [scsi] bfa: Add support to collect fabric stats (Rob Evers) [725913]
- [scsi] bfa: Added support to configure QOS and collect stats (Rob Evers) [725913]
- [scsi] bfa: Add support to configure trunking on Brocade adapter ports (Rob Evers) [725913]
- [scsi] bfa: Add support to configure and query flash boot partition (Rob Evers) [725913]
- [scsi] bfa: Added support to collect and reset fcport stats (Rob Evers) [725913]
- [scsi] bfa: Add support for IO profiling (Rob Evers) [725913]
- [scsi] bfa: Extend BSG to support more user commands (Rob Evers) [725913]
- [scsi] bfa: Check supported speed based on port mode (Rob Evers) [725913]
- [scsi] bfa: Update RME interrupt handling (Rob Evers) [725913]
- [scsi] bfa: BSG return value fix to be compatible with kernel convention (Rob Evers) [725913]
- [scsi] bfa: Add FC-transport based Asynchronous Event Notification support (Rob Evers) [725913]
- [scsi] bfa: Move debugfs initialization before bfa init (Rob Evers) [701485]
- [scsi] bfa: Update the driver version to 3.0.2.1 (Rob Evers) [701485]
- [scsi] bfa: Driver and BSG enhancements (Rob Evers) [701485]
- [scsi] bfa: Added support to query PHY (Rob Evers) [701485]
- [scsi] bfa: Added HBA diagnostics support (Rob Evers) [701485]
- [scsi] bfa: Added support for flash configuration (Rob Evers) [701485]
- [scsi] bfa: Added support to obtain SFP info (Rob Evers) [701485]
- [scsi] bfa: Added support for CEE info and stats query (Rob Evers) [701485]
- [scsi] bfa: Extend BSG interface (Rob Evers) [701485]
- [scsi] bfa: FCS bug fixes (Rob Evers) [701485]
- [scsi] bfa: DMA memory allocation enhancement (Rob Evers) [701485]
- [scsi] bfa: Brocade-1860 Fabric Adapter vHBA support (Rob Evers) [701485]
- [scsi] bfa: Brocade-1860 Fabric Adapter PLL init fixes (Rob Evers) [701485]
- [scsi] bfa: Added Fabric Assigned Address(FAA) support (Rob Evers) [701485]
- [scsi] bfa: IOC bug fixes (Rob Evers) [701485]
- [scsi] bfa: Enable ASIC block configuration and query (Rob Evers) [701485]
- [scsi] bfa: Update the driver version to 3.0.2.0 (Rob Evers) [701485]
- [scsi] bfa: Add BSG interface to support ELS, CT and vendor commands (Rob Evers) [701485]
- [scsi] bfa: Driver initialization and model description fix (Rob Evers) [701485]
- [scsi] bfa: Enhancement for fcpim and IO tag handling (Rob Evers) [701485]
- [scsi] bfa: FC credit recovery and misc bug fixes (Rob Evers) [701485]
- [scsi] bfa: Brocade-1860 Fabric Adapter 16Gbs support and flash controller fixes (Rob Evers) [701485]
- [scsi] bfa: IOC and PLL init changes for Brocade-1860 Fabric Adapter (Rob Evers) [701485]
- [scsi] bfa: Changes to support vport disable and enable operations (Rob Evers) [701485]
- [scsi] bfa: Brocade-1860 Fabric Adapter Hardware Enablement (Rob Evers) [701485]
- [scsi] bfa: Add pbc port disable check and fix LPS message name (Rob Evers) [701485]
- [scsi] bfa: Introduce IOC event notification mechanism (Rob Evers) [701485]
- [scsi] bfa: Introduced generic address len pair to represent DMA memory chunk (Rob Evers) [701485]

* Fri Aug 26 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-193.el6]
- [pci] remove quirk for pre-production systems with Intel 82576 NIC (Prarit Bhargava) [729677]
- [x86] efi: Revert new_memmap code (Matthew Garrett) [723274]
- [infiniband] mlx4: add new module parameters (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: Avoid duplicate devices from LUN scan (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: Fix integer -> pointer cast warnings (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: try to use larger FMR sizes to cover  our mappings (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: add support for indirect tables that  don't fit in SRP_CMD (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: rework mapping engine to use multiple  FMR entries (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: allow sg_tablesize to be set for each  target (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: move IB CM setup completion into its  own function (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: always avoid non-zero offsets into an FMR (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: Test only once whether iu allocation  succeeded (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IPoIB: Add GRO support (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IPoIB: Remove LRO support (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: consolidate hot-path variables into  cache lines (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: stop sharing the host lock with SCSI (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] Touch up a merge issue, fixes compilation (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: reduce lock coverage of command completion (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: reduce local coverage for command  submission and EH (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: don't move active requests to their own  list (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: allow lockless work posting (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: consolidate state change code (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/srp: allow task management without a  previous request (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] rds/ib: use system_wq instead of rds_ib_fmr_wq (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [net] rds: Makefile: Remove deprecated items (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] Manual backport of alloc_netdev_mqs (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] Fix a merge issue (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: Restoring RX buffer pointer in case of  failure (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4: Sensing link type at device initialization (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4: Fixing bad size of event queue buffer (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: Fix loss of promiscuity (Doug Ledford) [612992 688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: Removing HW info from ethtool -i report (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: updated driver version to 1.5.4.1 (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: Using blue flame support (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_core: reserve UARs for userspace consumers (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_core: maintain available field in bitmap  allocator (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4: Add blue flame support for kernel consumers (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: Reporting HW revision in ethtool -i (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4: Wake on LAN support (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: using new mlx4 interrupt scheme (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4: Changing interrupt scheme (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: bringing link up when registering  netdevice (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: optimize adaptive moderation algorithm  for better latency (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: moderation parameters are not reseted (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_en: going out of range of TX rings when  reporting stats (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/mlx4: Handle protocol field in multicast table (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_core, ib,  en: Fix driver when sizeof phys_addr_t > sizeof long (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/mlx4: Handle -ENOMEM in forward_trap() (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4_core: Avoid vunmap() of invalid pointer if  allocation fails (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/mlx4: Don't call dma_free_coherent() with  irqs disabled (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] mlx4: Call alloc_etherdev to allocate RX and TX  queues (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/nes: Add a check for strict_strtoul() (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/ipath: Use pci_dev->revision, again (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB: Increase DMA max_segment_size on Mellanox  hardware (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/nes: Don't print success message at level  KERN_ERR (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/ipath: Don't reset disabled devices (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/nes: Don't generate async events for  unregistered devices (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/amso1100: Fix compile warnings (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/nes: Fix incorrect SFP+ link status  detection on driver init (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/nes: Fix SFP+ link down detection issue  with switch port disable (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/nes: Generate  IB_EVENT_PORT_ERR/PORT_ACTIVE events (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/nes: Fix bonding on iw_nes (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA: Use vzalloc() to replace vmalloc()+memset(0) (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/mthca: Fix driver when sizeof (phys_addr_t)  > sizeof (long) (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/nes: Fix string continuation line (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/mthca: Handle -ENOMEM in forward_trap() (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/ipath: Use printf extension pR for struct  resource (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA: Check for NULL mode in .devnode methods (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/cma: Save PID of ID's owner (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/cma: Add support for netlink statistics  export (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/cma: Pass QP type into rdma_create_id() (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA: Update exported headers list (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/cma: Export enum cma_state in  <rdma/rdma_cm.h> (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB: Add devnode methods to cm_class and umad_class (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/mad: Return EPROTONOSUPPORT when an RDMA  device lacks the QP required (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/uverbs: Add devnode method to set path/mode (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/ucma: Add .nodename/.mode to tell  userspace where to create device node (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA: Add netlink infrastructure (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] Backports to fix compile of changes that  upstream made but relied on changes that don't exist in rhel6 (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA: Add error handling to ib_core_init() (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/iwcm: Get rid of enum iw_cm_event_status (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/cma: Add an ID_REUSEADDR option (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/cma: Fix handling of IPv6 addressing in  cma_use_port (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/mad: Improve an error message so error code  is included (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/cma: Replace global lock in  rdma_destroy_id() with id-specific one (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] IB/cm: Cancel pending LAP message when exiting  IB_CM_ESTABLISH state (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA: Update missed conversion of  flush_scheduled_work() (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA/ucma: Copy iWARP route information on queries (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] RDMA: Update workqueue usage (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [infiniband] infiniband: remove dev_base_lock use (Doug Ledford) [688944 690152 698275 698279 698283 700277 707092 710159]
- [virt] vmalloc: eagerly clear ptes on vunmap (Igor Mammedov) [730503]

* Tue Aug 23 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-192.el6]
- [build] spec: add more drivers to initrd (Andy Gospodarek) [714883]
- [target] add to tech-preview.txt and call mark_tech_preview (Andy Grover) [638007]
- [x86] ucode-amd: Don't warn when no ucode is available for a CPU revision (Anton Arapov) [731409]
- [scsi] isci: remove core/scic_sds_port_configuration_agent.c (David Milburn) [730136]
- [scsi] qla4xxx: export iface name (Mike Christie) [730599]
- [s390x] config: switch on CONFIG_DEBUG_PAGEALLOC on s390x-debug kernel (Hendrik Brueckner) [702405]
- [char] tpm: Fix uninitialized usage of data buffer (Stanislaw Gruszka) [684675] {CVE-2011-1160}
- [ata] libata: remove SCSI host lock (David Milburn) [732062]
- [scsi] scsi_dh_rdac: decide on whether to send mode select or not (Tomas Henzl) [683613]
- [scsi] scsi_dh_rdac: Detect the different RDAC operating modes (Tomas Henzl) [683613]
- [scsi] scsi_dh_rdac: Add definitions for different RDAC operating modes (Tomas Henzl) [683613]
- [target] modify rhel config for tcm (Andy Grover) [638007]
- [target] backport to old queuecommand interface (Andy Grover) [638007]
- [target] fixup file backstore for vfs_fsync_range api change (Andy Grover) [638007]
- [target] fixes for iblock backport (Andy Grover) [638007]
- [scsi] add ACA_TAG definition to scsi/scsi_tcq.h (Andy Grover) [638007]
- [scsi] Add missing SPC-4 CDB and MAINTENANCE_[IN, OUT] service action definitions (Andy Grover) [638007]
- [target] Fix UTS_RELEASE build errors (Andy Grover) [638007]
- [scsi] tcm_fc: Fixing reference counting problem which was causing ft_sess to be deleted (Andy Grover) [638007]
- [scsi] Add FCoE Target support (Andy Grover) [638007]
- [block] cfq-iosched: Reduce linked group count upon group destruction (Vivek Goyal) [726099]
- [kdump] x86: Fix crashkernel=auto to take into account memory needed by filtering utility (Vivek Goyal) [730077]

* Wed Aug 17 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-191.el6]
- [drm] radeon: post-3.0 fixes (Jerome Glisse) [730838]
- [netdrv] netxen-firmware: rename firmware files (Andy Gospodarek) [693743]
- [netdrv] netxen_nic: Fix common misspellings (Tony Camuso) [693740]
- [netdrv] netxen_nic: Add support for VLAN RX HW acceleration (Tony Camuso) [693740]
- [netdrv] netxen_nic: Fix ethtool->set_flags not intended -EINVAL return value (Tony Camuso) [693740]
- [netdrv] netxen_nic: Support for GbE port settings (Tony Camuso) [693740]
- [netdrv] netxen_nic: Notify firmware of Flex 10 interface down (Tony Camuso) [693740]
- [netdrv] netxen-firmware: Update firmware to version 4.0.544 or greater (Tony Camuso) [693743]
- [fs] autofs: fix some further kabi inconsistencies (Ian Kent) [704941]
- [fs] kabi - add back do_add_mount() (Ian Kent) [704941]
- [fs] kabi - rename follow_down_one() to follow_down() (Ian Kent) [704941]
- [fs] VFS: Fix automount for negative autofs dentries (Ian Kent) [704941]
- [fs] VFS: Fix vfsmount overput on simultaneous automount (Ian Kent) [704941]
- [fs] autofs4 - reinstate last used update on access (Ian Kent) [704941]
- [fs] tidy up around finish_automount() (Ian Kent) [704941]
- [fs] don't drop newmnt on error in do_add_mount() (Ian Kent) [704941]
- [fs] Take the completion of automount into new helper (Ian Kent) [704941]
- [fs] autofs4: Merge the remaining dentry ops tables (Ian Kent) [704941]
- [fs] Unexport do_add_mount() and add in follow_automount(), not ->d_automount() (Ian Kent) [704941]
- [fs] vfs - Remove a further kludge from __do_follow_link() (Ian Kent) [704941]
- [fs] autofs4 - bump version (Ian Kent) [704941]
- [fs] autofs4 - add v4 pseudo direct mount support (Ian Kent) [704941]
- [fs] autofs4 - fix wait validation (Ian Kent) [704941]
- [fs] autofs4: cleanup autofs4_free_ino() (Ian Kent) [704941]
- [fs] autofs4: cleanup dentry operations (Ian Kent) [704941]
- [fs] autofs4: cleanup inode operations (Ian Kent) [704941]
- [fs] autofs4: removed unused code (Ian Kent) [704941]
- [fs] autofs4: add d_manage() dentry operation (Ian Kent) [704941]
- [fs] autofs4: add d_automount() dentry operation (Ian Kent) [704941]
- [fs] CIFS: Use d_automount() rather than abusing follow_link() [ver #2] (Ian Kent) [704941]
- [fs] NFS: Use d_automount() rather than abusing follow_link() (Ian Kent) [704941]
- [fs] VFS: Add an AT_NO_AUTOMOUNT flag to suppress terminal automount [ver #2] (Ian Kent) [704941]
- [fs] Add a dentry op to allow processes to be held during pathwalk transit (Ian Kent) [704941]
- [fs] VFS: Add a dentry op to handle automounting rather than abusing follow_link() (Ian Kent) [704941]
- [fs] dcache remove d_mounted (Ian Kent) [704941]
- [fs] Sanitize autofs_dev_ioctl_ismountpoint() (Ian Kent) [704941]
- [fs] autofs4 - rename dentry to expiring in autofs4_lookup_expiring() (Ian Kent) [704941]
- [fs] autofs4 - rename dentry to active in autofs4_lookup_active() (Ian Kent) [704941]
- [fs] autofs4 - eliminate d_unhashed in path walk checks (Ian Kent) [704941]
- [fs] autofs4 - cleanup active and expire lookup (Ian Kent) [704941]
- [fs] autofs4 - rename unhashed to active in autofs4_lookup() (Ian Kent) [704941]
- [fs] autofs4 - use autofs_info for pending flag (Ian Kent) [704941]
- [fs] autofs4 - use helper for need mount check (Ian Kent) [704941]
- [fs] autofs4 - use helpers for expiring list (Ian Kent) [704941]
- [fs] autofs4 - use helpers for active list handling (Ian Kent) [704941]
- [md] Using poll /proc/mdstat can monitor the events of adding a spare disks (Doug Ledford) [729696]
- [md] raid5: get rid of duplicated call to bio_data_dir() (Doug Ledford) [729696]
- [md] raid5: use kmem_cache_zalloc() (Doug Ledford) [729696]
- [md] raid10: share pages between read and write bio's during recovery (Doug Ledford) [729696]
- [md] raid10: factor out common bio handling code (Doug Ledford) [729696]
- [md] raid10: get rid of duplicated conditional expression (Doug Ledford) [729696]
- [md] raid5: remove unusual use of bio_iovec_idx() (Doug Ledford) [729696]
- [md] raid5: fix raid5_set_bi_hw_segments (Doug Ledford) [729696]
- [md] bitmap: remove unused fields from struct bitmap (Doug Ledford) [729696]
- [md] bitmap: use proper accessor macro (Doug Ledford) [729696]
- [md] check ->hot_remove_disk when removing disk (Doug Ledford) [729696]
- [md] use is_power_of_2 macro (Doug Ledford) [729696]
- [md] allow resync_start to be set while an array is active (Doug Ledford) [729696]
- [md] raid10: reformat some loops with less indenting (Doug Ledford) [729696]
- [md] raid10: remove unused variable (Doug Ledford) [729696]
- [md] raid10: make more use of 'slot' in raid10d (Doug Ledford) [729696]
- [md] raid10: some tidying up in fix_read_error (Doug Ledford) [729696]
- [md] raid1: improve handling of pages allocated for write-behind (Doug Ledford) [729696]
- [md] raid1: try fix_sync_read_error before process_checks (Doug Ledford) [729696]
- [md] raid1: tidy up new functions: process_checks and fix_sync_read_error (Doug Ledford) [729696]
- [md] raid1: split out two sub-functions from sync_request_write (Doug Ledford) [729696]
- [md] make error_handler functions more uniform and correct (Doug Ledford) [729696]
- [md] multipath: discard working_disks in favour of degraded (Doug Ledford) [729696]
- [md] raid1: clean up read_balance (Doug Ledford) [729696]
- [md] simplify raid10 read_balance (Doug Ledford) [729696]
- [md] bitmap: fix saving of events_cleared and other state (Doug Ledford) [729696]
- [md] reject a re-add request that cannot be honoured (Doug Ledford) [729696]
- [md] Fix race when creating a new md device (Doug Ledford) [729696]
- [md] raid5: fix build error, sector_t usage (Doug Ledford) [729696]
- [md] Fix dev_sectors on takeover from raid0 to raid4/5 (Doug Ledford) [729696]
- [input] kabi fixes after addition of MT slot fields (Mauro Carvalho Chehab) [464653]
- [input] synaptics: retry failed resets when reconnecting (Mauro Carvalho Chehab) [464653]
- [input] synaptics: fix reconnect logic on MT devices (Mauro Carvalho Chehab) [464653]
- [input] synaptics: ignore bogus mt packet (Mauro Carvalho Chehab) [464653]
- [input] synaptics: add multi-finger and semi-mt support (Mauro Carvalho Chehab) [464653]
- [input] create a separate code for handling mt slots (Mauro Carvalho Chehab) [464653]
- [input] introduce MT event slots (Mauro Carvalho Chehab) [464653]
- [input] synaptics: fix handling of 2-button ClickPads (Mauro Carvalho Chehab) [464653]
- [input] synaptics: simplify pass-through port handling (Mauro Carvalho Chehab) [464653]
- [input] synaptics: relax capability ID checks on newer hardware (Mauro Carvalho Chehab) [464653]
- [input] synaptics: set min/max for finger width (Mauro Carvalho Chehab) [464653]
- [input] synaptics: only report width on hardware that supports it (Mauro Carvalho Chehab) [464653]
- [input] synaptics: set dimensions as reported by firmware (Mauro Carvalho Chehab) [464653]
- [input] Add support of Synaptics Clickpad device (Mauro Carvalho Chehab) [464653]
- [input] psmouse: fix Synaptics detection when protocol is disabled (Mauro Carvalho Chehab) [464653]

* Tue Aug 16 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-190.el6]
- [mm] mremap: resurrect overflow check in move_page_tables() (Andrea Arcangeli) [725926]
- [security] SELinux: indicate fatal error in compat netfilter code (Eric Paris) [656952]
- [security] SELinux: Only return netlink error when we know the return is fatal (Eric Paris) [656952]
- [security] SELinux: return -ECONNREFUSED from ip_postroute to signal fatal error (Eric Paris) [656952]
- [net] tcp_connect should return certain errors up the stack (Eric Paris) [656952]
- [net] netfilter: allow hooks to pass error code back up the stack (Eric Paris) [656952]
- [scsi] isci: remove reserved device IDs from isci_id_table (David Milburn) [730131]
- [kernel] perf: Fix software event overflow (Peter Zijlstra) [730708]
- [watchdog] hpwdt support for upcoming ProLiant generations (Tony Camuso) [726719]
- [perf] spec: Adding python-perf package (Jiri Olsa) [725812]
- [perf] tools: Add support to install perf python extension (Jiri Olsa) [725812]
- [perf] sched: Usage leftover from trace -> script rename (Jiri Olsa) [726589]
- [perf] sched: Do not delete session object prematurely (Jiri Olsa) [726595]
- [perf] buildid-cache: Zero out buffer of filenames when adding/removing buildid (Jiri Olsa) [696044]
- [x86] UV: Correct UV2 BAU destination timeout (George Beshers) [696269]
- [x86] UV: Allow for non-consecutive sockets (George Beshers) [696269]
- [x86] UV: Correct failed topology memory leak (George Beshers) [696269]
- [x86] UV: Remove cpumask_t from the stack (George Beshers) [696269]
- [x86] UV: Rename hubmask to pnmask (George Beshers) [696269]
- [x86] UV: Correct reset_with_ipi() (George Beshers) [696269]
- [x86] UV: Inline header file functions (George Beshers) [696269]
- [x86] UV: Fix smp_processor_id() use in a preemptable region (George Beshers) [696269]
- [x86] UV: Clean up uv_tlb.c (George Beshers) [696269]
- [x86] Fix UV BAU for non-consecutive nasids (George Beshers) [696269]
- [x86] UV: Enable 64-bit ACPI MFCG support (George Beshers) [696269]
- [x86] UV: Avoid KABI breakage (George Beshers) [696269]
- [x86] UV: Add support for SGI UV2 hub chip (George Beshers) [696269]
- [x86] UV: Update node controller MMRs (George Beshers) [696269]
- [scsi] libsas: fix/amend device gone notification is sas_deform_port() (David Milburn) [695955]
- [scsi] revert libsas: fix/amend device gone notification is sas_deform_port() (David Milburn) [695955]
- [scsi] libsas: fix loopback topology bug during discovery (David Milburn) [695955]
- [ata] libata: fix locking for sas paths (David Milburn) [695955]
- [scsi] libsas: plumb sas port scan into standard libata paths (David Milburn) [695955]
- [scsi] libsas: Add option for SATA soft reset (David Milburn) [695955]
- [scsi] libsas: fix SATA NCQ error (David Milburn) [695955]
- [scsi] libsas: fix ata list corruption issue (David Milburn) [695955]
- [scsi] libsas: convert to libata new error handler (David Milburn) [695955]
- [ata] libata: separate error handler into usable components (David Milburn) [695955]
- [scsi] libsas: remove spurious sata control register read/write (David Milburn) [695955]
- [ata] libata: fix eh locking (David Milburn) [695955]
- [ata] libsas: fix ATAPI check condition termination (David Milburn) [695955]
- [scsi] Unify SAM_ and SAM_STAT_ macros (David Milburn) [695955]
- [ata] libata: kill ATA_FLAG_DISABLED (David Milburn) [695955]
- [ata] libata-sff: kill unused ata_bus_reset() (David Milburn) [695955]

* Mon Aug 15 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-189.el6]
- [dm] RAID: add RAID1 to DM_RAID Kconfig (Mike Snitzer) [723010]
- [block] DM RAID: add call to 'mark_tech_preview' (Jonathan E Brassow) [723010]
- [dm] RAID: add RAID module to config (Mike Snitzer) [723010]
- [md] RAID1: Generic unplug (Jonathan E Brassow) [723010]
- [dm] RAID: Included header cleanup (Jonathan E Brassow) [723010]
- [dm] RAID: Support RAID1 personality (Jonathan E Brassow) [723010]
- [dm] RAID: Support Metadata devices (Jonathan E Brassow) [723010]
- [dm] RAID: Allow write_mostly specification (Jonathan E Brassow) [723010]
- [dm] RAID: Allow region_size specification (Jonathan E Brassow) [723010]
- [dm] RAID: documentation update (Jonathan E Brassow) [723010]
- [dm] RAID: cleanup parameter handling (Jonathan E Brassow) [723010]
- [dm] RAID: RAID 4/5/6 basic support (Jonathan E Brassow) [723010]
- [md] RAID1 changes for device-mapper (Jonathan E Brassow) [723010]
- [md] Generate event on sync completion (Jonathan E Brassow) [723010]
- [md] Prevent NULL ptr dereference (Jonathan E Brassow) [723010]
- [md] support bitmap creation by DM (Jonathan E Brassow) [723010]
- [md] raid5 do not set fullsync (Jonathan E Brassow) [723010]
- [md] add sync_super to mddev_t struct (Jonathan E Brassow) [723010]
- [md] move thread wakeups into resume (Jonathan E Brassow) [723010]
- [md] Misc message clean-up (Jonathan E Brassow) [723010]
- [md] No sync I/O while suspended (Jonathan E Brassow) [723010]
- [md] No integrity register if no gendisk (Jonathan E Brassow) [723010]
- [dm] table: propagate non-rotational flag (Mike Snitzer) [723005]
- [dm] table: avoid crash if integrity profile changes (Mike Snitzer) [723005]
- [dm] flakey: fix corrupt_bio_byte error path (Mike Snitzer) [723005]
- [dm] add features flag to dm_target structure (Mike Snitzer) [714992]
- [block] dm table: set flush capability based on underlying devices (Mike Snitzer) [725816]
- [block] dm: suppress endian warnings (Mike Snitzer) [723005]
- [block] eliminate potential for infinite loop in blkdev_issue_discard (Mike Snitzer) [723005]
- [dm] introduce and use BIO_DISCARD (Mike Snitzer) [723005]
- [dm] ioctl: prevent empty message (Mike Snitzer) [723005]
- [dm] export dm_get_md (Mike Snitzer) [723005]
- [dm] table: add always-writeable feature (Mike Snitzer) [723005]
- [dm] table: add singleton feature (Mike Snitzer) [723005]
- [dm] table: clean dm_get_device and move exports (Mike Snitzer) [723005]
- [dm] ioctl: forbid multiple device specifiers (Mike Snitzer) [723005]
- [dm] ioctl: introduce __get_dev_cell (Mike Snitzer) [723005]
- [dm] ioctl: fill in device parameters in more ioctls (Mike Snitzer) [723005]
- [dm] flakey: add corrupt_bio_byte feature (Mike Snitzer) [723005]
- [dm] flakey: add drop_writes (Mike Snitzer) [723005]
- [dm] flakey: support feature args (Mike Snitzer) [723005]
- [dm] flakey: use dm_target_offset and support discards (Mike Snitzer) [723005]
- [dm] table: share target argument parsing functions (Mike Snitzer) [723005]
- [dm] snapshot: skip reading origin when overwriting complete chunk (Mike Snitzer) [723005]
- [dm] ignore merge_bvec for-snapshots when safe (Mike Snitzer) [723005]
- [dm] kcopyd: add dm_kcopyd_zero to zero an area (Mike Snitzer) [723005]
- [dm] snapshot: style cleanups (Mike Snitzer) [723005]
- [dm] snapshot: remove unused definitions (Mike Snitzer) [723005]
- [dm] kcopyd: remove nr_pages field from job structure (Mike Snitzer) [723005]
- [dm] kcopyd: remove offset field from job structure (Mike Snitzer) [723005]
- [dm] use vzalloc (Mike Snitzer) [723005]
- [dm] log userspace: use list_move (Mike Snitzer) [723005]
- [dm] table: fix discard support (Mike Snitzer) [723005]
- [dm] mpath: fix potential NULL pointer in feature arg processing (Mike Snitzer) [723005]
- [dm] snapshot: flush disk cache when merging (Mike Snitzer) [723005]
- [dm] io: RHEL specific updates to support interface changes (Mike Snitzer) [723005]
- [dm] kcopyd: return client directly and not through a pointer (Mike Snitzer) [723005]
- [dm] kcopyd: reserve fewer pages (Mike Snitzer) [723005]
- [dm] io: use fixed initial mempool size (Mike Snitzer) [723005]
- [dm] kcopyd: alloc pages from the main page allocator (Mike Snitzer) [723005]
- [dm] kcopyd: add gfp parm to alloc_pl (Mike Snitzer) [723005]
- [dm] kcopyd: remove superfluous page allocation spinlock (Mike Snitzer) [723005]
- [dm] kcopyd: preallocate sub jobs to avoid deadlock (Mike Snitzer) [723005]
- [dm] kcopyd: avoid pointless job splitting (Mike Snitzer) [723005]
- [dm] table: reject devices without request fns (Mike Snitzer) [723005]
- [dm] table: allow targets to support discards internally (Mike Snitzer) [723005]
- [dm] mpath: allow table load with no priority groups (Mike Snitzer) [723005]
- [dm] mpath: fail message ioctl if specified path is not valid (Mike Snitzer) [723005]
- [dm] flakey: enable on all supported RHEL6 architectures (Mike Snitzer) [723005]
- [dm] add flakey target (Mike Snitzer) [723005]
- [dm] fix opening log and cow devices for read only tables (Mike Snitzer) [723005]
- [dm] per target unplug callback support (Mike Snitzer) [723005]
- [dm] introduce target callbacks and congestion callback (Mike Snitzer) [723005]
- [dm] snapshot: remove unused dm_snapshot queued_bios_work (Mike Snitzer) [723005]
- [block] cciss: do not attempt to read from a write-only register (Tony Camuso) [728676]
- [scsi] mpt2sas: mark lockless mode tech preview (Prarit Bhargava)
- [perf] x86: Add model 45 SandyBridge support (Prarit Bhargava) [729557]
- [x86] section mismatch fix for boot_cpu_data_rh (Prarit Bhargava) [729341]
- [mm] Avoid merging a VMA with another VMA which is cloned from the parent process. (Larry Woodman) [725855]
- [pci] revert latest SRIOV patchset (Aristeu Rozanski) [730144]

* Fri Aug 12 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-188.el6]
- [fs] sysfs: use rb-tree for inode number lookup (Mikulas Patocka) [725580]
- [fs] sysfs: remove s_sibling hacks (Mikulas Patocka) [725580]
- [fs] sysfs: use rb-tree for name lookups (Mikulas Patocka) [725580]
- [fs] sysfs: count subdirectories (Mikulas Patocka) [725580]
- [mm] backing-dev: use synchronize_rcu_expedited instead of synchronize_rcu (Mikulas Patocka) [725580]
- [fs] cifs: don't start signing too early (Jeff Layton) [729437]
- [fs] cifs: Fix signing failure when server mandates signing for NTLMSSP (Jeff Layton) [729437]
- [net] net: don't set VLAN_TAG_PRESENT for VLAN 0 frames (Stefan Assmann) [706208]
- [netdrv] bnx2x: fix undesired VLAN stripping (Michal Schmidt) [702752]
- [fs] nfs: don't use d_move in nfs_async_rename_done (Jeff Layton) [729434]
- [net] af_packet: prevent information leak (Jiri Pirko) [728033]
- [net] gro: Only reset frag0 when skb can be pulled (Jiri Pirko) [726556]
- [net] Fix security_socket_sendmsg() bypass problem. (Jiri Pirko) [708365]
- [net] Cap number of elements for sendmmsg (Jiri Pirko) [708365]
- [net] sendmmsg should only return an error if no messages were sent (Jiri Pirko) [708365]
- [net] net: Add sendmmsg socket system call (Jiri Pirko) [708365]
- [gfs2] assert in __gfs2_ail_flush after #676626 patch is applied (Robert S Peterson) [724921]
- [fs] FS-Cache: Only call mark_tech_preview() when caching is actually begun (David Howells) [696396]
- [fs] Fix mark_tech_preview() to not disable lock debugging (David Howells) [696396]
- [netdrv] bonding: fix potential deadlock in bond_uninit() (Andy Gospodarek) [719587]
- [netdrv] vmxnet3: Update to latest upstream (Neil Horman) [694893]

* Thu Aug 11 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-187.el6]
- [fs] xfs: unpin stale inodes directly in IOP_COMMITTED (Dave Chinner) [695827]
- [fs] xfs: prevent bogus assert when trying to remove non-existent attribute (Dave Chinner) [695827]
- [fs] xfs: clear XFS_IDIRTY_RELEASE on truncate down (Dave Chinner) [695827]
- [fs] xfs: reset inode per-lifetime state when recycling it (Dave Chinner) [695827]
- [fs] xfs: make log devices with write back caches work (Dave Chinner) [695827]
- [fs] xfs: fix ->mknod() return value on xfs_get_acl() failure (Dave Chinner) [695827]
- [fs] xfs: correctly decrement the extent buffer index in xfs_bmap_del_extent (Dave Chinner) [695827]
- [fs] xfs: check for valid indices in xfs_iext_get_ext and xfs_iext_idx_to_irec (Dave Chinner) [695827]
- [fs] xfs: fix up asserts in xfs_iflush_fork (Dave Chinner) [695827]
- [fs] xfs: do not do pointer arithmetic on extent records (Dave Chinner) [695827]
- [fs] xfs: do not use unchecked extent indices in xfs_bunmapi (Dave Chinner) [695827]
- [fs] xfs: do not use unchecked extent indices in xfs_bmapi (Dave Chinner) [695827]
- [fs] xfs: do not use unchecked extent indices in xfs_bmap_add_extent_* (Dave Chinner) [695827]
- [fs] xfs: remove if_lastex (Dave Chinner) [695827]
- [fs] xfs: remove the unused XFS_BMAPI_RSVBLOCKS flag (Dave Chinner) [695827]
- [fs] xfs: obey minleft values during extent allocation correctly (Dave Chinner) [695827]
- [fs] xfs: reset buffer pointers before freeing them (Dave Chinner) [695827]
- [fs] xfs: avoid getting stuck during async inode flushes (Dave Chinner) [695827]
- [fs] xfs: fix xfs_itruncate_start tracing (Dave Chinner) [695827]
- [fs] xfs: kill off xfs_printk() (Dave Chinner) [695827]
- [fs] xfs: treewide: fix a few typos in comments (Dave Chinner) [695827]
- [fs] xfs: make AIL target updates and compares 32bit safe. (Dave Chinner) [695827]
- [fs] xfs: always push the AIL to the target (Dave Chinner) [695827]
- [fs] xfs: ensure reclaim cursor is reset correctly at end of AG (Dave Chinner) [695827]
- [fs] xfs: add an x86 compat handler for XFS_IOC_ZERO_RANGE (Dave Chinner) [695827]
- [fs] xfs: fix compiler warning in xfs_trace.h (Dave Chinner) [695827]
- [fs] xfs: cleanup duplicate initializations (Dave Chinner) [695827]
- [fs] xfs: reduce the number of pagb_lock roundtrips in xfs_alloc_clear_busy (Dave Chinner) [695827]
- [fs] xfs: exact busy extent tracking (Dave Chinner) [695827]
- [fs] xfs: do not immediately reuse busy extent ranges (Dave Chinner) [695827]
- [fs] xfs: optimize AGFL refills (Dave Chinner) [695827]
- [fs] xfs: fix duplicate message output (Dave Chinner) [695827]
- [fs] xfs: fix xfs_debug warnings (Dave Chinner) [695827]
- [fs] xfs: fix variable set but not used warnings (Dave Chinner) [695827]
- [fs] xfs: convert log tail checking to a warning (Dave Chinner) [695827]
- [fs] xfs: catch bad block numbers freeing extents. (Dave Chinner) [695827]
- [fs] xfs: fix extent format buffer allocation size (Dave Chinner) [695827]
- [fs] xfs: Fix common misspellings (Dave Chinner) [695827]
- [fs] xfs: fix unreferenced var error in xfs_buf.c (Dave Chinner) [695827]
- [fs] xfs: stop using the page cache to back the buffer cache (Dave Chinner) [695827]
- [fs] xfs: register the inode cache shrinker before quotachecks (Dave Chinner) [695827]
- [fs] xfs: xfs_trans_read_buf() should return an error on failure (Dave Chinner) [695827]
- [fs] xfs: introduce inode cluster buffer trylocks for xfs_iflush (Dave Chinner) [695827]
- [fs] xfs: vmap: flush vmap aliases when mapping fails (Dave Chinner) [695827]
- [fs] xfs: preallocation transactions do not need to be synchronous (Dave Chinner) [695827]
- [fs] xfs: don't name variables "panic" (Dave Chinner) [695827]
- [fs] xfs: factor agf counter updates into a helper (Dave Chinner) [695827]
- [fs] xfs: clean up the xfs_alloc_compute_aligned calling convention (Dave Chinner) [695827]
- [fs] xfs: kill support/debug.[ch] (Dave Chinner) [695827]
- [fs] xfs: Convert remaining cmn_err() callers to new API (Dave Chinner) [695827]
- [fs] xfs: convert the quota debug prints to new API (Dave Chinner) [695827]
- [fs] xfs: rename xfs_cmn_err_fsblock_zero() (Dave Chinner) [695827]
- [fs] xfs: convert xfs_fs_cmn_err to new error logging API (Dave Chinner) [695827]
- [fs] xfs: kill xfs_fs_mount_cmn_err() macro (Dave Chinner) [695827]
- [fs] xfs: kill xfs_fs_repair_cmn_err() macro (Dave Chinner) [695827]
- [fs] xfs: convert xfs_cmn_err to xfs_alert_tag (Dave Chinner) [695827]
- [fs] xfs: Convert xlog_warn to new logging interface (Dave Chinner) [695827]
- [fs] xfs: Convert linux-2.6/ files to new logging interface (Dave Chinner) [695827]
- [fs] xfs: introduce new logging API. (Dave Chinner) [695827]
- [fs] xfs: enable delaylog by default (Dave Chinner) [695827]
- [fs] xfs: more sensible inode refcounting for ialloc (Dave Chinner) [695827]
- [fs] xfs: stop using xfs_trans_iget in the RT allocator (Dave Chinner) [695827]
- [fs] xfs: check if device support discard in xfs_ioc_trim() (Dave Chinner) [695827]
- [fs] xfs: add lockdep annotations for the rt inodes (Dave Chinner) [695827]
- [fs] xfs: fix xfs_get_extsz_hint for a zero extent size hint (Dave Chinner) [695827]
- [fs] xfs: only lock the rt bitmap inode once per allocation (Dave Chinner) [695827]
- [fs] xfs: xfs_bmap_add_extent_delay_real should init br_startblock (Dave Chinner) [695827]
- [fs] xfs: fix dquot shaker deadlock (Dave Chinner) [695827]
- [fs] xfs: handle CIL transaction commit failures correctly (Dave Chinner) [695827]
- [fs] xfs: limit extsize to size of AGs and/or MAXEXTLEN (Dave Chinner) [695827]
- [fs] xfs: prevent extsize alignment from exceeding maximum extent size (Dave Chinner) [695827]
- [fs] xfs: limit extent length for allocation to AG size (Dave Chinner) [695827]
- [fs] xfs: speculative delayed allocation uses rounddown_power_of_2 badly (Dave Chinner) [695827]
- [fs] xfs: fix efi item leak on forced shutdown (Dave Chinner) [695827]
- [fs] xfs: fix log ticket leak on forced shutdown. (Dave Chinner) [695827]
- [fs] xfs: Do not name variables "panic" (Dave Chinner) [695827]
- [fs] xfs: prevent NMI timeouts in cmn_err (Dave Chinner) [695827]
- [fs] xfs: workqueue: convert cancel_rearming_delayed_work[queue]() users to cancel_delayed_work_sync() (Dave Chinner) [695827]
- [fs] make the feature checks in ->fallocate future proof (Dave Chinner) [695827]
- [fs] xfs: Add log level to assertion printk (Dave Chinner) [695827]
- [fs] xfs: fix an assignment within an ASSERT() (Dave Chinner) [695827]
- [fs] xfs: fix error handling for synchronous writes (Dave Chinner) [695827]
- [fs] xfs: add FITRIM support (Dave Chinner) [695827]
- [fs] xfs: ensure log covering transactions are synchronous (Dave Chinner) [695827]
- [fs] xfs: factor common write setup code (Dave Chinner) [695827]
- [fs] xfs: split buffered IO write path from xfs_file_aio_write (Dave Chinner) [695827]
- [fs] xfs: split direct IO write path from xfs_file_aio_write (Dave Chinner) [695827]
- [fs] xfs: introduce xfs_rw_lock() helpers for locking the inode (Dave Chinner) [695827]
- [fs] xfs: factor post-write newsize updates (Dave Chinner) [695827]
- [fs] xfs: factor common post-write isize handling code (Dave Chinner) [695827]
- [fs] xfs: convert grant head manipulations to lockless algorithm (Dave Chinner) [695827]
- [fs] xfs: introduce new locks for the log grant ticket wait queues (Dave Chinner) [695827]
- [fs] xfs: log timestamp changes to the source inode in rename (Dave Chinner) [695827]
- [fs] xfs: convert log grant heads to atomic variables (Dave Chinner) [695827]
- [fs] xfs: convert l_tail_lsn to an atomic variable. (Dave Chinner) [695827]
- [fs] xfs: convert l_last_sync_lsn to an atomic variable (Dave Chinner) [695827]
- [fs] xfs: make AIL tail pushing independent of the grant lock (Dave Chinner) [695827]
- [fs] xfs: use wait queues directly for the log wait queues (Dave Chinner) [695827]
- [fs] xfs: combine grant heads into a single 64 bit integer (Dave Chinner) [695827]
- [fs] xfs: rework log grant space calculations (Dave Chinner) [695827]
- [fs] xfs: fact out common grant head/log tail verification code (Dave Chinner) [695827]
- [fs] xfs: convert log grant ticket queues to list heads (Dave Chinner) [695827]
- [fs] xfs: use AIL bulk delete function to implement single delete (Dave Chinner) [695827]
- [fs] xfs: use AIL bulk update function to implement single updates (Dave Chinner) [695827]
- [fs] xfs: remove all the inodes on a buffer from the AIL in bulk (Dave Chinner) [695827]
- [fs] xfs: consume iodone callback items on buffers as they are processed (Dave Chinner) [695827]
- [fs] xfs: reduce the number of AIL push wakeups (Dave Chinner) [695827]
- [fs] xfs: bulk AIL insertion during transaction commit (Dave Chinner) [695827]
- [fs] xfs: clean up xfs_ail_delete() (Dave Chinner) [695827]
- [fs] xfs: Pull EFI/EFD handling out from under the AIL lock (Dave Chinner) [695827]
- [fs] xfs: fix EFI transaction cancellation. (Dave Chinner) [695827]
- [fs] xfs: connect up buffer reclaim priority hooks (Dave Chinner) [695827]
- [fs] xfs: add a lru to the XFS buffer cache (Dave Chinner) [695827]
- [fs] xfs: only run xfs_error_test if error injection is active (Dave Chinner) [695827]
- [fs] xfs: avoid moving stale inodes in the AIL (Dave Chinner) [695827]
- [fs] xfs: delayed alloc blocks beyond EOF are valid after writeback (Dave Chinner) [695827]
- [fs] xfs: push stale, pinned buffers on trylock failures (Dave Chinner) [695827]
- [fs] xfs: fix failed write truncation handling. (Dave Chinner) [695827]
- [fs] xfs: convert xfsbud shrinker to a per-buftarg shrinker. (Dave Chinner) [695827]
- [fs] xfs: convert pag_ici_lock to a spin lock (Dave Chinner) [695827]
- [fs] xfs: convert inode cache lookups to use RCU locking (Dave Chinner) [695827]
- [fs] xfs: rcu free inodes (Dave Chinner) [695827]
- [fs] xfs: don't truncate prealloc from frequently accessed inodes (Dave Chinner) [695827]
- [fs] xfs: dynamic speculative EOF preallocation (Dave Chinner) [695827]
- [fs] xfs: use KM_NOFS for allocations during attribute list operations (Dave Chinner) [695827]
- [fs] xfs: provide a inode iolock lockdep class (Dave Chinner) [695827]
- [fs] xfs: factor duplicate code in xfs_alloc_ag_vextent_near into a helper (Dave Chinner) [695827]
- [fs] xfs: clean up xfs_alloc_ag_vextent_exact (Dave Chinner) [695827]
- [fs] xfs: simplify xfs_map_at_offset (Dave Chinner) [695827]
- [fs] xfs: refactor xfs_vm_writepage (Dave Chinner) [695827]
- [fs] xfs: remove the all_bh flag from xfs_convert_page (Dave Chinner) [695827]
- [fs] xfs: remove xfs_probe_cluster (Dave Chinner) [695827]
- [fs] xfs: simplify xfs_map_blocks (Dave Chinner) [695827]
- [fs] xfs: kill xfs_iomap (Dave Chinner) [695827]
- [fs] xfs: cleanup the xfs_iomap_write_* helpers (Dave Chinner) [695827]
- [fs] xfs: a few small tweaks for overwrites in xfs_vm_writepage (Dave Chinner) [695827]
- [fs] xfs: remove some dead bio handling code (Dave Chinner) [695827]
- [fs] xfs: improve mapping type check in xfs_vm_writepage (Dave Chinner) [695827]
- [fs] xfs: untangle phase1 vs phase2 recovery helpers (Dave Chinner) [695827]
- [fs] xfs: refactor xlog_recover_commit_trans (Dave Chinner) [695827]
- [fs] xfs: use struct list_head for the buf cancel table (Dave Chinner) [695827]
- [fs] xfs: remove leftovers of old buffer log items in recovery code (Dave Chinner) [695827]
- [fs] xfs: fix exporting with left over 64-bit inodes (Dave Chinner) [695827]
- [fs] xfs: remove incorrect assert in xfs_vm_writepage (Dave Chinner) [695827]
- [fs] xfs: fix a few compiler warnings with CONFIG_XFS_QUOTA=n (Dave Chinner) [695827]
- [fs] xfs: tell lockdep about parent iolock usage in filestreams (Dave Chinner) [695827]
- [fs] xfs: move delayed write buffer trace (Dave Chinner) [695827]
- [fs] xfs: fix per-ag reference counting in inode reclaim tree walking (Dave Chinner) [695827]
- [fs] xfs: xfs_ioctl: fix information leak to userland (Dave Chinner) [695827]
- [fs] xfs: remove experimental tag from the delaylog option (Dave Chinner) [695827]
- [fs] tree-wide: fix comment/printk typos (Dave Chinner) [695827]
- [fs] writeback: remove nonblocking/encountered_congestion references (Dave Chinner) [695827]
- [fs] xfs: semaphore cleanup (Dave Chinner) [695827]
- [fs] xfs: Extend project quotas to support 32bit project ids (Dave Chinner) [695827]
- [fs] xfs: remove xfs_buf wrappers (Dave Chinner) [695827]
- [fs] xfs: remove xfs_cred.h (Dave Chinner) [695827]
- [fs] xfs: remove xfs_globals.h (Dave Chinner) [695827]
- [fs] xfs: remove xfs_version.h (Dave Chinner) [695827]
- [fs] xfs: remove xfs_refcache.h (Dave Chinner) [695827]
- [fs] xfs: fix the xfs_trans_committed (Dave Chinner) [695827]
- [fs] xfs: remove unused t_callback field in struct xfs_trans (Dave Chinner) [695827]
- [fs] xfs: fix bogus m_maxagi check in xfs_iget (Dave Chinner) [695827]
- [fs] xfs: do not use xfs_mod_incore_sb_batch for per-cpu counters (Dave Chinner) [695827]
- [fs] xfs: do not use xfs_mod_incore_sb for per-cpu counters (Dave Chinner) [695827]
- [fs] xfs: remove XFS_MOUNT_NO_PERCPU_SB (Dave Chinner) [695827]
- [fs] xfs: pack xfs_buf structure more tightly (Dave Chinner) [695827]
- [fs] xfs: convert buffer cache hash to rbtree (Dave Chinner) [695827]
- [fs] xfs: serialise inode reclaim within an AG (Dave Chinner) [695827]
- [fs] xfs: batch inode reclaim lookup (Dave Chinner) [695827]
- [fs] xfs: implement batched inode lookups for AG walking (Dave Chinner) [695827]
- [fs] xfs: split out inode walk inode grabbing (Dave Chinner) [695827]
- [fs] xfs: split inode AG walking into separate code for reclaim (Dave Chinner) [695827]
- [fs] xfs: remove buftarg hash for external devices (Dave Chinner) [695827]
- [fs] xfs: use unhashed buffers for size checks (Dave Chinner) [695827]
- [fs] xfs: kill XBF_FS_MANAGED buffers (Dave Chinner) [695827]
- [fs] xfs: store xfs_mount in the buftarg instead of in the xfs_buf (Dave Chinner) [695827]
- [fs] xfs: introduced uncached buffer read primitve (Dave Chinner) [695827]
- [fs] xfs: rename xfs_buf_get_nodaddr to be more appropriate (Dave Chinner) [695827]
- [fs] xfs: don't use vfs writeback for pure metadata modifications (Dave Chinner) [695827]
- [fs] xfs: lockless per-ag lookups (Dave Chinner) [695827]
- [fs] xfs: remove debug assert for per-ag reference counting (Dave Chinner) [695827]
- [fs] xfs: reduce the number of CIL lock round trips during commit (Dave Chinner) [695827]
- [fs] xfs: eliminate some newly-reported gcc warnings (Dave Chinner) [695827]
- [fs] xfs: remove the ->kill_root btree operation (Dave Chinner) [695827]
- [fs] xfs: stop using xfs_qm_dqtobp in xfs_qm_dqflush (Dave Chinner) [695827]
- [fs] xfs: simplify xfs_qm_dqusage_adjust (Dave Chinner) [695827]
- [fs] xfs: Introduce XFS_IOC_ZERO_RANGE (Dave Chinner) [695827]
- [fs] xfs: use range primitives for xfs page cache operations (Dave Chinner) [695827]
- [fs] xfs: force background CIL push under sustained load (Dave Chinner) [695827]
- [fs] xfs: Make fiemap work with sparse files (Dave Chinner) [695827]
- [fs] xfs: prevent 32bit overflow in space reservation (Dave Chinner) [695827]
- [fs] xfs: Disallow 32bit project quota id (Dave Chinner) [695827]
- [fs] xfs: improve buffer cache hash scalability (Dave Chinner) [695827]
- [fs] xfs: do not discard page cache data on EAGAIN (Dave Chinner) [695827]
- [fs] xfs: don't do memory allocation under the CIL context lock (Dave Chinner) [695827]
- [fs] xfs: Reduce log force overhead for delayed logging (Dave Chinner) [695827]
- [fs] xfs: dummy transactions should not dirty VFS state (Dave Chinner) [695827]
- [fs] xfs: ensure f_ffree returned by statfs() is non-negative (Dave Chinner) [695827]
- [fs] xfs: handle negative wbc->nr_to_write during sync writeback (Dave Chinner) [695827]
- [fs] xfs: unlock items before allowing the CIL to commit (Dave Chinner) [695827]
- [fs] xfs: new truncate sequence (Dave Chinner) [695827]
- [fs] xfs: get rid of block_write_begin_newtrunc (Dave Chinner) [695827]
- [fs] sort out blockdev_direct_IO variants (Dave Chinner) [695827]
- [fs] xfs simplify and speed up direct I/O completions (Dave Chinner) [695827]
- [fs] xfs: fix big endian build (Dave Chinner) [695827]
- [fs] xfs: clean up xfs_bmap_get_bp (Dave Chinner) [695827]
- [fs] xfs: simplify xfs_truncate_file (Dave Chinner) [695827]
- [fs] xfs: kill the b_strat callback in xfs_buf (Dave Chinner) [695827]
- [fs] xfs: remove obsolete osyncisosync mount option (Dave Chinner) [695827]
- [fs] xfs: clean up filestreams helpers (Dave Chinner) [695827]
- [fs] xfs: fix gcc 4.6 set but not read and unused statement warnings (Dave Chinner) [695827]
- [fs] xfs: Fix build when CONFIG_XFS_POSIX_ACL=n (Dave Chinner) [695827]
- [fs] xfs: fix unsigned underflow in xfs_free_eofblocks (Dave Chinner) [695827]
- [fs] xfs: use GFP_NOFS for page cache allocation (Dave Chinner) [695827]
- [fs] xfs: fix memory reclaim recursion deadlock on locked inode buffer (Dave Chinner) [695827]
- [fs] xfs: fix xfs_trans_add_item() lockdep warnings (Dave Chinner) [695827]
- [fs] xfs: simplify and remove xfs_ireclaim (Dave Chinner) [695827]
- [fs] xfs: remove a dmapi leftover (Dave Chinner) [695827]
- [fs] xfs: writepage always has buffers (Dave Chinner) [695827]
- [fs] xfs: allow writeback from kswapd (Dave Chinner) [695827]
- [fs] xfs: remove incorrect log write optimization (Dave Chinner) [695827]
- [fs] xfs: split xfs_itrace_entry (Dave Chinner) [695827]
- [fs] xfs: remove xfs_iput (Dave Chinner) [695827]
- [fs] xfs: remove xfs_iput_new (Dave Chinner) [695827]
- [fs] xfs: some iget tracing cleanups / fixes (Dave Chinner) [695827]
- [fs] xfs: do not use emums for flags used in tracing (Dave Chinner) [695827]
- [fs] xfs: remove explicit xfs_sync_data/xfs_sync_attr calls on umount (Dave Chinner) [695827]
- [fs] xfs: small cleanups for xfs_iomap / __xfs_get_blocks (Dave Chinner) [695827]
- [fs] xfs: reduce stack usage in xfs_iomap (Dave Chinner) [695827]
- [fs] xfs: avoid synchronous transaction in xfs_fs_write_inode (Dave Chinner) [695827]
- [fs] xfs: simplify xfs_vm_writepage (Dave Chinner) [695827]
- [fs] xfs: simplify xfs_vm_releasepage (Dave Chinner) [695827]
- [fs] xfs: remove unused delta tracking code in xfs_bmapi (Dave Chinner) [695827]
- [fs] xfs: remove unused XFS_BMAPI_ flags (Dave Chinner) [695827]
- [fs] xfs: remove the unused XFS_TRANS_NOSLEEP/XFS_TRANS_WAIT flags (Dave Chinner) [695827]
- [fs] xfs: remove the unused XFS_LOG_SLEEP and XFS_LOG_NOSLEEP flags (Dave Chinner) [695827]
- [fs] xfs: kill the unused xlog_debug variable (Dave Chinner) [695827]
- [fs] xfs: fix the xfs_log_iovec i_addr type (Dave Chinner) [695827]
- [fs] xfs: simplify inode to transaction joining (Dave Chinner) [695827]
- [fs] xfs: simplify buffer pinning (Dave Chinner) [695827]
- [fs] xfs: give li_cb callbacks the correct prototype (Dave Chinner) [695827]
- [fs] xfs: give xfs_item_ops methods the correct prototypes (Dave Chinner) [695827]
- [fs] xfs: merge iop_unpin_remove into iop_unpin (Dave Chinner) [695827]
- [fs] xfs: simplify log item descriptor tracking (Dave Chinner) [695827]
- [fs] xfs: remove unneeded #include statements (Dave Chinner) [695827]
- [fs] xfs: drop dmapi hooks (Dave Chinner) [695827]
- [fs] xfs: improve xfs_isilocked (Dave Chinner) [695827]
- [fs] xfs: skip writeback from reclaim context (Dave Chinner) [695827]
- [fs] xfs: fix access to upper inodes without inode64 (Dave Chinner) [695827]
- [fs] xfs: fix might_sleep() warning when initialising per-ag tree (Dave Chinner) [695827]
- [fs] xfs/quota: Add missing mutex_unlock (Dave Chinner) [695827]
- [fs] xfs: remove duplicated #include (Dave Chinner) [695827]
- [fs] xfs: convert more trace events to DEFINE_EVENT (Dave Chinner) [695827]
- [fs] xfs: xfs_trace.c: remove duplicated #include (Dave Chinner) [695827]
- [fs] xfs: Check new inode size is OK before preallocating (Dave Chinner) [695827]
- [fs] xfs: clean up xlog_align (Dave Chinner) [695827]
- [fs] xfs: cleanup log reservation calculactions (Dave Chinner) [695827]
- [fs] xfs: be more explicit if RT mount fails due to config (Dave Chinner) [695827]
- [fs] xfs: replace E2BIG with EFBIG where appropriate (Dave Chinner) [695827]
- [fs] xfs: Ensure inode allocation buffers are fully replayed (Dave Chinner) [695827]
- [fs] xfs: enable background pushing of the CIL (Dave Chinner) [695827]
- [fs] xfs: forced unmounts need to push the CIL (Dave Chinner) [695827]
- [fs] xfs: Introduce delayed logging core code (Dave Chinner) [695827]
- [fs] xfs: Improve scalability of busy extent tracking (Dave Chinner) [695827]
- [fs] xfs: make the log ticket ID available outside the log infrastructure (Dave Chinner) [695827]
- [fs] xfs: clean up log ticket overrun debug output (Dave Chinner) [695827]
- [fs] xfs: Clean up XFS_BLI_* flag namespace (Dave Chinner) [695827]
- [fs] xfs: modify buffer item reference counting (Dave Chinner) [695827]
- [fs] xfs: allow log ticket allocation to take allocation flags (Dave Chinner) [695827]
- [fs] xfs: Don't reuse the same transaction ID for duplicated transactions. (Dave Chinner) [695827]
- [fs] xfs: mark xfs_iomap_write_ helpers static (Dave Chinner) [695827]
- [fs] xfs: clean up end index calculation in xfs_page_state_convert (Dave Chinner) [695827]
- [fs] xfs: clean up mapping size calculation in __xfs_get_blocks (Dave Chinner) [695827]
- [fs] xfs: clean up xfs_iomap_valid (Dave Chinner) [695827]
- [fs] xfs: move I/O type flags into xfs_aops.c (Dave Chinner) [695827]
- [fs] xfs: kill struct xfs_iomap (Dave Chinner) [695827]
- [fs] xfs: report iomap_bn in block base (Dave Chinner) [695827]
- [fs] xfs: report iomap_offset and iomap_bsize in block base (Dave Chinner) [695827]
- [fs] xfs: remove iomap_delta (Dave Chinner) [695827]
- [fs] xfs: remove iomap_target (Dave Chinner) [695827]
- [fs] xfs: limit xfs_imap_to_bmap to a single mapping (Dave Chinner) [695827]
- [fs] xfs: simplify buffer to transaction matching (Dave Chinner) [695827]
- [fs] xfs: kill off l_sectbb_mask (Dave Chinner) [695827]
- [fs] xfs: record log sector size rather than log2(that) (Dave Chinner) [695827]
- [fs] xfs: remove dead XFS_LOUD_RECOVERY code (Dave Chinner) [695827]
- [fs] xfs: removed unused XFS_QMOPT_ flags (Dave Chinner) [695827]
- [fs] xfs: remove a few macro indirections in the quota code (Dave Chinner) [695827]
- [fs] xfs: access quotainfo structure directly (Dave Chinner) [695827]
- [fs] xfs: wait for direct I/O to complete in fsync and write_inode (Dave Chinner) [695827]
- [fs] xfs: xfs_trace.c: duplicated include (Dave Chinner) [695827]
- [fs] xfs: minor odds and ends in xfs_log_recover.c (Dave Chinner) [695827]
- [fs] xfs: avoid repeated pointer dereferences (Dave Chinner) [695827]
- [fs] xfs: change a few labels in xfs_log_recover.c (Dave Chinner) [695827]
- [fs] xfs: enforce synchronous writes in xfs_bwrite (Dave Chinner) [695827]
- [fs] xfs: remove periodic superblock writeback (Dave Chinner) [695827]
- [fs] xfs: make the log ticket transaction id random (Dave Chinner) [695827]
- [fs] xfs: nothing special about 1-block log sector (Dave Chinner) [695827]
- [fs] xfs: encapsulate bbcount validity checking (Dave Chinner) [695827]
- [fs] xfs: kill XLOG_SECTOR_ROUND*() (Dave Chinner) [695827]
- [fs] xfs: simplify XLOG_SECTOR_ROUND*() (Dave Chinner) [695827]
- [fs] xfs: fix min bufsize bugs in two places (Dave Chinner) [695827]
- [fs] xfs: add const qualifiers to xfs error function args (Dave Chinner) [695827]
- [fs] xfs: remove xfs_dqmarker (Dave Chinner) [695827]
- [fs] xfs: convert the dquot free list to use list heads (Dave Chinner) [695827]
- [fs] xfs: convert the dquot hash list to use list heads (Dave Chinner) [695827]
- [fs] xfs: remove duplicate code from dquot reclaim (Dave Chinner) [695827]
- [fs] xfs: convert the per-mount dquot list to use list heads (Dave Chinner) [695827]
- [fs] xfs: add log item recovery tracing (Dave Chinner) [695827]
- [fs] xfs: clean up xlog_write_adv_cnt (Dave Chinner) [695827]
- [fs] xfs: introduce new internal log vector structure (Dave Chinner) [695827]
- [fs] xfs: reindent xlog_write (Dave Chinner) [695827]
- [fs] xfs: factor xlog_write (Dave Chinner) [695827]
- [fs] xfs: log ticket reservation underestimates the number of iclogs (Dave Chinner) [695827]
- [fs] xfs: Clean up xfs_trans_committed code after factoring (Dave Chinner) [695827]
- [fs] xfs: update and factor xfs_trans_committed() (Dave Chinner) [695827]
- [fs] xfs: clean up xfs_trans_commit logic even more (Dave Chinner) [695827]
- [fs] xfs: split out iclog writing from xfs_trans_commit() (Dave Chinner) [695827]
- [fs] xfs: fix reservation release commit flag in xfs_bmap_add_attrfork() (Dave Chinner) [695827]
- [fs] xfs: remove stale parameter from ->iop_unpin method (Dave Chinner) [695827]
- [fs] xfs: Add inode pin counts to traces (Dave Chinner) [695827]
- [fs] xfs: factor log item initialisation (Dave Chinner) [695827]
- [fs] xfs: add blockdev name to kthreads (Dave Chinner) [695827]
- [fs] xfs: Fix integer overflow in fs/xfs/linux-2.6/xfs_ioctl*.c (Dave Chinner) [695827]
- [fs] include cleanup: Update gfp.h and slab.h includes to prepare for breaking implicit slab.h inclusion from percpu.h (Dave Chinner) [695827]
- [fs] xfs: use scalable vmap API (Dave Chinner) [695827]
- [fs] xfs: remove old vmap cache (Dave Chinner) [695827]
- [fs] xfs: backport of vmapped buffer helpers (Dave Chinner) [695827]
- [fs] quota: drop permission checks from xfs_fs_set_xstate/xfs_fs_set_xquota (Dave Chinner) [695827]
- [fs] quota: clean up Q_XQUOTASYNC (Dave Chinner) [695827]
- [fs] xfs: remove xfs_ipin/xfs_iunpin (Dave Chinner) [695827]
- [fs] xfs: cleanup xfs_iunpin_wait/xfs_iunpin_nowait (Dave Chinner) [695827]
- [fs] xfs: kill xfs_lrw.h (Dave Chinner) [695827]
- [fs] xfs: factor common xfs_trans_bjoin code (Dave Chinner) [695827]
- [fs] xfs: stop passing opaque handles to xfs_log.c routines (Dave Chinner) [695827]
- [fs] xfs: split xfs_bmap_btalloc (Dave Chinner) [695827]
- [fs] xfs: fix xfs_fsblock_t tracing (Dave Chinner) [695827]
- [fs] xfs: implement optimized fdatasync (Dave Chinner) [695827]
- [fs] xfs: remove wrapper for the fsync file operation (Dave Chinner) [695827]
- [fs] xfs: remove wrappers for read/write file operations (Dave Chinner) [695827]
- [fs] xfs: merge xfs_lrw.c into xfs_file.c (Dave Chinner) [695827]
- [fs] fs/xfs: Correct NULL test (Dave Chinner) [695827]
- [fs] xfs: only clear the suid bit once in xfs_write (Dave Chinner) [695827]
- [fs] xfs: turn off sign warnings (Dave Chinner) [695827]
- [fs] xfs: replace KM_LARGE with explicit vmalloc use (Dave Chinner) [695827]
- [fs] xfs: rearrange xfs_mod_sb() to avoid array subscript warning (Dave Chinner) [695827]
- [fs] xfs: suppress spurious uninitialised var warning in xfs_bmapi() (Dave Chinner) [695827]
- [fs] xfs: make compile warn about char sign mismatches again (Dave Chinner) [695827]
- [fs] xfs: clean up sign warnings in dir2 code (Dave Chinner) [695827]
- [fs] xfs: convert attr to use unsigned names (Dave Chinner) [695827]
- [fs] xfs: xfs_buf_iomove() doesn't care about signedness (Dave Chinner) [695827]
- [fs] xfs: make xfs_dir_cilookup_result use unsigned char (Dave Chinner) [695827]
- [fs] xfs: convert dirnameops to unsigned char names (Dave Chinner) [695827]
- [fs] xfs: convert DM ops to use unsigned char names (Dave Chinner) [695827]
- [fs] xfs: directory names are unsigned (Dave Chinner) [695827]
- [fs] xfs: Use list_heads for log recovery item lists (Dave Chinner) [695827]
- [fs] xfs: make several more functions static (Dave Chinner) [695827]
- [fs] xfs: fix incorrect quota return value sign (Dave Chinner) [695827]
- [kernel] vsprintf: Recursive vsnprintf: Add "pV", struct va_format (Dave Chinner) [695827]
- [fs] check ATTR_SIZE contraints in inode_change_ok (Dave Chinner) [695827]
- [fs] new helper: ihold() (Dave Chinner) [695827]
- [fs] introduce new truncate sequence (Dave Chinner) [695827]

* Thu Aug 11 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-186.el6]
- [virt] KVM: Don't spin on virt instruction faults during reboot (Marcelo Tosatti) [637520]
- [virt] KVM: Mask unsupported cpuid leaves (Don Dugger) [729060]
- [virt] KVM: move and fix substitue search for missing CPUID entries (Don Dugger) [729060]
- [virt] KVM: fix XSAVE bit scanning (Don Dugger) [729060]
- [virt] KVM: SVM: Add xsetbv intercept (Don Dugger) [729060]
- [virt] KVM: fix poison overwritten caused by using wrong xstate size (Don Dugger) [729060]
- [virt] KVM: Fix OSXSAVE after migration (Don Dugger) [729060]
- [virt] Fix OSXSAVE VXEXIT handling (Don Dugger) [729060]
- [virt] KVM: x86: Enable AVX for guest (Don Dugger) [729060]
- [virt] KVM: Fix xsave and xcr save/restore memory leak (Don Dugger) [729060]
- [virt] KVM: x86: XSAVE/XRSTOR live migration support (Don Dugger) [729060]
- [virt] KVM: VMX: Enable XSAVE/XRSTOR for guest (Don Dugger) [729060]
- [x86] Export FPU API for KVM use (Don Dugger) [729060]
- [virt] KVM: x86: Use FPU API (Don Dugger) [729060]
- [perf] Fix static build of perf tool (Jiri Olsa) [725522]
- [perf] clear out make flags when calling kernel make kernelver (Jiri Olsa) [725522]
- [perf] Use make kernelversion instead of parsing the Makefile (Jiri Olsa) [725522]
- [perf] python: Fix argument name list of read_on_cpu() (Jiri Olsa) [725522]
- [perf] evlist: Don't die if sample_{id_all|type} is invalid (Jiri Olsa) [725522]
- [perf] python: Use exception to propagate errors (Jiri Olsa) [725522]
- [perf] evlist: Remove dependency on debug routines (Jiri Olsa) [725522]
- [perf] top: Don't stop if no kernel symtab is found (Jiri Olsa) [725522]
- [perf] top: Handle kptr_restrict (Jiri Olsa) [725522]
- [perf] top: Remove unused macro (Jiri Olsa) [725522]
- [perf] events: initialize fd array to -1 instead of 0 (Jiri Olsa) [725522]
- [perf] tools: Make sure kptr_restrict warnings fit 80 col terms (Jiri Olsa) [725522]
- [perf] tools: Fix build on older systems (Jiri Olsa) [725522]
- [perf] symbols: Handle /proc/sys/kernel/kptr_restrict (Jiri Olsa) [725522]
- [perf] Remove duplicate headers (Jiri Olsa) [725522]
- [perf] tools: Fix sample type size calculation in 32 bits archs (Jiri Olsa) [725522]
- [perf] tools: Fix sample size bit operations (Jiri Olsa) [725522]
- [perf] tools: Fix ommitted mmap data update on remap (Jiri Olsa) [725522]
- [perf] tools: Propagate event parse error handling (Jiri Olsa) [725522]
- [perf] tools: Robustify dynamic sample content fetch (Jiri Olsa) [725522]
- [perf] tools: Pre-check sample size before parsing (Jiri Olsa) [725522]
- [perf] tools: Move evlist sample helpers to evlist area (Jiri Olsa) [725522]
- [perf] tools: Remove junk code in mmap size handling (Jiri Olsa) [725522]
- [perf] tools: Check we are able to read the event size on mmap (Jiri Olsa) [725522]
- [perf] Only include annotate.h once in tools/perf/util/ui/browsers/annotate.c (Jiri Olsa) [725522]
- [perf] stat: Add more cache-miss percentage printouts (Jiri Olsa) [725522]
- [perf] stat: Add -d -d and -d -d -d options to show more CPU events (Jiri Olsa) [725522]
- [perf] bench, x86: Add alternatives-asm.h wrapper (Jiri Olsa) [725522]
- [perf] Fix multi-event parsing bug (Jiri Olsa) [725522]
- [perf] probe: Fix the missed parameter initialization (Jiri Olsa) [725522]
- [perf] stat: Tell user about unsupported events in the list (Jiri Olsa) [725522]
- [perf] list: Fix max event string size (Jiri Olsa) [725522]
- [perf] stat: Fail softly on unsupported events (Jiri Olsa) [725522]
- [perf] stat: Leave more room for percentages (Jiri Olsa) [725522]
- [perf] stat: Adjust stall cycles warning percentages (Jiri Olsa) [725522]
- [perf] stat: Analyze front-end and back-end stall counts (Jiri Olsa) [725522]
- [perf] tools: Add front-end and back-end stalled cycles support (Jiri Olsa) [725522]
- [perf] stat: Fix compatibility behavior (Jiri Olsa) [725522]
- [perf] stat: Add --sync/-S option (Jiri Olsa) [725522]
- [perf] stat: Fix printout vertical alignment (Jiri Olsa) [725522]
- [perf] stat: Add -d/--detailed flag to run with a lot of events (Jiri Olsa) [725522]
- [perf] stat: Print out miss/hit ratio for L1 data-cache events (Jiri Olsa) [725522]
- [perf] stat: Print branch misses warning colors (Jiri Olsa) [725522]
- [perf] stat: Print stalled cycles warning colors (Jiri Olsa) [725522]
- [perf] stat: Fix -nan output in perf stat noise printouts (Jiri Olsa) [725522]
- [perf] stat: Add stalled cycles to the default output (Jiri Olsa) [725522]
- [perf] stat: Add stalled cycles accounting, prettify the resulting output (Jiri Olsa) [725522]
- [perf] stat: Factor our shadow stats (Jiri Olsa) [725522]
- [perf] stat: Make all displayed event names parseable as well (Jiri Olsa) [725522]
- [perf] stat: Fail more clearly when an invalid modifier is specified (Jiri Olsa) [725522]
- [perf] tools: Accept case-insensitive symbolic event variants (Jiri Olsa) [725522]
- [perf] stat: Print cache misses as percentage (Jiri Olsa) [725522]
- [perf] stat: Print stalled cycles percentage (Jiri Olsa) [725522]
- [perf] events: Add stalled cycles generic event - PERF_COUNT_HW_STALLED_CYCLES (Jiri Olsa) [725522]
- [perf] script: improve validation of sample attributes for output fields (Jiri Olsa) [725522]
- [perf] script: Add support for PERF_TYPE_RAW (Jiri Olsa) [725522]
- [perf] tools: git mv tools/perf/{features-tests.mak, config/} (Jiri Olsa) [725522]
- [perf] tools: Move `try-cc' (Jiri Olsa) [725522]
- [perf] tools: Makefile: PYTHON{, _CONFIG} to bandage Python 3 incompatibility (Jiri Olsa) [725522]
- [perf] tools: Makefile: Clean up `python/perf.so' rule (Jiri Olsa) [725522]
- [perf] symbols: Give more useful names to 'self' parameters (Jiri Olsa) [725522]
- [perf] script: Add more documentation about the -f/--fields parameters (Jiri Olsa) [725522]
- [perf] script: If type not given fields apply to all event types (Jiri Olsa) [725522]
- [perf] probe: Add fastpath to do lookup by function name (Jiri Olsa) [725522]
- [perf] Fix a build error with some GCC versions (Jiri Olsa) [725522]
- [perf] python: Add cgroup.c to setup.py to get it building again (Jiri Olsa) [725522]
- [perf] tool: Add cgroup support (Jiri Olsa) [725522]
- [x86] perf: Cherry pick from linux-3.1 for pentium 4 (Peter Zijlstra) [692677 725524] {CVE-2011-2693}
- [x86] perf: Cherry pick from linux-3.1 (Peter Zijlstra) [725524]
- [kernel] perf: Redo RHEL fixups (Peter Zijlstra) [725524]
- [x86] perf: Sync to linux-3.0 (Peter Zijlstra) [725524]
- [kernel] perf: Core perf sync to linux-3.0 (Peter Zijlstra) [725524]
- [powerpc] perf: Roll-back to last mainline sync (Peter Zijlstra) [725524]
- [x86] perf: Roll-back to last mainline sync (Peter Zijlstra) [725524]
- [kernel] perf: Undo core perf differences (Peter Zijlstra) [725524]
- [kernel] perf: enable perf-cgroup support (Peter Zijlstra) [725524]

* Wed Aug 10 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-185.el6]
- [scsi] isci: fix checkpatch errors (David Milburn) [695954]
- [scsi] isci: Retrieve the EFI variable for OEM parameter (David Milburn) [695954]
- [scsi] isci: Device reset should request sas_phy_reset (David Milburn) [695954]
- [scsi] isci: pare back error messages (David Milburn) [695954]
- [scsi] isci: cleanup silicon revision detection (David Milburn) [695954]
- [scsi] isci: merge scu_unsolicited_frame.h into unsolicited_frame_control.h (David Milburn) [695954]
- [scsi] isci: merge sata.[ch] into request.c (David Milburn) [695954]
- [scsi] isci: kill 'get/set' macros (David Milburn) [695954]
- [scsi] isci: retire scic_sds_ and scic_ prefixes (David Milburn) [695954]
- [scsi] isci: unify isci_host and scic_sds_controller (David Milburn) [695954]
- [scsi] isci: unify isci_remote_device and scic_sds_remote_device (David Milburn) [695954]
- [scsi] isci: unify isci_port and scic_sds_port (David Milburn) [695954]
- [scsi] isci: fix scic_sds_remote_device_terminate_requests (David Milburn) [695954]
- [scsi] isci: unify isci_phy and scic_sds_phy (David Milburn) [695954]
- [scsi] isci: unify isci_request and scic_sds_request (David Milburn) [695954]
- [scsi] isci: rename / clean up scic_sds_stp_request (David Milburn) [695954]
- [scsi] isci: preallocate requests (David Milburn) [695954]
- [scsi] isci: combine request flags (David Milburn) [695954]
- [scsi] isci: unify can_queue tracking on the tci_pool, uplevel tag assignment (David Milburn) [695954]
- [scsi] isci: Terminate dev requests on FIS err bit rx in NCQ (David Milburn) [695954]
- [scsi] isci: fix frame received locking (David Milburn) [695954]
- [scsi] isci: possible buffer overflow in isci_parse_oem_parameters fixed (David Milburn) [695954]
- [scsi] isci: fix isci_task_execute_tmf completion (David Milburn) [695954]
- [scsi] isci: fix support for arbitrarily large smp requests (David Milburn) [695954]
- [scsi] isci: fix dma_unmap_sg usage (David Milburn) [695954]
- [scsi] isci: fix smp response frame overrun (David Milburn) [695954]
- [scsi] isci: kill device_sequence (David Milburn) [695954]
- [scsi] isci: kill isci_remote_device_change_state() (David Milburn) [695954]
- [scsi] isci: atomic device lookup and reference counting (David Milburn) [695954]
- [scsi] isci: fix ssp response iu buffer size in isci_tmf (David Milburn) [695954]
- [scsi] isci: cleanup request allocation (David Milburn) [695954]
- [scsi] isci: cleanup/optimize queue increment macros (David Milburn) [695954]
- [scsi] isci: cleanup tag macros (David Milburn) [695954]
- [scsi] isci: cleanup/optimize pool implementation (David Milburn) [695954]
- [scsi] isci: Disable link layer hang detection (David Milburn) [695954]
- [scsi] isci: Hard reset failure will link reset all phys in the port (David Milburn) [695954]
- [scsi] isci: Explicitly decode remote node ready and suspended states (David Milburn) [695954]
- [scsi] isci: fix isci_terminate_pending() list management (David Milburn) [695954]
- [scsi] isci: Handle timed-out request terminations correctly (David Milburn) [695954]
- [scsi] isci: Requests that do not start must be set to "complete" (David Milburn) [695954]
- [scsi] isci: Add decode for SMP request retry error condition (David Milburn) [695954]
- [scsi] isci: filter broadcast change notifications during SMP phy resets (David Milburn) [695954]
- [scsi] isci: Move the reset delay after the remote node resumption (David Milburn) [695954]
- [scsi] isci: remove 'min memory' infrastructure (David Milburn) [695954]
- [scsi] isci: Added support for C0 to SCU Driver (David Milburn) [695954]
- [scsi] isci: additional state machine cleanup (David Milburn) [695954]
- [scsi] isci: state machine cleanup (David Milburn) [695954]
- [scsi] isci: Removing unused variables compiler warnings (David Milburn) [695954]
- [scsi] isci: removing the kmalloc in smp request construct (David Milburn) [695954]
- [scsi] isci: remove isci_timer interface (David Milburn) [695954]
- [scsi] isci: Remove tmf timeout_timer (David Milburn) [695954]
- [scsi] isci: convert phy_startup_timer to sci_timer (David Milburn) [695954]
- [scsi] isci: convert scic_timeout_timer to sci_timer (David Milburn) [695954]
- [scsi] isci: convert power control timer to sci_timer (David Milburn) [695954]
- [scsi] isci: convert phy sata_timeout_timer to sci_timer (David Milburn) [695954]
- [scsi] isci: convert port config agent timer to sci_timer (David Milburn) [695954]
- [scsi] isci: replace isci_timer list with proper embedded timers (David Milburn) [695954]
- [scsi] isci: add some type safety to the state machine interface (David Milburn) [695954]
- [scsi] isci: unify rnc start{io|task} handlers (David Milburn) [695954]
- [scsi] isci: unify rnc suspend/resume handlers (David Milburn) [695954]
- [scsi] isci: unify rnc destruct handlers (David Milburn) [695954]
- [scsi] isci: unify rnc event handlers (David Milburn) [695954]
- [scsi] isci: unify port start_io and complete_io handlers (David Milburn) [695954]
- [scsi] isci: unify port link_up and link_down handlers (David Milburn) [695954]
- [scsi] isci: remove port frame and event handlers (David Milburn) [695954]
- [scsi] isci: unify port reset, add_phy, and remove_phy handlers (David Milburn) [695954]
- [scsi] isci: remove port destruct handler (David Milburn) [695954]
- [scsi] isci: unify port stop handlers (David Milburn) [695954]
- [scsi] isci: remove port start handler (David Milburn) [695954]
- [scsi] isci: merge port ready substates into primary state machine (David Milburn) [695954]
- [scsi] isci: c99 port state handlers (David Milburn) [695954]
- [scsi] isci: clarify phy to port lookups (David Milburn) [695954]
- [scsi] isci: unify phy consume_power handlers (David Milburn) [695954]
- [scsi] isci: unify phy event handlers (David Milburn) [695954]
- [scsi] isci: unify phy frame handlers (David Milburn) [695954]
- [scsi] isci: remove phy destruct handlers (David Milburn) [695954]
- [scsi] isci: unify phy reset handlers (David Milburn) [695954]
- [scsi] isci: unify phy stop handlers (David Milburn) [695954]
- [scsi] isci: unify phy start handlers (David Milburn) [695954]
- [scsi] isci: merge phy substates (David Milburn) [695954]
- [scsi] isci: remove the completion and event state handlers (David Milburn) [695954]
- [scsi] isci: remove request task context completion state handler (David Milburn) [695954]
- [scsi] isci: unify request frame handlers (David Milburn) [695954]
- [scsi] isci: unify request start handlers (David Milburn) [695954]
- [scsi] isci: unify request abort handlers (David Milburn) [695954]
- [scsi] isci: merge stp request substates into primary state machine (David Milburn) [695954]
- [scsi] isci: merge smp request substates into primary state machine (David Milburn) [695954]
- [scsi] isci: merge ssp task management substates into primary state machine (David Milburn) [695954]
- [scsi] isci: uplevel port infrastructure (David Milburn) [695954]
- [scsi] isci: uplevel phy infrastructure (David Milburn) [695954]
- [scsi] isci: uplevel request infrastructure (David Milburn) [695954]
- [scsi] isci: uplevel state machine (David Milburn) [695954]
- [scsi] isci: uplevel register hardware data structures and unsolicited frame handling (David Milburn) [695954]
- [scsi] isci: move core/controller to host (David Milburn) [695954]
- [scsi] isci: unify constants (David Milburn) [695954]
- [scsi] isci: unify request data structures (David Milburn) [695954]
- [scsi] isci: make command/response iu explicit request object members (David Milburn) [695954]
- [scsi] isci: move task context alignment from run-time to compile time (David Milburn) [695954]
- [scsi] isci: make sgl explicit/aligned request object member (David Milburn) [695954]
- [scsi] isci: move stp request info to scic_sds_request (David Milburn) [695954]
- [scsi] isci: unify port data structures (David Milburn) [695954]
- [scsi] isci: unify phy data structures (David Milburn) [695954]
- [scsi] isci: rnc state machine table c99 conversion (David Milburn) [695954]
- [scsi] isci: remove scic_sds_port_increment_request_count (David Milburn) [695954]
- [scsi] isci: kill scic_controller_get_port_handle function (David Milburn) [695954]
- [scsi] isci: Removing unnecessary functions in request.c (David Milburn) [695954]
- [scsi] isci: unify isci_host data structures (David Milburn) [695954]
- [scsi] isci: implement I_T_nexus_reset (David Milburn) [695954]
- [scsi] isci: fix ata locking (David Milburn) [695954]
- [scsi] isci: removing intel_*.h headers (David Milburn) [695954]
- [scsi] isci: Using Linux SSP frame header (David Milburn) [695954]
- [scsi] isci: Remove SCIC_SWAP_DWORD() (David Milburn) [695954]
- [scsi] isci: fixup SAS iaf protocols data structure (David Milburn) [695954]
- [scsi] isci: remove redundant copies of IAF (David Milburn) [695954]
- [scsi] isci: Converting smp_response to Linux native smp_resp (David Milburn) [695954]
- [scsi] isci: Fixup of smp request (David Milburn) [695954]
- [scsi] isci: Convert of sci_ssp_response_iu to ssp_response_iu (David Milburn) [695954]
- [scsi] isci: Fixup SSP command IU and task IU (David Milburn) [695954]
- [scsi] isci: renaming sas_capabilities to scic_phy_cap (David Milburn) [695954]
- [scsi] isci: Collapsing of phy_type data structure (David Milburn) [695954]
- [scsi] isci: Convert SAS identify address frame to Linux Native format (David Milburn) [695954]
- [scsi] isci: Convert ATA defines to Linux native defines (David Milburn) [695954]
- [scsi] isci: Convert SATA fis data structures to Linux native (David Milburn) [695954]
- [scsi] isci: remove compile-time silicon configuration (David Milburn) [695954]
- [scsi] isci: Removing unused define SCIC_SDS_4_ENABLED (David Milburn) [695954]
- [scsi] isci: kill scic_sds_remote_device.state_handlers (David Milburn) [695954]
- [scsi] isci: unify remote_device frame_handlers (David Milburn) [695954]
- [scsi] isci: unify remote_device event_handlers (David Milburn) [695954]
- [scsi] isci: kill remote_device resume_handler (David Milburn) [695954]
- [scsi] isci: unify remote_device suspend_handlers (David Milburn) [695954]
- [scsi] isci: kill remote_device complete_task_handler (David Milburn) [695954]
- [scsi] isci: unify remote_device start_task_handlers (David Milburn) [695954]
- [scsi] isci: kill remote_device continue_io_handler (David Milburn) [695954]
- [scsi] isci: unify remote_device complete_io_handlers (David Milburn) [695954]
- [scsi] isci: unify remote_device start_io_handlers (David Milburn) [695954]
- [scsi] isci: unify remote_device reset_complete_handlers (David Milburn) [695954]
- [scsi] isci: unify remote_device reset_handlers (David Milburn) [695954]
- [scsi] isci: unify remote_device destruct_handlers (David Milburn) [695954]
- [scsi] isci: kill remote_device fail_handler (David Milburn) [695954]
- [scsi] isci: unify remote_device stop_handlers (David Milburn) [695954]
- [scsi] isci: unify remote_device start_handlers (David Milburn) [695954]
- [scsi] isci: fix remote_device start_io regressions (David Milburn) [695954]
- [scsi] isci: kill scic_remote_device_get_connection_rate (David Milburn) [695954]
- [scsi] isci: merge remote_device substates into a single state machine (David Milburn) [695954]
- [scsi] isci: Removed sci_object.h from project (David Milburn) [695954]
- [scsi] isci: Removed sci_base_object from scic_sds_request (David Milburn) [695954]
- [scsi] isci: Removed sci_base_object from scic_sds_remote_node_context (David Milburn) [695954]
- [scsi] isci: Removed sci_base_object from scic_sds_remote_device (David Milburn) [695954]
- [scsi] isci: Removed sci_base_object from scic_sds_port (David Milburn) [695954]
- [scsi] isci: Removed sci_base_object from scic_sds_phy (David Milburn) [695954]
- [scsi] isci: Removed sci_base_object from scic_sds_controller (David Milburn) [695954]
- [scsi] isci: Removed struct sci_base_object from state machine (David Milburn) [695954]
- [scsi] isci: Implement SCU AFE recipe 10 (David Milburn) [695954]
- [scsi] isci: Remove excessive log noise with expander hot-unplug (David Milburn) [695954]
- [scsi] isci: allow fallback to option-rom if efi variable retrieval fails (David Milburn) [695954]
- [scsi] isci: removing non-working ATAPI code (David Milburn) [695954]
- [scsi] isci: remove scic_sds_remote_device_get_port_index (David Milburn) [695954]
- [scsi] isci: remove usage of sci_sas_address in scic_sds_remote_device (David Milburn) [695954]
- [scsi] isci: kill smp_discover_response (David Milburn) [695954]
- [scsi] isci: kill smp_discover_response_protocols in favor of domain_device.dev_type (David Milburn) [695954]
- [scsi] isci: cleanup remote device construction and comments (David Milburn) [695954]
- [scsi] isci: move remote_device handling out of the core (David Milburn) [695954]
- [scsi] isci: unify remote_device data structures (David Milburn) [695954]
- [scsi] isci: remove rnc->device back pointer (David Milburn) [695954]
- [scsi] isci: make a remote_node_context a proper member of a remote_device (David Milburn) [695954]
- [scsi] isci: rely on irq core for intx multiplexing, and silence screaming intx (David Milburn) [695954]
- [scsi] isci: replace this_* and this_* to variable names that are more meaningful and tell us what they actually are (David Milburn) [695954]
- [scsi] isci: audit usage of BUG_ON macro in isci driver (David Milburn) [695954]
- [scsi] isci: sparse warnings cleanup (David Milburn) [695954]
- [scsi] isci: replace sci_sas_link_rate with sas_linkrate (David Milburn) [695954]
- [scsi] isci: remove base_phy abstraction (David Milburn) [695954]
- [scsi] isci: remove base_port abstraction (David Milburn) [695954]
- [scsi] isci: remove base_remote_device abstraction (David Milburn) [695954]
- [scsi] isci: remove scic_controller state handlers (David Milburn) [695954]
- [scsi] isci: simplify dma coherent allocation (David Milburn) [695954]
- [scsi] isci: simplify request state handlers (David Milburn) [695954]
- [scsi] isci: kill dead data structurs in scic_io_request.h (David Milburn) [695954]
- [scsi] isci: remove base_request abstraction (David Milburn) [695954]
- [scsi] isci: remove base_controller abstraction (David Milburn) [695954]

* Tue Aug 09 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-184.el6]
- [s390x] qeth: add support for af_iucv HiperSockets transport (Hendrik Brueckner) [694262]
- [s390x] qeth: exploit asynchronous delivery of storage blocks (Hendrik Brueckner) [694262]
- [s390x] qeth: support forced signal adapter indications (Hendrik Brueckner) [694262]
- [s390x] qdio: support forced signal adapter indications (Hendrik Brueckner) [694262]
- [s390x] qdio: support asynchronous delivery of storage blocks (Hendrik Brueckner) [694262]
- [s390x] af_iucv: add HiperSockets transport (Hendrik Brueckner) [694262]
- [s390x] if_ether: add new Ethernet Protocol ID (Hendrik Brueckner) [694262]
- [s390x] af_iucv: cleanup - use iucv_sk(sk) early (Hendrik Brueckner) [694262]
- [s390x] af_iucv: use loadable iucv interface (Hendrik Brueckner) [694262]
- [s390x] iucv: kernel option for z/VM IUCV and HiperSockets transports (Hendrik Brueckner) [694262]
- [s390x] iucv: introduce loadable iucv interface (Hendrik Brueckner) [694262]
- [scsi] Taints the kernel for mpt2sas inlockless mode (Luming Yu) [717090]
- [scsi] mpt2sas: lockless mode (Tomas Henzl) [717090]
- [scsi] qla4xxx: Boot from SAN support for open-iscsi (Mike Christie) [634584]
- [scsi] qla4xxx: Remove reduandant code after open-iscsi integration (Mike Christie) [634584]
- [scsi] qla4xxx: support session management using iscsiadm (Mike Christie) [634584]
- [scsi] scsi_transport_iscsi: Add conn login, kernel to user, event to support offload session login (Mike Christie) [634584]
- [scsi] qla4xxx: add bsg support (Mike Christie) [634584]
- [scsi] iscsi class: add bsg support to iscsi class (Mike Christie) [634584]
- [block] bsg: add bsg heler library (Mike Christie) [634584]
- [scsi] qla4xxx: Add VLAN support (Mike Christie) [634584]
- [scsi] libiscsi: don't bugon when if user sets markers (Mike Christie) [634584]
- [scsi] iscsi class: expand vlan support (Mike Christie) [634584]
- [scsi] be2iscsi: remove host and session casts (Mike Christie) [634584]
- [scsi] iscsi class: sysfs group is_visible callout for iscsi host attrs (Mike Christie) [634584]
- [scsi] iscsi class: remove iface param mask (Mike Christie) [634584]
- [scsi] iscsi class: sysfs group is_visible callout for session attrs (Mike Christie) [634584]
- [scsi] iscsi cls: sysfs group is_visible callout for conn attrs (Mike Christie) [634584]
- [scsi] qla4xxx: added support to show multiple iface in sysfs (Mike Christie) [634584]
- [scsi] iscsi class: add iface representation (Mike Christie) [634584]
- [scsi] qla4xxx: Added new "struct ipaddress_config" (Mike Christie) [634584]
- [scsi] qla4xxx: add support for set_net_config (Mike Christie) [634584]
- [scsi] iscsi_transport: add support for net settings (Mike Christie) [634584]
- [scsi] iscsi: support qla4xxx boot and session mgmt (Mike Christie) [634584]
- [drm] nvc0/gr: remove MODULE_FIRMWARE() lines (Ben Skeggs) [727981]
- [ppc] kdump: CPUs assume the context of the oopsing CPU, remove extra longjmp (Steve Best) [727478]
- [virt] SVM: Implement Flush-By-Asid feature (Frank Arnold) [634275]
- [virt] SVM: Use svm_flush_tlb instead of force_new_asid (Frank Arnold) [634275]
- [virt] SVM: Remove flush_guest_tlb function (Frank Arnold) [634275]
- [x86] kvm: add new AMD SVM feature bits (Frank Arnold) [634275]
- [virt] SVM: Add clean-bit for LBR state (Frank Arnold) [634288]
- [virt] SVM: Add clean-bit for CR2 register (Frank Arnold) [634288]
- [virt] SVM: Add clean-bit for segments and CPL (Frank Arnold) [634288]
- [virt] SVM: Add clean-bit for GDT and IDT (Frank Arnold) [634288]
- [virt] SVM: Add clean-bit for DR6 and DR7 (Frank Arnold) [634288]
- [virt] SVM: Add clean-bit for control registers (Frank Arnold) [634288]
- [virt] SVM: Add clean-bit for NPT state (Frank Arnold) [634288]
- [virt] SVM: Add clean-bit for interrupt state (Frank Arnold) [634288]
- [virt] SVM: Add clean-bit for the ASID (Frank Arnold) [634288]
- [virt] SVM: Add clean-bit for IOPM_BASE and MSRPM_BASE (Frank Arnold) [634288]
- [virt] SVM: Add clean-bit for intercepts, tsc-offset and pause filter count (Frank Arnold) [634288]
- [virt] SVM: Add clean-bits infrastructure code (Frank Arnold) [634288]
- [virt] SVM: copy instruction bytes from VMCB (Frank Arnold) [634291]
- [virt] SVM: implement enhanced INVLPG intercept (Frank Arnold) [634291]
- [virt] SVM: enhance MOV DR intercept handler (Frank Arnold) [634291]
- [virt] SVM: enhance MOV CR intercept handler (Frank Arnold) [634291]
- [virt] SVM: add Decode Assist SVM feature bit name (Frank Arnold) [634291]
- [virt] cleanup emulate_instruction (Frank Arnold) [634291]
- [virt] x86: fix CR8 handling (Frank Arnold) [634291]
- [virt] SVM: implement NEXTRIPsave SVM feature (Frank Arnold) [634291]
- [scsi] IB/qib: Fix potential deadlock with link down interrupt (Chad Dupuis) [724021]
- [scsi] megaraid: update to v5.38 (Tomas Henzl) [705835]
- [scsi] arcmsr: driver update (Tomas Henzl) [697403]

* Sun Aug 07 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-183.el6]
- [pci] Only enable SRIOV on the bootstring pci=realloc (James Takahashi) [587729]
- [pci] update bridge resources to get more big ranges in PCI assign unssigned (James Takahashi) [587729]
- [pci] Clear bridge resource flags if requested size is 0 (James Takahashi) [587729]
- [pci] fix PCI bus allocation alignment handling (James Takahashi) [587729]
- [pci] pre-allocate additional resources to devices only after successful allocation of essential resources. (James Takahashi) [587729]
- [pci] introduce reset_resource() (James Takahashi) [587729]
- [pci] data structure agnostic free list function (James Takahashi) [587729]
- [pci] refactor io size calculation code (James Takahashi) [587729]
- [scsi] mpt2sas: WarpDrive Infinite command retries due to wrong scsi command entry in MPI message (Tomas Henzl) [703192]
- [scsi] mpt2sas: Adding support for customer specific branding (Tomas Henzl) [703192]
- [scsi] mpt2sas: Added DID_NO_CONNECT return when driver remove and avoid shutdown call (Tomas Henzl) [703192]
- [scsi] mpt2sas: fix broadcast AEN and task management issue (Tomas Henzl) [703192]
- [scsi] mpt2sas: Set max_sector count from module parameter (Tomas Henzl) [703192]
- [scsi] mpt2sas MPI next revision header update (Tomas Henzl) [703192]
- [scsi] mpt2sas: Fixed Big Indian Issues on 32 bit PPC (Tomas Henzl) [703192]
- [scsi] mpt2sas: Fix missing reference tag seed with Type 2 devices (Tomas Henzl) [703192]
- [scsi] mpt2sas : WarpDrive New product SSS6200 support added (Tomas Henzl) [703192]
- [scsi] mpt2sas: do not check serial_number in the abort handler (Tomas Henzl) [703192]
- [scsi] mpt2sas: remove flush_scheduled_work() usages (Tomas Henzl) [703192]
- [scsi] mptfusion: Bump version 3.4.19 (Tomas Henzl) [703194]
- [scsi] mptfusion: Adding inline data padding support for TAPE drive. (Tomas Henzl) [703194]
- [scsi] mptfusion: Remove debug print from mptscsih_qcmd() (Tomas Henzl) [703194]
- [scsi] mptfusion: do not check serial_number in the abort handler (Tomas Henzl) [703194]
- [fs] dio: don't zero out the pages array inside struct dio (Jeff Moyer) [725444]
- [scsi] bnx2fc: set lockless to 1 in scsi_host_template (Mike Christie) [696773]
- [scsi] bnx2fc: Update copyright and bump version to 1.0.4 (Mike Christie) [696773]
- [scsi] bnx2fc: Tx BDs cache in write tasks (Mike Christie) [696773]
- [scsi] bnx2fc: Do not arm CQ when there are no CQEs (Mike Christie) [696773]
- [scsi] bnx2fc: hold tgt lock when calling cmd_release (Mike Christie) [696773]
- [scsi] bnx2fc: Enable support for sequence level error recovery (Mike Christie) [696773]
- [scsi] bnx2fc: HSI changes for tape (Mike Christie) [696773]
- [scsi] bnx2fc: Handle REC_TOV error code from firmware (Mike Christie) [696773]
- [scsi] bnx2fc: REC/SRR link service request and response handling (Mike Christie) [696773]
- [scsi] bnx2fc: Support 'sequence cleanup' task (Mike Christie) [696773]
- [scsi] bnx2fc: Enable REC & CONF support for the session (Mike Christie) [696773]
- [scsi] bnx2fc: Introduce interface structure for each vlan interface (Mike Christie) [696773]
- [scsi] bnx2fc: Replace printks with KERN_ALERT to KERN_ERR/KERN_INFO (Mike Christie) [696773]
- [scsi] bnx2fc: call ethtool's get/set_settings callbacks with cleaned data (Mike Christie) [696773]
- [netdrv] firmware: add bnx2x FW 7.0.20.0 (Michal Schmidt)
- [netdrv] bnx2x: update driver to v1.70 (Michal Schmidt) [695631 695847 695857 698285 701288]
- [fs] jbd2: Improve scalability by not taking j_state_lock in jbd2_journal_stop() (Larry Woodman) [721044]
- [net] lo: Do not allow VLAN on loopback (Jiri Pirko) [703709]
- [fs] ext4: Rewrite ext4_page_mkwrite() to use generic helpers (Eric Sandeen) [692167]
- [fs] vfs: Block mmapped writes while the fs is frozen (Eric Sandeen) [692167]
- [fs] vfs: Create __block_page_mkwrite() helper passing error values back (Eric Sandeen) [692167]
- [fs] cifs: fix compiler warning in CIFSSMBQAllEAs (Jeff Layton) [725370]
- [fs] cifs: fix name parsing in CIFSSMBQAllEAs (Jeff Layton) [725370]

* Sat Aug 06 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-182.el6]
- [virt] KVM: Enable ERMS feature support for KVM (Don Dugger) [721135]
- [virt] KVM: Expose RDWRGSFS bit to KVM guests (Don Dugger) [721205]
- [virt] KVM: Add RDWRGSFS support when setting CR4 (Don Dugger) [721205]
- [virt] KVM: Remove RDWRGSFS bit from CR4_RESERVED_BITS (Don Dugger) [721205]
- [virt] KVM: MMU: Adjust shadow paging to work when SMEP=1 and CR0.WP=0 (Don Dugger) [703053]
- [virt] KVM: Add instruction fetch checking when walking guest page table (Don Dugger) [703053]
- [virt] KVM: Mask function7 ebx against host capability word9 (Don Dugger) [703053]
- [virt] KVM: Add SMEP support when setting CR4 (Don Dugger) [703053]
- [virt] KVM: Remove SMEP bit from CR4_RESERVED_BITS (Don Dugger) [703053]
- [virt] KVM: Mask KVM_GET_SUPPORTED_CPUID data with Linux cpuid info (Don Dugger) [703053]
- [x86] enable supervision mode execution protection (Luming Yu) [696152]
- [x86] cpufeature: Fix cpuid leaf 7 feature detection (Prarit Bhargava) [696457]
- [x86] x86, mem, intel: Initialize Enhanced REP MOVSB/STOSB (Prarit Bhargava) [696457]
- [x86] x86, alternative, doc: Add comment for applying alternatives order (Prarit Bhargava) [696457]
- [x86] alternative: Add altinstruction_entry macro (Prarit Bhargava) [696457]
- [x86] x86, mem: clear_page_64.S: Support clear_page() with enhanced REP MOVSB/STOSB (Prarit Bhargava) [696457]
- [x86] x86, mem: copy_user_64.S: Support copy_to/from_user by enhanced REP MOVSB/STOSB (Prarit Bhargava) [696457]
- [x86] mem: memcpy_64.S: Optimize memcpy by enhanced REP MOVSB/STOSB (Prarit Bhargava) [696457]
- [x86] mem: memset_64.S: Optimize memset by enhanced REP MOVSB/STOSB (Prarit Bhargava) [696457]
- [x86] mem: memmove_64.S: Optimize memmove by enhanced REP MOVSB/STOSB (Prarit Bhargava) [696457]
- [x86] x86, cpufeature: Add CPU feature bit for enhanced REP MOVSB/STOSB (Prarit Bhargava) [696457]
- [x86] Fix spelling error in the memcpy() source code comment (Prarit Bhargava) [696457]
- [x86] x86-64, mem: Convert memmove() to assembly file and fix return value bug (Prarit Bhargava) [696457]
- [x86] x86, mem: Optimize memmove for small size and unaligned cases (Prarit Bhargava) [696457]
- [x86] x86, mem: Optimize memcpy by avoiding memory false dependence (Prarit Bhargava) [696457]
- [x86] x86, mem: Don't implement forward memmove() as memcpy() (Prarit Bhargava) [696457]
- [x86] x86, alternatives: Fix one more open-coded 8-bit alternative number (Prarit Bhargava) [696457]
- [x86] cpu: Support the features flags in new CPUID leaf 7 (Prarit Bhargava) [696457]
- [x86] x86, alternatives: Use 16-bit numbers for cpufeature index (Prarit Bhargava) [696457]
- [x86] x86-32: Rework cache flush denied handler (Prarit Bhargava) [696457]
- [x86] x86-64: Modify memcpy()/memset() alternatives mechanism (Prarit Bhargava) [696457]
- [x86] x86-64: Modify copy_user_generic() alternatives mechanism (Prarit Bhargava) [696457]
- [x86] x86/alternatives: Check replacementlen <= instrlen at build time (Prarit Bhargava) [696457]
- [x86] x86-64: __copy_from_user_inatomic() adjustments (Prarit Bhargava) [696457]
- [mm] oom killer output should display UID (Frantisek Hrbata) [700499]
- [mm] avoid wrapping vm_pgoff in mremap() and stack expansion (Jerome Marchand) [716541] {CVE-2011-2496}
- [pci] MSI: Restore read_msi_msg_desc(); add get_cached_msi_msg_desc() (Don Zickus) [696511]
- [pci] MSI: Remove unsafe and unnecessary hardware access (Don Zickus) [696511]
- [mm] Fix node_start/end_pfn() definition for mm/page_cgroup.c (Johannes Weiner) [703499]
- [mm] memcg: fix init_page_cgroup nid with sparsemem (Johannes Weiner) [703499]
- [mm] page_cgroup: allocate memory cgroup structures on local nodes (Johannes Weiner) [703499]
- [mm] add alloc_pages_exact_nid() (Johannes Weiner) [703499]
- [mm] page_cgroup: reduce allocation overhead for page_cgroup array (Johannes Weiner) [703499]
- [scsi] ipr: fix possible false positive detection of stuck interrupt (Steve Best) [693817]
- [scsi] ipr: Driver version 2.5.2 (Steve Best) [693817]
- [scsi] ipr: increase the dump size for 64 bit adapters (Steve Best) [693817]
- [mm] mem-hotplug: update pcp->stat_threshold when memory hotplug occur (Johannes Weiner) [625264]
- [mm] vmstat: use a single setter function and callback for adjusting percpu thresholds (Johannes Weiner) [625264]
- [mm] page allocator: adjust the per-cpu counter threshold when memory is low (Johannes Weiner) [625264]
- [mm] page allocator: calculate a better estimate of NR_FREE_PAGES when memory is low and kswapd is awake (Johannes Weiner) [625264]
- [mm] vmstat: update zone stat threshold when onlining a cpu (Johannes Weiner) [625264]
- [scsi] qla4xxx: Update driver version to 5.02.00-k7 (Mike Christie) [694098]
- [scsi] qla4xxx: Added vendor specific sysfs attributes (Mike Christie) [694098]
- [scsi] qla4xxx: do not take host lock in queuecommand (Mike Christie) [694098]
- [scsi] qla4xxx: Remove AF_DPC_SCHEDULED flag from ha. (Mike Christie) [694098]
- [scsi] qla4xxx: Don't check FW alive if ISP82XX reset is in progress (Mike Christie) [694098]
- [scsi] qla4xxx: Don't process mbx interrupt unconditionally (Mike Christie) [694098]
- [scsi] qla4xxx: Complete the cmd if sense_len is zero (Mike Christie) [694098]
- [scsi] qla4xxx: Dump HW/FW reg to figure out what caused FW to be hung for ISP82XX (Mike Christie) [694098]
- [scsi] qla4xxx: Updated the reset sequence for ISP82xx (Mike Christie) [694098]
- [scsi] qla4xxx: update function qla4xxx_isr_decode_mailbox() (Mike Christie) [694098]
- [scsi] treewide: fix a few typos in comments (Mike Christie) [694098]
- [scsi] remove cmd->serial_number litter (Mike Christie) [694098]
- [scsi] Fix common misspellings (Mike Christie) [694098]
- [scsi] qla4xxx: Use polling mode for disable interrupt mailbox completion (Mike Christie) [694098]
- [scsi] qla4xxx: Update driver version to 5.02.00-k6 (Mike Christie) [694098]
- [scsi] qla4xxx: masking required bits of add_fw_options during initialization (Mike Christie) [694098]
- [scsi] qla4xxx: added new function qla4xxx_relogin_all_devices (Mike Christie) [694098]
- [scsi] qla4xxx: add support for ql4xsess_recovery_tmo cmd line param (Mike Christie) [694098]
- [scsi] qla4xxx: Add support for ql4xmaxqdepth command line parameter (Mike Christie) [694098]
- [scsi] qla4xxx: cleanup function qla4xxx_process_ddb_changed (Mike Christie) [694098]
- [scsi] qla4xxx: Prevent other port reinitialization during remove_adapter (Mike Christie) [694098]
- [scsi] qla4xxx: remove unused ddb flag DF_NO_RELOGIN (Mike Christie) [694098]
- [scsi] qla4xxx: cleanup DDB relogin logic during initialization (Mike Christie) [694098]
- [scsi] qla4xxx: Do not retry ISP82XX initialization if H/W state is failed (Mike Christie) [694098]
- [scsi] qla4xxx: Do not send mbox command if FW is in failed state (Mike Christie) [694098]
- [scsi] qla4xxx: cleanup qla4xxx_initialize_ddb_list() (Mike Christie) [694098]
- [scsi] drivers:scsi Change printk typo initate -> initiate (Mike Christie) [694098]
- [scsi] bnx2i: Updated version (Mike Christie) [696760]
- [scsi] bnx2i: Modified to skip CNIC registration if iSCSI is not supported (Mike Christie) [696760]
- [scsi] bnx2i: Optimized the iSCSI offload performance (Mike Christie) [696760]
- [scsi] bnx2i: Updated the connection shutdown/cleanup timeout (Mike Christie) [696760]
- [scsi] bnx2i: Fixed packet error created when the sq_size is set to 16 (Mike Christie) [696760]
- [scsi] Bumping the driver version (Mike Christie) [647268 698288]
- [scsi] Fix for proper setting of FW (Mike Christie) [647268 698288]
- [scsi] Set a timeout to FW (Mike Christie) [647268 698288]
- [scsi] Modifying Maintainer's emailid (Mike Christie) [647268 698288]
- [scsi] change in copyright notice (Mike Christie) [647268 698288]
- [scsi] remove extra semicolons (Mike Christie) [647268 698288]
- [scsi] Fix common misspellings (Mike Christie) [647268 698288]
- [scsi] libiscsi_tcp: fix LLD data allocation (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi_tcp: fix locking around iscsi sk user data (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi_ibft, be2iscsi, iscsi_boot: fix boot kobj data lifetime management (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi: Use struct scsi_lun in iscsi structs instead of u8[8] (Mike Christie) [647268 694098 696760 698288]
- [scsi] libiscsi_tcp: use kmap in xmit path (Mike Christie) [647268 694098 696760 698288]
- [scsi] Fix common misspellings (Mike Christie) [647268 694098 696760 698288]
- [scsi] scsi_transport_iscsi: make priv_sess file writeable only by root (Mike Christie) [647268 694098 696760 698288]
- [scsi] be2iscsi: fix null ptr ref in conn get param (Mike Christie) [647268 694098 696760 698288]
- [scsi] iser: export addr and port (Mike Christie) [647268 694098 696760 698288]
- [scsi] bnx2i: fix null ptr ref in conn get param (Mike Christie) [647268 694098 696760 698288]
- [scsi] cxgbi: convert to use iscsi_conn_get_addr_param (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi class: add callout to get iscsi_endpoint values (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi_tcp: use iscsi_conn_get_addr_param libiscsi function (Mike Christie) [647268 694098 696760 698288]
- [scsi] libiscsi: add helper to convert addr to string (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi: fix iscsi_endpoint leak (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi: add module alias (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi transport: fix kernel-doc notation (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi_transport: wait on session in error handler path (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi_transport: Modidify recovery_tmo from sysfs (Mike Christie) [647268 694098 696760 698288]
- [scsi] iscsi_transport: added new iscsi_param to display target alias in sysfs (Mike Christie) [647268 694098 696760 698288]
- [scsi] libiscsi: use bh locking instead of irq with session lock (Mike Christie) [647268 694098 696760 698288]
- [scsi] libiscsi: do not take host lock in queuecommand (Mike Christie) [647268 694098 696760 698288]

* Thu Aug 04 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-181.el6]
- [net] Fix prior ABI breakage in net_device (Neil Horman) [725716]
- [net] fix xps patches kabi breakage (Jiri Pirko) [668256]
- [net] Adjust TX queue kobjects if number of queues changes during unregister (Jiri Pirko) [668256]
- [net] xps: NUMA allocations for per cpu data (Jiri Pirko) [668256]
- [net] xps: Transmit Packet Steering (Jiri Pirko) [668256]
- [net] xps: Improvements in TX queue selection (Jiri Pirko) [668256]
- [net] check queue_index from sock is valid for device (Jiri Pirko) [668256]
- [net] fix tx queue selection for bridged devices implementing select_queue (Jiri Pirko) [668256]
- [net] check the return value of ndo_select_queue() (Jiri Pirko) [668256]
- [net] fix problem in reading sock TX queue (Jiri Pirko) [668256]
- [net] dev_pick_tx() fix (Jiri Pirko) [668256]
- [net] Use sk_tx_queue_mapping for connected sockets (Jiri Pirko) [668256]
- [net] Introduce sk_tx_queue_mapping (Jiri Pirko) [668256]
- [net] change set_real_num_tx_queues to fail on invalid number of queues (Jiri Pirko) [668256]
- [net] sock: do not change prot->obj_size (Jiri Pirko) [668256 725711]
- [netdrv] be2net: bump version (Ivan Vecera) [702739]
- [netdrv] be2net: request native mode each time the card is reset (Ivan Vecera) [702739]
- [netdrv] be2net: account for skb allocation failures (Ivan Vecera) [702739]
- [netdrv] benet: Add missing comma between constant string array (Ivan Vecera) [702739]
- [netdrv] be2net: create/destroy rx-queues on interface open/close (Ivan Vecera) [702739]
- [netdrv] be2net: fix initialization of vlan_prio_bmap (Ivan Vecera) [702739]
- [netdrv] be2net: get rid of multi_rxq module param (Ivan Vecera) [702739]
- [netdrv] be2net: fix netdev_stats_update (Ivan Vecera) [702739]
- [netdrv] be2net: support multiple TX queues (Ivan Vecera) [702739]
- [netdrv] be2net: Enable NETIF_F_TSO6 for VLAN traffic for BE (Ivan Vecera) [702739]
- [netdrv] be2net: Fix Rx pause counter for lancer (Ivan Vecera) [702739]
- [netdrv] be2net: Fallback to the older opcode if MCC_CREATE_EXT opcode is not supported on the card (Ivan Vecera) [702739]
- [netdrv] be2net: hash key for rss-config cmd not set (Ivan Vecera) [702739]
- [netdrv] be2net: Kill set but unused variable 'req' in lancer_fw_download() (Ivan Vecera) [702739]
- [netdrv] be2net: Enable SR-IOV for Lancer (Ivan Vecera) [702739]
- [netdrv] be2net: FW download for Lancer (Ivan Vecera) [702739]
- [netdrv] be2net: Stats for Lancer (Ivan Vecera) [702739]
- [netdrv] be2net: Support for version 1 of stats for BE3 (Ivan Vecera) [702739]
- [netdrv] be2net: fix mbox polling for signal reception (Ivan Vecera) [702739]
- [netdrv] be2net: handle signal reception while waiting for POST (Ivan Vecera) [702739]
- [netdrv] be2net: Fix to prevent flooding of TX queue (Ivan Vecera) [702739]
- [netdrv] be2net: Use NTWK_RX_FILTER command for promiscous mode (Ivan Vecera) [702739]
- [netdrv] be2net: In case of UE, do not dump registers for Lancer (Ivan Vecera) [702739]
- [netdrv] be2net: Disable coalesce water mark mode of CQ for Lancer (Ivan Vecera) [702739]
- [netdrv] be2net: Handle error completion in Lancer (Ivan Vecera) [702739]
- [netdrv] be2net: Fixed bugs related to PVID. (Ivan Vecera) [702739]
- [netdrv] be2net: ethtool: cosmetic: Use ethtool ethtool_cmd_speed API (Ivan Vecera) [702739]
- [netdrv] be2net: Fixed a bug in be_cmd_get_regs(). (Ivan Vecera) [702739]
- [netdrv] be2net: increment work_counter in be_worker (Ivan Vecera) [702739]
- [netdrv] be2net: add code to display default value of tx rate for VFs (Ivan Vecera) [702739]
- [netdrv] be2net: pass domain id to be_cmd_link_status_query (Ivan Vecera) [702739]
- [netdrv] be2net: fix be_mcc_compl_process to identify eth_get_stat command (Ivan Vecera) [702739]
- [netdrv] be2net: Add code to display nic speeds other than 1Gbps/10Gbps (Ivan Vecera) [702739]
- [netdrv] be2net: allow register dump only for PFs (Ivan Vecera) [702739]
- [netdrv] be2net: Fix unused-but-set variables. (Ivan Vecera) [702739]
- [netdrv] benet: convert to hw_features (Ivan Vecera) [702739]
- [netdrv] be2net: call FLR after setup wol in be_shutdown (Ivan Vecera) [702739]
- [netdrv] be2net: dynamically allocate adapter->vf_cfg (Ivan Vecera) [702739]
- [netdrv] be2net: fix to get max VFs supported from adapter (Ivan Vecera) [702739]
- [netdrv] be2net: use common method to check for sriov function type (Ivan Vecera) [702739]
- [netdrv] be2net: add rxhash support (Ivan Vecera) [702739]
- [netdrv] be2net: Fix suspend/resume operation (Ivan Vecera) [702739]
- [netdrv] be2net: Rename some struct members for clarity (Ivan Vecera) [702739]
- [netdrv] be2net: Fix a potential crash during shutdown. (Ivan Vecera) [702739]
- [netdrv] be2net: Fix common misspellings (Ivan Vecera) [702739]
- [netdrv] be2net: remove one useless line (Ivan Vecera) [702739]
- [netdrv] be2net: cancel be_worker in be_shutdown() even when i/f is down (Ivan Vecera) [702739]
- [netdrv] be2net: remove redundant code in be_worker() (Ivan Vecera) [702739]
- [netdrv] be2net: parse vid and vtm fields of rx-compl only if vlanf bit is set (Ivan Vecera) [702739]
- [netdrv] be2net: refactor code that decides adapter->num_rx_queues (Ivan Vecera) [702739]
- [netdrv] be2net: Support for FAT dump retrieval using ethtool --register-dump option (Ivan Vecera) [702739]
- [netdrv] be2net: Bump up the version number (Ivan Vecera) [702739]
- [netdrv] be2net: Copyright notice change. Update to Emulex instead of ServerEngines (Ivan Vecera) [702739]
- [netdrv] be2net: Fix UDP packet detected status in RX compl (Ivan Vecera) [702739]
- [netdrv] be2net: Add multicast filter capability for Lancer (Ivan Vecera) [702739]
- [netdrv] be2net: Disarm CQ and EQ to disable interrupt in Lancer (Ivan Vecera) [702739]
- [netdrv] be2net: Remove TX Queue stop in close (Ivan Vecera) [702739]
- [netdrv] be2net: Add error recovery during load for Lancer (Ivan Vecera) [702739]
- [netdrv] benet: use GFP_KERNEL allocations when possible (Ivan Vecera) [702739]
- [netdrv] be2net: use hba_port_num instead of port_num (Ivan Vecera) [702739]
- [netdrv] be2net: add code to display temperature of ASIC (Ivan Vecera) [702739]
- [netdrv] be2net: variable name change (Ivan Vecera) [702739]
- [netdrv] be2net: fixes in ethtool selftest (Ivan Vecera) [702739]
- [netdrv] be2net: add new counters to display via ethtool stats (Ivan Vecera) [702739]
- [netdrv] be2net: restrict WOL to PFs only. (Ivan Vecera) [702739]
- [netdrv] be2net: detect a UE even when a interface is down. (Ivan Vecera) [702739]
- [netdrv] be2net: gracefully handle situations when UE is detected (Ivan Vecera) [702739]
- [netdrv] be2net: fix be_suspend/resume/shutdown (Ivan Vecera) [702739]
- [netdrv] be2net: Fix broken priority setting when vlan tagging is enabled. (Ivan Vecera) [702739]
- [netdrv] be2net: For the VF MAC, use the OUI from current MAC address (Ivan Vecera) [702739]
- [netdrv] be2net: Cleanup the VF interface handles (Ivan Vecera) [702739]
- [netdrv] be2net: call be_vf_eth_addr_config() after register_netdev (Ivan Vecera) [702739]
- [netdrv] be2net: endianness fix in be_cmd_set_qos(). (Ivan Vecera) [702739]
- [netdrv] be2net: use device model DMA API (Ivan Vecera) [702739]
- [netdrv] be2net: remove netif_stop_queue being called before register_netdev. (Ivan Vecera) [702739]
- [netdrv] be2net: fix a crash seen during insmod/rmmod test (Ivan Vecera) [702739]
- [fs] NFS readdirs losing their cookies (Steve Dickson) [722257]
- [fs] jbd: Add fixed tracepoints (Lukas Czerner) [696332]
- [fs] ext3: Add fixed tracepoints (Lukas Czerner) [696332]
- [fs] ext4: remove alloc_semp (Lukas Czerner) [527222]
- [fs] ext4: teach ext4_mb_init_cache() to skip uptodate buddy caches (Lukas Czerner) [527222]
- [fs] ext4: synchronize ext4_mb_init_group() with buddy page lock (Lukas Czerner) [527222]
- [fs] ext4: implement ext4_add_groupblocks() by freeing blocks (Lukas Czerner) [527222]
- [fs] ext4: move ext4_add_groupblocks() to mballoc.c (Lukas Czerner) [527222]
- [fs] ext4: move ext4_mb_{get, put}_buddy_cache_lock and make them static (Lukas Czerner) [527222]
- [net] bridge: Only flood traffic for unregistered groups to routers (Herbert Xu) [711592]
- [net] bridge: restore the right netpoll dev (Amerigo Wang) [680759]
- [net] bridge: call NETDEV_JOIN notifiers when add a slave (Amerigo Wang) [680759]
- [net] netpoll: prevent setup netpoll on a slave device (Amerigo Wang) [680759]
- [net] netpoll: fix use after free (Amerigo Wang) [680759]
- [net] netpoll: fix a softirq warning (Amerigo Wang) [680759]
- [net] Revert "[net] Revert "[net] bridge: make bridge support netpoll"" (Amerigo Wang) [680759]

* Thu Aug 04 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-180.el6]
- [sched] dont reference cfs_rq->tg outside CONFIG_CFS_BANDWIDTH (Larry Woodman) [632509]
- [sched] update config options for CFS bandwidth (Larry Woodman) [632509]
- [sched] kabi specific fixes (Larry Woodman) [632509]
- [sched] replace raw calls (Larry Woodman) [632509]
- [sched] Move inc_nr_running and dec_nr_running (Larry Woodman) [632509]
- [sched] Add CFS Bandwidth Documentation (Larry Woodman) [632509]
- [sched] return majority of remaining quota to global bandwidth pool (Larry Woodman) [632509]
- [sched] introduce statistics exports for the cpu sub-system (Larry Woodman) [632509]
- [sched] enable throttling (Larry Woodman) [632509]
- [sched] Throttled tasks are invisisble to cpu-offline (Larry Woodman) [632509]
- [sched] ensure that throttled entities arent falsely nominated as buddies (Larry Woodman) [632509]
- [sched] make throttled entities invisible (Larry Woodman) [632509]
- [sched] Extend walk_tg_tree to accept a positional argument (Larry Woodman) [632509]
- [sched] refresh the global bandwidth pool (Larry Woodman) [632509]
- [sched] add support to throttle group entities (Larry Woodman) [632509]
- [sched] ensure that per-cpu state is synchronized (Larry Woodman) [632509]
- [sched] adds a per-task_group timer (Larry Woodman) [632509]
- [sched] Account bandwidth usage (Larry Woodman) [632509]
- [sched] Add constraints validation for CFS bandwidth hierarchies (Larry Woodman) [632509]
- [sched] introduce the notion of CFS bandwidth (Larry Woodman) [632509]
- [sched] Introduce hierarchical task accounting (Larry Woodman) [632509]
- [kernel] sched: dont update shares twice on on_rq parent (Larry Woodman) [632509]
- [fs] ext4: backport fixes for lazy inode table initialization (Lukas Czerner) [696559]
- [fs] ext4: use sb_issue_zeroout in ext4_ext_zeroout (Lukas Czerner) [696559]
- [fs] ext4: use sb_issue_zeroout in setup_new_group_blocks (Lukas Czerner) [696559]
- [fs] ext4: add batched_discard into ext4 feature list (Lukas Czerner) [696559]
- [fs] ext4: add interface to advertise ext4 features in sysfs (Lukas Czerner) [696559]
- [fs] ext4: add support for lazy inode table initialization (Lukas Czerner) [696559]
- [block] Add helper function for blkdev_issue_zeroout sb_issue_discard (Lukas Czerner) [696559]
- [block] blkdev: add blkdev_issue_zeroout helper function (Lukas Czerner) [696559]
- [s390x] ap: Fix ap_queue_status structure declaration (Hendrik Brueckner) [724904]
- [kernel] first time swap use results in heavy swapping (Hendrik Brueckner) [722461]
- [hwmon] lm78: Make ISA interface depend on CONFIG_ISA (Dean Nelson) [717215]
- [hwmon] lm78: Avoid forward declarations (Dean Nelson) [717215]
- [hwmon] KConfig: avoid building drivers for powerpc that read/write ISA addresses (Dean Nelson) [717215]
- [security] SELinux: do not compute transition labels on mountpoint labeled filesystems (Eric Paris) [658291]
- [security] SELinux: implement the new sb_remount LSM hook (Eric Paris) [656952]
- [security] LSM: Pass -o remount options to the LSM (Eric Paris) [656952]
- [block] Support Ricoh memstick driver with new KFIFO api (Shyam Iyer) [637234]
- [block] add RICOH memstick Config option (Shyam Iyer) [637234]
- [block] memstick: make enable_dma less generic in r592 (Shyam Iyer) [637234]
- [block] memstick: add driver for Ricoh R5C592 card reader (Shyam Iyer) [637234]

* Thu Aug 04 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-179.el6]
- [usb] remove remaining usages of hcd->state from usbcore and fix regression (Don Zickus) [696600 696602 696603]
- [usb] UHCI: remove uses of hcd->state (Don Zickus) [696600 696602 696603]
- [usb] Initialize hcd->state roothubs. (Don Zickus) [696600 696602 696603]
- [usb] xhci - fix interval calculation for FS isoc endpoints (Don Zickus) [696600 696602 696603]
- [usb] xhci: Disable MSI for some Fresco Logic hosts. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Do not issue device reset when device is not setup (Don Zickus) [696600 696602 696603]
- [usb] xhci: Add defines for hardcoded slot states (Don Zickus) [696600 696602 696603]
- [usb] xhci: Bigendian fix for xhci_check_bandwidth() (Don Zickus) [696600 696602 696603]
- [usb] xhci: Bigendian fix for skip_isoc_td() (Don Zickus) [696600 696602 696603]
- [usb] Intel xhci: Limit number of active endpoints to 64. (Don Zickus) [696600 696602 696603]
- [usb] Intel xhci: Ignore spurious successful event. (Don Zickus) [696600 696602 696603]
- [usb] Intel xhci: Add PCI id for Panther Point xHCI host. (Don Zickus) [696600 696602 696603]
- [usb] Intel xhci: Support EHCI/xHCI port switching. (Don Zickus) [696600 696602 696603]
- [usb] xhci: STFU: Be quieter during URB submission and completion. (Don Zickus) [696600 696602 696603]
- [usb] xhci: STFU: Don't print event ring dequeue pointer. (Don Zickus) [696600 696602 696603]
- [usb] xhci: STFU: Remove function tracing. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Don't submit commands when the host is dead. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Clear stopped_td when Stop Endpoint command completes. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fix memory leak bug when dropping endpoints (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fix memory leak in ring cache deallocation. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fix full speed bInterval encoding. (Don Zickus) [696600 696602 696603]
- [usb] xhci: move the common code to a function to get max ports and port array (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fix bug in control transfer cancellation. (Don Zickus) [696600 696602 696603]
- [usb] xHCI 1.0: Max Exit Latency Too Large Error (Don Zickus) [695615 696600 696602 696603]
- [usb] xHCI 1.0: TT_THINK_TIME set (Don Zickus) [695615 696600 696602 696603]
- [usb] xHCI 1.0: Block Interrupts for Isoch transfer (Don Zickus) [695615 696600 696602 696603]
- [usb] xHCI 1.0: Isoch endpoint CErr field set (Don Zickus) [695615 696600 696602 696603]
- [usb] xHCI 1.0: Control endpoint average TRB length field set (Don Zickus) [695615 696600 696602 696603]
- [usb] xHCI 1.0: Setup Stage TRB Transfer Type flag (Don Zickus) [695615 696600 696602 696603]
- [usb] xHCI: Clear PLC in xhci_bus_resume() (Don Zickus) [696600 696602 696603]
- [usb] xhci 1.0: Set transfer burst last packet count field. (Don Zickus) [695615 696600 696602 696603]
- [usb] xhci 1.0: Set transfer burst count field. (Don Zickus) [695615 696600 696602 696603]
- [usb] xhci 1.0: Update TD size field format. (Don Zickus) [695615 696600 696602 696603]
- [usb] xhci 1.0: Only interrupt on short packet for IN EPs. (Don Zickus) [695615 696600 696602 696603]
- [usb] xhci: Remove sparse warning about cmd_status. (Don Zickus) [696600 696602 696603]
- [usb] xHCI: report USB3.0 portstatus comply with USB3.0 specification (Don Zickus) [696600 696602 696603]
- [usb] xHCI: Set link state support (Don Zickus) [696600 696602 696603]
- [usb] xHCI: Clear link state change support (Don Zickus) [696600 696602 696603]
- [usb] xHCI: warm reset support (Don Zickus) [696600 696602 696603]
- [usb] xhci-hcd: Include <linux/slab.h> in xhci-pci.c (Don Zickus) [696600 696602 696603]
- [usb] xHCI: Implement AMD PLL quirk (Don Zickus) [696600 696602 696603]
- [usb] xhci: Tell USB core both roothubs lost power. (Don Zickus) [696600 696602 696603]
- [usb] xhci - also free streams when resetting devices (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fix NULL pointer deref in handle_port_status() (Don Zickus) [696600 696602 696603]
- [usb] xhci - fix math in xhci_get_endpoint_interval() (Don Zickus) [696600 696602 696603]
- [usb] xhci: simplify logic of skipping missed isoc TDs (Don Zickus) [696600 696602 696603]
- [usb] xhci - remove excessive 'inline' markings (Don Zickus) [696600 696602 696603]
- [usb] xhci: unsigned char never equals -1 (Don Zickus) [696600 696602 696603]
- [usb] xhci - fix unsafe macro definitions (Don Zickus) [696600 696602 696603]
- [usb] xhci: Clean up cycle bit math used during stalls. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fix cycle bit calculation during stall handling. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Update internal dequeue pointers after stalls. (Don Zickus) [696600 696602 696603]
- [usb] Remove bogus USB_PORT_STAT_SUPER_SPEED symbol. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Return canceled URBs immediately when host is halted. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fixes for suspend/resume of shared HCDs. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fix re-init on power loss after resume. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Make roothub functions deal with device removal. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Limit roothub ports to 15 USB3 & 31 USB2 ports. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Return a USB 3.0 hub descriptor for USB3 roothub (Don Zickus) [696600 696602 696603]
- [usb] xhci: Register second xHCI roothub. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Change xhci_find_slot_id_by_port() API. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Refactor bus suspend state into a struct. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Index with a port array instead of PORTSC addresses. (Don Zickus) [696600 696602 696603]
- [usb] Set usb_hcd->state and flags for shared roothubs. (Don Zickus) [696600 696602 696603]
- [usb] Make core allocate resources per PCI-device. (Don Zickus) [696600 696602 696603]
- [usb] Store bus type in usb_hcd, not in driver flags. (Don Zickus) [696600 696602 696603]
- [usb] Change usb_hcd->bandwidth_mutex to a pointer. (Don Zickus) [696600 696602 696603]
- [usb] Refactor irq enabling out of usb_add_hcd() (Don Zickus) [696600 696602 696603]
- [usb] xhci: Change hcd_priv into a pointer. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Always use usb_hcd in URB instead of converting xhci_hcd. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Modify check for TT info. (Don Zickus) [696600 696602 696603]
- [usb] USB 3.0 Hub Changes (Don Zickus) [696520 696600 696602 696603]
- [usb] USB3.0 ch11 definitions (Don Zickus) [696600 696602 696603]
- [usb] xhci: Remove references to HC_STATE_RUNNING. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Remove references to HC_STATE_HALT. (Don Zickus) [696600 696602 696603]
- [usb] xHCI: prolong host controller halt time limit (Don Zickus) [696600 696602 696603]
- [usb] xHCI: Remove redundant variable in xhci_resume() (Don Zickus) [696600 696602 696603]
- [usb] xhci: Rename variables and reduce register reads. (Don Zickus) [696600 696602 696603]
- [usb] xhci: Rework port suspend structures for limited ports. (Don Zickus) [696600 696602 696603]
- [usb] Remove bitmap #define from hcd.h (Don Zickus) [696600 696602 696603]
- [usb] xhci: Remove old no-op test. (Don Zickus) [696600 696602 696603]
- [usb] move usbcore away from hcd->state (Don Zickus) [696600 696602 696603]
- [usb] xhci: mark local functions as static (Don Zickus) [696600 696602 696603]
- [usb] xhci: fix couple sparse annotations (Don Zickus) [696600 696602 696603]
- [usb] xhci: rework xhci_print_ir_set() to get ir set from xhci itself (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fix an error in count_sg_trbs_needed() (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fix errors in the running total calculations in the TRB math (Don Zickus) [696600 696602 696603]
- [usb] xhci: Clarify some expressions in the TRB math (Don Zickus) [696600 696602 696603]
- [usb] host: Move AMD PLL quirk to pci-quirks.c (Don Zickus) [696600 696602 696603]
- [usb] EHCI: ASPM quirk of ISOC on AMD SB800 (Don Zickus) [696600 696602 696603]
- [usb] xhci: Fix issue with port array setup and buggy hosts. (Don Zickus) [696600 696602 696603]
- [usb] convert usb_hcd bitfields into atomic flags (Don Zickus) [696600 696602 696603]
- [x86] ACPI, APEI, EINJ Param support is disabled by default (Don Zickus) [725435]
- [fs] pstore: Allow the user to explicitly choose a backend (Don Zickus) [696135]
- [x86] ACPI, APEI, Add WHEA _OSC support (Don Zickus) [717515]
- [x86] ACPI, APEI, Add APEI bit support in generic _OSC call (Don Zickus) [696088]
- [x86] ACPI, APEI, GHES, Support disable GHES at boot time (Don Zickus) [696088]
- [x86] ACPI, APEI, GHES, Prevent GHES to be built as module (Don Zickus) [696088]
- [x86] PCI / ACPI: Fix build of the AER driver for CONFIG_ACPI unset (Don Zickus) [696081]
- [x86] PCI: remove unused AER functions (Don Zickus) [696081]
- [x86] pstore: Fix Kconfig dependencies for apei->pstore (Don Zickus) [696135]
- [x86] pstore: fix one type of return value in pstore (Don Zickus) [696135]
- [x86] pstore: fix pstore filesystem mount/remount issue (Don Zickus) [696135]
- [x86] pstore: fix one type of return value in pstore (Don Zickus) [696081 696135]
- [x86] pstore: cleanups to pstore_dump() (Don Zickus) [696135]
- [x86] ACPI, APEI, Add PCIe AER error information printing support (Don Zickus) [696078]
- [x86] PCIe, AER, use pre-generated prefix in error information printing (Don Zickus) [696078]
- [x86] ACPI, APEI, Add ERST record ID cache (Don Zickus) [713716]
- [x86] pstore: use mount option instead sysfs to tweak kmsg_bytes (Don Zickus) [696135]
- [x86] pstore: fix leaking ->i_private (Don Zickus) [696135]
- [x86] Some fixes for pstore (Don Zickus) [696135]
- [x86] ACPI: Fix boot problem related to APEI with acpi_disabled set (Don Zickus) [696081]
- [x86] PCI/ACPI: Request _OSC control once for each root bridge (v3) (Don Zickus) [696081]
- [x86] ACPI, APEI, Generic Hardware Error Source POLL/IRQ/NMI notification type support (Don Zickus) [696088]
- [x86] pstore: fix build warning for unused return value from sysfs_create_file (Don Zickus) [696135]
- [x86] pstore: X86 platform interface using ACPI/APEI/ERST (Don Zickus) [696135]
- [x86] pstore: new filesystem interface to platform persistent storage (Don Zickus) [696135]
- [x86] ACPI, APEI, Report GHES error information via printk (Don Zickus) [696078]
- [x86] ACPI, APEI, Add APEI generic error status printing support (Don Zickus) [696078]
- [x86] Add CPER PCIe error section structure and constants definition (Don Zickus) [696078]
- [ppc] perf: Handle events that raise an exception without overflowing (Steve Best) [720743]
- [fs] powerpc: Wire up sys_syncfs (Lukas Czerner) [691267]
- [fs] s390: wire up sys_syncfs (Lukas Czerner) [691267]
- [fs] introduce sys_syncfs to sync a single file system (Lukas Czerner) [691267]
- [v4l] Avoid kABI to complain about is_stereo() unused callback (Mauro Carvalho Chehab) [679755]
- [v4l] em28xx: Fix handling of V4L2 ctrl ioctl's (Mauro Carvalho Chehab) [679755]
- [v4l] Fix tuner-core behavior to properly return the right flags (Mauro Carvalho Chehab) [679755]
- [x86] UV Scalability: improve drain_pages (George Beshers) [635800]
- [virt] x86: report valid microcode update ID (Marcelo Tosatti) [694747]

* Wed Aug 03 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-178.el6]
- [scsi] lpfc: Update lpfc version for 8.3.5.45.2p driver release (Rob Evers) [725092]
- [scsi] lpfc: Fixed driver build not building in debugfs even kernel CONFIG_DEBUG_FS=y is set (Rob Evers) [725092]
- [scsi] lpfc: Fix issue where the FC/FCoE Async Receive CQE did not scale for 16G FC adapters (Rob Evers) [725092]
- [scsi] lpfc: Fix FLOGI payload having multiple N_port_ID set when lpfc_enable_npiv is 0 (Rob Evers) [725092]
- [scsi] lpfc: Fixed new ASIC device-mgmt BSG pass-through failed multi-buffer fw download (Rob Evers) [725092]
- [scsi] lpfc: Fixed bug with improperly reported number of supported VFs (Rob Evers) [725092]
- [scsi] lpfc: Fixed bug were driver was not waiting for SLI port status after firmware reset (Rob Evers) [725092]
- [scsi] lpfc: Remove unnecessary define that is causing warnings (Rob Evers) [725092]
- [scsi] lpfc: Fixed failure to enable PCIe AER prevent driver initialize and attach to device (Rob Evers) [725092]
- [scsi] lpfc: Fix split pde code (Rob Evers) [725092]
- [scsi] lpfc: Fix BlockGuard error path handling (Rob Evers) [725092]
- [scsi] lpfc: Fix EEH recovery so state is saved after every PCI reset for SLI4 (Rob Evers) [725092]
- [scsi] lpfc: Fix FC Port swap on SLI3 adapters (Rob Evers) [725092]
- [scsi] lpfc: Fixed Virtual link loss during Face plate failover test (Rob Evers) [725092]
- [scsi] lpfc: Fix 2KB limitation for extended mailbox command (Rob Evers) [725092]
- [scsi] lpfc: Fix vpi initialization in lpfc_init_vfi (Rob Evers) [725092]
- [netdrv] bonding: reduce noise during init (Andy Gospodarek) [563174]
- [netdrv] bonding: fix string comparison errors (Andy Gospodarek) [682946]
- [netdrv] bonding: allow non-standard link-speeds (Andy Gospodarek) [723032]
- [netdrv] bonding: don't lock when copying/clearing VLAN list on slave (Andy Gospodarek) [722901]
- [net] enable GRO by default for vlan devices (Weiping Pan) [725891]
- [fs] nfsd4: fix file leak on open_downgrade (J. Bruce Fields) [714153]
- [fs] nfsd4: remember to put RW access on stateid destruction (J. Bruce Fields) [714153]
- [fs] nfsd4: Fix filp leak (J. Bruce Fields) [714153]
- [netdrv] bonding:delete lacp_fast from ad_bond_info (Weiping Pan) [707142]
- [netdrv] bonding: make 802.3ad use latest lacp_rate (Weiping Pan) [707142]
- [netdrv] bonding 802.3ad: Rename rx_machine_lock to state_machine_lock (Weiping Pan) [707142]
- [netdrv] bonding 802.3ad: Fix the state machine locking (Weiping Pan) [707142]

* Tue Aug 02 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-177.el6]
- [scsi] lpfc: Update lpfc version for 8.3.5.45.1p driver release (Rob Evers) [706517]
- [scsi] lpfc: Fixed compiler warning for putting large amount of memory on stack (Rob Evers) [706517]
- [scsi] lpfc: Update lpfc version for 8.3.5.45 driver release (Rob Evers) [706517]
- [scsi] lpfc: Turn on MSI-X by default (Rob Evers) [706517]
- [scsi] lpfc: Added setting specific pf_number in GET_PROFILE_CONFIG to get maximum virtfn (Rob Evers) [706517]
- [scsi] lpfc: Added driver capability of reseting new ASIC firmware and device from sysfs entry (Rob Evers) [706517]
- [scsi] lpfc: Add firmware upgrade code to driver (Rob Evers) [706517]
- [scsi] lpfc: Added capability of inducing new ASIC firmware dump obj file to flash filesystem (Rob Evers) [706517]
- [scsi] lpfc: Added 100ms delay before driver action following IF_TYPE_2 function reset (Rob Evers) [706517]
- [scsi] lpfc: Added Linux driver SR-IOV management support for both SLI3 and SLI4 devices (Rob Evers) [706517]
- [scsi] lpfc: Fragment ELS and SCSI SGE lists based on Extent regions (Rob Evers) [706517]
- [scsi] lpfc: Remove GET_ALLOCATED extent count response work-around (Rob Evers) [706517]
- [scsi] lpfc: Fixed potential missed SLI4 device initialization failure conditions (Rob Evers) [706517]
- [scsi] lpfc: Fixed build warning (Rob Evers) [706517]
- [scsi] lpfc: Fixed Back to back Flogis sent without a logo (Rob Evers) [706517]
- [scsi] lpfc: Add model names for new hardware (Rob Evers) [706517]
- [scsi] lpfc: Fix bug with lpfc driver not updating the wwnn and wwpn after a name change (Rob Evers) [706517]
- [scsi] lpfc: Set the maximum SGE size to 0x80000000 when HBA does not have any restriction (Rob Evers) [706517]
- [scsi] lpfc: New ASIC device link diagonstic test and link diagnostic loopback test support (Rob Evers) [706517]
- [scsi] lpfc: Rework svn rev 10898 (Rob Evers) [706517]
- [scsi] lpfc: Fixed mix-and-match backward compability with the new new ASIC device management (Rob Evers) [706517]
- [scsi] lpfc: Fix SLI3 and non-NPIV crashes with new extent code (Rob Evers) [706517]
- [scsi] lpfc: Fixed BSG failure in handing pass-through mailbox with multiple external buffers (Rob Evers) [706517]
- [scsi] lpfc: Fix CT command never completing on Big Endian system (Rob Evers) [706517]
- [scsi] lpfc: Refactor lpfc_sli4_alloc_extent some more (Rob Evers) [706517]
- [scsi] lpfc: Restore SLI4_PARAMETER mailbox can fail as nonerror functionality (Rob Evers) [706517]
- [scsi] lpfc: Rework svn rev 11479 (Rob Evers) [706517]
- [scsi] lpfc: Rework svn rev 11379 (Rob Evers) [706517]
- [scsi] lpfc: Do not post RPI Headers to SLI4 port that support extents (Rob Evers) [706517]
- [scsi] lpfc: Back out r9872 (Rob Evers) [706517]
- [scsi] lpfc: Refactor code in lpfc_sli4_alloc_extent (Rob Evers) [706517]
- [scsi] lpfc: Fix port capabilities and get parameters mailbox calls (Rob Evers) [706517]
- [scsi] lpfc: Fix SLI2 crashes with new extent code (Rob Evers) [706517]
- [scsi] lpfc: Fixed EEH failure on PPC-P7 due to the platform required PCI fundamental reset (Rob Evers) [706517]
- [scsi] lpfc: Fixed incorrect size set into the sysfs binary file access interface (Rob Evers) [706517]
- [scsi] lpfc: Brought debugfs accessing new ASIC extents information into the iDiag framework (Rob Evers) [706517]
- [scsi] lpfc: Fix mailbox processing to not overwrite mailbox status codes (Rob Evers) [706517]
- [scsi] lpfc: Changed enumerate members starting from none zero value (Rob Evers) [706517]
- [scsi] lpfc: Remove driver workaround for COMMON_ALLOC_RESOURCE_EXTENTS endianess issue (Rob Evers) [706517]
- [scsi] lpfc: Fix lpfc_printf_log message numbers (Rob Evers) [706517]
- [scsi] lpfc: Implement debugfs support for resource extents (Rob Evers) [706517]
- [scsi] lpfc: iDiag method for read write bitset bitclear access to new ASIC control registers (Rob Evers) [706517]
- [scsi] lpfc: Call correct mailbox cleanup routine after extents are allocated (Rob Evers) [706517]
- [scsi] lpfc: Implement extent block list member cleanup and free memory resources (Rob Evers) [706517]
- [scsi] lpfc: Fix memory leak in extent block lists (Rob Evers) [706517]
- [scsi] lpfc: Modified variables for XRIs to be unsigned variable (Rob Evers) [706517]
- [scsi] lpfc: Update lpfc version for 8.3.5.47 driver release (Rob Evers) [706517]
- [scsi] lpfc: iDiag method for endian explicit dumping at iussue SLI4 mailbox command routine (Rob Evers) [706517]
- [scsi] lpfc: Fixed compilation error/warning (Rob Evers) [706517]
- [scsi] lpfc: iDiag method for dumping mailbox command from SLI4 issue mailbox command routine (Rob Evers) [706517]
- [scsi] lpfc: Implement support for nonembedded Extent mailbox IOCTLs (Rob Evers) [706517]
- [scsi] lpfc: Fix crash in rpi clean when driver load fails (Rob Evers) [706517]
- [scsi] lpfc: Fixed race condition between driver multi-buffer seesion reset and bsg job done (Rob Evers) [706517]
- [scsi] lpfc: Rework revision 10933 (Rob Evers) [706517]
- [scsi] lpfc: Update lpfc version for 8.3.5.41 driver release (Rob Evers) [706517]
- [scsi] lpfc: Fixed mask size for the wq_id mask (Rob Evers) [706517]
- [scsi] lpfc: Fix Port Error detected during POST (Rob Evers) [706517]
- [scsi] lpfc: iDiag dump methods for new ASIC BSG multiple buffer mailbox command pass-through (Rob Evers) [706517]
- [scsi] lpfc: Added protection on new ASIC specific mbox cmd passed to existing interface type (Rob Evers) [706517]
- [scsi] lpfc: Added protection on non-embedded mailbox command for number of external buffers (Rob Evers) [706517]
- [scsi] lpfc: Apply dropped patch from initial new ASIC bring up (Rob Evers) [706517]
- [scsi] lpfc: Rework revision 10898 (Rob Evers) [706517]
- [scsi] lpfc: Fixed mailbox command completion invoke BSG job_done while holding spinlock (Rob Evers) [706517]
- [scsi] lpfc: Fixed double byte swap on received RRQ (Rob Evers) [706517]
- [scsi] lpfc: Fixed no BSG data transfer size protection in mailbox command pass-through path (Rob Evers) [706517]
- [scsi] lpfc: Make adjustments for systems with Page Size Larger than 4k (Rob Evers) [706517]
- [scsi] lpfc: Reorganize CQ and EQ usage to comply with SLI4 Specification (Rob Evers) [706517]
- [scsi] lpfc: Fix KERN levels on log messages 3008, 2903, 0383 (Rob Evers) [706517]
- [scsi] lpfc: Fixed new ASIC mbox queue id collision with work queue id in debugfs queue access (Rob Evers) [706517]
- [scsi] lpfc: Fixed not resetting session on pass-through read mbox cmd with single buffer (Rob Evers) [706517]
- [scsi] lpfc: Initial checkin of SLI4 Extents code (Rob Evers) [706517]
- [scsi] lpfc: Added new ASIC pass-through mbox cmd extension on multi-external-buffer handling (Rob Evers) [706517]
- [scsi] lpfc: Fixed bug in BSG pass-through mailbox size check to non-embedded external buffer (Rob Evers) [706517]
- [scsi] lpfc: Update lpfc version for 8.3.5.40 driver release (Rob Evers) [706517]
- [scsi] lpfc: Add LOG_ELS message to NPIV LOGO (Rob Evers) [706517]
- [scsi] lpfc: Fixed Vports not sending FDISC after lips (Rob Evers) [706517]
- [scsi] lpfc: Added 0x9B multi-buffer subsystem/opcode macros in user-kernel shared BSG header (Rob Evers) [706517]
- [scsi] lpfc: Extended dfc_mbox_req struct with mbox tag and multi-buffer sequence number (Rob Evers) [706517]
- [scsi] lpfc: Fixed a bug BSG treated all SLI_CONFIG (0x9B) mailbox commands as non-embedded (Rob Evers) [706517]
- [scsi] lpfc: Removed unnecessary buffer-to-buffer copies in handling pass-through mbox cmds (Rob Evers) [706517]
- [scsi] lpfc: Fixed the mixed declarations and codes which violate ISO C90 (Rob Evers) [706517]
- [scsi] lpfc: Fix FCFI incorrect on received unsolicited frames (Rob Evers) [706517]
- [scsi] lpfc: Misc upstream fixes (Rob Evers) [706517]
- [scsi] lpfc: Fix bug with lpfc driver causing a system crash during driver unload (Rob Evers) [706517]
- [scsi] lpfc: Added user-kernel shared sli-config mailbox header for new ASIC device management (Rob Evers) [706517]
- [scsi] lpfc: Update lpfc version for 8.3.5.39 driver release (Rob Evers) [706517]
- [scsi] lpfc: iDiag driver support debugfs SLI4 device doorbell reigster access methods (Rob Evers) [706517]
- [scsi] lpfc: Fix RQ_CREATE version 1 fails (Rob Evers) [706517]
- [scsi] lpfc: Fix FCFI incorrect on received unsolicited frames (Rob Evers) [706517]
- [scsi] lpfc: iDiag driver support debugfs SLI4 device display host/port index in decimal (Rob Evers) [706517]
- [scsi] lpfc: Do not limit RPI Count to a minimum of 64 (Rob Evers) [706517]
- [scsi] lpfc: Do not override CT field in issue_els_flogi for SLI4 IF type 2 (Rob Evers) [706517]
- [scsi] lpfc: Fix build introduced in r10532 (Rob Evers) [706517]
- [scsi] lpfc: Add Temporary RPI field to the ELS request WQE (Rob Evers) [706517]
- [scsi] lpfc: Allow SLI4 with FCOE_MODE not set for new SLI4 FC adapters (Rob Evers) [706517]
- [scsi] lpfc: Restrict driver to look at BAR2 or BAR4 only for if_type 0 (Rob Evers) [706517]
- [scsi] lpfc: iDiag driver support debugfs SLI4 device queue entry access methods (Rob Evers) [706517]
- [scsi] lpfc: Update copyright date for all changed files (Rob Evers) [706517]
- [scsi] lpfc: Update lpfc version for 8.3.5.37 driver release (Rob Evers) [706517]
- [scsi] lpfc: Fixed the compiler warning (Rob Evers) [706517]
- [scsi] lpfc: Modified existing driver code to handle PCI Link drop detection failure (Rob Evers) [706517]
- [scsi] lpfc: 4K boundary issue + lpfc driver (Rob Evers) [706517]
- [scsi] lpfc: Fix debugfs build error caused by undefined Macro (Rob Evers) [706517]
- [scsi] lpfc: Add selective reset jump table entry (Rob Evers) [706517]
- [scsi] lpfc: Update lpfc version for 8.3.5.36 driver release (Rob Evers) [706517]
- [scsi] lpfc: Merge from upstream: lpfc: lower stack use in lpfc_fc_frame_check (Rob Evers) [706517]
- [scsi] lpfc: Merge from upstream: fix comment typo diable -> disable (Rob Evers) [706517]
- [scsi] lpfc: Merge from upstream: tree-wide: fix comment/printk typos (Rob Evers) [706517]
- [scsi] lpfc: Add new Queue create Mailbox versions for new ASIC (Rob Evers) [706517]
- [scsi] lpfc: Place LPFC driver module parameters to /sys/module/<driver_name>/parameters (Rob Evers) [706517]
- [scsi] lpfc: Performance Hints support (Rob Evers) [706517]
- [scsi] lpfc: Add new driver interfaces for encryption products (Rob Evers) [706517]
- [scsi] lpfc: iDiag driver support debugfs queue information get (Rob Evers) [706517]
- [scsi] lpfc: iDiag driver support debugfs PCI config space register bits set/clear methods (Rob Evers) [706517]
- [scsi] lpfc: iDiag driver support debugfs framework and read/write PCI config space registers (Rob Evers) [706517]
- [scsi] lpfc: Update lpfc version for 8.3.5.35 driver release (Rob Evers) [706517]
- [scsi] lpfc: Configuration parameter lpfc_suppress_link_up is ignored for SLI-4 (Rob Evers) [706517]
- [scsi] lpfc: Modified lpfc_delay_discovery implementation (Rob Evers) [706517]
- [scsi] lpfc: Update lpfc version for 8.3.5.34 driver release (Rob Evers) [706517]
- [scsi] lpfc: Print something out if the link_speed is not supported by this adapter (Rob Evers) [706517]
- [scsi] lpfc: Update lpfc version for 8.3.5.33 driver release (Rob Evers) [706517]
- [scsi] lpfc: Added support for clean address bit (Rob Evers) [706517]
- [x86] x86, UV: Fix NMI handler for UV platforms (George Beshers) [689026]
- [x86] x86, NMI: Add priorities to handlers (George Beshers) [689026]
- [x86] x86, nmi_watchdog: Remove ARCH_HAS_NMI_WATCHDOG and rely on CONFIG_HARDLOCKUP_DETECTOR (George Beshers) [689026]
- [mm] zram: Fix kunmapping order (Jerome Marchand) [722926]
- [mm] zram: Replace mutex lock by a R/W semaphore (Jerome Marchand) [722926]
- [mm] zram: allow partial page operations (Jerome Marchand) [722926]
- [mm] zram: Refactor zram_read/write() functions (Jerome Marchand) [722926]
- [mm] zram: Remove useless offset calculation in handle_uncompressed_page (Jerome Marchand) [722926]
- [kernel] sched: Next buddy hint on sleep and preempt path (Rik van Riel) [711600]
- [kernel] sched: Make set_*_buddy() work on non-task entities (Rik van Riel) [711600]
- [dma] ioatdma: add support for SandyBridge (John Feeney) [701443]
- [x86] Don't use the EFI reboot method by default (Matthew Garrett) [723849]
- [mm] thp: fix move_huge_pmd (Andrea Arcangeli) [706385]

* Mon Aug 01 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-176.el6]
- [virt] xen: x86_32: Ignore not present at boot time HIGHMEM pages (Igor Mammedov) [523122]
- [virt] xen: prevent crashes with non-HIGHMEM 32-bit kernels with largeish memory (Igor Mammedov) [523122]
- [virt] xen/balloon: Move dec_totalhigh_pages() from __balloon_append() to balloon_append() (Igor Mammedov) [523122]
- [virt] xen/balloon: Use PageHighMem() for high memory page detection (Igor Mammedov) [523122]
- [virt] xen/balloon: Removal of driver_pages (Igor Mammedov) [523122]
- [virt] xen: Mark all initial reserved pages for the balloon as INVALID_P2M_ENTRY (Igor Mammedov) [523122]
- [virt] xen: clean up "extra" memory handling some more (Igor Mammedov) [523122]
- [virt] xen/balloon: the balloon_lock is useless (Igor Mammedov) [523122]
- [virt] xen/balloon: make sure we only include remaining extra ram (Igor Mammedov) [523122]
- [virt] xen: add extra pages to balloon (Igor Mammedov) [523122]
- [virt] xen: don't add extra_pages for RAM after mem_end (Igor Mammedov) [523122]
- [virt] xen: make sure xen_max_p2m_pfn is up to date (Igor Mammedov) [523122]
- [virt] xen: limit extra memory to a certain ratio of base (Igor Mammedov) [523122]
- [virt] xen: add extra pages for E820 RAM regions, even if beyond mem_end (Igor Mammedov) [523122]
- [virt] xen: make sure xen_extra_mem_start is beyond all non-RAM e820 (Igor Mammedov) [523122]
- [virt] xen: implement "extra" memory to reserve space for pages not present at boot (Igor Mammedov) [523122]
- [virt] xen: Use host-provided E820 map (Igor Mammedov) [523122]
- [virt] xen: don't map missing memory (Igor Mammedov) [716498]
- [virt] xen: Rename the balloon lock (Igor Mammedov) [523122]
- [virt] xen: make sure pages are really part of domain before freeing (Igor Mammedov) [523122]
- [virt] xen: release unused free memory (Igor Mammedov) [523122]
- [virt] vhost: optimize interrupt enable/disable (Jason Wang) [725199]
- [virt] vhost: set log when updating used flags or avail event (Jason Wang) [725199]
- [virt] vhost: init used ring after backend was set (Jason Wang) [725199]
- [virt] vhost-net: remove unlocked use of receive_queue (Jason Wang) [725199]
- [virt] vhost: lock receive queue, not the socket (Jason Wang) [725199]
- [virt] vhost-net: Unify the code of mergeable and big buffer handling (Jason Wang) [725199]
- [virt] vhost-net: check the support of mergeable buffer outside the receive loop (Jason Wang) [725199]
- [virt] vhost: copy_from_user -> __copy_from_user (Jason Wang) [725199]
- [infiniband] qib: Adjust to use cpumask_weight() and cpumask_first() (Chad Dupuis) [696226]
- [infiniband] qib: Ensure that LOS and DFE are being turned off (Chad Dupuis) [696226]
- [infiniband] qib: Prevent driver hang with unprogrammed boards (Chad Dupuis) [696226]
- [infiniband] qib: Fix M_Key field in SubnGet and SubnGetResp MADs (Chad Dupuis) [696226]
- [infiniband] qib: Set default LE2 value for active cables to 0 (Chad Dupuis) [696226]
- [infiniband] qib: Return correct MAD when setting link width to 255 (Chad Dupuis) [696226]
- [infiniband] qib: Prevent double completions after a timeout or RNR error (Chad Dupuis) [696226]
- [infiniband] qib: Kernel BUG at include/linux/timer.h:82 (Chad Dupuis) [696226]
- [infiniband] qib: Hold link for Tx SERDES settings (Chad Dupuis) [696226]
- [infiniband] qib: Improve SERDES tunning on QMH boards (Chad Dupuis) [696226]
- [infiniband] qib: Un-necessary delayed completions on RC connection (Chad Dupuis) [696226]
- [infiniband] qib: Issue pre-emptive NAKs on eager buffer overflow (Chad Dupuis) [696226]
- [infiniband] qib: RDMA lkey/rkey validation is inefficient for large MRs (Chad Dupuis) [696226]
- [infiniband] qib: change qpn increment (Chad Dupuis) [696226]
- [infiniband] qib: adding fix missing from earlier patch (Chad Dupuis) [696226]
- [infiniband] qib: change rcv queue/qpn selection (Chad Dupuis) [696226]
- [infiniband] qib: interrupt mitigation fix (Chad Dupuis) [696226]
- [infiniband] qib: Avoid duplicate writes to the rcv head register (Chad Dupuis) [696226]
- [infiniband] qib: Add a few new SERDES tunings (Chad Dupuis) [696226]
- [infiniband] qib: Reset packet list after freeing (Chad Dupuis) [696226]
- [infiniband] qib: New SERDES init routine and improvements to SI quality (Chad Dupuis) [696226]
- [infiniband] qib: clear WAIT_SEND flags when setting QP to error state (Chad Dupuis) [696226]
- [infiniband] qib: fix context allocation with multiple HCAs (Chad Dupuis) [696226]
- [infiniband] qib: Multi Florida HCA Hosts panic on reboot (Chad Dupuis) [696226]
- [infiniband] qib: Handle transitions from ACTIVE_DEFERRED to ACTIVE better (Chad Dupuis) [696226]
- [infiniband] qib: UD send with immediate Rx completion has wrong size (Chad Dupuis) [696226]
- [infiniband] qib: set port physical state even if other fields are invalid (Chad Dupuis) [696226]
- [infiniband] qib: generate completion callback on errors (Chad Dupuis) [696226]
- [infiniband] qib: add thresholds to VendorPortCounters PMA operation (Chad Dupuis) [696226]
- [infiniband] qib: add support for the new QME7362 card (Chad Dupuis) [696226]
- [infiniband] qib: add receive header queue size module parameters (Chad Dupuis) [696226]
- [infiniband] qib: remove IB latency turnoff (Chad Dupuis) [696226]
- [ata] Add Intel IDE-R support (John Feeney) [695587]
- [agp] fix arbitrary kernel memory writes (Jerome Marchand) [699308] {CVE-2011-1745 CVE-2011-2022}
- [agp] fix OOM and buffer overflow (Jerome Marchand) [699306] {CVE-2011-1746}
- [kernel] run_rebalance_domains() is using too much cpu time (George Beshers) [635848]
- [x86] Enable UV MMTIMER (George Beshers) [635713]
- [ppc] Use correct ccr bit for syscall error status (Steve Best) [691579]
- [s390x] qdio: clear shared DSCI before scheduling the queue handler (Hendrik Brueckner) [725690]
- [scsi] scsi_dh_alua: Attach to UNAVAILABLE/OFFLINE AAS devices (Mike Christie) [698329]
- [kernel] backport upstream change to remove prefetch instructions from list and rculist functions (Larry Woodman) [725538]
- [input] wacom: add support for DTU-2231 (Aristeu Rozanski) [705210]
- [infiniband] iw_cxgb4: update driver to latest upstream (Neil Horman) [717377]
- [kernel] taskstats: don't allow duplicate entries in listener mode (Jerome Marchand) [715448] {CVE-2011-2484}
- [kernel] Monitor and log change in system time when the system time drifts by user configured time interval warning (James Takahashi) [694910]
- [security] Translate secctx to 0 if SELinux disabled (David Howells) [667177]
- [pm] hibernate: Handle marginal memory conditions correctly (Matthew Garrett) [700264]
- [kernel] Oprofile support for Sandy Bridge processors (John Villalovos) [696562]
- [kernel] misc: add support for IB700 module (Don Zickus) [667090]
- [x86] ACPI: Use ioremap_cache() (George Beshers) [635860]
- [x86] ACPI: introduce "acpi_rsdp=" parameter for kdump (Takao Indoh) [723670]
- [x86] UV: Kernel log overflows on boot on large systems (George Beshers) [696287]
- [x86] amd-iommu: Fix 3 possible endless loops (Frank Arnold) [713517]
- [x86] amd-iommu: Use only per-device dma_ops (Frank Arnold) [712369]
- [x86] setup: Fix EDD3.0 data verification (Gleb Natapov) [704128]
- [virt] xen: Revert p2m tree (Andrew Jones) [725519]
- [virt] xen-blkfront: fix data size for xenbus_gather in blkfront_connect (Andrew Jones) [716452]
- [virt] xen/hvc: only notify if we actually sent something (Igor Mammedov) [725041]
- [virt] xen mmu: fix a race window causing leave_mm BUG() (Radim Krcmar) [724995]
- [virt] xen: off by one errors in multicalls.c (Radim Krcmar) [725007]
- [virt] virtio_net: introduce VIRTIO_NET_HDR_F_DATA_VALID (Jason Wang) [713337]

* Sun Jul 31 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-175.el6]
- [netdrv] be2net: clear intr bit in be_probe() (Ivan Vecera) [702739 722596]
- [fs] fs: call security_d_instantiate in d_obtain_alias (Josef Bacik) [656458]
- [fs] dlm: use vmalloc for hash tables (David Teigland) [719357]
- [fs] quota: Fix WARN_ON in lookup_one_len (Eric Sandeen) [718332]
- [net] skbuff: fix error handling in pskb_copy() (Michael S. Tsirkin) [632752]
- [net] vlan: allow TSO setting on vlan interfaces (Andy Gospodarek) [645785]
- [netdrv] Support 'passthru' mode using macvlan/macvtap (James Takahashi) [693874]
- [netdrv] asix: fix setting mac address for AX88772 (Jiri Pirko) [725234]
- [netdrv] ixgbevf: update to upstream version 2.1.0-k (Andy Gospodarek) [694231]
- [netdrv] bnx2x: remove a log-spamming message (Michal Schmidt) [712000]
- [netdrv] cxgb4 driver update (Neil Horman) [717801]
- [netdrv] iwlwifi: accept EEPROM version 0x423 for iwl6000 (Stanislaw Gruszka) [691846]
- [netdrv] cxgb3 driver update (Neil Horman) [717805]
- [netdrv] net: bonding: allow all slave speeds (Jiri Pirko) [720941]
- [netdrv] ixgbe: update to upstream version 3.4.8-k (Andy Gospodarek) [689998 696045]
- [netdrv] e1000e: update to upstream version 1.3.16-k (Andy Gospodarek) [694223 698291]
- [net] introduce __netdev_alloc_skb_ip_align (Andy Gospodarek) [694223]
- [net] dcbnl: unlock on an error path in dcbnl_cee_fill() (Dean Nelson) [695947]
- [net] dcbnl: Add CEE notification (Dean Nelson) [695947]
- [net] dcbnl: Aggregated CEE GET operation (Dean Nelson) [695947]
- [net] dcb: use nlmsg_free() instead of kfree() (Dean Nelson) [695947]
- [net] dcb: Add missing error check in dcb_ieee_set() (Dean Nelson) [695947]
- [net] dcb: fix return type on dcb_setapp() (Dean Nelson) [695947]
- [net] dcb: Add dcb_ieee_getapp_mask() for drivers to query APP settings (Dean Nelson) [695947]
- [net] dcb: Add ieee_dcb_delapp() and dcb op to delete app entry (Dean Nelson) [695947]
- [net] dcb: Add ieee_dcb_setapp() to be used for IEEE 802.1Qaz APP data (Dean Nelson) [695947]
- [net] net: dcbnl, add multicast group for DCB (Dean Nelson) [695947]
- [net] dcb: Add DCBX capabilities bitmask to the get_ieee response (Dean Nelson) [695947]
- [net] net: dcbnl: Update copyright dates (Dean Nelson) [695947]
- [net] net: dcbnl: Fix misspellings (Dean Nelson) [695947]
- [net] net: dcbnl: Add IEEE app selector value definitions (Dean Nelson) [695947]
- [net] dcbnl: add support for retrieving peer configuration - cee (Dean Nelson) [695947]
- [net] dcbnl: add support for retrieving peer configuration - ieee (Dean Nelson) [695947]
- [net] net: dcbnl: check correct ops in dcbnl_ieee_set() (Dean Nelson) [695947]
- [net] net: dcb: match dcb_app protocol field with 802.1Qaz spec (Dean Nelson) [695947]
- [net] ixgbe: DCB, implement 802.1Qaz routines (Dean Nelson) [695947]
- [net] net: dcb: application priority is per net_device (Dean Nelson) [695947]
- [net] dcbnl: make get_app handling symmetric for IEEE and CEE DCBx (Dean Nelson) [695947]
- [net] include cleanup: Update gfp.h and slab.h includes to prepare for breaking implicit slab.h inclusion from percpu.h (Dean Nelson) [695947]
- [net] const: struct nla_policy (Dean Nelson) [695947]
- [net] net: Move && and || to end of previous line (Dean Nelson) [695947]
- [net] net: use net_eq to compare nets (Dean Nelson) [695947]
- [kernel] include/linux/kernel.h: abs(): fix handling of 32-bit unsigneds on 64-bit (Thomas Graf) [679456]
- [net] sctp: stop pending timers and purge queues when peer restart asoc (Thomas Graf) [679456]
- [net] sctp: fix memory leak of the ASCONF queue when free asoc (Thomas Graf) [679456]
- [net] SCTP: fix race between sctp_bind_addr_free() and sctp_bind_addr_conflict() (Thomas Graf) [679456]
- [net] sctp: move chunk from retransmit queue to abandoned list (Thomas Graf) [679456]
- [net] sctp: fix to check the source address of COOKIE-ECHO chunk (Thomas Graf) [679456]
- [net] sctp: handle ootb packet in chunk order as defined (Thomas Graf) [679456]
- [net] sctp: check invalid value of length parameter in error cause (Thomas Graf) [679456]
- [net] sctp: check parameter value of length in ERROR chunk (Thomas Graf) [679456]
- [net] sctp: Release all routes when processing acks ADD_IP or DEL_IP (Thomas Graf) [679456]
- [net] sctp: Allow bindx_del to accept 0 port (Thomas Graf) [679456]
- [net] sctp: teach CACC algorithm about removed transports (Thomas Graf) [679456]
- [net] sctp: fix oops while removed transport still using as retran path (Thomas Graf) [679456]
- [net] sctp: fix oops when updating retransmit path with DEBUG on (Thomas Graf) [679456]
- [net] sctp: malloc enough room for asconf-ack chunk (Thomas Graf) [679456]
- [net] sctp: fix auth_hmacs field's length of struct sctp_cookie (Thomas Graf) [679456]
- [net] sctp: Pass __GFP_NOWARN to hash table allocation attempts. (Thomas Graf) [679456]
- [net] sctp: fix compile warnings in sctp_tsnmap_num_gabs (Thomas Graf) [679456]
- [net] sctp: fix reporting of unknown parameters (Thomas Graf) [679456]
- [net] sctp: user perfect name for Delayed SACK Timer option (Thomas Graf) [679456]
- [net] sctp: fix the return value of getting the sctp partial delivery point (Thomas Graf) [679456]
- [net] SCTP: Fix SCTP_SET_PEER_PRIMARY_ADDR to accpet v4mapped address (Thomas Graf) [679456]
- [net] sctp: prevent reading out-of-bounds memory (Thomas Graf) [679456]
- [net] sctp: fix test for end of loop (Thomas Graf) [679456]
- [net] sctp: dubious bitfields in sctp_transport (Thomas Graf) [679456]
- [net] sctp: fix append error cause to ERROR chunk correctly (Thomas Graf) [679456]
- [net] sctp: delete active ICMP proto unreachable timer when free transport (Thomas Graf) [679456]
- [net] sctp: Fix a race between ICMP protocol unreachable and connect() (Thomas Graf) [679456]
- [net] sctp: Tag messages that can be Nagle delayed at creation. (Thomas Graf) [679456]
- [net] sctp: Optimize computation of highest new tsn in SACK. (Thomas Graf) [679456]
- [net] sctp: correctly mark missing chunks in fast recovery (Thomas Graf) [679456]
- [net] sctp: rwnd_press should be cumulative (Thomas Graf) [679456]
- [net] sctp: fast recovery algorithm is per association. (Thomas Graf) [679456]
- [net] sctp: update transport initializations (Thomas Graf) [679456]
- [net] sctp: Save some room in the sctp_transport by using bitfields (Thomas Graf) [679456]
- [net] sctp: Do not force T3 timer on fast retransmissions. (Thomas Graf) [679456]
- [net] sctp: remove 'resent' bit from the chunk (Thomas Graf) [679456]
- [net] sctp: Make sure we always return valid retransmit path (Thomas Graf) [679456]
- [net] sctp: Do no select unconfirmed transports for retransmissions (Thomas Graf) [679456]
- [net] sctp: fix to retranmit at least one DATA chunk (Thomas Graf) [679456]
- [net] sctp: missing set src and dest port while lookup output route (Thomas Graf) [679456]
- [net] sctp: discard ABORT chunk with zero verification tag in COOKIE-WAIT state (Thomas Graf) [679456]
- [net] sctp: assure at least one T3-rtx timer is running if a FORWARD TSN is sent (Thomas Graf) [679456]
- [net] sctp: send SHUTDOWN-ACK chunk back to the source. (Thomas Graf) [679456]
- [net] sctp: Use correct address family in sctp_getsockopt_peer_addrs() (Thomas Graf) [679456]
- [net] sctp: Fix oops when sending queued ASCONF chunks (Thomas Graf) [679456]
- [net] sctp: per_cpu variables should be in bh_disabled section (Thomas Graf) [679456]
- [net] sctp: fix potential reference of a freed pointer (Thomas Graf) [679456]
- [net] sctp: avoid irq lock inversion while call sk->sk_data_ready() (Thomas Graf) [679456]
- [net] sctp: eliminate useless code (Thomas Graf) [679456]
- [net] sctp: Use ipv6_addr_diff() in sctp_v6_addr_match_len(). (Thomas Graf) [679456]
- [net] sctp/socket.c: squish warning (Thomas Graf) [679456]
- [net] sctp: fix sctp_setsockopt_autoclose compile warning (Thomas Graf) [679456]
- [net] sctp: prevent too-fast association id reuse (Thomas Graf) [679456]
- [net] sctp: fix integer overflow when setting the autoclose timer (Thomas Graf) [679456]
- [net] sctp: limit maximum autoclose setsockopt value (Thomas Graf) [679456]
- [net] sctp: Fix mis-ordering of user space data when multihoming in use (Thomas Graf) [679456]
- [net] sctp: Update max.burst implementation (Thomas Graf) [679456]
- [net] sctp: Remove useless last_time_used variable (Thomas Graf) [679456]
- [net] sctp: allow setting path_maxrxt independent of SPP_PMTUD_ENABLE (Thomas Graf) [679456]
- [net] sctp: Update SWS avaoidance receiver side algorithm (Thomas Graf) [679456]
- [net] sctp: Select a working primary during sctp_connectx() (Thomas Graf) [679456]
- [net] sctp: Fix malformed "Invalid Stream Identifier" error (Thomas Graf) [679456]

* Wed Jul 27 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-174.el6]
- [drm] radeon/kms: fix DP training for DPEncoderService revision bigger than 1.1 (Dave Airlie) [722957]
- [drm] nouveau fixes for RHEL 6.2 (Dave Airlie) [722957]
- [drm] i915: Skip GPU wait for scanout pin while wedged (Dave Airlie) [722957]
- [drm] i915: Fix opregion notifications (Dave Airlie) [722957]
- [drm] ACPI: Don't send KEY_UNKNOWN for random video notifications (Dave Airlie) [722957]
- [drm] drm/agp: complete 3.0.0 fixes backport. (Dave Airlie) [722957]
- [kernel] /proc/stat: fix scalability of irq sum of all cpu (George Beshers) [635855]
- [kernel] /proc/stat: scalability of irq num per cpu (George Beshers) [635855]
- [virt] vhost: handle wrap around in # of bufs math (Michael S. Tsirkin) [632752]
- [virt] vhost-net: update used ring on backend change (Michael S. Tsirkin) [632752]
- [virt] vhost: fix zcopy reference counting (Michael S. Tsirkin) [632752]
- [virt] vhost: vhost TX zero-copy support (Michael S. Tsirkin) [632752]
- [netdrv] macvtap: macvtapTX zero-copy support (Michael S. Tsirkin) [632752]
- [net] skbuff: clear tx zero-copy flag (Michael S. Tsirkin) [632752]
- [net] skbuff: skb supports zero-copy buffers (Michael S. Tsirkin) [632752]
- [net] sock.h: Add a new sock zero-copy flag (Michael S. Tsirkin) [632752]
- [net] pskb_expand_head() optimization (Michael S. Tsirkin) [632752]
- [netdrv] qlcnic: Support for GBE port settings (Chad Dupuis) [693735]
- [netdrv] qlcnic: support rcv ring configuration through sysfs (Chad Dupuis) [693735]
- [netdrv] qlcnic: Update version number to 5.0.16 (Chad Dupuis) [693735]
- [netdrv] qlcnic: Fix LRO disable (Chad Dupuis) [693735]
- [netdrv] qlcnic: Use flt method to determine flash fw region (Chad Dupuis) [693735]
- [netdrv] qlcnic: Remove unused code (Chad Dupuis) [693735]
- [netdrv] qlcnic: Code optimization patch (Chad Dupuis) [693735]
- [netdrv] qlcnic: Cleanup patch (Chad Dupuis) [693735]
- [netdrv] qlcnic: Memory leak fix (Chad Dupuis) [693735]
- [netdrv] qlcnic: Make PCI info available in all modes (Chad Dupuis) [693735]
- [net] fix ethtool->set_flags not intended -EINVAL return value (Chad Dupuis) [693735]
- [netdrv] qlcnic: Remove validation for max tx and max rx queues (Chad Dupuis) [693735]
- [netdrv] qlcnic: fix checks for auto_fw_reset (Chad Dupuis) [693735]
- [virt] virtio_net: delay TX callbacks (Michael S. Tsirkin) [710945]
- [virt] virtio: add api for delayed callbacks (Michael S. Tsirkin) [710945]
- [virt] vhost: support event index (Michael S. Tsirkin) [710945]
- [virt] virtio_ring: support event idx feature (Michael S. Tsirkin) [710945]
- [virt] virtio ring: inline function to check for events (Michael S. Tsirkin) [710945]
- [virt] virtio: event index interface (Michael S. Tsirkin) [710945]
- [scsi] fcoe: cleanup cpu selection for incoming requests (Mike Christie) [695945]
- [scsi] libfc: post reset event on lport reset (Mike Christie) [695945]
- [scsi] libfc: Fix for exchange/seq loopup failure when FCoE stack is used as target and connected to windows initiator (Mike Christie) [695945]
- [scsi] fcoe: Amends previous patch, Round-robin based selection of CPU for post processing of incoming request for FCoE target (Mike Christie) [695945]
- [scsi] fcoe: Round-robin based selection of CPU for post-processing of incoming commands (Mike Christie) [695945]
- [scsi] fcoe: Unable to select the exchangeID from offload pool for storage targets (Mike Christie) [695945]
- [scsi] libfc: Enhancement to RPORT state machine applicable only for VN2VN mode (Mike Christie) [695945]
- [scsi] libfcoe: Remove unnecessary module state checks (Mike Christie) [695945]
- [scsi] libfc: do not immediately retry the cmd when seq_send fails in fc_fcp_send_data (Mike Christie) [695945]
- [scsi] libfc: fix race in SRR response (Mike Christie) [695945]
- [scsi] libfc: don't call resp handler after FC_EX_TIMEOUT (Mike Christie) [695945]
- [scsi] libfc: release DDP context if frame_send() fails (Mike Christie) [695945]
- [scsi] libfc: fix mm leak in handling incoming request for target discovery (Mike Christie) [695945]
- [scsi] fcoe: Prevent creation of an NPIV port with duplicate WWPN (Mike Christie) [695945]
- [sound] Update the ALSA HDA audio driver from upstream (Jaroslav Kysela) [723853]
- [mm] exec: account anon_rss instead of total_vm in acct_arg_size (Frantisek Hrbata) [645770]
- [mm] debug: reintroduce would_have_oomkilled procfs ctl (Frantisek Hrbata) [645770]
- [mm] kabi: __GENKSYMS__ for oom_disable_count struct mm_struct (Frantisek Hrbata) [645770]
- [mm] kabi: __GENKSYMS__ for oom_score_adj in struct signal_struct (Frantisek Hrbata) [645770]
- [mm] oom: replace PF_OOM_ORIGIN with toggling oom_score_adj (Frantisek Hrbata) [645770]
- [mm] oom: use pte pages in OOM score (Frantisek Hrbata) [645770]
- [kernel] lib, arch: add filter argument to show_mem and fix private implementations (Frantisek Hrbata) [645770]
- [mm] oom: suppress nodes that are not allowed from meminfo on page alloc failure (Frantisek Hrbata) [645770]
- [mm] oom: suppress show_mem() for many nodes in irq context on page alloc failure (Frantisek Hrbata) [645770]
- [mm] oom: suppress nodes that are not allowed from meminfo on oom kill (Frantisek Hrbata) [645770]
- [mm] oom: avoid deferring oom killer if exiting task is being traced (Frantisek Hrbata) [645770]
- [mm] oom: skip zombies when iterating tasklist (Frantisek Hrbata) [645770]
- [mm] oom: prevent unnecessary oom kills or kernel panics (Frantisek Hrbata) [645770]
- [mm] oom: allow a non-CAP_SYS_RESOURCE proces to oom_score_adj down (Frantisek Hrbata) [645770]
- [mm] oom: fix locking for oom_adj and oom_score_adj (Frantisek Hrbata) [645770]
- [mm] oom: rewrite error handling for oom_adj and oom_score_adj tunables (Frantisek Hrbata) [645770]
- [mm] oom: kill all threads sharing oom killed task's mm (Frantisek Hrbata) [645770]
- [mm] oom: avoid killing a task if a thread sharing its mm cannot be killed (Frantisek Hrbata) [645770]
- [mm] oom: add per-mm oom disable count (Frantisek Hrbata) [645770]
- [mm] oom: filter unkillable tasks from tasklist dump (Frantisek Hrbata) [645770]
- [mm] oom: always return a badness score of non-zero for eligible tasks (Frantisek Hrbata) [645770]
- [mm] oom: __task_cred() need rcu_read_lock() (Frantisek Hrbata) [645770]
- [mm] oom: fix tasklist_lock leak (Frantisek Hrbata) [645770]
- [mm] oom: fix NULL pointer dereference (Frantisek Hrbata) [645770]
- [mm] memcg: use find_lock_task_mm() in memory cgroups oom (Frantisek Hrbata) [645770]
- [mm] oom: badness heuristic rewrite (Frantisek Hrbata) [645770]
- [mm] oom: move badness() declaration into oom.h (Frantisek Hrbata) [645770]
- [mm] oom: multi threaded process coredump don't make deadlock (Frantisek Hrbata) [645770]
- [mm] oom: give the dying task a higher priority (Frantisek Hrbata) [645770]
- [mm] oom: remove child->mm check from oom_kill_process() (Frantisek Hrbata) [645770]
- [mm] oom: cleanup has_intersects_mems_allowed() (Frantisek Hrbata) [645770]
- [mm] oom: move OOM_DISABLE check from oom_kill_task to out_of_memory() (Frantisek Hrbata) [645770]
- [mm] oom: kill duplicate OOM_DISABLE check (Frantisek Hrbata) [645770]
- [mm] oom: /proc/<pid>/oom_score treat kernel thread honestly (Frantisek Hrbata) [645770]
- [mm] oom: oom_kill_process() needs to check that p is unkillable (Frantisek Hrbata) [645770]
- [mm] oom: make oom_unkillable_task() helper function (Frantisek Hrbata) [645770]
- [mm] oom: oom_kill_process() doesn't select kthread child (Frantisek Hrbata) [645770]
- [mm] oom: don't try to kill oom_unkillable child (Frantisek Hrbata) [645770]
- [mm] oom: fold __out_of_memory into out_of_memory (Frantisek Hrbata) [645770]
- [mm] oom: remove constraint argument from select_bad_process and __out_of_memory (Frantisek Hrbata) [645770]
- [mm] rename try_set_zone_oom() to try_set_zonelist_oom() (Frantisek Hrbata) [645770]
- [mm] oom: remove unnecessary code and cleanup (Frantisek Hrbata) [645770]
- [mm] oom: remove special handling for pagefault ooms (Frantisek Hrbata) [645770]
- [mm] oom: extract panic helper function (Frantisek Hrbata) [645770]
- [mm] oom: enable oom tasklist dump by default (Frantisek Hrbata) [645770]
- [mm] oom: select task from tasklist for mempolicy ooms (Frantisek Hrbata) [645770]
- [mm] oom: sacrifice child with highest badness score for parent (Frantisek Hrbata) [645770]
- [mm] oom: filter tasks not sharing the same cpuset (Frantisek Hrbata) [645770]
- [mm] oom: avoid sending exiting tasks a SIGKILL (Frantisek Hrbata) [645770]
- [mm] oom: give current access to memory reserves if it has been killed (Frantisek Hrbata) [645770]
- [mm] oom: dump_tasks use find_lock_task_mm too fix (Frantisek Hrbata) [645770]
- [mm] oom: improve commentary in dump_tasks() (Frantisek Hrbata) [645770]
- [mm] oom: dump_tasks use find_lock_task_mm too (Frantisek Hrbata) [645770]
- [mm] oom: introduce find_lock_task_mm() to fix !mm false positives (Frantisek Hrbata) [645770]
- [mm] oom: PF_EXITING check should take mm into account (Frantisek Hrbata) [645770]
- [mm] oom: check PF_KTHREAD instead of !mm to skip kthreads (Frantisek Hrbata) [645770]
- [mm] memcg: make oom killer a no-op when no killable task can be found (Frantisek Hrbata) [645770]
- [mm] memcg: handle panic_on_oom=always case (Frantisek Hrbata) [645770]
- [mm] oom-kill: dump_header takes task_struct as parameter (Frantisek Hrbata) [645770]
- [mm] oom-kill: fix NUMA constraint check with nodemask (Frantisek Hrbata) [645770]
- [mm] oom-kill: use task_lock when accessing task_struct members in __oom_kill_task (Frantisek Hrbata) [645770]
- [mm] oom: dump stack and VM state when oom killer panics (Frantisek Hrbata) [645770]
- [mm] Revert "[Fedora] [debug] add would_have_oomkilled procfs ctl" (Frantisek Hrbata) [645770]

* Wed Jul 27 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-173.el6]
- [mm] hold the page lock until after set_page_stable_node (Andrea Arcangeli) [683658]

* Tue Jul 26 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-172.el6]
- [netdrv] be2net: remove certain cmd failure logging (Ivan Vecera) [719304]
- [netdrv] enic driver update (Stefan Assmann) [695882]
- [net] nl80211: missing check for valid SSID size in scan operation (Stanislaw Gruszka) [718158] {CVE-2011-2517}
- [net] bluetooth: l2cap and rfcomm: fix 1 byte infoleak to userspace. (Thomas Graf) [703023] {CVE-2011-2492}
- [net] inet_diag: fix validation of user data in inet_diag_bc_audit() (Thomas Graf) [714541] {CVE-2011-2213}
- [fs] proc: restrict access to /proc/PID/io (Oleg Nesterov) [716830] {CVE-2011-2495}
- [fs] validate size of EFI GUID partition entries (Anton Arapov) [703030] {CVE-2011-1776}
- [fs] GFS2: Print warning rather than calling assert during direct I/O page invalidation race (Steven Whitehouse) [697019]
- [fs] ext4: Fix max file size and logical block counting of extent format file (Lukas Czerner) [722569] {CVE-2011-2695}
- [netdrv] e1000: remove unnecessary code (Dean Nelson) [694233]
- [netdrv] e1000: Add appropriate <linux/prefetch.h> include for prefetch users (Dean Nelson) [694233]
- [netdrv] e1000: more robust ethtool duplex/speed configuration (Dean Nelson) [694233]
- [netdrv] e1000: ethtool: cosmetic: Use ethtool ethtool_cmd_speed API (Dean Nelson) [694233]
- [netdrv] e1000: ethtool: Use full 32 bit speed range in ethtool's set_settings (Dean Nelson) [694233]
- [netdrv] e1000: fix sparse warning (Dean Nelson) [694233]
- [netdrv] e1000: add support for Marvell Alaska M88E1118R PHY (Dean Nelson) [694233]
- [netdrv] e1000: drivers/net: avoid some skb->ip_summed initializations (Dean Nelson) [694233]
- [fs] SUNRPC: Fix use of static variable in rpcb_getport_async (Steve Dickson) [723650]
- [fs] NFSv4.1: update nfs4_fattr_bitmap_maxsz (Steve Dickson) [723650]
- [fs] SUNRPC: Fix a race between work-queue and rpc_killall_tasks (Steve Dickson) [723650]
- [fs] SUNRPC: Ensure we always run the tk_callback before tk_action (Steve Dickson) [723650]
- [netdrv] e100: net: remove interrupt.h inclusion from netdevice.h (Dean Nelson) [694236]
- [netdrv] e100: fix build warning (Dean Nelson) [694236]
- [netdrv] e100: ethtool: Use full 32 bit speed range in ethtool's set_settings (Dean Nelson) [694236]
- [netdrv] e100: ethtool: cosmetic: Use ethtool ethtool_cmd_speed API (Dean Nelson) [694236]
- [netdrv] e100: ethtool: Call ethtool's get/set_settings callbacks with cleaned data (Dean Nelson) [694236]
- [netdrv] bna: Separate handling of irq type flags variable from the irq_flags request_irq variable (Ivan Vecera) [717011]
- [netdrv] Fix call trace when interrupts are disabled while sleeping function kzalloc is called (Ivan Vecera) [717011]
- [netdrv] Additional tg3 bug fixes (John Feeney) [695996 696004 696068 698308 705492 716693]
- [netdrv] Update tg3 to version 3.119 (John Feeney) [695996 696004 696068 698308 705492 716693]
- [netdrv] Update tg3 to version 3.118 (John Feeney) [695996 696004 696068 698308 705492 716693]
- [netdrv] Update tg3 to version 3.117 (John Feeney) [695996 696004 696068 698308 705492 716693]

* Thu Jul 21 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-171.el6]
- [virt] kvm: Disable device assignment without interrupt remapping (Alex Williamson) [711504] {CVE-2011-1898}
- [virt] iommu-api: Extension to check for interrupt remapping (Alex Williamson) [711504] {CVE-2011-1898}
- [net] core: add tracepoints for queueing skb to rcvbuf (Satoru Moriya) [696387]
- [net] udp: add tracepoints for queueing skb to rcvbuf (Satoru Moriya) [696387]
- [serial] 8250: Fix capabilities when changing the port type (Steve Best) [696695]
- [serial] 8250_pci: Add EEH support to the 8250 driver for IBM/Digi PCIe 2-port Adapter (Steve Best) [696695]
- [serial] 8250_pci: Add support for the Digi/IBM PCIe 2-port Adapter (Steve Best) [696695]
- [scsi] scsi_dh_rdac: Adding couple more vendor product ids (David Milburn) [690952]
- [scsi] lock pushdown in error handling (Rob Evers) [695542]
- [scsi] Reduce error recovery time by reducing use of TURs (Mike Christie) [691945]
- [scsi] Fix /proc/interrupts corruption when be2iscsi driver is loaded (Prarit Bhargava) [706511]
- [scsi] megaraid_sas: Disable interrupts/free_irq() in megasas_shutdown() (Tomas Henzl) [613564]
- [pci] ARI is a PCIe v2 feature (Don Dutile) [632086]
- [pci] add latency tolerance reporting enable/disable support (Myron Stowe) [696532]
- [pci] Assign values to 'pci_obff_signal_type' enumeration (Myron Stowe) [696534]
- [pci] add OBFF enable/disable support (Myron Stowe) [696534]
- [pci] add ID-based ordering enable/disable support (Myron Stowe) [696530]
- [fs] nfsd: fix NULL dereference in nfsd_statfs() (Eric Sandeen) [689223]
- [fs] add f_flags to struct statfs(64) (Eric Sandeen) [689223]
- [fs] pass a struct path to vfs_statfs (Eric Sandeen) [689223]
- [fs] Take statfs variants to fs/statfs.c (Eric Sandeen) [689223]
- [netdrv] tg3: Apply rx_discards fix to 5719/5720 (John Feeney) [696206]
- [netdrv] tg3: Fix stats for 5704 and later devices (John Feeney) [696206]
- [netdrv] tg3: Fix IPv6 TCP problems for 5719 (John Feeney) [696206]
- [netdrv] tg3: Fix int generation hw bug for 5719 / 5720 (John Feeney) [696206]
- [netdrv] tg3: Workaround rx_discards stat bug (John Feeney) [696206]
- [netdrv] tg3: Automatically size stat/test string arrays (John Feeney) [696206]
- [netdrv] tg3: Enable 5720 support (John Feeney) [696206]
- [netdrv] tg3: Add 5720 PHY ID (John Feeney) [696206]
- [netdrv] tg3: Add 5720 H2BMC support (John Feeney) [696206]
- [netdrv] tg3: Add 5720 NVRAM decoding (John Feeney) [696206]
- [netdrv] tg3: Add 5720 ASIC rev (John Feeney) [696206]
- [netdrv] tg3: Reintroduce 5717_PLUS (John Feeney) [696206]
- [netdrv] tg3: 5717_PLUS => 57765_PLUS (John Feeney) [696206]
- [netdrv] tg3: Add missed 5719 workaround change (John Feeney) [696206]
- [netdrv] tg3: Expand 5719 workaround (John Feeney) [696206]
- [netdrv] tg3: Disable multivec mode for 1 MSIX vector (John Feeney) [696206]
- [netdrv] tg3: Fix 5719 A0 tx completion bug (John Feeney) [696206]
- [netdrv] tg3: Revise 5719 internal FIFO overflow solution (John Feeney) [696206]
- [netdrv] tg3: Update version to 3.116 (John Feeney) [696206]
- [netdrv] tg3: use dma_alloc_coherent() instead of pci_alloc_consistent() (John Feeney) [696206]
- [netdrv] tg3: Always turn on APE features in mac_mode reg (John Feeney) [696206]
- [netdrv] tg3: Do not call device_set_wakeup_enable() under spin_lock_bh (John Feeney) [696206]
- [netdrv] vlan: Don't check for vlan group before vlan_tx_tag_present. (John Feeney) [696206]
- [netdrv] tg3: Update version to 3.115 (John Feeney) [696206]
- [netdrv] tg3: Report invalid link from tg3_get_settings() (John Feeney) [696206]
- [netdrv] tg3: Don't allocate jumbo ring for 5780 class devs (John Feeney) [696206]
- [netdrv] tg3: Cleanup tg3_alloc_rx_skb() (John Feeney) [696206]
- [netdrv] tg3: Disable unused transmit rings (John Feeney) [696206]
- [netdrv] tg3: Add support for selfboot format 1 v6 (John Feeney) [696206]
- [netdrv] net/tg3: simplify conditional (John Feeney) [696206]
- [netdrv] tg3: Update version to 3.114 (John Feeney) [696206]
- [netdrv] tg3: Futureproof the loopback test (John Feeney) [696206]
- [netdrv] tg3: Cleanup missing VPD partno section (John Feeney) [696206]
- [netdrv] tg3: Remove 5724 device ID (John Feeney) [696206]
- [netdrv] tg3: Fix potential netpoll crash (John Feeney) [696206]
- [netdrv] drivers/net: return operator cleanup (John Feeney) [696206]
- [netdrv] tg3: phy tmp variable roundup (John Feeney) [696206]
- [netdrv] tg3: Dynamically allocate VPD data memory (John Feeney) [696206]
- [netdrv] tg3: Use skb_is_gso_v6() (John Feeney) [696206]
- [netdrv] tg3: Move producer ring struct to tg3_napi (John Feeney) [696206]
- [netdrv] tg3: Clarify semantics of TG3_IRQ_MAX_VECS (John Feeney) [696206]
- [netdrv] tg3: Don't send APE events for NCSI firmware (John Feeney) [696206]
- [netdrv] drivers/net: avoid some skb->ip_summed initializations (John Feeney) [696206]
- [x86] x86, boot: Wait for boot cpu to show up if nr_cpus limit is about to hit (Vivek Goyal) [717918]
- [x86] x86: Fix and clean up generic_processor_info() (Vivek Goyal) [717918]
- [x86] x86, ia64, acpi: Clean up x86-ism in drivers/acpi/numa.c (Vivek Goyal) [717918]
- [x86] x86, acpi: Add MAX_LOCAL_APIC for 32bit (Vivek Goyal) [717918]
- [x86] x86, acpi: Parse all SRAT cpu entries even above the cpu number limitation (Vivek Goyal) [717918]
- [kernel] smp: Use nr_cpus= to set nr_cpu_ids early (Vivek Goyal) [717918]
- [mm] do not use page_count without a page pin (Andrea Arcangeli) [722565]
- [mm] improve isolate_lru_pages neighbour isolation (Andrea Arcangeli) [722565]
- [scsi] qla2xxx: Update driver version to 8.03.07.05.06.2-k. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Remove host_lock in queuecommand function (Chad Dupuis) [693744]
- [scsi] qla2xxx: Refactor call to qla2xxx_read_sfp for thermal temperature. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Unify the read/write sfp mailbox command routines. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Clear complete initialization control block. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Allow an override of the registered maximum LUN. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Add host number in reset and quiescent message logs. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Fix virtual port failing to login after chip reset. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Correctly read sfp single byte mailbox register. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Fix vport delete hang when logins are outstanding. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Fix hang during driver unload when vport is active. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Properly set the dsd_list_len for dsd_chaining in cmd type 6. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Correct buffer start in edc sysfs debug print. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Log if firmware fails to load from flash for ISP82xx. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Correction to sysfs edc interface. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Add qla82xx_rom_unlock() function. (Chad Dupuis) [693744]
- [scsi] qla2xxx: Update firmware version after flash update. (Chad Dupuis) [693744]
- [hwmon] hwmon: (coretemp) Fix section mismatch (Jane Lv) [709252]
- [hwmon] hwmon: (coretemp) Update comments describing the handling of HT CPUs (Jane Lv) [709252]
- [hwmon] hwmon: (coretemp) Add comments describing the handling of HT CPUs (Jane Lv) [709252]
- [hwmon] hwmon: (coretemp) Fix compile error if CONFIG_SMP is not defined (Jane Lv) [709252]
- [hwmon] hwmon: (coretemp) Fix checkpatch errors (Jane Lv) [709252]
- [hwmon] hwmon: Remove pkgtemp driver (Jane Lv) [709252]
- [hwmon] hwmon: (coretemp) Merge pkgtemp with coretemp (Jane Lv) [709252]
- [netdrv] igbvf driver update (Stefan Assmann) [694229]
- [netdrv] igb driver update (Stefan Assmann) [694211]
- [netdrv] r8169: fix Rx checksum offloading bugs (Ivan Vecera) [635596]
- [netdrv] be2net: changes for BE3 native mode support (Ivan Vecera) [695231]
- [net] bridge gets duplicate packets when using vlan over bonding (Flavio Leitner) [700610]
- [net] bonding: fix receiving of dups due vlan hwaccel (Flavio Leitner) [720689]
- [kernel] Fix nohz balance kick (Matthew Garrett) [695606]
- [kernel] repair gdbstub to match the gdbserial protocol specification (Prarit Bhargava) [710668]
- [misc] enclosure: fix error path to actually return ERR_PTR() on error (Tomas Henzl) [713730]
- [x86] fix memory leak in acpu_cpufreq_exit (Luming Yu) [688038]
- [x86] Ensure MTRR config is applied to all CPUs on resume (Matthew Garrett) [695612]

* Tue Jul 19 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-170.el6]
- [s390x] crypto: prng error in initial seed calculation. (Hendrik Brueckner) [709710]
- [s390x] qeth: serialize device removal and config changes (Hendrik Brueckner) [707293]
- [s390x] ap: Toleration for ap bus devices with device type 10 (Hendrik Brueckner) [694267]
- [s390x] chsc: process channel-path-availability information (Hendrik Brueckner) [694464]
- [s390x] kernel: Get CPC name (Hendrik Brueckner) [694265]
- [s390x] qeth: change some configurations defaults (Hendrik Brueckner) [694248]
- [s390x] crypto: Exploit z196 hardware accelerated crypto aplgorithms (Hendrik Brueckner) [694246]
- [s390x] dasd: do path verification for paths added at runtime (Hendrik Brueckner) [694460]
- [s390x] cio: notify drivers of channel path events (Hendrik Brueckner) [694460]
- [s390x] dasd: automatic recognition of read-only devices (Hendrik Brueckner) [633389]
- [s390x] dasd: Add support for raw ECKD access (Hendrik Brueckner) [633543]
- [s390x] kernel: diagnose 10 does not release memory above 2GB (Hendrik Brueckner) [701274]
- [s390x] qdio: reset error states immediately (Hendrik Brueckner) [700463]
- [s390x] dasd: check sense type in device change handler (Hendrik Brueckner) [700688]
- [s390x] dasd: fix race between open and offline (Hendrik Brueckner) [695677]
- [s390x] cio: prevent purging of CCW devices in the online state (Hendrik Brueckner) [695377]
- [s390x] kernel: missing ASLR for exec/heap/libc/vdso/mmap in s390x (Hendrik Brueckner) [647363]
- [ppc] nvram: Unbreak kABI, efficiency tweaks, remove unnecessary casts (Steve Best) [694509]
- [ppc] pseries/nvram: Capture oops/panic reports in ibm, oops-log partition (Steve Best) [694509]
- [ppc] nvram: Generalize code for OS partitions in NVRAM (Steve Best) [694509]
- [ppc] nvram: Handle partition names >= 12 chars (Steve Best) [694509]
- [ppc] nvram: Fix NVRAM partition list setup (Steve Best) [694509]
- [ppc] nvram: Rename ppc64, linux partition to ibm, rtas-log (Steve Best) [694509]
- [ppc] nvram: Move the log partition stuff to pseries (Steve Best) [694509]
- [ppc] nvram: Change nvram_setup_partition() to use new helper (Steve Best) [694509]
- [ppc] nvram: Add nvram_find_partition() (Steve Best) [694509]
- [ppc] nvram: Improve partition removal (Steve Best) [694509]
- [ppc] nvram: Shuffle code around in nvram_create_partition() (Steve Best) [694509]
- [ppc] nvram: Completely clear a new partition (Steve Best) [694509]
- [ppc] nvram: Ensure that the partition header/block size is right (Steve Best) [694509]
- [ppc] nvram: nvram_create_partitions() now uses bytes (Steve Best) [694509]
- [ppc] nvram: More flexible nvram_create_partition() (Steve Best) [694509]
- [ppc] nvram: Move things out of asm/nvram.h (Steve Best) [694509]
- [ppc] Fix continuation line formats (Steve Best) [694509]
- [ppc] Use unlocked ioctl in nvram_64 (Steve Best) [694509]
- [ppc] nvram_64: Mark init code __init (Steve Best) [694509]
- [ppc] nvram_64: Check nvram_error_log_index in nvram_clear_error_log() (Steve Best) [694509]
- [ppc] nvram_64: Remove unused code (Steve Best) [694509]
- [netdrv] qlge: Version change to v1.00.00.29 (Chad Dupuis) [713168]
- [netdrv] qlge: Fix printk priority so chip fatal errors are always reported. (Chad Dupuis) [713168]
- [netdrv] qlge: Fix crash caused by mailbox execution on wedged chip. (Chad Dupuis) [713168]
- [netdrv] qlge: make nic_operations struct const (Chad Dupuis) [713168]
- [netdrv] qlge: Fix incorrect usage of module parameters and netdev msg level (Chad Dupuis) [713168]
- [netdrv] qlge: Remove unnecessary casts of netdev_priv (Chad Dupuis) [713168]
- [fs] NFS: Detect loops in a readdir due to bad cookies (Steve Dickson) [720712]
- [fs] NFS: Create nfs_open_dir_context (Steve Dickson) [720712]
- [fs] NFS: Ensure that we update the readdir filp->f_pos correctly (Steve Dickson) [720712]
- [fs] GFS2: Get rid of metadata pages for inodes we can't deallocate (Robert S Peterson) [676626]
- [fs] GFS2: list_del_entry corruption (Robert S Peterson) [676626]
- [fs] GFS2: Fix ail list traversal (Robert S Peterson) [676626]
- [fs] GFS2: Add an AIL writeback tracepoint (Robert S Peterson) [676626]
- [fs] GFS2: Make writeback more responsive to system conditions (Robert S Peterson) [676626]
- [fs] GFS2: Improve tracing support (adds two flags) (Robert S Peterson) [676626]
- [fs] GFS2: Optimise glock lru and end of life inodes (Robert S Peterson) [676626]
- [fs] GFS2: Clean up fsync() (Robert S Peterson) [676626]
- [fs] fs: add sync_inode_metadata (Robert S Peterson) [676626]
- [fs] GFS2: Make ->write_inode() really write (Robert S Peterson) [676626]
- [fs] GFS2: Use filemap_fdatawrite() to write back the AIL (Robert S Peterson) [676626]
- [fs] GFS2: Alter point of entry to glock lru list for glocks with an address_space (Robert S Peterson) [676626]
- [fs] GFS2: Update to AIL list locking (Robert S Peterson) [676626]
- [fs] GFS2: introduce AIL lock (Robert S Peterson) [676626]
- [netdrv] bnx2: update to latest upstream (Neil Horman) [696756]
- [fs] cifs: don't allow cifs_reconnect to exit with NULL socket pointer (Jeff Layton) [711400]

* Fri Jul 15 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-169.el6]
- [x86] apic: Fix spurious error interrupts triggering on all non-boot APs (Prarit Bhargava) [712286]
- [x86] apic: Print verbose error interrupt reason on apic=debug (Prarit Bhargava) [712286]
- [mm] fix negative commitlimit when gigantic hugepages are allocated (Andrea Arcangeli) [704511]
- [mm] migrate: dont account swapcache as shmem (Andrea Arcangeli) [712260]
- [mm] compaction: Ensure that the compaction free scanner does not move to the next zone (Andrea Arcangeli) [712258]
- [mm] vmscan: correctly check if reclaimer should schedule during shrink_slab (Andrea Arcangeli) [712252]
- [virt] ksm: fix race between ksmd and exiting task (Andrea Arcangeli) [710341]
- [mm] thp: fix build with !SMP (Andrea Arcangeli) [711636]
- [kernel] !SMP build quirks fixes (Andrea Arcangeli) [711636]
- [kernel] allow sched.c to build with !SMP (Andrea Arcangeli) [711636]
- [net] dev.c: allow build when !SMP (Andrea Arcangeli) [711636]
- [virt] xen-netfront: send gARP after backend moved to XenbusStateConnected (Laszlo Ersek) [713585]
- [x86] UV: add_smp_affinity_list (George Beshers) [696422]
- [pci] aer-inject: Override PCIe AER Mask Registers (Prarit Bhargava) [719373]
- [kernel] proc: signedness issue in next_pidmap() (Jerome Marchand) [697825] {CVE-2011-1593}
- [net] bluetooth: Prevent buffer overflow in l2cap config request (Jiri Pirko) [716810] {CVE-2011-2497}
- [netdrv] cnic: Move indexing function pointers to struct kcq_info (Mike Christie) [696757]
- [netdrv] cnic, bnx2: Check iSCSI support early in bnx2_init_one() (Mike Christie) [696757]
- [netdrv] cnic: Improve NETDEV_UP event handling (Mike Christie) [696757]
- [netdrv] cnic: Randomize initial TCP port for iSCSI connections (Mike Christie) [696757]
- [netdrv] cnic: Fix race conditions with firmware (Mike Christie) [696757]
- [netdrv] cnic: Fix interrupt logic (Mike Christie) [696757]
- [netdrv] Add appropriate <linux/prefetch.h> include for prefetch users (Mike Christie) [696757]

* Tue Jul 12 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-168.el6]
- [fs] NFS41: do not update isize if inode needs layoutcommit (Steve Dickson) [714740]
- [fs] NFSv4.1: Clean ups for the device id cache (Steve Dickson) [714740]
- [net] igmp: call ip_mc_clear_src() only when we have no users of ip_mc_list (Thomas Graf) [707479]
- [net] bridge: fix bridging to properly recieve/forward ipv6 RA's (Neil Horman) [716263]
- [net] sctp: ABORT if receive, reassmbly, or reodering queue is not empty while closing socket (Thomas Graf) [705840]
- [net] sctp: Enforce retransmission limit during shutdown (Thomas Graf) [705840]
- [net] netfilter: Enable CONFIG_NETFILTER_XT_SET and CONFIG_IP_SET (Thomas Graf) [599054]
- [net] netfilter: ipset: Use the stored first cidr value instead of '1' (Thomas Graf) [599054]
- [net] netfilter: ipset: Fix return code for destroy when sets are in use (Thomas Graf) [599054]
- [net] netfilter: ipset: fix ip_set_flush return code (Thomas Graf) [599054]
- [net] netfilter: ipset: remove unused variable from type_pf_tdel() (Thomas Graf) [599054]
- [net] netfilter: ipset: Use proper timeout value to jiffies conversion (Thomas Graf) [599054]
- [net] netfilter: ipset: Fix the order of listing of sets (Thomas Graf) [599054]
- [net] netfilter: ipset: SCTP, UDPLITE support added (Thomas Graf) [599054]
- [net] netfilter: ipset: set match and SET target fixes (Thomas Graf) [599054]
- [net] netfilter: ipset: bitmap:ip, mac type requires "src" for MAC (Thomas Graf) [599054]
- [net] netfilter: ipset: remove extra semicolons (Thomas Graf) [599054]
- [net] netfilter: ipset: references are protected by rwlock instead of mutex (Thomas Graf) [599054]
- [net] netfilter: ipset: list:set timeout variant fixes (Thomas Graf) [599054]
- [net] netfilter: ipset: Fix common misspellings (Thomas Graf) [599054]
- [net] netfilter: ipset: References are protected by rwlock instead of mutex (Thomas Graf) [599054]
- [net] netfilter: ipset: list:set timeout variant fixes (Thomas Graf) [599054]
- [net] netfilter: ipset: fix checking the type revision at create command (Thomas Graf) [599054]
- [net] netfilter: ipset: fix address ranges at hash:*port* types (Thomas Graf) [599054]
- [net] netfilter: ipset: fix the compile warning in ip_set_create (Thomas Graf) [599054]
- [net] netfilter: ipset: add dependency on CONFIG_NETFILTER_NETLINK (Thomas Graf) [599054]
- [net] netfilter: ipset: send error message manually (Thomas Graf) [599054]
- [net] netfilter: ipset: fix linking with CONFIG_IPV6=n (Thomas Graf) [599054]
- [net] netfilter: ipset: add missing break statemtns in ip_set_get_ip_port() (Thomas Graf) [599054]
- [net] netfilter: ipset: install ipset related header files (Thomas Graf) [599054]
- [net] netfilter: ipset: remove unnecessary includes (Thomas Graf) [599054]
- [net] netfilter: ipset: use nla_parse_nested() (Thomas Graf) [599054]
- [net] netfilter: xtables: "set" match and "SET" target support (Thomas Graf) [599054]
- [net] netfilter: ipset: list:set set type support (Thomas Graf) [599054]
- [net] netfilter: ipset: hash:net, port set type support (Thomas Graf) [599054]
- [net] netfilter: ipset: hash:net set type support (Thomas Graf) [599054]
- [net] netfilter: ipset: hash:ip, port, net set type support (Thomas Graf) [599054]
- [net] netfilter: ipset: hash:ip, port, ip set type support (Thomas Graf) [599054]
- [net] netfilter: ipset: hash:ip, port set type support (Thomas Graf) [599054]
- [net] netfilter: ipset: hash:ip set type support (Thomas Graf) [599054]
- [net] netfilter: ipset; bitmap:port set type support (Thomas Graf) [599054]
- [net] netfilter: ipset: bitmap:ip,mac type support (Thomas Graf) [599054]
- [net] netfilter: ipset: bitmap:ip set type support (Thomas Graf) [599054]
- [net] netfilter: ipset: IP set core support (Thomas Graf) [599054]
- [net] netfilter: NFNL_SUBSYS_IPSET id and NLA_PUT_NET* macros (Thomas Graf) [599054]
- [net] ipv6: Prepare the tree for un-inlined jhash. (Thomas Graf) [599054]
- [kernel] The new jhash implementation (Thomas Graf) [599054]
- [fs] cifs: fix wsize negotiation to respect max buffer size and active signing (try #4) (Jeff Layton) [708000]
- [fs] cifs: clean up wsize negotiation and allow for larger wsize (Jeff Layton) [708000]
- [fs] cifs: convert cifs_writepages to use async writes (Jeff Layton) [708000]
- [fs] cifs: convert async write callback to slow_work (Jeff Layton) [708000]
- [fs] cifs: add cifs_async_writev (Jeff Layton) [708000]
- [fs] cifs: don't call mid_q_entry->callback under the Global_MidLock (try #5) (Jeff Layton) [708000]
- [fs] cifs: add ignore_pend flag to cifs_call_async (Jeff Layton) [708000]
- [fs] cifs: make cifs_send_async take a kvec array (Jeff Layton) [708000]
- [fs] cifs: consolidate SendReceive response checks (Jeff Layton) [708000]
- [fs] cifs: don't allow mmap'ed pages to be dirtied while under writeback (try #3) (Jeff Layton) [708000]
- [fs] cifs: turn BCC into a static inlined function (Jeff Layton) [692709]
- [fs] cifs: keep BCC in little-endian format (Jeff Layton) [692709]
- [fs] cifs: consistently use smb_buf_length as be32 for cifs (try 3) (Jeff Layton) [692709]
- [fs] CIFS: Add match_port check during looking for an existing connection (try #4) (Jeff Layton) [692709]
- [fs] CIFS: Simplify ipv*_connect functions into one (try #4) (Jeff Layton) [692709]
- [fs] cifs: fix cifsConvertToUCS() for the mapchars case (Jeff Layton) [692709]
- [fs] cifs: handle errors from coalesce_t2 (Jeff Layton) [692709]
- [fs] cifs: refactor mid finding loop in cifs_demultiplex_thread (Jeff Layton) [692709]
- [fs] cifs: sanitize length checking in coalesce_t2 (try #3) (Jeff Layton) [692709]
- [fs] cifs: check for bytes_remaining going to zero in CIFS_SessSetup (Jeff Layton) [692709]
- [fs] cifs: change bleft in decode_unicode_ssetup back to signed type (Jeff Layton) [692709]
- [fs] cifs: Fix memory over bound bug in cifs_parse_mount_options (Jeff Layton) [692709]
- [fs] cifs: clean up various nits in unicode routines (try #2) (Jeff Layton) [692709]
- [fs] cifs: clean up length checks in check2ndT2 (Jeff Layton) [692709]
- [fs] cifs: fix broken BCC check in is_valid_oplock_break (Jeff Layton) [692709]
- [fs] cifs: always do is_path_accessible check in cifs_mount (Jeff Layton) [692709]
- [fs] cifs: add check for kmalloc in parse_dacl (Jeff Layton) [692709]
- [fs] cifs: various endian fixes to cifs (Jeff Layton) [692709]
- [fs] cifs: simplify SMB header check routine (Jeff Layton) [692709]
- [fs] cifs: fix up CIFSSMBEcho for unaligned access (Jeff Layton) [692709]
- [fs] cifs: fix unaligned accesses in cifsConvertToUCS (Jeff Layton) [692709]
- [fs] cifs: clean up unaligned accesses in cifs_unicode.c (Jeff Layton) [692709]
- [fs] cifs: fix unaligned access in check2ndT2 and coalesce_t2 (Jeff Layton) [692709]
- [fs] cifs: clean up unaligned accesses in validate_t2 (Jeff Layton) [692709]
- [fs] cifs: use get/put_unaligned functions to access ByteCount (Jeff Layton) [692709]
- [fs] cifs: fix up KConfig options with latest changes (Jeff Layton) [668791]
- [fs] cifs: mark CONFIG_CIFS_NFSD_EXPORT as BROKEN (Jeff Layton) [668791]
- [fs] cifs: Don't compile in unused reparse point symlink code (Jeff Layton) [668791]
- [fs] cifs: Remove unused CIFSSMBNotify worker function (Jeff Layton) [668791]
- [fs] cifs: cleanup: Rename and remove config flags (Jeff Layton) [668791]
- [fs] cifs: replace /proc/fs/cifs/Experimental with a module parm (Jeff Layton) [668791]
- [fs] cifs: move "ntlmssp" and "local_leases" options out of experimental code (Jeff Layton) [668791]
- [fs] cifs: fix use of CONFIG_CIFS_ACL (Jeff Layton) [668791]
- [fs] cifs: Handle extended attribute name cifs_acl to generate cifs acl blob (try #4) (Jeff Layton) [668791]
- [fs] cifs: Misc. cleanup in cifsacl handling [try #4] (Jeff Layton) [668791]
- [fs] cifs: Percolate error up to the caller during get/set acls [try #4] (Jeff Layton) [668791]
- [fs] cifs: Fix lease break for writes (Jeff Layton) [668791]
- [fs] cifs: clarify the meaning of tcpStatus == CifsGood (Jeff Layton) [654198]
- [fs] cifs: don't always drop malformed replies on the floor (try #3) (Jeff Layton) [654198]
- [fs] cifs: Possible slab memory corruption while updating extended stats (repost) (Jeff Layton) [654198]
- [fs] cifs: clean up checks in cifs_echo_request (Jeff Layton) [654198]
- [fs] cifs: Do not send SMBEcho requests on new sockets until SMBNegotiate (Jeff Layton) [654198]
- [fs] cifs: remove checks for ses->status == CifsExiting (Jeff Layton) [654198]
- [fs] cifs: don't send an echo request unless NegProt has been done (Jeff Layton) [654198]
- [fs] cifs: enable signing flag in SMB header when server has it on (Jeff Layton) [654198]
- [fs] cifs: fix length vs. total_read confusion in cifs_demultiplex_thread (Jeff Layton) [654198]
- [fs] cifs: fix length checks in checkSMB (Jeff Layton) [654198]
- [fs] cifs: force a reconnect if there are too many MIDs in flight (Jeff Layton) [654198]
- [fs] cifs: don't pop a printk when sending on a socket is interrupted (Jeff Layton) [654198]
- [fs] cifs: send an NT_CANCEL request when a process is signalled (Jeff Layton) [654198]
- [fs] cifs: handle cancelled requests better (Jeff Layton) [654198]
- [fs] cifs: mangle existing header for SMB_COM_NT_CANCEL (Jeff Layton) [654198]
- [fs] cifs: remove code for setting timeouts on requests (Jeff Layton) [654198]
- [fs] cifs: reconnect unresponsive servers (Jeff Layton) [654198]
- [fs] cifs: set up recurring workqueue job to do SMB echo requests (Jeff Layton) [654198]
- [fs] cifs: add ability to send an echo request (Jeff Layton) [654198]
- [fs] cifs: add cifs_call_async (Jeff Layton) [654198]
- [fs] cifs: allow for different handling of received response (Jeff Layton) [654198]
- [fs] cifs: clean up sync_mid_result (Jeff Layton) [654198]
- [fs] cifs: don't reconnect server when we don't get a response (Jeff Layton) [654198]
- [fs] cifs: wait indefinitely for responses (Jeff Layton) [654198]
- [fs] cifs: move mid result processing into common function (Jeff Layton) [654198]
- [fs] cifs: move locked sections out of DeleteMidQEntry and AllocMidQEntry (Jeff Layton) [654198]
- [fs] cifs: clean up accesses to midCount (Jeff Layton) [654198]
- [fs] cifs: make wait_for_free_request take a TCP_Server_Info pointer (Jeff Layton) [654198]
- [fs] cifs: no need to mark smb_ses_list as cifs_demultiplex_thread is exiting (Jeff Layton) [654198]
- [fs] cifs: don't fail writepages on -EAGAIN errors (Jeff Layton) [654198]
- [fs] cifs: free blkcipher in smbhash (Jeff Layton) [662626]
- [fs] cifs: correctly handle NULL tcon pointer in CIFSTCon (Jeff Layton) [662626]
- [fs] cifs: show sec= option in /proc/mounts (Jeff Layton) [662626]
- [fs] cifs: silence printk when establishing first session on socket (Jeff Layton) [662626]
- [fs] cifs: Fix extended security auth failure (Jeff Layton) [662626]
- [fs] cifs: make CIFS depend on CRYPTO_ECB (Jeff Layton) [662626]
- [fs] cifs: Use ecb des kernel crypto APIs instead of local cifs functions (repost) (Jeff Layton) [662626]
- [fs] cifs: wrap received signature check in srv_mutex (Jeff Layton) [662626]
- [fs] cifs: Max share size is too small (Jeff Layton) [662626]
- [fs] cifs: Allow user names longer than 32 bytes (Jeff Layton) [662626]
- [fs] cifs: Fix regression in LANMAN (LM) auth code (Jeff Layton) [662626]
- [fs] cifs: No need to check crypto blockcipher allocation (Jeff Layton) [662626]
- [fs] cifs: make CIFS depend on CRYPTO_MD4 (Jeff Layton) [662626]
- [fs] cifs: fix two compiler warning about uninitialized vars (Jeff Layton) [662626]
- [fs] cifs: More crypto cleanup (try #2) (Jeff Layton) [662626]
- [fs] cifs: Replace cifs md5 hashing functions with kernel crypto APIs (Jeff Layton) [662626]
- [fs] cifs: Fix regression during share-level security mounts (Jeff Layton) [662626]
- [fs] cifs: remove unnecessary locking around sequence_number (Jeff Layton) [662626]
- [fs] cifs: Support NTLM2 session security during NTLMSSP authentication [try #5] (Jeff Layton) [662626]
- [fs] cifs: fs/cifs/Kconfig: CIFS depends on CRYPTO_HMAC (Jeff Layton) [662626]
- [fs] cifs: Cleanup and thus reduce smb session structure and fields used during authentication (Jeff Layton) [662626]
- [fs] cifs: NTLM auth and sign - Use appropriate server challenge (Jeff Layton) [662626]
- [fs] cifs: NTLM auth and sign - minor error corrections and cleanup (Jeff Layton) [662626]
- [fs] cifs: fix module refcount leak in find_domain_name (Jeff Layton) [662626]
- [fs] cifs: NTLM auth and sign - Use kernel crypto apis to calculate hashes and smb signatures (Jeff Layton) [662626]
- [fs] cifs: NTLM auth and sign - Define crypto hash functions and create and send keys needed for key exchange (Jeff Layton) [662626]
- [fs] cifs: NTLM auth and sign - Allocate session key/client response dynamically (Jeff Layton) [662626]
- [fs] cifs: ntlm authentication and signing - Correct response length for ntlmv2 authentication without extended security (Jeff Layton) [662626]
- [fs] cifs: convert cifs_tcp_ses_lock from a rwlock to a spinlock (Jeff Layton) [662626]
- [fs] cifs: Clean up two declarations of blob_len (Jeff Layton) [662626]
- [fs] cifs: NTLM authentication and signing - Calculate auth response per smb session (Jeff Layton) [662626]
- [fs] cifs: ntlm authentication and signing - Build a proper av/ti pair blob for ntlmv2 without extended security authentication (Jeff Layton) [662626]
- [fs] cifs: NTLMv2/NTLMSSP ntlmv2 within ntlmssp autentication code (Jeff Layton) [662626]
- [fs] cifs: NTLMv2/NTLMSSP Change variable name mac_key to session key to reflect the key it holds (Jeff Layton) [662626]
- [fs] cifs: ntlmv2/ntlmssp remove-unused-function CalcNTLMv2_partial_mac_key (Jeff Layton) [662626]

* Thu Jul 07 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-167.el6]
- [block] initialise bd_super in bdget() (Lachlan McIlroy) [718107]
- [virt] Revert "virtio balloon: kill tell-host-first logic" (Aristeu Rozanski) [712044]
- [fs] NLM: Don't hang forever on NLM unlock requests (Jeff Layton) [709549]
- [x86] x86-64: Only set max_pfn_mapped to 512 MiB if we enter via head_64.S (Igor Mammedov) [716498]
- [virt] xen: correct size of level2_kernel_pgt (Igor Mammedov) [716498]
- [virt] Unset CONFIG_DEBUG_FORCE_WEAK_PER_CPU on x86/x86_64 platforms (Igor Mammedov) [716498]
- [virt] xen: bump memory limit for x86 domU PV guest to 128Gb (Igor Mammedov) [716498]
- [virt] xen: annotate functions which only call into __init at start of day (Igor Mammedov) [716498]
- [virt] xen: correctly rebuild mfn list list after migration (Igor Mammedov) [716498]
- [virt] xen: don't map missing memory (Igor Mammedov) [716498]
- [virt] xen: defer building p2m mfn structures until kernel is mapped (Igor Mammedov) [716498]
- [virt] xen: add return value to set_phys_to_machine() (Igor Mammedov) [716498]
- [virt] xen: allocate level1_ident_pgt (Igor Mammedov) [716498]
- [virt] xen: use early_brk for level2_kernel_pgt (Igor Mammedov) [716498]
- [virt] xen: convert p2m to a 3 level tree (Igor Mammedov) [716498]
- [virt] xen: make install_p2mtop_page() static (Igor Mammedov) [716498]
- [virt] xen: set shared_info->arch.max_pfn to max_p2m_pfn (Igor Mammedov) [716498]
- [virt] xen: allocate p2m size based on actual max size (Igor Mammedov) [716498]
- [virt] xen: dynamically allocate p2m space (Igor Mammedov) [716498]
- [x86] add RESERVE_BRK_ARRAY() helper (Igor Mammedov) [716498]
- [edac] Correct MiB_TO_PAGES() macro (Mauro Carvalho Chehab) [633935]
- [edac] amd64_edac: Erratum #637 workaround (Frank Arnold) [633935]
- [edac] amd64_edac: Factor in CC6 save area (Frank Arnold) [633935]
- [edac] amd64_edac: Remove node interleave warning (Frank Arnold) [633935]
- [edac] Remove debugging output in scrub rate handling (Frank Arnold) [633935]
- [edac] amd64_edac: Fix potential memleak (Frank Arnold) [633935]
- [edac] amd64_edac: Fix decode_syndrome types (Frank Arnold) [633935]
- [edac] amd64_edac: Fix DCT argument type (Frank Arnold) [633935]
- [edac] amd64_edac: Fix ranges signedness (Frank Arnold) [633935]
- [edac] amd64_edac: Drop local variable (Frank Arnold) [633935]
- [edac] amd64_edac: Fix PCI config addressing types (Frank Arnold) [633935]
- [edac] amd64_edac: Fix DRAM base macros (Frank Arnold) [633935]
- [edac] amd64_edac: Fix node id signedness (Frank Arnold) [633935]
- [edac] amd64_edac: Drop redundant declarations (Frank Arnold) [633935]
- [edac] amd64_edac: Enable driver on F15h (Frank Arnold) [633935]
- [pci] Rename CPU PCI id define (Frank Arnold) [633935]
- [edac] amd64_edac: Adjust ECC symbol size to F15h (Frank Arnold) [633935]
- [edac] amd64_edac: Simplify scrubrate setting (Frank Arnold) [633935]
- [edac] amd64_edac: Improve DRAM address mapping (Frank Arnold) [633935]
- [edac] amd64_edac: Sanitize ->read_dram_ctl_register (Frank Arnold) [633935]
- [edac] amd64_edac: Adjust sys_addr to chip select conversion routine to F15h (Frank Arnold) [633935]
- [edac] amd64_edac: Beef up early exit reporting (Frank Arnold) [633935]
- [edac] amd64_edac: Revamp online spare handling (Frank Arnold) [633935]
- [edac] amd64_edac: Fix channel interleave removal (Frank Arnold) [633935]
- [edac] amd64_edac: Correct node interleaving removal (Frank Arnold) [633935]
- [edac] amd64_edac: Add support for interleaved region swapping (Frank Arnold) [633935]
- [edac] amd64_edac: Unify get_error_address (Frank Arnold) [633935]
- [edac] amd64_edac: Simplify decoding path (Frank Arnold) [633935]
- [edac] amd64_edac: Adjust channel counting to F15h (Frank Arnold) [633935]
- [edac] amd64_edac: Cleanup old defines cruft (Frank Arnold) [633935]
- [edac] amd64_edac: Cleanup NBSH cruft (Frank Arnold) [633935]
- [edac] amd64_edac: Cleanup NBCFG handling (Frank Arnold) [633935]
- [edac] amd64_edac: Cleanup NBCTL code (Frank Arnold) [633935]
- [edac] amd64_edac: Cleanup DCT Select Low/High code (Frank Arnold) [633935]
- [edac] amd64_edac: Cleanup Dram Configuration registers handling (Frank Arnold) [633935]
- [edac] amd64_edac: Cleanup DBAM handling (Frank Arnold) [633935]
- [edac] amd64_edac: Replace huge bitmasks with a macro (Frank Arnold) [633935]
- [edac] amd64_edac: Sanitize f10_get_base_addr_offset (Frank Arnold) [633935]
- [edac] amd64_edac: Sanitize channel extraction (Frank Arnold) [633935]
- [edac] amd64_edac: Cleanup chipselect handling (Frank Arnold) [633935]
- [edac] amd64_edac: Cleanup DHAR handling (Frank Arnold) [633935]
- [edac] amd64_edac: Remove DRAM base/limit subfields caching (Frank Arnold) [633935]
- [edac] amd64_edac: Add support for F15h DCT PCI config accesses (Frank Arnold) [633935]
- [edac] amd64_edac: Fix DIMMs per DCTs output (Frank Arnold) [633935]
- [edac] MCE: Fix NB error formatting (Frank Arnold) [633935]
- [edac] MCE: Use BIT_64() to eliminate warnings on 32-bit (Frank Arnold) [633935]
- [edac] MCE: Enable MCE decoding on F15h (Frank Arnold) [633935]
- [edac] MCE: Allow F15h bank 6 MCE injection (Frank Arnold) [633935]
- [edac] MCE: Shorten error report formatting (Frank Arnold) [633935]
- [edac] MCE: Overhaul error fields extraction macros (Frank Arnold) [633935]
- [edac] MCE: Add F15h FP MCE decoder (Frank Arnold) [633935]
- [edac] MCE: Add F15 EX MCE decoder (Frank Arnold) [633935]
- [edac] MCE: Add an F15h NB MCE decoder (Frank Arnold) [633935]
- [edac] MCE: No F15h LS MCE decoder (Frank Arnold) [633935]
- [edac] MCE: Add F15h CU MCE decoder (Frank Arnold) [633935]
- [edac] MCE: Add F15h IC MCE decoder (Frank Arnold) [633935]
- [edac] MCE: Add F15h DC MCE decoder (Frank Arnold) [633935]
- [edac] MCE: Select extended error code mask (Frank Arnold) [633935]
- [edac] amd64_edac: Disable DRAM ECC injection on K8 (Frank Arnold) [633935]
- [edac] Fixup scrubrate manipulation (Frank Arnold) [633935]
- [edac] amd64_edac: Remove two-stage initialization (Frank Arnold) [633935]
- [edac] amd64_edac: Check ECC capabilities initially (Frank Arnold) [633935]
- [edac] amd64_edac: Carve out ECC-related hw settings (Frank Arnold) [633935]
- [edac] amd64_edac: Remove PCI ECS enabling functions (Frank Arnold) [633935]
- [edac] amd64_edac: Allocate driver instances dynamically (Frank Arnold) [633935]
- [edac] amd64_edac: Rework printk macros (Frank Arnold) [633935]
- [edac] amd64_edac: Rename CPU PCI devices (Frank Arnold) [633935]
- [edac] amd64_edac: Concentrate per-family init even more (Frank Arnold) [633935]
- [edac] amd64_edac: Cleanup the CPU PCI device reservation (Frank Arnold) [633935]
- [edac] amd64_edac: Simplify CPU family detection (Frank Arnold) [633935]
- [edac] amd64_edac: Add per-family init function (Frank Arnold) [633935]
- [edac] amd64_edac: Use cached extended CPU model (Frank Arnold) [633935]
- [edac] amd64_edac: Remove F11h support (Frank Arnold) [633935]
- [edac] amd64_edac: Fix interleaving check (Frank Arnold) [633935]
- [edac] MCE: Fix edac_init_mce_inject error handling (Frank Arnold) [633935]
- [edac] MCE: Fix shift warning on 32-bit (Frank Arnold) [633935]
- [edac] MCE: Add a BIT_64() macro (Frank Arnold) [633935]
- [edac] MCE: Enable MCE decoding on F12h (Frank Arnold) [633935]
- [edac] MCE: Add F12h NB MCE decoder (Frank Arnold) [633935]
- [edac] MCE: Add F12h IC MCE decoder (Frank Arnold) [633935]
- [edac] MCE: Add F12h DC MCE decoder (Frank Arnold) [633935]
- [edac] MCE: Add support for F11h MCEs (Frank Arnold) [633935]
- [edac] MCE: Enable MCE decoding on F14h (Frank Arnold) [633935]
- [edac] MCE: Fix FR MCEs decoding (Frank Arnold) [633935]
- [edac] MCE: Complete NB MCE decoders (Frank Arnold) [633935]
- [edac] MCE: Warn about LS MCEs on F14h (Frank Arnold) [633935]
- [edac] MCE: Adjust IC decoders to F14h (Frank Arnold) [633935]
- [edac] MCE: Adjust DC decoders to F14h (Frank Arnold) [633935]
- [edac] MCE: Rename files (Frank Arnold) [633935]
- [edac] MCE: Rework MCE injection (Frank Arnold) [633935]
- [edac] Export edac sysfs class to users (Frank Arnold) [633935]
- [edac] EDAC: Fix error return (Frank Arnold) [633935]
- [x86] EDAC, MCE: Pass complete MCE info to decoders (Frank Arnold) [633935]
- [x86] EDAC, MCE: Sanitize error codes (Frank Arnold) [633935]
- [x86] EDAC, MCE: Remove unused function parameter (Frank Arnold) [633935]
- [x86] EDAC, MCE: Add HW_ERR prefix (Frank Arnold) [633935]
- [x86] amd64_edac: Do not report error overflow as a separate error (Frank Arnold) [633935]
- [x86] MCE, AMD: Limit MCE decoding to current families for now (Frank Arnold) [633935]
- [x86] amd64_edac: Minor formatting fix (Frank Arnold) [633935]
- [x86] amd64_edac: Fix operator precendence error (Frank Arnold) [633935]
- [x86] edac, mc: Improve scrub rate handling (Frank Arnold) [633935]
- [x86] amd64_edac: Correct scrub rate setting (Frank Arnold) [633935]
- [x86] amd64_edac: Fix DCT base address selector (Frank Arnold) [633935]
- [x86] amd64_edac: Remove polling mechanism (Frank Arnold) [633935]
- [x86] amd64_edac: Remove unneeded defines (Frank Arnold) [633935]
- [edac] amd64_edac: Sanitize syndrome extraction (Frank Arnold) [633935]
- [x86] amd64_edac: Fix syndrome calculation on K8 (Frank Arnold) [633935]

* Wed Jul 06 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-166.el6]
- [x86] efi: Default to virtual mode (Matthew Garrett) [695859]
- [x86] Backport upstream EFI fixups (Matthew Garrett) [695859]
- [x86] bootmem: Add free_bootmem_late() (Matthew Garrett) [695859]
- [x86] UV: warnings on slowpath (George Beshers) [699763]
- [scsi] cxgb3i: fix EEH error on ppc due to invalid page size computation (Neil Horman) [714325]
- [block] elevator: fix O_DIRECT I/O starving readers (Jeff Moyer) [587402]
- [fs] NFS: Fix NFSv3 exclusive open semantics (Jeff Layton) [694210]
- [fs] GFS2: Incorrect inode state during deallocation (Steven Whitehouse) [712139]
- [net] tcp: Increase the initial congestion window to 10. (Thomas Graf) [667754]
- [net] TCP: update initial windows according to RFC 5681 (Thomas Graf) [667754]
- [net] tcp/dccp: Consolidate common code for RFC 3390 conversion (Thomas Graf) [667754]

* Fri Jul 01 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-165.el6]
- [v4l] Remove the old V4L1 v4lgrab.c file (Don Zickus) [714183]
- [scsi] libfc, fcoe: Remove usage of the Scsi_Host's host_lock (Rob Evers) [695542]
- [scsi] Host lock pushdown using Scsi_Host flag (Rob Evers) [695542]
- [drm] drm backport from 3.0-rc3 + fixes (Dave Airlie) [713621]
- [drm] agp: backport intel driver from 3.0-rc3 (Dave Airlie) [713621]
- [drm] Backport gpu VGA drivers from 3.0-rc3 (Dave Airlie) [713620]
- [x86] x86/platform: backport MXM driver from 3.0-rc3 (Dave Airlie) [713620]
- [kernel] kref: Add a kref_sub function (Dave Airlie) [713620]
- [kernel] Move round_up/down to kernel.h (Dave Airlie) [713620]
- [virt] virtio-blk: fix request leak (Amit Shah) [694553]
- [virt] virtio_blk: Add 'serial' attribute to virtio-blk devices (Amit Shah) [694553]
- [virt] Add virtio disk identification support (Amit Shah) [694553]
- [mm] remove is_hwpoison_address (Dean Nelson) [696095]
- [virt] KVM: Replace is_hwpoison_address with __get_user_pages (Dean Nelson) [696095]
- [mm] make __get_user_pages return -EHWPOISON for HWPOISON page optionally (Dean Nelson) [696095]
- [mm] export __get_user_pages (Dean Nelson) [696095]
- [ppc] kexec: Check crash_base for relocatable kernel (Steve Best) [713868]
- [scsi] ibmvfc: Fix Virtual I/O failover hang (Steve Best) [710497]
- [tty] Clean console safely (Frantisek Hrbata) [714684]
- [kernel] build: backport LSMOD=file for localmodconfig (Andrew Jones)
- [perf] x86: Add Intel SandyBridge CPU support (Neil Horman) [695608]
- [block] cfq-iosched: Fix locking around ioc->ioc_data assignment (Vivek Goyal) [716520]
- [x86] AMD IOMMU: Re-enable AMD IOMMU (Alex Williamson) [716553]
- [virt] KVM: Fix register corruption in pvclock_scale_delta (Avi Kivity) [712102]
- [virt] Mask dangerous features when running as xen guest hvm (Igor Mammedov) [711317]
- [virt] virtio balloon: kill tell-host-first logic (Amit Shah) [712044]

* Tue Jun 28 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-164.el6]
- [fs] nfs: set lock context and fix error handling in new DIO functions (Jeff Layton) [694309]
- [net] ipv6: Fix tcp_v6_send_response transport header setting (Jiri Olsa) [702508]
- [netdrv] iwlwifi: fix general 11n instability (Stanislaw Gruszka) [714590]
- [netdrv] ehea: Fix memory hotplug oops (Steve Best) [702036]
- [netdrv] tun: do not put self in waitq if doing a nonblock read (Amos Kong) [713612]
- [fs] ext4: check for a good block group before loading buddy pages (Eric Sandeen) [652262]
- [fs] Bouncing locks in a cluster is slow in GFS2 (Robert S Peterson) [663356]
- [fs] NFSv4.1: do not use deviceids after MDS clientid invalidation (Steve Dickson) [714740]
- [fs] NFSv4.1: Fix a refcounting issue in the pNFS device id cache (Steve Dickson) [714740]
- [fs] NFSv4.1: deprecate headerpadsz in CREATE_SESSION (Steve Dickson) [714740]
- [fs] NFSv4.1: allow zero fh array in filelayout decode layout (Steve Dickson) [714740]
- [fs] NFSv4.1: allow nfs_fhget to succeed with mounted on fileid (Steve Dickson) [714740]
- [fs] NFS: fix umount of pnfs filesystems (Steve Dickson) [714740]
- [fs] NFSv4.1: use layout driver in global device cache (Steve Dickson) [714740]
- [fs] pnfs: CB_NOTIFY_DEVICEID (Steve Dickson) [714740]
- [fs] NFSv4.1: purge deviceid cache on nfs_free_client (Steve Dickson) [714740]
- [fs] NFSv4.1: make deviceid cache global (Steve Dickson) [714740]
- [fs] NFSv4.1: Correct offset for LAYOUTCOMMIT (Steve Dickson) [714740]
- [fs] NFSv4: Ensure we request the ordinary fileid when doing readdirplus (Steve Dickson) [714740]
- [net] TCP: increase default initial receive window. (Thomas Graf) [664725]
- [net] tcp: Bug fix in initialization of receive window. (Thomas Graf) [664725]
- [net] tcp: update also tcp_output with regard to RFC 5681 (Thomas Graf) [664725]

* Fri Jun 24 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-163.el6]
- [net] Fix memory leak/corruption on VLAN GRO_DROP (Herbert Xu) [695176] {CVE-2011-1576}
- [block] cfq-iosched: Set group_isolation=1 by default (Vivek Goyal) [707757]
- [scsi] cciss: Annotate cciss_kdump_soft_reset and cciss_sent_reset as __devinit (Tomas Henzl) [698268]
- [scsi] cciss: Don't wait forever for soft reset to complete, give up after awhile (Tomas Henzl) [698268]
- [scsi] cciss: use cmd_alloc not cmd_special_alloc for the kdump soft reset command (Tomas Henzl) [698268]
- [scsi] cciss: do not use bit 2 doorbell reset (Tomas Henzl) [698268]
- [scsi] cciss: do not attempt PCI power management reset method if we know it won't work (Tomas Henzl) [698268]
- [scsi] cciss: increase timeouts for post-reset no-ops (Tomas Henzl) [698268]
- [scsi] cciss: remove superfluous sleeps around reset code (Tomas Henzl) [698268]
- [scsi] cciss: do soft reset if hard reset is broken (Tomas Henzl) [698268]
- [scsi] cciss: clarify messages around reset behavior (Tomas Henzl) [698268]
- [scsi] cciss: increase time to wait for board reset to start (Tomas Henzl) [698268]
- [scsi] cciss: factor out irq_request code (Tomas Henzl) [698268]
- [scsi] cciss: factor out scatterlist allocation functions (Tomas Henzl) [698268]
- [scsi] cciss: factor out command pool allocation functions (Tomas Henzl) [698268]
- [scsi] cciss: use new doorbell-bit-5 reset method (Tomas Henzl) [698268]
- [scsi] cciss: wait longer for no-op to complete after resetting controller (Tomas Henzl) [698268]
- [scsi] cciss: do a better job of detecting controller reset failure (Tomas Henzl) [698268]
- [scsi] hpsa: do not attempt PCI PM reset if we know it will not work (Tomas Henzl) [698268]
- [scsi] hpsa: remove superfluous sleeps around reset code (Tomas Henzl) [698268]
- [scsi] hpsa: do soft reset if hard reset is broken (Tomas Henzl) [698268]
- [scsi] hpsa: clarify messages around reset behavior (Tomas Henzl) [698268]
- [scsi] hpsa: factor out irq request code (Tomas Henzl) [698268]
- [scsi] hpsa: factor out cmd_pool allocation functions (Tomas Henzl) [698268]
- [scsi] hpsa: do not use bit 2 doorbell reset, it causes NMIs (Tomas Henzl) [698268]
- [scsi] hpsa: wait longer for no-op to complete after resetting controller (Tomas Henzl) [698268]
- [scsi] hpsa: use new doorbell-bit-5 reset method (Tomas Henzl) [698268]
- [scsi] hpsa: adjust timing of post-reset sleeps (Tomas Henzl) [698268]
- [scsi] hpsa: do a better job of detecting controller reset failure (Tomas Henzl) [698268]
- [usb] xhci: Remove some unnecessary casts and tidy some endian swap code (Steve Best) [693903]
- [usb] xhci: Remove recursive call to xhci_handle_event (Steve Best) [693903]
- [usb] xhci: Add an assertion to check for virt_dev=0 bug (Steve Best) [693903]
- [usb] xhci: Add rmb() between reading event validity & event data access (Steve Best) [693903]
- [usb] xhci: Make xHCI driver endian-safe (Steve Best) [693903]
- [hwmon] setting CONFIG_THERMAL_HWMON as built in (Dean Nelson) [619044]
- [hwmon] thermal framework: fix crash during hwmon unregister (Dean Nelson) [619044]
- [md] Fix resync hang after surprise removal (James Paradis) [707268]
- [pci] Skip id checking if no id is passed (Prarit Bhargava) [714044]
- [pci] Make PCIe error handling boot messages less scary (Prarit Bhargava) [710291]

* Fri Jun 24 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-162.el6]
- [virt] xen: bump memory limit for x86_64 domU PV guest to 128Gb (Igor Mammedov) [669739]

* Wed Jun 22 2011 Kyle McMartin <kmcmarti@redhat.com> [2.6.32-161.el6]
- [kernel] perf evlist: Fix per thread mmap setup (Jiri Olsa) [691343]
- [kernel] perf tools: Honour the cpu list parameter when also monitoring a thread list (Jiri Olsa) [691343]
- [kernel] perf evsel: Fix use of inherit (Jiri Olsa) [691343]
- [kernel] perf hists browser: Fix seg fault when annotate null symbol (Jiri Olsa) [691343]
- [kernel] perf probe: Fix listing incorrect line number with inline function (Jiri Olsa) [691343]
- [kernel] perf probe: Fix to find recursively inlined function (Jiri Olsa) [691343]
- [kernel] perf probe: Fix multiple --vars options behavior (Jiri Olsa) [691343]
- [kernel] perf probe: Fix to remove redundant close (Jiri Olsa) [691343]
- [kernel] perf probe: Fix to ensure function declared file (Jiri Olsa) [691343]
- [kernel] perf: mmap 512 kiB by default (Jiri Olsa) [691343]
- [kernel] perf tools: Emit clearer message for sys_perf_event_open ENOENT return (Jiri Olsa) [691343]
- [kernel] perf tools: Fixup exit path when not able to open events (Jiri Olsa) [691343]
- [kernel] perf tools: Fix NO_NEWT=1 python build error (Jiri Olsa) [691343]
- [kernel] perf symbols: Properly align symbol_conf.priv_size (Jiri Olsa) [691343]
- [kernel] perf symbols: Fix vsyscall symbol lookup (Jiri Olsa) [691343]
- [kernel] perf symbols: Look at .dynsym again if .symtab not found (Jiri Olsa) [691343]
- [kernel] perf build-id: Add quirk to deal with perf.data file format breakage (Jiri Olsa) [691343]
- [kernel] perf session: Pass evsel in event_ops->sample() (Jiri Olsa) [691343]
- [kernel] perf top: Fix uninitialized 'counter' variable (Jiri Olsa) [691343]
- [kernel] perf lock: Fix sorting by wait_min (Jiri Olsa) [691343]
- [kernel] perf tools: Version incorrect with some versions of grep (Jiri Olsa) [691343]
- [kernel] perf evlist: New command to list the names of events present in a perf.data file (Jiri Olsa) [691343]
- [kernel] perf script: Add support for H/W and S/W events (Jiri Olsa) [691343]
- [kernel] perf script: Add support for dumping symbols (Jiri Olsa) [691343]
- [kernel] perf script: Support custom field selection for output (Jiri Olsa) [691343]
- [kernel] perf script: Move printing of 'common' data from print_event and rename (Jiri Olsa) [691343]
- [kernel] perf tracing: Remove print_graph_cpu and print_graph_proc from trace-event-parse (Jiri Olsa) [691343]
- [kernel] perf script: Change process_event prototype (Jiri Olsa) [691343]
- [kernel] perf stat: Provide support for filters (Jiri Olsa) [691343]
- [kernel] perf symbol: Move sym_entry->skip to symbol->ignore (Jiri Olsa) [691343]
- [kernel] perf symbols: Rename dso->origin to dso->symtab_type (Jiri Olsa) [691343]
- [kernel] perf top: Remove redundant syme->origin field (Jiri Olsa) [691343]
- [kernel] perf top: Remove redundant perf_top->sym_counter (Jiri Olsa) [691343]
- [kernel] perf probe: Clean up probe_point_lazy_walker() return value (Jiri Olsa) [691343]
- [kernel] perf header: Stop using 'self' (Jiri Olsa) [691343]
- [kernel] perf session: Use evlist/evsel for managing perf.data attributes (Jiri Olsa) [691343]
- [kernel] perf top: Don't let events to eat up whole header line (Jiri Olsa) [691343]
- [kernel] perf top: Fix events overflow in top command (Jiri Olsa) [691343]
- [kernel] perf report tui: Improve multi event session support (Jiri Olsa) [691343]
- [kernel] perf tools: Improve support for sessions with multiple events (Jiri Olsa) [691343]
- [kernel] perf evlist: Split perf_evlist__id_hash (Jiri Olsa) [691343]
- [kernel] perf hists browser: Handle browsing empty hists tree (Jiri Olsa) [691343]
- [kernel] perf hists: Remove needless global col lenght calcs (Jiri Olsa) [691343]
- [kernel] perf report tui: Fix multi event switching (Jiri Olsa) [691343]
- [kernel] perf: Fix undefined PyVarObject_HEAD_INIT in python 2.5 (Jiri Olsa) [691343]
- [kernel] perf: Fix missing strndup declaration (Jiri Olsa) [691343]
- [kernel] perf: Set filters before mmaping events (Jiri Olsa) [691343]
- [kernel] perf top tui: Wait till the first sample to refresh the screen. (Jiri Olsa) [691343]
- [kernel] perf top: Fix reporting of invalid --vmlinux (Jiri Olsa) [691343]
- [kernel] perf tui: Make ui__warning modal (Jiri Olsa) [691343]
- [kernel] perf top browser: Handle empty active symbols list (Jiri Olsa) [691343]
- [kernel] perf ui browser: Introduce ui_browser__show_title (Jiri Olsa) [691343]
- [kernel] perf top browser: Fix up exit keys (Jiri Olsa) [691343]
- [kernel] perf annotate: Show better message when no vmlinux is found (Jiri Olsa) [691343]
- [kernel] perf lock: Document valid sort keys (Jiri Olsa) [691343]
- [kernel] perf top browser: Adjust the browser indexes when refreshing (Jiri Olsa) [691343]
- [kernel] perf top: Live TUI Annotation (Jiri Olsa) [691343]
- [kernel] perf probe: Remove redundant checks (Jiri Olsa) [691343]
- [kernel] perf evsel: Fix inverted test for fixing up attr.inherit flag (Jiri Olsa) [691343]
- [kernel] perf probe: Fix error propagation leading to segfault (Jiri Olsa) [691343]
- [kernel] perf tools: Makefile: Remove various and sundry cruft (Jiri Olsa) [691343]
- [kernel] perf tools: Makefile: Remove tool-specific cruft (Jiri Olsa) [691343]
- [kernel] perf tools: Makefile: Remove platform-specific cruft (Jiri Olsa) [691343]
- [kernel] perf tools: Makefile: Remove vestigial git-specific cruft (Jiri Olsa) [691343]
- [kernel] perf list: Allow filtering list of events (Jiri Olsa) [691343]
- [kernel] perf report: Tell the user when a perf.data file has no samples (Jiri Olsa) [691343]
- [kernel] perf record: Delay setting the header writing atexit call (Jiri Olsa) [691343]
- [kernel] perf: make perf stat print user provided full event names (Jiri Olsa) [691343]
- [kernel] perf probe: Show filename which contains target function (Jiri Olsa) [691343]
- [kernel] perf probe: Support function@filename syntax for --line (Jiri Olsa) [691343]
- [kernel] perf tools: Update Makefile with some help (Jiri Olsa) [691343]
- [kernel] perf annotate browser: Use the percent color for the whole line (Jiri Olsa) [691343]
- [kernel] perf annotate: Check if offset is less than symbol size (Jiri Olsa) [691343]
- [kernel] perf ui: Serialize screen updates (Jiri Olsa) [691343]
- [kernel] perf report: Fix initializion of annotate symbol priv area (Jiri Olsa) [691343]
- [kernel] perf annotate: Fix annotate context lines regression (Jiri Olsa) [691343]
- [kernel] perf annotate: Move locking to struct annotation (Jiri Olsa) [691343]
- [kernel] perf annotate: Fix --stdio rendering (Jiri Olsa) [691343]
- [kernel] perf probe: Add bitfield member support (Jiri Olsa) [691343]
- [kernel] perf tool: Fix gcc 4.6.0 issues (Jiri Olsa) [691343]
- [kernel] perf probe: Rewrite find_lazy_match_lines() by using getline(3) (Jiri Olsa) [691343]
- [kernel] perf top: Use pid_t for target_{pid|tid} (Jiri Olsa) [691343]
- [kernel] perf tools: Makefile: Use $(QUIET_GEN) for perf.so (Jiri Olsa) [691343]
- [kernel] perf top: Ditch private annotation code, share perf annotate's (Jiri Olsa) [691343]
- [kernel] perf annotate: Separate objdump parsing from actual screen rendering (Jiri Olsa) [691343]
- [kernel] perf annotate: Config options for symbol__tty_annotate (Jiri Olsa) [691343]
- [kernel] perf annotate: Support multiple histograms in annotation (Jiri Olsa) [691343]
- [kernel] perf annotate: Move annotate functions to util/ (Jiri Olsa) [691343]
- [kernel] perf top: Remove superfluous name_len field (Jiri Olsa) [691343]
- [kernel] perf top: Fix TUI compilation (Jiri Olsa) [691343]
- [kernel] perf tools: Don't try to build python bindings if Python.h not available (Jiri Olsa) [691343]
- [kernel] perf stat: Fix up resource release order (Jiri Olsa) [691343]
- [kernel] perf tools: Fix up 'make clean' target (Jiri Olsa) [691343]
- [kernel] perf tools: Remove verbose build messages for the python binding (Jiri Olsa) [691343]
- [kernel] perf python: Fix build on 32-bit (Jiri Olsa) [691343]
- [kernel] perf probe: Use td for pointer arithmetic result (Jiri Olsa) [691343]
- [kernel] perf top: Introduce slang based TUI (Jiri Olsa) [691343]
- [kernel] perf tools: Don't fallback to setup_pager unconditionally (Jiri Olsa) [691343]
- [kernel] perf top: Move display agnostic routines to util/top.[ch] (Jiri Olsa) [691343]
- [kernel] perf evlist: Store pointer to the cpu and thread maps (Jiri Olsa) [691343]
- [kernel] perf evlist: Move evlist methods to evlist.c (Jiri Olsa) [691343]
- [kernel] perf tools: Initial python binding (Jiri Olsa) [691343]
- [kernel] perf tools: Kill event_t typedef, use 'union perf_event' instead (Jiri Olsa) [691343]
- [kernel] perf tools: Rename 'struct sample_data' to 'struct perf_sample' (Jiri Olsa) [691343]
- [kernel] perf top: Switch to non overwrite mode (Jiri Olsa) [691343]
- [kernel] perf evlist: Support non overwrite mode in perf_evlist__read_on_cpu (Jiri Olsa) [691343]
- [kernel] perf events: Account PERF_RECORD_LOST events in event__process (Jiri Olsa) [691343]
- [kernel] perf record: No need to check for overwrites (Jiri Olsa) [691343]
- [kernel] perf test: Fix return values checking (Jiri Olsa) [691343]
- [kernel] perf probe: Add filters support for available functions (Jiri Olsa) [691343]
- [kernel] perf probe: Add variable filter support (Jiri Olsa) [691343]
- [kernel] perf tools: Add strfilter for general purpose string filter (Jiri Olsa) [691343]
- [kernel] perf evsel: Introduce perf_evsel__{in, ex}it (Jiri Olsa) [691343]
- [kernel] perf tools: Move event__parse_sample to evsel.c (Jiri Olsa) [691343]
- [kernel] perf threads: Move thread_map to separate file (Jiri Olsa) [691343]
- [kernel] perf tools: Pass the struct opt to the wildcard parsing routine (Jiri Olsa) [691343]
- [kernel] perf record: auto detect when stdout is a pipe (Jiri Olsa) [691343]
- [kernel] perf probe: Add --funcs to show available functions in symtab (Jiri Olsa) [691343]
- [kernel] perf probe: Enable to put probe inline function call site (Jiri Olsa) [691343]
- [kernel] perf probe: Introduce lines walker interface (Jiri Olsa) [691343]
- [kernel] perf top: Add native_safe_halt to skip symbols (Jiri Olsa) [691343]
- [kernel] perf callchain: Don't give arbitrary gender to callchain tree nodes (Jiri Olsa) [691343]
- [kernel] perf callchain: Rename register_callchain_param into callchain_register_param (Jiri Olsa) [691343]
- [kernel] perf callchain: Rename cumul_hits into callchain_cumul_hits (Jiri Olsa) [691343]
- [kernel] perf callchain: Feed callchains into a cursor (Jiri Olsa) [691343]
- [kernel] perf test: Add test for the evlist mmap routines (Jiri Olsa) [691343]
- [kernel] perf evlist: Steal mmap reading routine from 'perf top' (Jiri Olsa) [691343]
- [kernel] perf test: check if cpu_map__new() return NULL (Jiri Olsa) [691343]
- [kernel] perf test: Check counts on all cpus in test__open_syscall_event_on_all_cpus (Jiri Olsa) [691343]
- [kernel] perf tools: Add missing cpu_map__delete() (Jiri Olsa) [691343]
- [kernel] perf record: Use perf_evlist__mmap (Jiri Olsa) [691343]
- [kernel] perf evlist: Move the mmap array from perf_evsel (Jiri Olsa) [691343]
- [kernel] perf record: Move perf_mmap__write_tail to perf.h (Jiri Olsa) [691343]
- [kernel] perf record: Use struct perf_mmap and helpers (Jiri Olsa) [691343]
- [kernel] perf evsel: Introduce mmap support (Jiri Olsa) [691343]
- [kernel] perf record: Use perf_evsel__open (Jiri Olsa) [691343]
- [kernel] perf top: Use perf_evsel__open (Jiri Olsa) [691343]
- [kernel] perf evsel: Allow specifying if the inherit bit should be set (Jiri Olsa) [691343]
- [kernel] perf evsel: Support event groups (Jiri Olsa) [691343]
- [kernel] perf evlist: Adopt the pollfd array (Jiri Olsa) [691343]
- [kernel] perf evsel: Introduce perf_evlist (Jiri Olsa) [691343]
- [kernel] perf record: Enable counters only when kernel is execing subcommand (Jiri Olsa) [691343]

* Fri Jun 17 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-160.el6]
- [audit] ia32entry.S sign extend error codes when calling 64 bit code (Eric Paris) [703935]
- [audit] push audit success and retcode into arch ptrace.h (Eric Paris) [703935]

* Wed Jun 15 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-159.el6]
- [net] force new skbs to allocate a minimum of 16 frags (Neil Horman) [694307]
- [net] rtnetlink: ignore NETDEV_RELEASE and NETDEV_JOIN event (Amerigo Wang) [587751]
- [net] net: rename NETDEV_BONDING_DESLAVE to NETDEV_RELEASE (Amerigo Wang) [587751]
- [net] netpoll: disable netpoll when enslave a device (Amerigo Wang) [587751]
- [net] netconsole: clarify stopping message (Amerigo Wang) [587751]
- [net] netconsole: don't announce stopping if nothing happened (Amerigo Wang) [587751]
- [net] bond: service netpoll arp queue on master device (Amerigo Wang) [587751]
- [net] net: Convert netpoll blocking api in bonding driver to be a counter (Amerigo Wang) [587751]
- [net] netpoll: Remove netpoll blocking from uninit path (Amerigo Wang) [587751]
- [net] bonding: Fix deadlock in bonding driver resulting from internal locking when using netpoll (Amerigo Wang) [587751]
- [net] bonding: Fix bonding drivers improper modification of netpoll structure (Amerigo Wang) [587751]
- [net] Revert "[net] Revert "[net] bonding: make bonding support netpoll"" (Amerigo Wang) [587751]
- [net] bonding: documentation and code cleanup for resend_igmp (Flavio Leitner) [698506]
- [virt] KVM: make guest mode entry to be rcu quiescent state (Gleb Natapov) [712653]
- [virt] rcu: provide rcu_virt_note_context_switch() function (Gleb Natapov) [712653]
- [fs] cifs: display fsc in /proc/mounts (Jeff Layton) [646224]
- [fs] cifs: enable fscache iff fsc mount option is used explicitly (Jeff Layton) [646224]
- [fs] cifs: allow fsc mount option only if CONFIG_CIFS_FSCACHE is set (Jeff Layton) [646224]
- [x86] intel-iommu: Flush unmaps at domain_exit (Alex Williamson) [705441]
- [x86] intel-iommu: Only unlink device domains from iommu (Alex Williamson) [705441]
- [watchdog] iTCO_wdt: TCO Watchdog patch for Intel Panther Point PCH (Prarit Bhargava) [695792]
- [i2c] i2c-i801: SMBus patch for Intel Panther Point DeviceIDs (Prarit Bhargava) [695792]
- [ata] ahci: AHCI-mode SATA patch for Intel Panther Point DeviceIDs (Prarit Bhargava) [695792]
- [ata] ata_piix: IDE-mode SATA patch for Intel Panther Point DeviceIDs (Prarit Bhargava) [695792]
- [pci] lpc: irq and pci_ids patch for Intel DH89xxCC DeviceIDs (Prarit Bhargava) [695792]
- [x86] perf: Fix AMD family 15h FPU event constraints (Frank Arnold) [698739]
- [x86] perf: Fix pre-defined cache-misses event for AMD family 15h cpus (Frank Arnold) [698739]
- [fs] GFS2: force a log flush when invalidating the rindex glock (Benjamin Marzinski) [702263]
- [fs] GFS2: remove potential race in flock code (Steven Whitehouse) [612608]
- [fs] gfs2: Call gfs2_meta_wipe for directory hash blocks (Abhijith Das) [706614]
- [ppc] remove exec-shield (Steve Best) [655688]
- [ppc] perf_event: Skip updating kernel counters if register value shrinks (Steve Best) [706528]
- [fs] nfs: coalesce small, page-aligned direct I/Os (Jeff Layton) [694309]
- [x86] Reboot via ACPI when appropriate (Matthew Garrett) [677476]
- [virt] xen: drop xen_sched_clock in favour of using plain wallclock time (Igor Mammedov) [711326]
- [virt] kvm: device-assignment: Disable the option to skip iommu setup (Alex Williamson) [710192]
- [virt] x86: Mask out unsupported CPUID features if running on xen (Igor Mammedov) [703055]
- [netdrv] ixgbe: add MACVLAN support (Neil Horman) [694254]
- [block] fix accounting bug on cross partition merges (Jerome Marchand) [669363]
- [block] blk-cgroup: Initialize ioc->cgroup_changed at ioc creation time (Vivek Goyal) [707755]
- [block] cfq-iosched: Fix a memory leak of per cpu stats for root group (Vivek Goyal) [707755]
- [block] blk-throttle: Make no throttling rule group processing lockless (Vivek Goyal) [707755]
- [block] blk-cgroup: Make cgroup stat reset path blkg->lock free for dispatch stats (Vivek Goyal) [707755]
- [block] blk-cgroup: Make 64bit per cpu stats safe on 32bit arch (Vivek Goyal) [707755]
- [block] blk-throttle: Make dispatch stats per cpu (Vivek Goyal) [707755]
- [block] blk-throttle: Free up a group only after one rcu grace period (Vivek Goyal) [707755]
- [block] blk-throttle: Use helper function to add root throtl group to lists (Vivek Goyal) [707755]
- [block] blk-throttle: Introduce a helper function to fill in device details (Vivek Goyal) [707755]
- [block] blk-throttle: Dynamically allocate root group (Vivek Goyal) [707755]
- [block] blk-cgroup: Allow sleeping while dynamically allocating a group (Vivek Goyal) [707755]
- [block] cfq-iosched: Fix a possible race with cfq cgroup removal code (Vivek Goyal) [707755]
- [block] cfq-iosched: Get rid of redundant function parameter "create" (Vivek Goyal) [707755]
- [block] blk-throttle: Do the new group initialization with the help of a function (Vivek Goyal) [707755]
- [net] u64_stats_fetch_begin_bh() and u64_stats_fetch_retry_bh() (Vivek Goyal) [707755]
- [net] u64_stats_sync improvements (Vivek Goyal) [707755]
- [net] Introduce u64_stats_sync infrastructure (Vivek Goyal) [707755]
- [block] cfq: Remove useless css reference get (Vivek Goyal) [707762]
- [block] cfq: don't use atomic_t for cfq_group (Vivek Goyal) [707762]
- [block] cfq: don't use atomic_t for cfq_queue (Vivek Goyal) [707762]
- [block] blk-throttle: Use task_subsys_state() to determine a task's blkio_cgroup (Vivek Goyal) [698094]
- [block] Store return Value of xchg() to supress compiler warning (Vivek Goyal) [707755]
- [block] blk-throttle: don't call xchg on bool (Vivek Goyal) [707762]
- [block] blk-throttle: Reset group slice when limits are changed (Vivek Goyal) [707762]
- [block] blk-throttle: Some cleanups and race fixes in limit update code (Vivek Goyal) [707762]
- [block] blk-throttle: process limit change only through one function (Vivek Goyal) [707762]
- [block] Move blk_throtl_exit() call to blk_cleanup_queue() (Vivek Goyal) [707762]
- [block] Initialize ->queue_lock to internal lock at queue allocation time (Vivek Goyal) [707762]
- [block] blk-throttle: Correct the placement of smp_rmb() (Vivek Goyal) [707762]
- [block] Revert "[block] blk-throttle: Correct the placement of smp_rmb()" (Vivek Goyal) [707762]

* Tue Jun 14 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-158.el6]
- [net] vlan: remove multiqueue ability from vlan device (Neil Horman) [703245]
- [kernel] cgroupfs: use init_cred when populating new cgroupfs mount (Eric Paris) [700538]

* Sun Jun 12 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-157.el6]
- [block] don't delay blk_run_queue_async (Mike Snitzer) [708542]
- [scsi] remove performance regression due to async queue run (Mike Snitzer) [708542]
- [block] get rid of QUEUE_FLAG_REENTER (Mike Snitzer) [708542]
- [block] flush-merge RHELisms (Mike Snitzer) [672988]
- [block] share request flush fields with elevator_private (Mike Snitzer) [672988]
- [ata] libata: enable non-queueable flush flag (Mike Snitzer) [672988]
- [ata] libata: set queue DMA alignment to sector size for ATAPI too (Mike Snitzer) [672988]
- [ata] libata: support for > 512 byte sectors (e.g. 4K Native) (Mike Snitzer) [672988]
- [block] hold queue if flush is running for non-queueable flush drive (Mike Snitzer) [672988]
- [block] add a non-queueable flush flag (Mike Snitzer) [672988]
- [block] Add sysfs documentation for the discard topology parameters (Mike Snitzer) [697995]
- [block] Fix discard topology stacking and reporting (Mike Snitzer) [697995]
- [scsi] sd: retry read_capacity on UNIT_ATTENTION (Mike Snitzer) [697995]
- [ata] libata: Use Maximum Write Same Length to report discard size limit (Mike Snitzer) [697995]
- [block] add blk_run_queue_async (Mike Snitzer) [672988]
- [block] add API for delaying work/request_fn a little bit (Mike Snitzer) [672988]
- [block] make the flush insertion use the tail of the dispatch list (Mike Snitzer) [672988]
- [block] skip elevator initialization for flush requests (Mike Snitzer) [672988]
- [block] reimplement FLUSH/FUA to support merge (Mike Snitzer) [672988]
- [block] improve flush bio completion (Mike Snitzer) [672988]
- [block] add REQ_FLUSH_SEQ (Mike Snitzer) [672988]
- [block] blk-flush shouldn't call directly into q->request_fn() (Mike Snitzer) [672988]
- [block] add @force_kblockd to __blk_run_queue() (Mike Snitzer) [672988]
- [scsi] sd: Fail discard requests when logical block provisioning has been disabled (Mike Snitzer) [697995]
- [scsi] scsi_debug: Logical Block Provisioning (Mike Snitzer) [697995]
- [scsi] sd: Logical Block Provisioning update (Mike Snitzer) [697995]
- [block] Consolidate min_not_zero (Mike Snitzer) [697995]
- [ata] libata: Signal that our SATL supports WRITE SAME(16) with UNMAP (Mike Snitzer) [697995]
- [dm] improve block integrity support (Mike Snitzer) [697992]
- [dm] mpath: integrity errors should not cause failover (Mike Snitzer) [697992]
- [block] Require subsystems to explicitly allocate bio_set integrity mempool (Mike Snitzer) [697992]
- [kernel] Include protection operation in SCSI command trace (Mike Snitzer) [697992]
- [kernel] tracing: scsi: sync with upstream scsi tracing (Mike Snitzer) [697992]
- [block] biovec_slab not needed for CONFIG_BLK_DEV_INTEGRITY (Mike Snitzer) [697992]
- [block] Make the integrity mapped property a bio flag (Mike Snitzer) [697992]
- [block] Fix double free in blk_integrity_unregister (Mike Snitzer) [697992]
- [scsi] Fix printing of failed 32-byte commands (Mike Snitzer) [697992]
- [scsi] sd: Combine DIF/DIX error handling (Mike Snitzer) [697992]
- [scsi] fix propagation of errors other than EIO (Mike Snitzer) [698655]
- [netdrv] ixgbe: adding FdirMode module option (Andy Gospodarek) [707287]
- [crypto] testmgr: add xts-aes-256 self-test (Jarod Wilson) [706167]
- [fs] ext3: Fix lost extented attributes for inode with ino == 11 (Eric Sandeen) [662666]
- [fs] ext4: Fix possible lost inode write in no journal mode (Lukas Czerner) [699151]
- [ppc] pseries: Add page coalescing support (Steve Best) [694530]
- [x86] ACPI/ACPICA: Fix global lock acquisition (Frank Arnold) [601120]
- [block] dm: add missing RAID45 Makefile bits (Aristeu Rozanski) [700772]
- [netdrv] netjet: blacklist Digium TDM400P (Prarit Bhargava) [700343]
- [virt] xenpv: mask MWAIT cpuid feature (Andrew Jones) [712131]
- [fs] NFSv4.1: Ensure that layoutget uses the correct gfp modes (Steve Dickson) [701788]
- [fs] Cleanup XDR parsing for LAYOUTGET, GETDEVICEINFO (Steve Dickson) [701788]
- [fs] NFSv4.1: remove pnfs_layout_hdr from pnfs_destroy_all_layouts tmp_list (Steve Dickson) [701788]
- [fs] NFSv41: Resend on NFS4ERR_RETRY_UNCACHED_REP (Steve Dickson) [701788]
- [fs] nfs: Don't mark_inode_dirty_sync() while holding lock (Steve Dickson) [701788]
- [fs] SUNRPC: Deal with the lack of a SYN_SENT sk->sk_state_change callback (Steve Dickson) [701788]
- [fs] SUNRPC: Never reuse the socket port after an xs_close() (Steve Dickson) [701788]
- [fs] NFSv4: Ensure that clientid and session establishment can time out (Steve Dickson) [701788]
- [fs] RPC: killing RPC tasks races fixed (Steve Dickson) [701788]
- [fs] nfs: don't lose MS_SYNCHRONOUS on remount of noac mount (Steve Dickson) [701788]
- [fs] SUNRPC: Allow RPC calls to return ETIMEDOUT instead of EIO (Steve Dickson) [701788]
- [fs] NFSv4.1: Don't loop forever in nfs4_proc_create_session (Steve Dickson) [701788]
- [fs] NFSv4.1: Don't update sequence number if rpc_task is not sent (Steve Dickson) [701788]
- [fs] NFSv4.1: Ensure state manager thread dies on last umount (Steve Dickson) [701788]
- [fs] SUNRPC: Fix the SUNRPC Kerberos V RPCSEC_GSS module dependencies (Steve Dickson) [701788]
- [fs] NFS: Eliminate duplicate call to nfs_mark_request_dirty (Steve Dickson) [701788]
- [fs] NFS: NFSv4 readdir loses entries (Steve Dickson) [701788]
- [fs] NFS: Don't use vm_map_ram() in readdir (Steve Dickson) [701788]
- [x86] AMD, cacheinfo: Fix L3 cache index disable checks (Frank Arnold) [638748]
- [x86] amd-nb: Convert spaces to tabs in amd_nb.c (Frank Arnold) [638748]
- [x86] amd-nb: Misc cleanliness fixes (Frank Arnold) [638748]
- [x86] amd: Support L3 Cache Partitioning on AMD family 0x15 CPUs (Frank Arnold) [638748]
- [x86] amd: Extend AMD northbridge caching code to support "Link Control" devices (Frank Arnold) [638748]
- [x86] amd: Enable L3 cache index disable on family 0x15 (Frank Arnold) [638748]
- [x86] amd: Normalize compute unit IDs on multi-node processors (Frank Arnold) [638748]
- [x86] cacheinfo: Cleanup L3 cache index disable support (Frank Arnold) [638748]
- [x86] amd-nb: Cleanup AMD northbridge caching code (Frank Arnold) [638748]
- [x86] amd-nb: Complete the rename of AMD NB and related code (Frank Arnold) [638748]
- [x86] k8: Rename k8.[ch] to amd_nb.[ch] and CONFIG_K8_NB to CONFIG_AMD_NB (Frank Arnold) [638748]
- [x86] k8-gart: Decouple handling of garts and northbridges (Frank Arnold) [638748]
- [x86] cacheinfo: Fix dependency of AMD L3 CID (Frank Arnold) [638748]
- [x86] cacheinfo: Carve out L3 cache slot accessors (Frank Arnold) [638748]
- [x86] cacheinfo: Disable index in all four subcaches (Frank Arnold) [638748]
- [x86] cacheinfo: Make L3 cache info per node (Frank Arnold) [638748]
- [x86] cacheinfo: Reorganize AMD L3 cache structure (Frank Arnold) [638748]
- [x86] cacheinfo: Enable L3 CID only on AMD (Frank Arnold) [638748]

* Mon Jun 06 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-156.el6]
- [virt] xenpv: zero all x86 power feature bits from cpuid (Andrew Jones) [709856]

* Tue May 31 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-155.el6]
- [mm] Prevent Disk IO throughput degradation due to memory allocation stalls (Larry Woodman) [679526]
- [x86] Add support for newer Thinkpads to thinkpad_acpi (Matthew Garrett) [682789]
- [x86] fix a shutdown regression in intel_idle (Prarit Bhargava) [707701]
- [fs] dlm: delayed reply message warning (David Teigland) [677409]
- [fs] dlm: make plock operation killable (David Teigland) [707005]
- [fs] ext4: Add mount options in superblock (Eric Sandeen) [704557]
- [fs] dlm: increase default hash table sizes (David Teigland) [678102]
- [fs] GFS2: Processes waiting on inode glock that no processes are holding (Robert S Peterson) [707263]
- [x86] microcode, AMD: Extend ucode size verification (Frank Arnold) [698014]
- [x86] amd-ucode: Remove needless log messages (Frank Arnold) [698014]
- [ppc] pseries/iommu: Add additional checks when changing iommu mask (Steve Best) [704401]
- [ppc] pseries/iommu: Use correct return type in dupe_ddw_if_already_created (Steve Best) [704401]
- [ppc] iommu: Restore iommu table pointer when restoring iommu ops (Steve Best) [704401]
- [ppc] Fix kexec with dynamic dma windows (Steve Best) [704401]
- [mm] smaps: have smaps show transparent huge pages (Andrea Arcangeli) [706385]
- [mm] smaps: teach smaps_pte_range() about THP pmds (Andrea Arcangeli) [706385]
- [mm] smaps: pass pte size argument in to smaps_pte_entry() (Andrea Arcangeli) [706385]
- [mm] smaps: break out smaps_pte_entry() from smaps_pte_range() (Andrea Arcangeli) [706385]
- [mm] pagewalk: only split huge pages when necessary (Andrea Arcangeli) [706385]
- [mm] /proc/pid/smaps: export amount of anonymous memory in a mapping (Andrea Arcangeli) [706385]
- [mm] Documentation/filesystems/proc.txt: improve smaps field documentation (Andrea Arcangeli) [706385]
- [mm] thp: fix /dev/zero MAP_PRIVATE and vm_flags cleanups (Andrea Arcangeli) [706385]
- [mm] thp: mremap support and TLB optimization (Andrea Arcangeli) [706385]
- [mm] mprotect: transparent huge page support (Andrea Arcangeli) [706385]
- [mm] mprotect: pass vma down to page table walkers (Andrea Arcangeli) [706385]
- [mm] add pmd_modify (Andrea Arcangeli) [706385]
- [mm] mincore transparent hugepage support (Andrea Arcangeli) [706385]
- [mm] mincore: do nested page table walks (Andrea Arcangeli) [706385]
- [mm] mincore: pass ranges as start, end address pairs (Andrea Arcangeli) [706385]
- [mm] mincore: break do_mincore() into logical pieces (Andrea Arcangeli) [706385]
- [mm] mincore: cleanups (Andrea Arcangeli) [706385]
- [mm] add VM counters for transparent hugepages (Andrea Arcangeli) [706385]
- [mm] compaction: enforce no writeback for async migration (Andrea Arcangeli) [706385]
- [fs] pNFS: request WRITE and COMMIT to DS be cached (Steve Dickson) [701788]
- [fs] pNFS: revert layoutcommit xdr (Steve Dickson) [701788]

* Wed May 25 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-154.el6]
- [fs] NFSv4.1 pnfs_layoutcommit_inode fixes (Steve Dickson) [701788]
- [fs] NFSv4.1 convert layoutcommit sync to boolean (Steve Dickson) [701788]
- [fs] NFSv4.1 remove temp code that prevented ds commits (Steve Dickson) [701788]
- [fs] NFSv4.1: layoutcommit (Steve Dickson) [701788]
- [fs] NFSv4.1: filelayout driver specific code for COMMIT (Steve Dickson) [701788]
- [fs] NFSv4.1: remove GETATTR from ds commits (Steve Dickson) [701788]
- [fs] NFSv4.1: add generic layer hooks for pnfs COMMIT (Steve Dickson) [701788]
- [fs] NFSv4.1: alloc and free commit_buckets (Steve Dickson) [701788]
- [fs] NFSv4.1: shift filelayout_free_lseg (Steve Dickson) [701788]
- [fs] NFSv4.1: pull out code from nfs_commit_release (Steve Dickson) [701788]
- [fs] NFSv4.1: pull error handling out of nfs_commit_list (Steve Dickson) [701788]
- [fs] NFSv4.1: add callback to nfs4_commit_done (Steve Dickson) [701788]
- [fs] NFSv4.1: rearrange nfs_commit_rpcsetup (Steve Dickson) [701788]
- [fs] NFSv4.1: don't send COMMIT to ds for data sync writes (Steve Dickson) [701788]
- [fs] NFSv4.1: Clear lseg pointer in ->doio function (Steve Dickson) [701788]
- [fs] NFSv4.1: rearrange ->doio args (Steve Dickson) [701788]
- [fs] NFSv4.1: pnfs filelayout driver write (Steve Dickson) [701788]
- [fs] NFSv4.1: remove GETATTR from ds writes (Steve Dickson) [701788]
- [fs] NFSv4.1: implement generic pnfs layer write switch (Steve Dickson) [701788]
- [fs] NFSv4.1: trigger LAYOUTGET for writes (Steve Dickson) [701788]
- [fs] NFSv4.1: Send lseg down into nfs_write_rpcsetup (Steve Dickson) [701788]
- [fs] NFSv4.1: add callback to nfs4_write_done (Steve Dickson) [701788]
- [fs] NFSv4.1: rearrange nfs_write_rpcsetup (Steve Dickson) [701788]
- [fs] NFSv4.1: lseg documentation (Steve Dickson) [701788]
- [fs] NFSv4.1: turn off pNFS on ds connection failure (Steve Dickson) [701788]
- [fs] NFSv4.1 move deviceid cache to filelayout driver (Steve Dickson) [701788]
- [fs] NFSv4.1: filelayout async error handler (Steve Dickson) [701788]
- [fs] NFSv4.1: filelayout read (Steve Dickson) [701788]
- [fs] NFSv4.1: filelayout i/o helpers (Steve Dickson) [701788]
- [fs] NFSv4.1: data server connection (Steve Dickson) [701788]
- [fs] NFSv4.1: generic read (Steve Dickson) [701788]
- [fs] NFSv4.1: shift pnfs_update_layout locations (Steve Dickson) [701788]
- [fs] NFSv4.1: coelesce across layout stripes (Steve Dickson) [701788]
- [fs] NFSv4.1: lseg refcounting (Steve Dickson) [701788]
- [fs] NFSv4.1: add MDS mount DS only check (Steve Dickson) [701788]
- [fs] NFSv4.1: new flag for lease time check (Steve Dickson) [701788]
- [fs] NFSv4.1: new flag for state renewal check (Steve Dickson) [701788]
- [fs] NFSv4.1: send zero stateid seqid on v4.1 i/o (Steve Dickson) [701788]
- [fs] NFS: move nfs_client initialization into nfs_get_client (Steve Dickson) [701788]
- [fs] NFSv4.1: put_layout_hdr can remove nfsi->layout (Steve Dickson) [701788]
- [fs] NFSv4: remove CONFIG_NFS_V4 from nfs_read_data (Steve Dickson) [701788]
- [fs] NFS: Allow walking nfs_client.cl_superblocks list outside client.c (Steve Dickson) [701788]

* Mon May 23 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-153.el6]
- [net] ipv6: Add GSO support on forwarding path (Thomas Graf) [683455]
- [net] ipv6/udp: fix the wrong headroom check (Thomas Graf) [698170]
- [net] dcbnl: potential risk in code in getapp handling (John Villalovos) [694354]
- [net] Fix netif_set_real_num_tx_queues (Neil Horman) [702742]
- [net] sock: adjust prot->obj_size always (Jiri Pirko) [704231]
- [net] dccp: Fix a few bugs in module loading (Neil Horman) [702183]
- [fs] GFS2: resource group bitmap corruption resulting in panics and withdraws (Robert S Peterson) [702057]
- [ppc] Add pgprot_writecombine (Steve Best) [694595]
- [input] xen-kbdfront: advertise either absolute or relative coordinates (Igor Mammedov) [703474]

* Fri May 20 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-152.el6]
- [cpuidle] Ensure poll_idle_init() is called (Matthew Garrett) [696850]
- [x86] intel_idle: add Sandy Bridge support (Matthew Garrett) [696172]
- [x86] intel_idle: disable NHM/WSM HW C-state auto-demotion (Matthew Garrett) [690393]
- [x86] intel_idle: open broadcast clock event (Matthew Garrett) [690392]
- [x86] gart: Make sure GART does not map physmem above 1TB (Myron Stowe) [698162]
- [x86] gart: Set DISTLBWALKPRB bit always (Myron Stowe) [698162]
- [x86] gart: Convert spaces to tabs in enable_gart_translation (Myron Stowe) [698162]
- [x86] amd: Disable GartTlbWlkErr when BIOS forgets it (Myron Stowe) [698162]
- [virt] virtio: console: Enable call to hvc_remove() on console port remove (Amit Shah) [693054]
- [virt] virtio_pci: Prevent double-free of pci regions after device hot-unplug (Amit Shah) [699358]
- [virt] virtio: Decrement avail idx on buffer detach (Amit Shah) [681122]
- [x86] cpufreq: Add APERF/MPERF support for AMD processors (Frank Arnold) [668085]
- [x86] k8: Fix section mismatch for powernowk8_exit() (Frank Arnold) [668085]
- [x86] powernow-k8: Add core performance boost support (Frank Arnold) [668085]
- [fs] ext3: Always set dx_node's fake_dirent explicitly (Eric Sandeen) [703329]
- [fs] GFS2: Tag all metadata with jid of last node to change it (Steven Whitehouse) [701578]
- [fs] nfs: Open with O_CREAT flag set fails to open existing files on non writable directories (J. Bruce Fields) [701825]
- [ppc] rtas: Only sleep in rtas_busy_delay if we have useful work to do (Steve Best) [702674]
- [scsi] ipr: fix synchronous request flags for better performance (Steve Best) [696640]
- [scsi] ibmvscsi: Improve CRQ reset reliability (Steve Best) [700165]
- [scsi] mpt2sas: move event handling of MPT2SAS_TURN_ON_FAULT_LED in process context (Tomas Henzl) [701951]
- [kernel] posix-timers: RCU conversion (Avi Kivity) [705082]
- [infiniband] RDMA/cxgb4: Reset wait condition atomically (Steve Best) [693930]
- [x86] kprobes: Disable irqs during optimized callback (Jiri Olsa) [699865]
- [x86] AMD IOMMU: Display warning for AMD systems (Prarit Bhargava) [681104]
- [netdrv] cxgb3: Apply interrupt coalescing settings to all queues (Neil Horman) [694581]
- [mm] slab, kmemleak: pass the correct pointer to kmemleak_erase() (Steve Best) [698023]

* Thu May 19 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-151.el6]
- [kernel] smp_call_function_many: handle concurrent clearing of mask (Jeff Moyer) [668775]
- [kernel] smp_call_function_many: add missing ordering (Jeff Moyer) [668775]
- [kernel] call_function_many: fix list delete vs add race (Jeff Moyer) [668775]
- [kernel] smp.c: consolidate writes in smp_call_function_interrupt() (Jeff Moyer) [668775]
- [kernel] smp.c: fix smp_call_function_many() SMP race (Jeff Moyer) [668775]
- [fs] NFS: change nfs_writeback_done to return void (Steve Dickson) [701373]
- [fs] NFS: remove pointless if statement in nfs_direct_write_result (Steve Dickson) [701373]
- [net] RPC: clarify rpc_run_task error handling (Steve Dickson) [701373]
- [net] RPC: remove check for impossible condition in rpc_make_runnable (Steve Dickson) [701373]
- [fs] pnfs: fix pnfs lock inversion of i_lock and cl_lock (Steve Dickson) [701373]
- [fs] pnfs: do not need to clear NFS_LAYOUT_BULK_RECALL flag (Steve Dickson) [701373]
- [fs] NFSv4: nfs4_state_mark_reclaim_nograce() should be static (Steve Dickson) [701373]
- [fs] pnfs: avoid incorrect use of layout stateid (Steve Dickson) [701373]
- [fs] NFSv4.1 reclaim complete must wait for completion (Steve Dickson) [701373]
- [fs] NFS: NFSROOT should default to "proto=udp" (Steve Dickson) [701373]
- [fs] NFSv4/4.1: Fix nfs4_schedule_state_recovery abuses (Steve Dickson) [701373]
- [fs] nfs4: remove duplicated #include (Steve Dickson) [701373]
- [fs] NFSv4: remove duplicate clientid in struct nfs_client (Steve Dickson) [701373]
- [fs] NFSv4: Fix the setlk error handler (Steve Dickson) [701373]
- [fs] NFSv4.1: Fix the handling of the SEQUENCE status bits (Steve Dickson) [701373]
- [fs] NFSv4.1: Retry CREATE_SESSION on NFS4ERR_DELAY (Steve Dickson) [701373]
- [fs] nfs: fix compilation warning (Steve Dickson) [701373]
- [net] SUNRPC: Remove resource leak in svc_rdma_send_error() (Steve Dickson) [701373]
- [fs] Fix nfs_compat_user_ino64 so it doesn't cause problems if bit 31 or 63 are set in fileid (Steve Dickson) [701373]
- [fs] nfs: add kmalloc return value check in decode_and_add_ds (Steve Dickson) [701373]
- [fs] nfs: close NFSv4 COMMIT vs. CLOSE race (Steve Dickson) [701373]
- [fs] SUNRPC: Close a race in __rpc_wait_for_completion_task() (Steve Dickson) [701373]
- [fs] NFSv4.1: Various fixes to the sequence flag error handling (Steve Dickson) [701373]

* Mon May 16 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-150.el6]
- [scsi] megaraid_sas: Driver only report tape drive, JBOD and logic drives (Tomas Henzl) [619422]
- [kernel] lib/vsprintf.c: add pU to print UUID/GUIDs (Stefan Assmann) [700299]

* Fri May 13 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-149.el6]
- [x86] MCE: Drop the default decoding notifier (Prarit Bhargava) [688281]
- [x86] MCE: Do not taint when handling correctable errors (Prarit Bhargava) [688281]
- [kernel] printk: use pK for /proc/kallsyms and /proc/modules (Phillip Lougher) [679262]
- [kernel] timer debug: Hide kernel addresses via pK in /proc/timer_list (Phillip Lougher) [679262]
- [drm] do not leak kernel addresses via /proc/dri/*/vma (Phillip Lougher) [679262]
- [kernel] kptr_restrict for hiding kernel pointers from unprivileged users (Phillip Lougher) [679262]
- [net] fix netns vs proto registration ordering (Wade Mealing) [702306] {CVE-2011-1767 CVE-2011-1768}

* Thu May 12 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-148.el6]
- [net] dccp: handle invalid feature options length (Jiri Pirko) [703013] {CVE-2011-1770}
- [fs] cifs: check for private_data before trying to put it (Jeff Layton) [702642] {CVE-2011-1771}
- [net] can: add missing socket check in can/raw and can/bcm release (Jiri Pirko) [698483] {CVE-2011-1598 CVE-2011-1748}
- [netdrv] ixgbe: do not clear FCoE DDP error status for received ABTS (Andy Gospodarek) [695966]
- [netdrv] ixgbe: DCB remove ixgbe_fcoe_getapp routine (Andy Gospodarek) [694358]
- [fs] setup_arg_pages: diagnose excessive argument size (Oleg Nesterov) [645229] {CVE-2010-3858}
- [scsi] bfa: change tech-preview to cover all cases (Rob Evers) [703251]
- [scsi] bfa: driver version update (Rob Evers) [703265]
- [scsi] bfa: kdump fix (Rob Evers) [703265]
- [scsi] bfa: firmware download fix (Rob Evers) [703265]
- [netdrv] bna: fix memory leak during RX path cleanup (Ivan Vecera) [698625]
- [netdrv] bna: fix for clean fw re-initialization (Ivan Vecera) [698625]

* Tue May 10 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-147.el6]
- [build] disable Werr for external modules (Aristeu Rozanski) [703504]

* Tue May 10 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-146.el6]
- [scsi] hpsa: fix reading a write only register causes a hang (Rob Evers) [703262]
- [scsi] mpt2sas: remove the use of writeq, since writeq is not atomic (Tomas Henzl) [701947]

* Wed May 04 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-145.el6]
- [kernel] sched: resched proper CPU on yield_to (Rik van Riel) [464276]
- [virt] sched: avoid kABI breakage (Rik van Riel) [464276]
- [virt] kvm: use yield_to instead of sleep in kvm_vcpu_on_spin (Rik van Riel) [464276]
- [virt] kvm: keep track of which task is running a KVM vcpu (Rik van Riel) [464276]
- [virt] export pid symbols needed for kvm_vcpu_on_spin (Rik van Riel) [464276]
- [virt] sched: Add yield_to(task, preempt) functionality (Rik van Riel) [464276]
- [virt] sched: Use a buddy to implement yield_task_fair() (Rik van Riel) [464276]
- [virt] sched: Limit the scope of clear_buddies (Rik van Riel) [464276]
- [virt] sched: Check the right ->nr_running in yield_task_fair() (Rik van Riel) [464276]
- [virt] VMX: increase ple_gap to 128 (Rik van Riel) [464276]
- [virt] KVM: introduce kvm_vcpu_on_spin (Rik van Riel) [464276]
- [virt] SVM: Support Pause Filter in AMD processors (Rik van Riel) [464276]
- [virt] VMX: Add support for Pause-Loop Exiting (Rik van Riel) [464276]
- [ppc] Add POWER7+ cputable entry (Steve Best) [694586]
- [fs] ext4: Allow indirect-block file to grow the file size to max file size (Lukas Czerner) [681647]
- GFS2: make sure fallocate bytes is a multiple of blksize (Benjamin Marzinski) [695763]
- [x86] Use KERN_DEFAULT log-level in __show_regs() (Prarit Bhargava) [691509]
- [x86] Make sure we also print a Code: line for show_regs() (Prarit Bhargava) [691509]
- [x86] Combine printk()s in show_regs_common() (Prarit Bhargava) [691509]
- [x86] dmi, debug: Log board name (when present) in dmesg/oops output (Prarit Bhargava) [691509]
- [x86] Factor duplicated code out of __show_regs() into show_regs_common() (Prarit Bhargava) [691509]
- [x86] dmi: log board, system, and BIOS information (Prarit Bhargava) [691509]
- [ppc] Fix oops if scan_dispatch_log is called too early (Steve Best) [696777]
- [scsi] ipr: improve interrupt service routine performance (Steve Best) [696754]
- [kernel] taskstats: use real microsecond granularity for CPU times (Oleg Nesterov) [662208]
- [x86] ACPI: Fix ioremap size for MMIO reads and writes (Myron Stowe) [690486]
- [virt] i8259: initialize isr_ack (Avi Kivity) [670765]
- [netdrv] mlx4_core: Remove warning message about firmware bug (Steve Best) [695229]
- Check if PTE is already allocated during page fault (Andrea Arcangeli) [696998]
- [mm] thp: simple fix for /dev/zero THP mprotect bug (Andrea Arcangeli) [690444]
- [mm] hugetlbfs: correct handling of negative input to nr_hugepages and nr_overcommit_hugepages (Petr Holasek) [673629]

* Mon May 02 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-144.el6]
- [scsi] hpsa: fix lost command problem (Tomas Henzl) [700430]
- [scsi] cciss: fix lost command problem (Tomas Henzl) [700430]
- [scsi] ibft: fix oops during boot (Mike Christie) [698737]

* Sun May 01 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-143.el6]
- [scsi] beiscsi: update version (Mike Christie) [674340]
- [scsi] be2iscsi: fix chip cleanup (Mike Christie) [674340]
- [scsi] be2iscsi: fix boot hang due to interrupts not getting rearmed (Mike Christie) [674340]
- [scsi] bnx2fc: fix regression due to incorrect setup of em for npiv port (Mike Christie) [700672]
- [ppc] pseries: Use a kmem cache for DTL buffers (Steve Best) [695678]

* Fri Apr 29 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-142.el6]
- [kdump] revert commit 8f4ec27fc to keep crashkernel=auto (Amerigo Wang) [605786]
- [kernel] sched: Drop rq->lock from idle_balance() (Larry Woodman) [623712]
- [kernel] sched: Fix unregister_fair_sched_group() (Larry Woodman) [623712]
- [kernel] sched: Allow update_cfs_load() to update global load (Larry Woodman) [623712]
- [kernel] sched: Implement demand based update_cfs_load() (Larry Woodman) [623712]
- [kernel] sched: Update shares on idle_balance (Larry Woodman) [623712]
- [kernel] sched: Add sysctl_sched_shares_window (Larry Woodman) [623712]
- [kernel] sched: Introduce hierarchal order on shares update list (Larry Woodman) [623712]
- [kernel] sched: Fix update_cfs_load() synchronization (Larry Woodman) [623712]
- [kernel] sched: Fix load corruption from update_cfs_shares() (Larry Woodman) [623712]
- [kernel] sched: Make tg_shares_up() walk on-demand (Larry Woodman) [623712]
- [kernel] sched: Implement on-demand (active) cfs_rq list (Larry Woodman) [623712]
- [kernel] sched: Rewrite tg_shares_up (Larry Woodman) [623712]
- [kernel] Prevent rt_sigqueueinfo and rt_tgsigqueueinfo from spoofing the signal code (Oleg Nesterov) [690033] {CVE-2011-1182}
- [net] ethtool RXHASH flag (Neil Horman) [690619]
- [fs] Revert "[fs] nfs: use unstable writes for groups of small DIO writes" (Jeff Layton) [694309]
- [fs] sendfile(): check f_op.splice_write() rather than f_op.sendpage() (Lukas Czerner) [689426]
- [fs] dcache: allow __d_obtain_alias() to return unhashed dentries (J. Bruce Fields) [636926]
- [virt] VMX: Save and restore tr selector across mode switches (Gleb Natapov) [693894]
- [virt] VMX: update live TR selector if it changes in real mode (Gleb Natapov) [693894]
- [mm] memcg: remove direct page_cgroup-to-page pointer (Johannes Weiner) [692490]
- [mm] memcg: condense page_cgroup-to-page lookup points (Johannes Weiner) [692490]
- [mm] memcg: change page_cgroup_zoneinfo signature (Johannes Weiner) [692490]
- [mm] memcg: no uncharged pages reach page_cgroup_zoneinfo (Johannes Weiner) [692490]
- [s390x] dasd: prevent panic with unresumed devices (Hendrik Brueckner) [676720]
- [s390x] qeth: wrong MAC-address displayed in error message (Hendrik Brueckner) [675211]

* Wed Apr 27 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-141.el6]
- [netdrv] cnic: fix hang due to rtnl_lock (Mike Christie) [694874]
- [netdrv] firmware: re-add the recently deleted bnx2x fw 6.2.5.0 (Michal Schmidt) [690470]
- [netdrv] firmware/bnx2x: add 6.2.9.0 fw, remove unused fw (Michal Schmidt) [690470]
- [netdrv] bnx2x, cnic: Disable iSCSI if DCBX negotiation is successful (Michal Schmidt) [690470]
- [netdrv] bnx2x: don't write dcb/llfc fields in STORM memory (Michal Schmidt) [690470]
- [netdrv] bnx2x: Update firmware to 6.2.9 (Michal Schmidt) [690470]

* Tue Apr 26 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-140.el6]
- [net] limit socket backlog add operation to prevent possible DoS (Jiri Pirko) [694396] {CVE-2010-4251}
- [scsi] mpt2sas: prevent heap overflows and unchecked (Tomas Henzl) [694023] {CVE-2011-1494 CVE-2011-1495}
- [fs] epoll: prevent creating circular epoll structures (Don Howard) [681683] {CVE-2011-1082}
- [mm] Prevent page_fault at do_mm_track_pte+0xc when Stratus dirty page tracking is active (Larry Woodman) [693786]
- [fs] GFS2 causes kernel panic in spectator mode (Steven Whitehouse) [696535]
- [net] bonding: interface doesn't issue IGMP report on slave interface during failover (Flavio Leitner) [640690]
- [scsi] isci: validate oem parameters early, and fallback (David Milburn) [698016]
- [scsi] isci: fix oem parameter header definition (David Milburn) [698016]

* Mon Apr 25 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-139.el6]
- [scsi] mark bfa fc adapters tech preview (Rob Evers) [698384]
- [virt] Revert pdpte registers are not flushed when PGD entry is changed in x86 PAE mode (Aristeu Rozanski) [691310]
- [i686] nmi watchdog: Enable panic on hardlockup (Don Zickus) [677532]
- [netdrv] Adding Chelsio Firmware for cxgb4 (Neil Horman) [691929]

* Thu Apr 21 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-138.el6]
- [virt] x86: better fix for race between nmi injection and enabling nmi window (Aristeu Rozanski)
- [virt] x86: revert "fix race between nmi injection and enabling nmi window" (Aristeu Rozanski)

* Wed Apr 20 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-137.el6]
- [net] bonding: fix jiffy comparison issues (Andy Gospodarek) [696337]

* Wed Apr 20 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-136.el6]
- [kernel] perf: add script command help (Jiri Olsa) [693050]
- [drm] radeon/kms: make radeon i2c put/get bytes less noisy (Frank Arnold) [693829]
- [drm] radeon/kms: fix hardcoded EDID handling (Frank Arnold) [693829]
- [x86] Revert "[x86] perf: P4 PMU - Fix unflagged overflows handling" (Don Zickus) [688547]
- [x86] perf: let everyone share counters on a P4 machine (Don Zickus) [688547]
- [fs] nfs: Ensure that NFS4 acl requests don't use slab in skb fraglist (Neil Horman) [682645] {CVE-2011-1090}
- [fs] partitions: Validate map_count in Mac partition tables (Danny Feng) [679286] {CVE-2011-1010}

* Tue Apr 19 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-135.el6]
- [scsi] ibft: search for broadcom specific ibft sign (Mike Christie) [696275]
- [fs] Fix corrupted OSF partition table parsing (Danny Feng) [688025] {CVE-2011-1163}
- [netdrv] ixgbe: DCB, X540 devices do not respond to pause frames (Andy Gospodarek) [694930]
- [netdrv] ixgbe: DCB, misallocated packet buffer size with X540 device (Andy Gospodarek) [694930]
- [netdrv] ixgbe: refactor common start_hw code for 82599 and x54 (Andy Gospodarek) [694930]
- [netdrv] ixgbe: balance free_irq calls with request_irq calls (Andy Gospodarek) [692988]

* Mon Apr 18 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-134.el6]
- [net] sctp: fix the INIT/INIT-ACK chunk length calculation (Thomas Graf) [690743] {CVE-2011-1573}
- [kernel] sched: Fix granularity of task_u/stime() (Jerome Marchand) [690998]
- [pci] Call PCIe _OSC methods earlier (Matthew Garrett) [693974]
- [fs] nfs: use unstable writes for groups of small DIO writes (Jeff Layton) [694309]
- [net] CAN: Use inode instead of kernel address for /proc file (Danny Feng) [664561] {CVE-2010-4565}
- [x86] mce: reject CEs on Westmere EX MCE bank 6 (Prarit Bhargava) [694891]
- [scsi] libfcoe: Incorrect CVL handling for NPIV ports (Mike Christie) [694906]
- [x86] perf: Complain louder about BIOSen corrupting CPU/PMU state and continue (Don Zickus) [694913]
- [fs] inotify: fix double free/corruption of stuct user (Eric Paris) [656832] {CVE-2010-4250}
- [netdrv] netxen: limit skb frags for non tso packet (Chad Dupuis) [695478]
- [fs] nfsd4: fix oops on lock failure (J. Bruce Fields) [696376]
- [netdrv] Return bnx2 firmware files to Makefile (John Feeney) [696365]
- [scsi] be2iscsi: fix be2iscsi rmmod (Mike Christie) [695585]
- [netdrv] qlcnic: limit skb frags for non tso packet (Bob Picco) [695488]
- [md] Cleanup after raid45->raid0 takeover (Dean Nelson) [694106]
- [md] revert "Cleanup after raid45->raid0 takeover patch" (Dean Nelson) [694106]
- [net] bonding: fix incorrect tx queue offset (Andy Gospodarek) [695548] {CVE-2011-1581}
- [netdrv] igb: for 82576 EEPROMs reporting invalid size default to 16kB (Stefan Assmann) [695751]
- [pci] return correct value when writing to the "reset" attribute (Alex Williamson) [690291]
- [kernel] Initalize call_single_queue during boot to handle left over ipi (Neil Horman) [680478]

* Mon Apr 18 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-133.el6]
- [virt] x86: better fix for race between nmi injection and enabling nmi window (Marcelo Tosatti) [684719]
- [virt] x86: revert "fix race between nmi injection and enabling nmi window" (Marcelo Tosatti) [684719]

* Tue Apr 12 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-132.el6]
- [mm] pdpte registers are not flushed when PGD entry is changed in x86 PAE mode (Larry Woodman) [691310]
- [drm] i915: backports from stable to fix some regressions (Dave Airlie) [690865]
- [fs] svcrpc: complete svsk processing on cb receive failure (J. Bruce Fields) [629030]
- [netdrv] cnic: fix hang due to rtnl_lock (Mike Christie) [694874]
- [netdrv] firmware/bnx2x: add 6.2.9.0 fw, remove unused fw (Michal Schmidt)
- [netdrv] bnx2x, cnic: Disable iSCSI if DCBX negotiation is successful (Michal Schmidt) [690470]
- [netdrv] bnx2x: don't write dcb/llfc fields in STORM memory (Michal Schmidt) [690470]
- [netdrv] bnx2x: Update firmware to 6.2.9 (Michal Schmidt) [690470]
- [ppc] pseries: fix hang caused by missing spin_unlock in dtl_disable (Steve Best) [694327]
- [ppc] pseries: Disable VPNH feature (Steve Best) [694266]
- [netdrv] bna: Avoid kernel panic in case of FW heartbeat failure (Ivan Vecera) [694115]
- [input] wacom: Move the cintiq initialization down (Peter Hutterer) [693573]
- [input] wacom: specify Cinitq supported tools (Peter Hutterer) [693573]
- [input] wacom: fix pressure in Cintiq 21UX2 (Peter Hutterer) [693573]
- [input] wacom: fix serial number handling on Cintiq 21UX2 (Peter Hutterer) [693573]
- [input] wacom: add Cintiq 21UX2 and Intuos4 WL (Peter Hutterer) [693573]
- [kernel] spec: strip note and comment from ppc64's vmlinux before checksum is calculated (Aristeu Rozanski) [692515]
- [scsi] fcoe: have fcoe log off and lport destroy before ndo_fcoe_disable (Mike Christie) [691611]
- [scsi] libfc: rec tov value and REC_TOV_CONST units usages is incorrect (Mike Christie) [691611]
- [scsi] libfcoe: fix wrong comment in fcoe_transport_detach (Mike Christie) [691611]
- [scsi] libfcoe: clean up netdev mapping properly when the transport goes away (Mike Christie) [691611]
- [scsi] fcoe: remove unnecessary module state check (Mike Christie) [691611]
- [scsi] fcoe: Remove mutex_trylock/restart_syscall checks (Mike Christie) [691611]
- [scsi] libfcoe: Remove mutex_trylock/restart_syscall checks (Mike Christie) [691611]
- [scsi] fcoe: correct checking for bonding (Mike Christie) [691611]
- [scsi] fcoe: fix broken fcoe interface reset (Mike Christie) [691611]
- [scsi] fcoe: precedence bug in fcoe_filter_frames() (Mike Christie) [691611]
- [scsi] libfcoe: Move FCOE_MTU definition from fcoe.h to libfcoe.h (Mike Christie) [691611]
- [scsi] libfc: remove duplicate ema_list init (Mike Christie) [691611]
- [scsi] fcoe, libfc: initialize EM anchors list and then update npiv EMs (Mike Christie) [691611]
- [scsi] libfc: Fixing a memory leak when destroying an interface (Mike Christie) [691611]
- [scsi] fc: Add GSPN_ID request to header file (Mike Christie) [691611]
- [x86] mce: don't print "human readable" message for corrected errors (Prarit Bhargava) [688281]
- [scsi] hpsa: fix pci_device_id table (Tomas Henzl) [684997]
- [netdrv] ixgbe: only enable WoL for magic packet by default (Andy Gospodarek) [632598]
- [mm] zram: disable zram on ppc64 (Jerome Marchand) [661293]
- [mm] zram: update config file (Jerome Marchand) [661293]
- [mm] zram: initialize device on first read (Jerome Marchand) [661293]
- [mm] zram: fix data corruption issue (Jerome Marchand) [661293]
- [mm] zram: xvmalloc: combine duplicate block delete code (Jerome Marchand) [661293]
- [mm] zram: Return zero'd pages on new reads (Jerome Marchand) [661293]
- [mm] zram: xvmalloc: Close 32byte hole on 64bit CPUs (Jerome Marchand) [661293]
- [mm] zram: xvmalloc: create CONFIG_ZRAM_DEBUG for debug code (Jerome Marchand) [661293]
- [mm] zram: xvmalloc: free bit block insertion optimization (Jerome Marchand) [661293]
- [mm] zram: Prevent overflow in logical block size (Jerome Marchand) [661293]
- [mm] zram: vmalloc: Correct tunings to enable use with 64K pages (Jerome Marchand) [661293]
- [mm] zram: xvmalloc.c: Fix a typo (Jerome Marchand) [661293]
- [mm] zram: Fix sparse warning 'Using plain integer as NULL pointer' (Jerome Marchand) [661293]

* Mon Apr 11 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-131.el6]
- [tracing] t_start: reset FTRACE_ITER_HASH in case of seek/pread (Jiri Olsa) [631626] {CVE-2010-3079}
- [scsi] scsi_dh_rdac: fix for lun_table update for rdac (Rob Evers) [687878]
- [usb] EHCI: unlink unused QHs when the controller is stopped (Don Zickus) [680987]
- [fs] Revert "[fs] sunrpc: Use static const char arrays" (Steve Dickson) [690754]
- [fs] sunrpc: Propagate errors from xs_bind() through xs_create_sock() (Steve Dickson) [689777]
- [net] netfilter: ipt_CLUSTERIP: fix buffer overflow (Jiri Pirko) [689342]
- [net] ipv6: netfilter: ip6_tables: fix infoleak to userspace (Jiri Pirko) [689351] {CVE-2011-1172}
- [net] netfilter: ip_tables: fix infoleak to userspace (Jiri Pirko) [689334] {CVE-2011-1171}
- [net] netfilter: arp_tables: fix infoleak to userspace (Jiri Pirko) [689325] {CVE-2011-1170}
- [kernel] remove kernel-debuginfo-common requires from perf-debuginfo (Jason Baron) [682012]
- [drm] radeon/kms: check AA resolve registers on r300 + regression fix (Dave Airlie) [680002] {CVE-2011-1016}
- [net] fix ebtables stack infoleak (Eugene Teo) [681323] {CVE-2011-1080}
- [drm] fix unsigned vs signed comparison issue in modeset ctl ioctl (Don Howard) [679928] {CVE-2011-1013}
- [fs] svcrpc: take advantage of tcp autotuning (J. Bruce Fields) [629030]
- [fs] SUNRPC: Don't wait for full record to receive tcp data (J. Bruce Fields) [629030]
- [net] svcrpc: copy cb reply instead of pages (J. Bruce Fields) [629030]
- [fs] svcrpc: close connection if client sends short packet (J. Bruce Fields) [629030]
- [fs] svcrpc: note network-order types in svc_process_calldir (J. Bruce Fields) [629030]
- [fs] SUNRPC: svc_tcp_recvfrom cleanup (J. Bruce Fields) [629030]
- [fs] SUNRPC: requeue tcp socket less frequently (J. Bruce Fields) [629030]
- [fs] rpc: move sk_bc_xprt to svc_xprt (J. Bruce Fields) [629030]
- [acpi] ACPICA: Truncate I/O addresses to 16 bits for Windows compatibility (Frank Arnold) [593766]

* Tue Apr 05 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-130.el6]
- [kernel] kcore: restrict access to the whole memory (Amerigo Wang) [663864]
- [scsi] libsas: flush initial device discovery before completing ->scan_finished (David Milburn) [682265]
- [md] Cleanup after raid45->raid0 takeover (Doug Ledford) [688725]
- [md] partition detection when array becomes active (Doug Ledford) [688725]
- [md] avoid spinlock problem in blk_throtl_exit (Doug Ledford) [679096 688725]
- [md] correctly handle probe of an 'mdp' device (Doug Ledford) [688725]
- [md] don't set_capacity before array is active (Doug Ledford) [688725]
- [md] Fix raid1->raid0 takeover (Doug Ledford) [688725]
- [md] process hangs at wait_barrier after 0->10 takeover (Doug Ledford) [688725]
- [md] md_make_request: don't touch the bio after calling make_request (Doug Ledford) [688725]
- [md] Don't allow slot_store while resync/recovery is happening (Doug Ledford) [688725]
- [md] don't clear curr_resync_completed at end of resync (Doug Ledford) [688725]
- [md] Don't use remove_and_add_spares to remove failed devices from a read-only array (Doug Ledford) [688725]
- [md] Add raid1->raid0 takeover support (Doug Ledford) [688725]
- [md] Remove the AllReserved flag for component devices (Doug Ledford) [688725]
- [md] don't abort checking spares as soon as one cannot be added (Doug Ledford) [688725]
- [md] fix the test for finding spares in raid5_start_reshape (Doug Ledford) [688725]
- [md] simplify some 'if' conditionals in raid5_start_reshape (Doug Ledford) [688725]
- [md] revert change to raid_disks on failure (Doug Ledford) [688725]
- [md] Fix removal of extra drives when converting RAID6 to RAID5 (Doug Ledford) [688725]
- [md] range check slot number when manually adding a spare (Doug Ledford) [688725]
- [md] raid5: handle manually-added spares in start_reshape (Doug Ledford) [688725]
- [md] fix sync_completed reporting for very large drives (>2TB) (Doug Ledford) [688725]
- [md] allow suspend_lo and suspend_hi to decrease as well as increase (Doug Ledford) [688725]
- [md] Don't let implementation detail of curr_resync leak out through sysfs (Doug Ledford) [688725]
- [md] separate meta and data devs (Doug Ledford) [688725]
- [md] add new param to_sync_page_io() (Doug Ledford) [688725]
- [md] new param to calc_dev_sboffset (Doug Ledford) [688725]
- [md] Be more careful about clearing flags bit in ->recovery (Doug Ledford) [688725]
- [md] md_stop_writes requires mddev_lock (Doug Ledford) [688725]
- [md] raid5: use sysfs_notify_dirent_safe to avoid NULL pointer (Doug Ledford) [688725]
- [md] Ensure no IO request to get md device before it is properly initialised (Doug Ledford) [688725]
- [md] Fix single printks with multiple KERN_<level>s (Doug Ledford) [688725]
- [md] fix regression resulting in delays in clearing bits in a bitmap (Doug Ledford) [688725]
- [md] fix regression with re-adding devices to arrays with no metadata (Doug Ledford) [688725]
- [md] pick some changes from commits to match upstream (Doug Ledford) [688725]
- [md] raid1: add takeover support for raid5->raid1 (Doug Ledford) [688725]
- [md] pick up some percpu annotations that upstream has (Doug Ledford) [688725]
- [md] update includes to match upstream (Doug Ledford) [688725]
- [scsi] isci: fix fragile/conditional isci_host lookups (David Milburn) [691591]
- [scsi] isci: cleanup isci_remote_device[_not]_ready interface (David Milburn) [691591]
- [scsi] isci: Qualify when the host lock is managed for STP/SATA callbacks (David Milburn) [691591]
- [scsi] isci: Fix use of SATA soft reset state machine (David Milburn) [691591]
- [scsi] isci: Free host lock for SATA/STP abort escalation at submission time (David Milburn) [691591]
- [scsi] isci: Properly handle requests in the "aborting" state (David Milburn) [691591]
- [scsi] isci: Remove "screaming" data types (David Milburn) [691591]
- [scsi] isci: remove unused "remote_device_started" (David Milburn) [691591]
- [scsi] isci: namespacecheck cleanups (David Milburn) [691591]
- [scsi] isci: kill some long macros (David Milburn) [691591]
- [scsi] isci: reorder init to cleanup unneeded declarations (David Milburn) [691591]
- [scsi] isci: Remove event_* calls as they are just wrappers (David Milburn) [691591]
- [netdrv] iwlagn: Support new 5000 microcode (Stanislaw Gruszka) [682742]
- [netdrv] iwlwifi: fix dma mappings and skbs leak (Stanislaw Gruszka) [682726]
- [netdrv] iwl3945: remove plcp check (Stanislaw Gruszka) [679002]
- [netdrv] iwlwifi: add {ack,plpc}_check module parameters (Stanislaw Gruszka) [620501]
- [fs] ext4: Fix ext4_quota_write cross block boundary behaviour (Lukas Czerner) [680105]
- [fs] quota: Don't write quota info in dquot_commit() (Lukas Czerner) [680105]
- [netdrv] be2net: Change f/w command versions for Lancer (Ivan Vecera) [685027]
- [netdrv] be2net: Remove ERR compl workaround for Lancer (Ivan Vecera) [685027]
- [netdrv] be2net: fix to ignore transparent vlan ids wrongly indicated by NIC (Ivan Vecera) [685027]
- [netdrv] be2net: pass proper hdr_size while flashing redboot (Ivan Vecera) [685027]
- [netdrv] be2net: Allow VFs to call be_cmd_reset_function (Ivan Vecera) [685027]
- [netdrv] be2net: pass domain numbers for pmac_add/del functions (Ivan Vecera) [685027]
- [netdrv] be2net: Initialize and cleanup sriov resources only if pci_enable_sriov has succeeded (Ivan Vecera) [685027]
- [netdrv] be2net: Use domain id when be_cmd_if_destroy is called (Ivan Vecera) [685027]
- [netdrv] be2net: While configuring QOS for VF, pass proper domain id (Ivan Vecera) [685027]
- [netdrv] benet: Avoid potential null deref in be_cmd_get_seeprom_data() (Ivan Vecera) [685027]
- [netdrv] benet: fix be_cmd_multicast_set() memcpy bug (Ivan Vecera) [685027]
- [ppc] kdump: Override crash_free_reserved_phys_range to avoid freeing RTAS (Steve Best) [672983]
- [kernel] kdump: Allow shrinking of kdump region to be overridden (Steve Best) [672983]
- [scsi] bnx2fc: Bumped version to 1.0.2 (Mike Christie) [683153]
- [scsi] bnx2fc: Fix kernel panic when deleting NPIV ports (Mike Christie) [683153]
- [scsi] bnx2fc: scsi_dma_unmap() not invoked on IO completions (Mike Christie) [683153]
- [scsi] bnx2fc: host stats show the link speed 'unknown' on NIC partitioned interfaces (Mike Christie) [683153]
- [scsi] bnx2fc: IO completion not processed due to missed wakeup (Mike Christie) [683153]
- [scsi] bnx2fc: Bump version to 1.0.1 (Mike Christie) [683153]
- [scsi] bnx2fc: Remove unnecessary module state checks (Mike Christie) [683153]
- [scsi] bnx2fc: Fix MTU issue by using static MTU (Mike Christie) [683153]
- [scsi] bnx2fc: Remove network bonding checking (Mike Christie) [683153]
- [scsi] bnx2fc: Call bnx2fc_return_rqe and bnx2fc_get_next_rqe with tgt lock held (Mike Christie) [683153]
- [scsi] bnx2fc: common free list for cleanup commands (Mike Christie) [683153]
- [scsi] bnx2fc: Remove rtnl_trylock/restart_syscall checks (Mike Christie) [683153]
- [netdrv] cnic: Fix lost interrupt on bnx2x (Mike Christie) [683153]
- [netdrv] cnic: Prevent status block race conditions with hardware (Mike Christie) [683153]
- [kernel] ring-buffer: Use sync sched protection on ring buffer resizing (Jiri Olsa) [676583]
- [kernel] tracing: avoid soft lockup in trace_pipe (Jiri Olsa) [676583]
- [kernel] tracing: Fix a race in function profile (Jiri Olsa) [676583]
- [block] cfq-iosched: Don't update group weights when on service tree (Vivek Goyal) [689551]
- [block] cfq-iosched: Get rid of on_st flag (Vivek Goyal) [689551]
- [net] tcp_cubic: fix low utilization of CUBIC with HyStart (Thomas Graf) [616985]
- [net] tcp_cubic: make the delay threshold of HyStart less sensitive (Thomas Graf) [616985]
- [net] tcp_cubic: enable high resolution ack time if needed (Thomas Graf) [616985]
- [net] tcp_cubic: fix clock dependency (Thomas Graf) [616985]
- [net] tcp_cubic: make ack train delta value a parameter (Thomas Graf) [616985]
- [net] tcp_cubic: fix comparison of jiffies (Thomas Graf) [616985]
- [net] tcp: fix RTT for quick packets in congestion control (Thomas Graf) [616985]
- [fs] fix GFS2 filesystem hang caused by incorrect lock order (Robert S Peterson) [651584]
- [fs] btrfs: bring us up to date with .38 (Josef Bacik) [684667]
- [ppc] add dynamic dma window support minor updates (Steve Best) [691952]
- [ppc] ptrace: Remove BUG_ON when full register set not available (Steve Best) [678099]
- [ppc] pseries: Disable MSI using new interface if possible (Steve Best) [684961]
- [ppc] kexec: Fix orphaned offline CPUs across kexec (Steve Best) [682875]
- [net] ipsec: Disable granular bundles (Herbert Xu) [631833]
- [scsi] libsas: fix runaway error handler problem (David Milburn) [691527]
- [scsi] mpt2sas: Added customer specific display support (Tomas Henzl) [684841]
- [scsi] Add next gen Dell Powervault controller MD36xxf into RDAC device list (Shyam Iyer) [688979]
- [kernel] perf: Fix task context scheduling (Jiri Olsa) [688065]
- [drm] nouveau: disable acceleration on NVA3/NVA5/NVA8/NVAF by default (Ben Skeggs) [684816]
- [kernel] radix: don't tag the root if we didn't tag within our range (Josef Bacik) [681439]
- [block] blk-throttle: Do not use kblockd workqueue for throtl work (Vivek Goyal) [681360]
- [sound] ALSA: HDA hdmi related fixes (Jaroslav Kysela) [671501]
- [pci] Preserve Existing pci sort whitelists for Dell systems (Shyam Iyer) [688954]
- [x86] perf: Add support for AMD family 15h core counters family 15h core counters (Robert Richter) [635671]
- [x86] hpwdt: fix section mismatch warning (Prarit Bhargava) [689837]
- [x86] UV: Correct kABI from upstream (George Beshers) [684957]
- [x86] When cleaning MTRRs, do not fold WP into UC (Prarit Bhargava) [682758]
- [virt] xen-blkfront: handle Xen major numbers other than XENVBD (Andrew Jones) [691339]
- [virt] Fix regression with SMP guests (Zachary Amsden) [681133]
- [netdrv] enic: update to version 2.1.1.13 (Andy Gospodarek) [684865]
- [netdrv] igb: full support for i350 devices (Stefan Assmann) [687932]
- [fs] NFS: Fix a hang/infinite loop in nfs_wb_page() (Steve Dickson) [672305]
- [fs] nfsd: fix auth_domain reference leak on nlm operations (J. Bruce Fields) [690900]
- [fs] svcrpc: ensure cache_check caller sees updated entry (J. Bruce Fields) [690900]
- [fs] svcrpc: take lock on turning entry NEGATIVE in cache_check (J. Bruce Fields) [690900]
- [fs] svcrpc: modifying valid sunrpc cache entries is racy (J. Bruce Fields) [690900]
- [fs] sunrpc: extract some common sunrpc_cache code from nfsd (Steve Dickson) [690900]
- [infiniband] RDMA/cxgb4: Initialization errors can cause crash (Steve Best) [647013]
- [infiniband] RDMA/cxgb4: Don't change QP state outside EP lock (Steve Best) [647013]
- [infiniband] RDMA/cxgb4: Remove db_drop_task (Steve Best) [647013]
- [infiniband] RDMA/cxgb4: Do CIDX_INC updates every 1/16 CQ depth CQE reaps (Steve Best) [647013]
- [infiniband] RDMA/cxgb4: Dispatch FATAL event on EEH errors (Steve Best) [647013]
- [infiniband] RDMA/cxgb4: Set the correct device physical function for iwarp connections (Steve Best) [647013]
- [infiniband] RDMA/cxgb4: limit MAXBURST EQ context field to 256B (Steve Best) [647013]
- [infiniband] RDMA/cxgb4: Don't re-init wait object in init/fini paths (Steve Best) [647013]
- [infiniband] RMDA/cxgb4 kfifo changes (Steve Best) [647013]
- [netdrv] cxgb4 driver update (Neil Horman) [647006]
- [tracing] Add unstable sched clock note to the warning (Jiri Olsa) [666264]
- [x86] Reevaluate T-states on CPU hot-add (Matthew Garrett) [673442]
- [scsi] libsas: fix/amend device gone notification in sas_deform_port (David Milburn) [682315]
- [kdump] kexec: move the crashkernel=auto logic into kernel spec file (Amerigo Wang) [605786]

* Mon Apr 04 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-129.el6]
- [fs] buffer: make invalidate_bdev() drain all percpu LRU add caches (Dave Chinner) [665056]
- [s390x] uaccess: missing sacf in uaccess error handling (Hendrik Brueckner) [670555]
- [v4l] media: minor v4l/dvb/rc regression fixes (Jarod Wilson) [682906]
- [kernel] capabilities: do not special case calculation of pE during exec of init (Eric Paris) [684008]
- [scsi] qla2xxx: Update version number to 8.03.07.03.06.1-k (Chad Dupuis) [686341]
- [scsi] qla2xxx: Display hardware/firmware registers to get more information about the error for ISP82xx (Chad Dupuis) [686341]
- [scsi] qla2xxx: Updated the reset sequence for ISP82xx (Chad Dupuis) [686341]
- [scsi] qla2xxx: Limit the logs in case device state does not change for ISP82xx (Chad Dupuis) [686341]
- [scsi] qla2xxx: Add test for valid loop id to qla2x00_relogin() (Chad Dupuis) [686341]
- [scsi] qla2xxx: Remove extra call to qla82xx_check_fw_alive() (Chad Dupuis) [686341]
- [scsi] Revert "qla2xxx: Remove code to not reset ISP82xx on failure" (Chad Dupuis) [686341]
- [scsi] qla2xxx: Log fcport state transitions when debug messages are enabled (Chad Dupuis) [686341]
- [scsi] qla2xxx: Free firmware PCB on logout request (Chad Dupuis) [686341]
- [scsi] qla2xxx: Include request queue ID in the upper 16-bits of the I/O handle for Abort I/O IOCBs (Chad Dupuis) [686341]
- [scsi] qla2xxx: Perform FCoE context reset before trying adapter reset for ISP82xx (Chad Dupuis) [686341]
- [scsi] qla2xxx: Update copyright banner (Chad Dupuis) [686341]
- [scsi] qla2xxx: Verify login-state has transitioned to PRLI-completed (Chad Dupuis) [686341]
- [scsi] qla2xxx: Remove extraneous setting of FCF_ASYNC_SENT during login-done completion (Chad Dupuis) [686341]
- [scsi] qla2xxx: Check for a match before attempting to set FCP-priority information (Chad Dupuis) [686341]
- [scsi] qla2xxx: Correct calling contexts of qla2x00_mark_device_lost() in async paths (Chad Dupuis) [686341]
- [scsi] qla2xxx: Display PortID information during FCP command-status handling (Chad Dupuis) [686341]
- [misc] mark various drivers/features as tech preview (Don Zickus) [689566]
- [mm] compaction beware writeback (Andrea Arcangeli) [690921]
- [scsi] megaraid_sas: Version and Changelog update (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Fix iMR OCR support to work correctly (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Fix max_sectors for IEEE SGL (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Fix fault state handling (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Fix tasklet_init call (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Add CFG_CLEARED AEN (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Fix megasas_build_dcdb_fusion to use correct LUN field (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Fix megasas_build_dcdb_fusion to not filter by TYPE_DISK (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Call tasklet_schedule for MSI-X (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Enable MSI-X before calling megasas_init_fw (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Add missing check_and_restore_queue_depth call (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Fix failure gotos (Shyam Iyer) [692673]
- [scsi] megaraid_sas: Fix probe_one to clear MSI-X flags in kdump (Tomas Henzl) [682110]
- [fs] jbd/ocfs2: Fix block checksumming when a buffer is used in several transactions (Eric Sandeen) [618440]
- [x86] UV: RHEL: avoid parsing the ACPI OSC table (George Beshers) [619426]
- [x86] UV: Fix the effect of extra bits in the hub nodeid register (George Beshers) [619426]
- [x86] UV: use native_halt on a halt (George Beshers) [619426]
- [x86] UV: Fix initialization of max_pnode (George Beshers) [619426]
- [x86] UV: Add common uv_early_read_mmr() function for reading MMR (George Beshers) [619426]
- [x86] UV: Fix a problem with long bitops during boot (George Beshers) [619426]
- [x86] UV: use BOOT_ACPI after crash dump (George Beshers) [619426]
- [x86] UV: Make kdump avoid stack dumps (George Beshers) [619426]
- [x86] UV: NMI_UNKNOWN (George Beshers) [619426]
- [x86] UV: Upstream enable NMI backtrace (George Beshers) [619426]
- [x86] Fix AMD PMU detection issue (Frank Arnold) [689065]
- [s390x] tape: deadlock on global work queue (Hendrik Brueckner) [681306]
- [s390x] qeth: remove needless IPA-commands in offline (Hendrik Brueckner) [679514]
- [s390x] qeth: allow channel path changes in suspend state (Hendrik Brueckner) [678067]
- [netdrv] ixgbe: receive packet statistics not incrementing (Andy Gospodarek) [689032]
- [netdrv] bnx2: update driver to latest upstream (Neil Horman) [669813]
- [mm] memcg: avoid deadlock between charge moving and try_charge() (Johannes Weiner) [592269]
- [mm] memcg: move charges of file pages (Johannes Weiner) [592269]
- [mm] memcg: clean up charge moving (Johannes Weiner) [592269]
- [mm] memcg: improve performance of swap charge moving (Johannes Weiner) [592269]
- [mm] memcg: move charges of anonymous swap (Johannes Weiner) [592269]
- [mm] memcg: avoid oom during charge moving (Johannes Weiner) [592269]
- [mm] memcg: improve performance of moving charges (Johannes Weiner) [592269]
- [mm] memcg: move charges of anonymous pages (Johannes Weiner) [592269]
- [mm] memcg: add interface to move charge at task migration (Johannes Weiner) [592269]
- [kernel] cgroup: introduce __css_get/put() for multiple references (Johannes Weiner) [592269]
- [kernel] cgroup: introduce cancel_attach() (Johannes Weiner) [592269]
- [mm] memcg: remove memcg_tasklist mutex (Johannes Weiner) [592269]
- [mm] memcg: cleanup mem_cgroup_move_parent() (Johannes Weiner) [592269]
- [mm] memcg: add mem_cgroup_cancel_charge() (Johannes Weiner) [592269]

* Mon Mar 28 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-128.el6]
- [netdrv] spec: add phy drivers to initrd (Andy Gospodarek) [650907]

* Mon Mar 28 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-127.el6]
- [x86] export SMBIOS version via sysfs (Prarit Bhargava) [684329]
- [fs] aio: fix up kabi breakage (Jeff Moyer) [690224]
- [scsi] lpfc: Update lpfc version for 8.3.5.30.1p driver release (Rob Evers) [689937]
- [scsi] lpfc: Fixed an issue where SLI4 adapter running on Powerpc was unable to login into Fabric (Rob Evers) [689937]
- [scsi] lpfc: Fixed driver sending FLOGI to a disconnected FCF (Rob Evers) [689937]
- [scsi] lpfc: Merge from upstream: block target when port queuing limit is hit (Rob Evers) [689937]
- [scsi] lpfc: Merge from upstream: force retry in queuecommand when port is transitioning (Rob Evers) [689937]
- [scsi] lpfc: Fix bug with incorrect BLS Response to BLS Abort (Rob Evers) [689937]
- [scsi] lpfc: Fixed crash when mailbox commands timeout through BSG (Rob Evers) [689937]
- [scsi] lpfc: Fix rrq cleanup for vport delete (Rob Evers) [689937]
- [scsi] lpfc: LOGO completion routine must invalidate both RPI and D_ID (Rob Evers) [689937]
- [scsi] lpfc: Do not take lock when clearing rrq active (Rob Evers) [689937]
- [scsi] lpfc: Save IRQ level when taking host_lock in findnode_did (Rob Evers) [689937]
- [scsi] lpfc: Fixed hang in lpfc_get_scsi_buf_s4 (Rob Evers) [689937]
- [scsi] lpfc: Fix xri lookup for received rrq (Rob Evers) [689937]
- [scsi] lpfc: Fixed missed setting of RRQ active for target aborted IOs (Rob Evers) [689937]
- [scsi] lpfc: Fixed fdisc sent with invalid VPI (Rob Evers) [689937]
- [scsi] lpfc: Fixed UE error reported by OneConnect UCNA BE2 hba with f/w 2.702.542.0 during reboot (Rob Evers) [689937]
- [scsi] lpfc: Fixed XRI reuse issue. (Rob Evers) [689937]
- [scsi] lpfc: Unreg login when PLOGI received from logged in port (Rob Evers) [689937]
- [scsi] lpfc: Fixed crashes for NULL vport dereference (Rob Evers) [689937]
- [scsi] lpfc: Fix for kmalloc failures in lpfc_workq_post_event (build error fix) (Rob Evers) [689937]
- [scsi] lpfc: Fix for kmalloc failures in lpfc_workq_post_event (Rob Evers) [689937]
- [scsi] lpfc: Adjust payload_length and request_length for sli4_config mailbox commands (Rob Evers) [689937]
- [fs] NFSD, VFS: Remove dead code in nfsd_rename() (J. Bruce Fields) [687935]
- [fs] nfsd: break lease on unlink due to rename (J. Bruce Fields) [687935]
- [fs] nfsd4: fix struct file leak (J. Bruce Fields) [687921]
- [fs] nfsd4: minor nfs4state.c reshuffling (J. Bruce Fields) [687921]
- [mm] thp+memcg-numa: fix BUG at mm.h:370 (Andrea Arcangeli) [687918]
- [mm] memcg: never OOM when charging huge pages, reinstated (Johannes Weiner) [685161]
- [ata] ahci: AHCI mode SATA patch for Intel Patsburg SATA RAID controller (David Milburn) [684366]
- [fs] GFS2: directly write blocks past i_size (Benjamin Marzinski) [684115]
- [net] netfilter: fix xt_AUDIT to work with ebtables (Thomas Graf) [683888]
- [net] bonding: change test for presence of VLANs (Jiri Pirko) [683496]
- [x86] UV: Initialize the broadcast assist unit base destination node id properly (Dean Nelson) [683268]
- [ppc] add missing mutex lock/unlock to device_pm_pre_add and device_pm_pre_add_cleanup (Steve Best) [683115]
- [mm] thp: fix page_referenced to modify mapcount/vm_flags only if page is found (Andrea Arcangeli) [683073]
- [netdrv] niu: Fix races between up/down and get_stats (Stefan Assmann) [683069]
- [fs] ext4: don't scan/accumulate more pages than mballoc will allocate (Eric Sandeen) [682831]
- [powerpc] kdump: CPUs assume the context of the oopsing CPU (Steve Best) [682303]
- [scsi] cciss: export resettable host attribute (Tomas Henzl) [682239]
- [scsi] hpsa: export resettable host attribute (Tomas Henzl) [682239]
- [scsi] hpsa: move device attributes to avoid forward declarations (Tomas Henzl) [682239]
- [pci] Fix missing pcie_port_platform_notify() (Prarit Bhargava) [681870]
- [scsi] ipr: Fix a race on multiple configuration changes (Steve Best) [681679]
- [net] bnep: fix buffer overflow (Don Howard) [681316] {CVE-2011-1079}
- [pci] Enable ASPM state clearing regardless of policy (Alex Williamson) [681017]
- [pci] Disable ASPM if BIOS asks us to (Alex Williamson) [681017]
- [scsi] scsi_dh: fix reference counting in scsi_dh_activate error path (Mike Snitzer) [680140]
- [scsi] aic94xx: world-writable sysfs update_bios file (Don Howard) [679307]
- [x86] tc1100-wmi: world-writable sysfs wireless and jogdial files (Don Howard) [679307]
- [x86] acer-wmi: world-writable sysfs threeg file (Don Howard) [679307]
- [mfd] ab3100: world-writable debugfs *_priv files (Don Howard) [679307]
- [v4l] sn9c102: world-wirtable sysfs files (Don Howard) [679307]
- [virt] unbreak userspace that does not sets tss address (Gleb Natapov) [677314]
- [virt] fix rcu usage in init_rmode_* functions (Gleb Natapov) [677314]
- [virt] VMX: Initialize vm86 TSS only once (Gleb Natapov) [677314]
- [virt] VMX: fix rcu usage warning in init_rmode() (Gleb Natapov) [677314]
- [netdrv] enic: update to upstream version 2.1.1.6 (Andy Gospodarek) [676134]
- [net] fix ipv6 binding to device (Shyam Iyer) [675321]
- [net] add POLLPRI to sock_def_readable() (Jiri Pirko) [672234]
- [x86] Fix mwait_usable section mismatch (Frank Arnold) [666493]
- [x86] Fix EFI pagetable to map whole memory (Takao Indoh) [664364]
- [netdrv] bnx2x: some more fixes from upstream (Michal Schmidt) [635942]
- [netdrv] bnx2x: bugfixes from driver version 1.62.00-6 (Michal Schmidt) [635942]
- [netdrv] ixgbe: DCB: enable RSS to be used with DCB (Andy Gospodarek) [684857]
- [netdrv] ixgbe: DCB, use multiple Tx rings per traffic class (Andy Gospodarek) [684856]
- [net] Implement infrastructure for HW based QOS (Neil Horman) [634006]
- [x86] intel-iommu: Fix get_domain_for_dev() error path (Alex Williamson) [619455]
- [x86] intel-iommu: Unlink domain from iommu (Alex Williamson) [619455]

* Mon Mar 28 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-126.el6]
- [kernel] CAP_SYS_MODULE bypass via CAP_NET_ADMIN (Phillip Lougher) [681773] {CVE-2011-1019}
- [kernel] failure to revert address limit override in OOPS error path (Dave Anderson) [659573] {CVE-2010-4258}
- [fs] xfs: zero proper structure size for geometry calls (Phillip Lougher) [677268]
- [fs] xfs: prevent leaking uninitialized stack memory in FSGEOMETRY_V1 (Phillip Lougher) [677268] {CVE-2011-0711}
- [watchdog] quiet down the boot messages (Don Zickus) [588861 684356]
- [x86] nmi_watchdog: compile-in i686 but disable by default (Don Zickus) [685021]
- [kernel] watchdog: Always return NOTIFY_OK during cpu up/down events (Don Zickus) [684649]
- [kernel] watchdog, nmi: Lower the severity of error messages (Don Zickus) [684649]
- [kernel] watchdog: Don't change watchdog state on read of sysctl (Don Zickus) [684649]
- [kernel] watchdog: Fix sysctl consistency (Don Zickus) [684649]
- [kernel] watchdog: Fix broken nowatchdog logic (Don Zickus) [684649]
- [scsi] isci: fix apc mode definition (David Milburn) [638569]
- [scsi] isci: Revert "isci: only call sas_task_abort for tasks with NEED_DEV_RESET" (David Milburn) [638569]
- [scsi] isci: Revert "isci: reset hardware at init (David Milburn) [638569]
- [scsi] isci: Revert "isci: SATA/STP and SMP tasks are never explicity put in the error (David Milburn) [638569]
- [scsi] isci config change (David Milburn) [638569]
- [scsi] isci: fixes (David Milburn) [638569]
- [scsi] isci: firmware (David Milburn) [638569]
- [scsi] isci: lldd (David Milburn) [638569]
- [scsi] isci/core: common definitions and utility functions (David Milburn) [638569]
- [scsi] isci/core: base state machine and memory descriptors (David Milburn) [638569]
- [scsi] isci/core: unsolicited frame handling and registers (David Milburn) [638569]
- [scsi] isci/core: request (general, ssp and smp) (David Milburn) [638569]
- [scsi] isci/core: stp (David Milburn) [638569]
- [scsi] isci/core: remote node context (David Milburn) [638569]
- [scsi] isci/core: remote device (David Milburn) [638569]
- [scsi] isci/core: port (David Milburn) [638569]
- [scsi] isci/core: phy (David Milburn) [638569]
- [scsi] isci/core: controller (David Milburn) [638569]
- [x86] introduce pci_map_biosrom() (David Milburn) [683211]
- [kernel] perf symbols: Avoid resolving [kernel.kallsyms] to real path for buildid cache (Jiri Olsa) [664900]
- [kernel] perf symbols: Fix vmlinux path when not using --symfs (Jiri Olsa) [664900]
- [kernel] perf timechart: Fix max number of cpus (Jiri Olsa) [664900]
- [kernel] perf timechart: Fix black idle boxes in the title (Jiri Olsa) [664900]
- [kernel] perf hists: Print number of samples, not the period sum (Jiri Olsa) [664900]
- [kernel] perf tools: Fix thread_map event synthesizing in top and record (Jiri Olsa) [664900]
- [kernel] perf stat: Fix aggreate counter reading accounting (Jiri Olsa) [664900]
- [kernel] perf tools: Fix time function double declaration with glibc (Jiri Olsa) [664900]
- [kernel] perf tools: Fix build by checking if extra warnings are supported (Jiri Olsa) [664900]
- [kernel] perf tools: Fix build when using gcc 3.4.6 (Jiri Olsa) [664900]
- [kernel] perf tools: Add missing header, fixes build (Jiri Olsa) [664900]
- [kernel] perf tools: Fix 64 bit integer format strings (Jiri Olsa) [664900]
- [kernel] perf test: Fix build on older glibcs (Jiri Olsa) [664900]
- [kernel] perf test: Use cpu_map->[cpu] when setting affinity (Jiri Olsa) [664900]
- [kernel] perf symbols: Fix annotation of thumb code (Jiri Olsa) [664900]
- [kernel] perf tools: Fix tracepoint id to string perf.data header table (Jiri Olsa) [664900]
- [kernel] perf tools: Fix handling of wildcards in tracepoint event selectors (Jiri Olsa) [664900]
- [kernel] perf record: Add "nodelay" mode, disabled by default (Jiri Olsa) [664900]
- [kernel] perf sched: Fix list of events, dropping unsupported ':r' modifier (Jiri Olsa) [664900]
- [kernel] Revert "perf tools: Emit clearer message for sys_perf_event_open ENOENT return" (Jiri Olsa) [664900]
- [kernel] perf top: Fix annotate segv (Jiri Olsa) [664900]
- [kernel] perf evsel: Fix order of event list deletion (Jiri Olsa) [664900]
- [kernel] perf session: Fix infinite loop in __perf_session__process_events (Jiri Olsa) [664900]
- [kernel] perf evsel: Support perf_evsel__open(cpus > 1 && threads > 1) (Jiri Olsa) [664900]
- [kernel] perf tools: Emit clearer message for sys_perf_event_open ENOENT return (Jiri Olsa) [664900]
- [kernel] perf stat: better error message for unsupported events (Jiri Olsa) [664900]
- [kernel] perf sched: Fix allocation result check (Jiri Olsa) [664900]
- [kernel] perf tools: Pass whole attr to event selectors (Jiri Olsa) [664900]
- [kernel] perf tools: Build with frame pointer (Jiri Olsa) [664900]
- [kernel] perf tools: Fix buffer overflow error when specifying all tracepoints (Jiri Olsa) [664900]
- [kernel] perf script: Make some lists static (Jiri Olsa) [664900]
- [kernel] perf script: Use the default lost event handler (Jiri Olsa) [664900]
- [kernel] perf session: Warn about errors when processing pipe events too (Jiri Olsa) [664900]
- [kernel] perf tools: Fix perf_event.h header usage (Jiri Olsa) [664900]
- [kernel] perf test: Clarify some error reports in the open syscall test (Jiri Olsa) [664900]
- [kernel] perf: add DWARF register lookup for s390 (Jiri Olsa) [664900]
- [kernel] perf timechart: Adjust perf timechart to the new power events (Jiri Olsa) [664900]
- [kernel] perf test: Add test for counting open syscalls (Jiri Olsa) [664900]
- [kernel] perf evsel: Auto allocate resources needed for some methods (Jiri Olsa) [664900]
- [kernel] perf evsel: Use {cpu, thread}_map to shorten list of parameters (Jiri Olsa) [664900]
- [kernel] perf tools: Refactor all_tids to hold nr and the map (Jiri Olsa) [664900]
- [kernel] perf tools: Refactor cpumap to hold nr and the map (Jiri Olsa) [664900]
- [kernel] perf evsel: Introduce per cpu and per thread open helpers (Jiri Olsa) [664900]
- [kernel] perf evsel: Steal the counter reading routines from stat (Jiri Olsa) [664900]
- [kernel] perf evsel: Delete the event selectors at exit (Jiri Olsa) [664900]
- [kernel] perf util: Move do_read from session to util (Jiri Olsa) [664900]
- [kernel] perf evsel: Adopt MATCH_EVENT macro from 'stat' (Jiri Olsa) [664900]
- [kernel] perf tools: Introduce event selectors (Jiri Olsa) [664900]
- [kernel] perf probe: Fix short file name probe location reporting (Jiri Olsa) [664900]
- [kernel] perf script: Fix event ordering settings to work with older kernels (Jiri Olsa) [664900]
- [kernel] perf record: Fix use of sample_id_all userspace with !sample_id_all kernels (Jiri Olsa) [664900]
- [kernel] perf script: Finish the rename from trace to script (Jiri Olsa) [664900]
- [kernel] perf probe: Fix wrong warning in __show_one_line() if read(1) errors happen (Jiri Olsa) [664900]
- [kernel] perf test: Look forward for symbol aliases (Jiri Olsa) [664900]
- [kernel] perf symbols: Improve kallsyms symbol end addr calculation (Jiri Olsa) [664900]
- [kernel] perf probe: Handle gracefully some stupid and buggy line syntaxes (Jiri Olsa) [664900]
- [kernel] perf probe: Don't always consider EOF as an error when listing source code (Jiri Olsa) [664900]
- [kernel] perf probe: Fix line range description since a single file is allowed (Jiri Olsa) [664900]
- [kernel] perf probe: Clean up redundant tests in show_line_range() (Jiri Olsa) [664900]
- [kernel] perf probe: Rewrite show_one_line() to make it simpler (Jiri Olsa) [664900]
- [kernel] perf probe: Make -L display the absolute path of the dumped file (Jiri Olsa) [664900]
- [kernel] perf probe: Cleanup messages (Jiri Olsa) [664900]
- [kernel] perf symbols: Add symfs option for off-box analysis using specified tree (Jiri Olsa) [664900]
- [kernel] perf record, report, annotate, diff: Process events in order (Jiri Olsa) [664900]
- [kernel] perf session: Fallback to unordered processing if no sample_id_all (Jiri Olsa) [664900]
- [kernel] perf session: Remove unneeded dump_printf calls (Jiri Olsa) [664900]
- [kernel] perf session: Split out user event processing (Jiri Olsa) [664900]
- [kernel] perf session: Split out sample preprocessing (Jiri Olsa) [664900]
- [kernel] perf session: Move dump code to event delivery path (Jiri Olsa) [664900]
- [kernel] perf session: Add file_offset to event delivery function (Jiri Olsa) [664900]
- [kernel] perf session: Store file offset in sample_queue (Jiri Olsa) [664900]
- [kernel] perf session: Consolidate the dump code (Jiri Olsa) [664900]
- [kernel] perf session: Dont queue events w/o timestamps (Jiri Olsa) [664900]
- [kernel] perf event: Prevent unbound event__name array access (Jiri Olsa) [664900]
- [kernel] perf session: Sort all events if ordered_samples=true (Jiri Olsa) [664900]
- [kernel] perf report: Allow user to specify path to kallsyms file (Jiri Olsa) [664900]
- [kernel] perf makefile: Allow strong and weak functions in LIB_OBJS (Jiri Olsa) [664900]
- [kernel] perf tools: Catch a few uncheck calloc/malloc's (Jiri Olsa) [664900]
- [kernel] perf script: Fix compiler warning in builtin_script.c:is_top_script() (Jiri Olsa) [664900]
- [kernel] perf options: add OPT_CALLBACK_DEFAULT_NOOPT (Jiri Olsa) [664900]
- [kernel] perf hist: Better displaying of unresolved DSOs and symbols (Jiri Olsa) [664900]
- [kernel] perf tools: Ask for ID PERF_SAMPLE_ info on all PERF_RECORD_ events (Jiri Olsa) [664900]
- [kernel] perf session: Parse sample earlier (Jiri Olsa) [664900]
- [kernel] perf stat: Add csv-style output (Jiri Olsa) [664900]
- [kernel] perf stat: Use --big-num format by default (Jiri Olsa) [664900]
- [kernel] perf stat: Document missing options (Jiri Olsa) [664900]
- [kernel] perf test: Fix spelling mistake in documentation (Jiri Olsa) [664900]
- [kernel] perf trace: Document missing options (Jiri Olsa) [664900]
- [kernel] perf top: Document missing options (Jiri Olsa) [664900]
- [kernel] perf sched: Document missing options (Jiri Olsa) [664900]
- [kernel] perf report: Document missing options (Jiri Olsa) [664900]
- [kernel] perf record: Document missing options (Jiri Olsa) [664900]
- [kernel] perf probe: Fix spelling mistake in documentation (Jiri Olsa) [664900]
- [kernel] perf lock: Document missing options (Jiri Olsa) [664900]
- [kernel] perf kvm: Document missing options (Jiri Olsa) [664900]
- [kernel] perf diff: Document missing options (Jiri Olsa) [664900]
- [kernel] perf diff: Fix displacement and modules options short flag (Jiri Olsa) [664900]
- [kernel] perf buildid-list: Document missing options (Jiri Olsa) [664900]
- [kernel] perf annotate: Document missing options (Jiri Olsa) [664900]
- [kernel] perf tools: fix event parsing of comma-separated tracepoint events (Jiri Olsa) [664900]
- [kernel] perf packaging: add memcpy to perf MANIFEST (Jiri Olsa) [664900]
- [kernel] perf debug: Simplify trace_event (Jiri Olsa) [664900]
- [kernel] perf session: Allocate chunks of sample objects (Jiri Olsa) [664900]
- [kernel] perf session: Cache sample objects (Jiri Olsa) [664900]
- [kernel] perf session: Keep file mmaped instead of malloc/memcpy (Jiri Olsa) [664900]
- [kernel] perf session: Use sensible mmap size (Jiri Olsa) [664900]
- [kernel] perf session: Simplify termination checks (Jiri Olsa) [664900]
- [kernel] perf session: Move ui_progress_update in __perf_session__process_events() (Jiri Olsa) [664900]
- [kernel] perf session: Cleanup __perf_session__process_events() (Jiri Olsa) [664900]
- [kernel] perf session: Use appropriate pointer type instead of silly typecasting (Jiri Olsa) [664900]
- [kernel] perf session: Fix list sort algorithm (Jiri Olsa) [664900]
- [kernel] perf tools: Fix lost and unknown events handling (Jiri Olsa) [664900]
- [kernel] perf trace: Handle DT_UNKNOWN on filesystems that don't support d_type (Jiri Olsa) [664900]
- [kernel] perf symbols: Correct final kernel map guesses (Jiri Olsa) [664900]
- [kernel] perf events: Default to using event__process_lost (Jiri Olsa) [664900]
- [kernel] perf record: Add option to disable collecting build-ids (Jiri Olsa) [664900]
- [kernel] perf stat: Change and clean up sys_perf_event_open error handling (Jiri Olsa) [664900]
- [kernel] perf tools: Remove hardcoded include paths for elfutils (Jiri Olsa) [664900]
- [kernel] perf stat: Add no-aggregation mode to -a (Jiri Olsa) [664900]
- [kernel] perf: Rename 'perf trace' to 'perf script' (Jiri Olsa) [664900]
- [fs] dlm: record full callback state (David Teigland) [635041]
- [net] bridge: do not learn from exact matches (Jiri Pirko) [623199]
- [x86] x86-32: Separate 1:1 pagetables from swapper_pg_dir (Frank Arnold) [638743]
- [tty] tty_audit: fix tty_audit_add_data live lock on audit disabled (Danny Feng) [680126]
- [kernel] sched: Try not to migrate higher priority RT tasks (Larry Woodman) [676948]

* Mon Mar 21 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-125.el6]
- [fs] GFS2: umount stuck on gfs2_gl_hash_clear (Steven Whitehouse) [682951]
- [fs] GFS2: add missed unlock_page() (Steven Whitehouse) [684705]
- [fs] GFS2: fix block allocation check for fallocate (Benjamin Marzinski) [674603]
- [fs] gfs2: quota allows exceeding hard limit (Abhijith Das) [675944]
- [ppc] perf: Fix frequency calculation for overflowing counters (Steve Best) [682842]
- [powerpc] rtas_flash needs to use rtas_data_buf (Steve Best) [682801]
- [powerpc] Use more accurate limit for first segment memory allocations (Steve Best) [682267]
- [powerpc] eeh: Fix oops when probing in early boot (Steve Best) [681668]
- [kernel] proc: protect mm start_code/end_code in /proc/pid/stat (Eugene Teo) [684573] {CVE-2011-0726}
- [net] dccp oops (Eugene Teo) [682958] {CVE-2011-1093}
- [scsi] sd: Export effective protection mode in sysfs (Mike Snitzer) [683266]
- [kernel] remove execute bit from perf scripts (Jason Baron) [676692]
- [firmware] dcdbas: force SMI to happen when expected (Shyam Iyer) [664832]
- [perf] record: Enable the enable_on_exec flag if record forks the target (Steve Best) [664598]
- [security] ima: fix add LSM rule bug (Eric Paris) [667915] {CVE-2011-0006}
- [block] dm stripe: implement merge method (Mike Snitzer) [688376]
- [dm] dm-ioctl: Fix using of possible uninitialised params struct, secure flag (Milan Broz) [683167]
- [block] Fix over-zealous flush_disk when changing device size (Jeff Moyer) [678357]
- [sound] caiaq: Fix possible string buffer overflow (Jaroslav Kysela) [678476]
- [x86] Fix AMD iommu over suspend/resume (Matthew Garrett) [625569]
- [virt] virtio: console: Don't access vqs if device was unplugged (Amit Shah) [681181]
- [netdrv] sfc: disable RX hash insertion (Michal Schmidt) [556563]
- [netdrv] sfc: remove filter management code (Michal Schmidt) [556563]
- [netdrv] sfc: add private ioctl to allow reset during online firmware update (Michal Schmidt) [556563]
- [netdrv] sfc: remove RX_FILTER_TBL0 from the register dump (Michal Schmidt) [556563]
- [netdrv] sfc: lower stack usage in efx_ethtool_self_test (Michal Schmidt) [556563]
- [drm] nouveau/vbios: parse more gpio tag bits from connector table (Ben Skeggs) [658896]
- [drm] nouveau: fix suspend/resume on GPUs that don't have PM support (Ben Skeggs) [658896]
- [drm] nv50: insert a delay before fb change to prevent display engine hang (Ben Skeggs) [658896]
- [scsi] qla2xxx: Update version number 8.03.07.00.06.1 (Chad Dupuis) [678104]
- [scsi] qla2xxx: Correct errant 82xx hardware state message (Chad Dupuis) [678104]
- [scsi] qla2xxx: Check return value of fc_block_scsi_eh() (Chad Dupuis) [678104]
- [scsi] qla2xxx: The ISP82XX should be online while waiting for commands completion (Chad Dupuis) [678104]
- [scsi] qla2xxx: Propagate block-layer tags on submitted I/Os (Chad Dupuis) [678104]
- [scsi] qla2xxx: Clear any stale login-states during an adapter reset (Chad Dupuis) [678104]
- [scsi] qla2xxx: Adjust FCP_RSP response-info field check after TMF completion (Chad Dupuis) [678104]
- [scsi] qla2xxx: Pass right CT command string for CT status processing (Chad Dupuis) [678104]
- [scsi] qla2xxx: Don't wait for active mailbox command completion when firmware is hung (Chad Dupuis) [678104]
- [scsi] qla2xxx: Abort pending commands for faster recovery during ISP reset (Chad Dupuis) [678104]
- [scsi] qla2xxx: Change from irq to irqsave with host_lock (Chad Dupuis) [678104]
- [scsi] qla2xxx: Do not return DID_NO_CONNECT when fcport state is FCS_DEVICE_LOST in qla2xxx_queuecommand() (Chad Dupuis) [678104]
- [scsi] qla2xxx: Display nport_id when any SNS command fails (Chad Dupuis) [678104]
- [scsi] qla2xxx: ROM lock recovery if fw hangs while holding the lock (Chad Dupuis) [678104]
- [scsi] qla2xxx: Fix array subscript is above array bounds in qla2xx_build_scsi_type_6_iocbs() (Chad Dupuis) [678104]
- [scsi] qla2xxx: Use sg_next to fetch next sg element while walking sg list (Chad Dupuis) [678104]
- [scsi] qla2xxx: Fix to avoid recursive lock failure during BSG timeout (Chad Dupuis) [678104]
- [scsi] qla2xxx: Remove code to not reset ISP82xx on failure (Chad Dupuis) [678104]
- [scsi] qla2xxx: Display mailbox register 4 during 8012 AEN for ISP82XX parts (Chad Dupuis) [678104]
- [scsi] qla2xxx: Remove redundant module parameter permission bits (Chad Dupuis) [678104]
- [scsi] qla2xxx: Don't perform a BIG_HAMMER if Get-ID (0x20) mailbox command fails on CNAs (Chad Dupuis) [678104]
- [scsi] qla2xxx: Add sysfs node for displaying board temperature (Chad Dupuis) [678104]
- [scsi] qla2xxx: Remove unwanted check for bad spd (Chad Dupuis) [678104]
- [scsi] qla2xxx: Memory wedge with peg_halt test in loop with ISP82XX (Chad Dupuis) [678104]
- [scsi] qla2xxx: Update FCP priority information to firmware before sending IOs (Chad Dupuis) [678104]
- [scsi] qla2xxx: Fixed zero test on new_config in qla2x00_process_loopback() (Chad Dupuis) [678104]
- [scsi] qla2xxx: Populate FCP_PRIO location for no *FLT* case (Chad Dupuis) [678104]
- [scsi] qla2xxx: Added support for quiescence mode for ISP82xx (Chad Dupuis) [678104]

* Tue Mar 15 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-124.el6]
- [mm] thp: add extra_gfp in alloc_hugepage non NUMA (Andrea Arcangeli) [674147]
- [mm] thp: Use GFP_OTHER_NODE for transparent huge pages (Andrea Arcangeli) [674147]
- [mm] thp: Add __GFP_OTHER_NODE flag (Andrea Arcangeli) [674147]
- [mm] thp: Use correct numa policy node for transparent hugepages (Andrea Arcangeli) [674147]
- [mm] thp: Preserve original node for transparent huge page copies (Andrea Arcangeli) [674147]
- [mm] thp: Add alloc_page_vma_node (Andrea Arcangeli) [674147]
- [mm] thp: Change alloc_pages_vma to pass down the policy node for local policy (Andrea Arcangeli) [674147]
- [mm] thp: Fix interleaving for transparent hugepages (Andrea Arcangeli) [674147]
- [mm] compaction: fix high compaction latencies and remove compaction-kswapd (Andrea Arcangeli) [674147]
- [mm] compaction: Minimise the time IRQs are disabled while isolating free pages (Andrea Arcangeli) [674147]
- [mm] thp: prevent hugepages during args/env copying into the user stack (Andrea Arcangeli) [674147]
- [mm] memcg: fix leak of accounting at failure path of hugepage collapsing (Andrea Arcangeli) [674147]
- [mm] vmscan: kswapd should not free an excessive number of pages when balancing small zones (Andrea Arcangeli) [674147]
- [mm] optimistic migration limited to movable pageblocks (Andrea Arcangeli) [674147]
- [mm] migrate_pages api bool (Andrea Arcangeli) [674147]
- [mm] migration: allow migration to operate asynchronously and avoid synchronous compaction in the faster path (Andrea Arcangeli) [674147]
- [mm] add compound_trans_head helper (Andrea Arcangeli) [674147]
- [mm] compaction: Avoid a potential deadlock due to lock_page() during direct compaction (Andrea Arcangeli) [674147]
- [mm] hugetlbfs fix hugepage migration in the same way (Andrea Arcangeli) [674147]
- [mm] fix migration hangs on anon_vma lock (Andrea Arcangeli) [674147]

* Tue Mar 15 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-123.el6]
- [net] gro: reset dev and skb_iff on skb reuse (Andy Gospodarek) [681970]
- [netdrv] ixgbe: limit VF access to network traffic (Andy Gospodarek) [678717]
- [netdrv] ixgbe: work around for DDP last buffer size (Andy Gospodarek) [678717]
- [x86] mtrr: Assume SYS_CFG[Tom2ForceMemTypeWB] exists on all future AMD CPUs (Frank Arnold) [652208 662238]

* Wed Mar 09 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-122.el6]
- [kernel] capabilites: allow the application of capability limits to usermode helpers (Eric Paris) [665080]
- [kernel] allow kernel-debuginfo-common to be biarch installable (Jason Baron) [682012]
- [mm] fix pgd_lock deadlock (Andrea Arcangeli) [671477]
- [net] Fix BUG halt in RDS when cong map len is returned to rds_send_xmit (Neil Horman) [680200] {CVE-2011-1023}

* Wed Mar 09 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-121.el6]
- [x86] watchdog, nmi: Allow hardlockup to panic by default (Don Zickus) [677532]
- [mm] Avoid possible bogus TLB entries (Larry Woodman) [681024]
- [net] udp: lockless transmit path (Thomas Graf) [680549]
- [mm] memcg: fix race at move_parent around compound_order() (Johannes Weiner) [679025]
- [mm] memcg: correctly order reading PCG_USED and pc->mem_cgroup (Johannes Weiner) [679025]
- [mm] memcg: fix race in mapped file accounting (Johannes Weiner) [679025]
- [mm] memcg: make memcg's file mapped consistent with global VM (Johannes Weiner) [679021]
- [net] fix rx queue refcounting (Neil Horman) [677786]
- [kernel] /proc/vmcore: speed up access to vmcore file (Neil Horman) [672937]
- [mm] ksm: drain pagevecs to lru (Andrea Arcangeli) [670063]
- [mm] memcg: fix charged shmem swapcache migration (Johannes Weiner) [663223]
- [mm] memcg: race-free migration of charged file pages (Johannes Weiner) [663223]
- [virt] KVM: SVM: check for progress after IRET interception (Avi Kivity) [612436]
- [virt] KVM: Fix race between nmi injection and enabling nmi window (Avi Kivity) [612436]
- [net] ipv6: Implement Any-IP support for IPv6 (Neal Kim) [591335]
- [net] netfilter: fix TPROXY IPv6 support build dependency (Andrew Jones) [591335]
- [x86] hpwdt: Include hpwdt in rh-configs by default (Tony Camuso) [462945]
- [x86] hpwdt and ipmi: use DIE_NMIUNKNOWN (Tony Camuso) [462945]
- [netdrv] cnic: Fix big endian bug (Steve Best) [676640]

* Mon Mar 07 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-120.el6]
- [scsi] libfcoe: check buffer length before write (Tomas Henzl) [635898 668114]
- [scsi] fcoe: add modparm compat interface (Mike Christie) [635898 668114]
- [scsi] bnx2fc: Avoid holding cq_lock when iounmap() is called (Mike Christie) [635898 668114]
- [scsi] bnx2fc: Makefile, Kconfig changes and FCoE interfaces (Mike Christie) [635898 668114]
- [scsi] bnx2fc: SCSI IO handling and session offload (Mike Christie) [635898 668114]
- [scsi] bnx2fc: Firmware interface and ELS handling (Mike Christie) [635898 668114]
- [scsi] bnx2fc: Header files (Mike Christie) [635898 668114]
- [scsi] libfcoe: Remove stale fcoe-netdev entries (Mike Christie) [635898 668114]
- [scsi] bnx2x: Proper netdev->ndo_set_rx_mode() implementation (Mike Christie) [635898 668114]
- [scsi] bnx2x: MTU for FCoE L2 ring (Mike Christie) [635898 668114]
- [scsi] bnx2x: multicasts in NPAR mode (Mike Christie) [635898 668114]
- [scsi] bnx2x, cnic: Consolidate iSCSI/FCoE shared mem logic in bnx2x (Mike Christie) [635898 668114]
- [scsi] libfc: introduce __fc_fill_fc_hdr that accepts fc_hdr as an argument (Mike Christie) [635898 668114]
- [scsi] libfc: revert patch to fix exchange being deleted when the abort itself is timed out (Mike Christie) [635898 668114]
- [scsi] fcoe: remove fcoe_ctlr_mode (Mike Christie) [635898 668114]
- [scsi] libfcoe: Move common code from fcoe to libfcoe module (Mike Christie) [635898 668114]
- [scsi] libfc: introduce LLD event callback (Mike Christie) [635898 668114]
- [scsi] libfc: Extending lport's roles for target if there is a registered target (Mike Christie) [635898 668114]
- [scsi] fcoe: convert fcoe.ko to become an fcoe transport provider driver (Mike Christie) [635898 668114]
- [scsi] fcoe: prepare fcoe for using fcoe transport (Mike Christie) [635898 668114]
- [scsi] libfcoe: include fcoe_transport.c into kernel libfcoe module (Mike Christie) [635898 668114]
- [scsi] libfcoe: rename libfcoe.c to fcoe_cltr.c for the coming fcoe_transport.c (Mike Christie) [635898 668114]
- [scsi] libfcoe: add implementation to support fcoe transport (Mike Christie) [635898 668114]
- [scsi] libfcoe: add fcoe_transport structure defines to include/scsi/libfcoe.h (Mike Christie) [635898 668114]
- [scsi] libfcoe: move logging macros into the local libfcoe.h header file (Mike Christie) [635898 668114]
- [scsi] libfc: Enhanced exchange ID selection mechanism and fix related EMA selection logic (Mike Christie) [635898 668114]
- [scsi] libfc: export seq_release() for users of seq_assign() (Mike Christie) [635898 668114]
- [scsi] libfc: use PRLI hook to get parameters when sending outgoing PRLI (Mike Christie) [635898 668114]
- [scsi] libfc: add hook to notify providers of local port changes (Mike Christie) [635898 668114]
- [scsi] libfc: add local port hook for provider session lookup (Mike Christie) [635898 668114]
- [scsi] libfc: add method for setting handler for incoming exchange (Mike Christie) [635898 668114]
- [scsi] libfc: add hook for FC-4 provider registration (Mike Christie) [635898 668114]
- [scsi] libfc: fix sparse static and non-ANSI warnings (Mike Christie) [635898 668114]
- [scsi] fcoe: drop FCoE LOGO in FIP mode (Mike Christie) [635898 668114]
- [scsi] fcoe: Fix module reference count for vports (Mike Christie) [635898 668114]
- [s390x] remove task_show_regs (Danny Feng) [677855] {CVE-2011-0710}

* Tue Mar 01 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-119.el6]
- [ib] cm: Bump reference count on cm_id before invoking callback (Doug Ledford) [676191]
- [rdma] cm: Fix crash in request handlers (Doug Ledford) [676191]
- [virt] Revert "kvm: Allow XSAVE/XRSTOR for a guest" series (Dor Laor) [464271]
- [x86] perf: Add support for AMD family 15h core counters (Frank Arnold) [635671]
- [x86] perf: Store perfctr msr addresses in config_base/event_base (Frank Arnold) [635671]
- [x86] perf: P4 PMU - Fix unflagged overflows handling (Frank Arnold) [635671]
- [x86] perf: Add new AMD family 15h msrs to perfctr reservation code (Frank Arnold) [635671]
- [x86] perf: Calculate perfctr msr addresses in helper functions (Frank Arnold) [635671]
- [x86] perf: Use helper function in x86_pmu_enable_all() (Frank Arnold) [635671]

* Mon Feb 21 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-118.el6]
- [netdrv] Keep all bnx2 firmware files (John Feeney) [678429]
- [crypto] sha-s390: Reset index after processing partial block (Herbert Xu) [626515]
- [kernel] make /dev/crash require CAP_SYS_RAWIO for access (Dave Anderson) [675998]
- [block] add sysfs knob for turning off disk entropy contributions (Jeff Moyer) [677447]
- [misc] support for marking code as tech preview (Don Zickus) [645198]
- [misc] move kernel/unsupported.c to kernel/rh_taint.c (Don Zickus) [645198]
- [scsi] ipr: clean up ipr_format_res_path (Steve Best) [633327]
- [scsi] ipr: Driver version 2.5.1 (Steve Best) [633327]
- [scsi] ipr: fix mailbox register definition and add a delay before reading (Steve Best) [633327]
- [scsi] ipr: fix lun assignment and comparison (Steve Best) [633327]
- [scsi] ipr: add definitions for a new adapter (Steve Best) [633327]
- [scsi] ipr: fix array error logging (Steve Best) [633327]
- [scsi] ipr: reverse the isr optimization changes (Steve Best) [633327]
- [scsi] ipr: fix resource address formatting and add attribute for device ID (Steve Best) [633327]
- [scsi] ipr: fix resource type update and add sdev and shost attributes (Steve Best) [633327]
- [scsi] ipr: fix transition to operational for new adapters (Steve Best) [633327]
- [scsi] ipr: change endian swap key to match hardware spec change (Steve Best) [633327]
- [scsi] ipr: add support for new Obsidian-E embedded adapter (Steve Best) [633327]
- [scsi] ipr: add MMIO write to perform BIST for 64 bit adapters (Steve Best) [633327]
- [scsi] ipr: add writeq definition if needed (Steve Best) [633327]
- [scsi] ipr: add endian swap enablement for 64 bit adapters (Steve Best) [633327]
- [scsi] ipr: fix resource path display and formatting (Steve Best) [633327]
- [scsi] ipr: improve interrupt service routine performance (Steve Best) [633327]
- [scsi] ipr: set the data list length in the request control block (Steve Best) [633327]
- [scsi] ipr: fix a register read to use correct address for 64 bit adapters (Steve Best) [633327]
- [scsi] ipr: include the resource path in the IOA status area structure (Steve Best) [633327]
- [scsi] ipr: Fixes for 64 bit support (Steve Best) [633327]
- [scsi] ipr: adds PCI ID definitions for new adapters (Steve Best) [633327]
- [scsi] ipr: add support for new IOASCs (Steve Best) [633327]
- [scsi] ipr: add support for multiple stages of initialization (Steve Best) [633327]
- [scsi] ipr: implement shutdown changes and remove obsolete write cache parameter (Steve Best) [633327]
- [scsi] ipr: add hardware assisted smart dump functionality (Steve Best) [633327]
- [scsi] ipr: define new offsets to registers for the next generation chip (Steve Best) [633327]
- [scsi] ipr: add error handling updates for the next generation chip (Steve Best) [633327]
- [scsi] ipr: update the configuration table code for the next generation chip (Steve Best) [633327]
- [scsi] ipr: add support for new adapter command structures for the next generation chip (Steve Best) [633327]
- [scsi] hpsa: change version string (Tomas Henzl) [630060]
- [scsi] cciss: change version string (Tomas Henzl) [630060]
- [scsi] cciss: fix dma addr before freeing (Tomas Henzl) [630060]
- [scsi] cciss: do not rescan luns on UNIT ATTN LUN DATA CHANGED (Tomas Henzl) [630060]
- [scsi] cciss: fix missing command status value CMD_UNABORTABLE (Tomas Henzl) [630060]
- [scsi] cciss: retry driver initiated cmds (Tomas Henzl) [630060]
- [scsi] cciss: update the vendor, model, rev, serial number (Tomas Henzl) [630060]
- [scsi] cciss: convert hlist_* functions to list_* functions (Tomas Henzl) [630060]
- [scsi] cciss: prevent from cycling thru nonexistent luns (Tomas Henzl) [630060]
- [scsi] cciss: fix revalidate panic (Tomas Henzl) [630060]
- [scsi] cciss: Fix cciss driver for CONFIG_PROC_FS not enabled (Tomas Henzl) [630060]
- [scsi] cciss: do not leak stack contents to userspace (Tomas Henzl) [630060]
- [scsi] cciss: limit commands in kdump scenario (Tomas Henzl) [630060]
- [scsi] cciss: do not proceed with kdump if reset fails (Tomas Henzl) [630060]
- [scsi] cciss: use kernel provided pci save and restore state functions (Tomas Henzl) [630060]
- [scsi] cciss: fix board status waiting code (Tomas Henzl) [630060]
- [scsi] cciss: Remove superfluous tests from cciss_bigpassthru (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_bigpassthru (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_passthru (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_getluninfo (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_getdrivver (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_getfirmver (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_getbustypes (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_getheartbeat (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_setnodename (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_getnodename (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_setintinfo (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_getintinfo (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_get_pci_info (Tomas Henzl) [630060]
- [scsi] cciss: fix queue depth reporting (Tomas Henzl) [630060]
- [scsi] cciss: fix botched tag masking for scsi tape commands (Tomas Henzl) [630060]
- [scsi] cciss: separate cmd_alloc() and cmd_special_alloc() (Tomas Henzl) [630060]
- [scsi] cciss: fix leak of ioremapped memory (Tomas Henzl) [630060]
- [scsi] cciss: factor out cciss_enter_performant_mode (Tomas Henzl) [630060]
- [scsi] cciss: use consistent variable names (Tomas Henzl) [630060]
- [scsi] cciss: change printks to dev_warn, etc (Tomas Henzl) [630060]
- [scsi] cciss: cleanup some debug ifdefs (Tomas Henzl) [630060]
- [scsi] cciss: Remove unnecessary kmalloc casts (Tomas Henzl) [630060]
- [scsi] cciss: set SCSI max cmd len (Tomas Henzl) [630060]
- [scsi] cciss: sanitize max commands (Tomas Henzl) [630060]
- [scsi] cciss: cleanup interrupt_not_for_us (Tomas Henzl) [630060]
- [scsi] cciss: Fix tape commandlist size (Tomas Henzl) [630060]
- [scsi] cciss: use performant mode (Tomas Henzl) [630060]
- [scsi] cciss: clean up interrupt handler (Tomas Henzl) [630060]
- [scsi] cciss: factor out enqueue_and_submit_io (Tomas Henzl) [630060]
- [scsi] cciss: Fix ENXIO weirdness (Tomas Henzl) [630060]
- [scsi] cciss: fix scatter gather code on scsi side of driver (Tomas Henzl) [630060]
- [scsi] cciss: add more commands for tapes (Tomas Henzl) [630060]
- [scsi] cciss: eliminate unnecessary pointer use (Tomas Henzl) [630060]
- [scsi] cciss: dont use void pointer for hba (Tomas Henzl) [630060]
- [scsi] cciss: factor out scatter gather chain block mapping code (Tomas Henzl) [630060]
- [scsi] cciss: fix DMA direction kludge (Tomas Henzl) [630060]
- [scsi] cciss: simplify scatter gather code (Tomas Henzl) [630060]
- [scsi] cciss: factor out scatter gather chain block (Tomas Henzl) [630060]
- [scsi] cciss: support for enhanced scatter/gather (Tomas Henzl) [630060]
- [scsi] cciss: remove sendcmd (Tomas Henzl) [630060]
- [scsi] cciss: remove the "withirq" parameter (Tomas Henzl) [630060]
- [scsi] cciss: clean up code in cciss_shutdown (Tomas Henzl) [630060]
- [scsi] cciss: Remove double setting of busy_configuring (Tomas Henzl) [630060]
- [scsi] cciss: Fix problem with remove_from_scan_list on driver unload (Tomas Henzl) [630060]
- [scsi] cciss: detect bad alignment of scsi commands at build time (Tomas Henzl) [630060]
- [scsi] hpsa: tell controller that we only use short tags (Tomas Henzl) [630060]
- [scsi] hpsa: fix bad compare (Tomas Henzl) [630060]
- [scsi] hpsa: cleanup debug ifdefs (Tomas Henzl) [630060]
- [scsi] hpsa: add new transport_mode sys entry (Tomas Henzl) [630060]
- [scsi] hpsa: make hpsa_simple_mode module parameter work (Tomas Henzl) [630060]
- [scsi] hpsa: do not re-order commands in internal queues (Tomas Henzl) [630060]
- [scsi] hpsa: Remove superflous variable (Tomas Henzl) [630060]
- [scsi] hpsa: avoid leaking stack contents to userland (Tomas Henzl) [630060]
- [scsi] hpsa: Add a commands_outstanding attribute in /sys (Tomas Henzl) [630060]
- [scsi] hpsa: add hpsa_simple_mode option (Tomas Henzl) [630060]
- [scsi] hpsa: take the adapter lock in hpsa_wait_for_mode_change_ack (Tomas Henzl) [630060]
- [scsi] hpsa: do not reset unknown boards on reset_devices (Tomas Henzl) [630060]
- [scsi] hpsa: limit commands allocated on reset_devices (Tomas Henzl) [630060]
- [scsi] hpsa: Use kernel PCI functions (Tomas Henzl) [630060]
- [scsi] hpsa: fix board status waiting code (Tomas Henzl) [630060]
- [scsi] hpsa: disable doorbell reset on reset_devices (Tomas Henzl) [630060]
- [scsi] hpsa: Fix problem with CMD_UNABORTABLE (Tomas Henzl) [630060]
- [scsi] hpsa: fix botched tag masking in interrupt handler (Tomas Henzl) [630060]
- [scsi] hpsa: correct new controller ids (Tomas Henzl) [630060]
- [scsi] hpsa: wait for board ready condition after hard reset (Tomas Henzl) [630060]
- [scsi] hpsa: sanitize max commands (Tomas Henzl) [630060]
- [scsi] hpsa: separate intx and msi/msix interrupt handlers (Tomas Henzl) [630060]
- [scsi] hpsa: enable Compaq Smart Arrays with hpsa_allow_any (Tomas Henzl) [630060]
- [scsi] hpsa: add new controllers (Tomas Henzl) [630060]
- [scsi] hpsa: Fix use of unitialized variable (Tomas Henzl) [630060]
- [scsi] hpsa: fix block fetch table problem (Tomas Henzl) [630060]
- [scsi] hpsa: expose ctlr firmware rev via sys (Tomas Henzl) [630060]
- [scsi] hpsa: initial add of hpsa.txt documentation (Tomas Henzl) [630060]
- [scsi] hpsa: remove unused firm_ver member of per-hba structure (Tomas Henzl) [630060]
- [scsi] hpsa: factor out hpsa_enter_performant_mode (Tomas Henzl) [630060]
- [scsi] hpsa: remove unused variable trans_offset (Tomas Henzl) [630060]
- [scsi] hpsa: factor out hpsa_wait_for_mode_change_ack (Tomas Henzl) [630060]
- [scsi] hpsa: mark as __devinit (Tomas Henzl) [630060]
- [scsi] hpsa: cleanup debug ifdefs (Tomas Henzl) [630060]
- [scsi] hpsa: factor out hpsa_enter_simple_mode (Tomas Henzl) [630060]
- [scsi] hpsa: add back the p600 quirk (Tomas Henzl) [630060]
- [scsi] hpsa: add hpsa_enable_scsi_prefetch (Tomas Henzl) [630060]
- [scsi] hpsa: factor out hpsa_CISS_signature_present (Tomas Henzl) [630060]
- [scsi] hpsa: factor out hpsa_find_board_params (Tomas Henzl) [630060]
- [scsi] hpsa: fix leak of ioremapped memory (Tomas Henzl) [630060]
- [scsi] hpsa: factor out hpsa_find_cfgtables (Tomas Henzl) [630060]
- [scsi] hpsa: factor out hpsa_wait_for_board_ready (Tomas Henzl) [630060]
- [scsi] hpsa: remove redundant board_id parameter from hpsa_interrupt_mode (Tomas Henzl) [630060]
- [scsi] hpsa: factor out hpsa_board_disabled (Tomas Henzl) [630060]
- [scsi] hpsa: save pdev pointer early (Tomas Henzl) [630060]
- [scsi] hpsa: hpsa remove READ_CAPACITY code (Tomas Henzl) [630060]
- [scsi] hpsa: Remove duplicate defines of DIRECT_LOOKUP_ constants (Tomas Henzl) [630060]
- [scsi] hpsa: fixup DMA address before freeing (Tomas Henzl) [630060]
- [scsi] hpsa: defend against zero sized buffers in passthru ioctls (Tomas Henzl) [630060]
- [scsi] hpsa: do not consider RAID level to be part of device identity (Tomas Henzl) [630060]
- [scsi] hpsa: do not consider firmware revision when looking for device changes (Tomas Henzl) [630060]
- [netdrv] ixgbe: fix panic due to uninitialized pointer (Andy Gospodarek) [676875]
- [net] Fix use-after-free in RPS sysfs handling (Herbert Xu) [676099]

* Tue Feb 15 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-117.el6]
- [usb] xhci: Remove more doorbell-related reads (Don Zickus) [674409]
- [usb] xHCI: fix printk_ratelimit() usage (Don Zickus) [674409]
- [usb] xHCI: replace dev_dbg() with xhci_dbg() (Don Zickus) [674409]
- [usb] xHCI: fix cycle bit set in giveback_first_trb() (Don Zickus) [674409]
- [usb] xHCI: remove redundant parameter in giveback_first_trb() (Don Zickus) [674409]
- [usb] xHCI: fix queue_trb in isoc transfer (Don Zickus) [674409]
- [usb] xhci: Use GFP_NOIO during device reset (Don Zickus) [674409]
- [usb] Realloc xHCI structures after a hub is verified (Don Zickus) [674409]
- [usb] xhci: Do not run xhci_cleanup_msix with irq disabled (Don Zickus) [674409]
- [usb] xHCI: synchronize irq in xhci_suspend() (Don Zickus) [674409]
- [usb] xhci: Resume bus on any port status change (Don Zickus) [674409]
- [x86] i2c-i801: Add PCI idents for Patsburg IDF SMBus controllers (Prarit Bhargava) [649054]
- [x86] i2c-i801: Handle multiple instances instead of keeping global state (Prarit Bhargava) [649054]
- [x86] PCI: update Intel chipset names and defines (Prarit Bhargava) [649054]
- [x86] hwmon: Fix autoloading of fschmd on recent Fujitsu machines (Prarit Bhargava) [649054]
- [x86] i2c-i801: Fix all checkpatch warnings (Prarit Bhargava) [649054]
- [x86] i2c-i801: All newer devices have all the optional features (Prarit Bhargava) [649054]
- [x86] i2c-i801: Let the user disable selected driver features (Prarit Bhargava) [649054]
- [virt] KVM: SVM: Add xsetbv intercept (Don Dugger) [464271]
- [virt] KVM: fix poison overwritten caused by using wrong xstate size (Don Dugger) [464271]
- [virt] Fix OSXSAVE after migration (Don Dugger) [464271]
- [virt] Fix OSXSAVE VXEXIT handling (Don Dugger) [464271]
- [virt] KVM: x86: Enable AVX for guest (Don Dugger) [464271]
- [virt] KVM: Fix xsave and xcr save/restore memory leak (Don Dugger) [464271]
- [virt] KVM: x86: XSAVE/XRSTOR live migration support (Don Dugger) [464271]
- [virt] KVM: VMX: Enable XSAVE/XRSTOR for guest (Don Dugger) [464271]
- [virt] x86: Export FPU API for KVM use (Don Dugger) [464271]
- [virt] KVM: x86: Use FPU API (Don Dugger) [464271]
- [virt] x86: Introduce 'struct fpu' and related API (Don Dugger) [464271]
- [net] bridge: Fix mglist corruption that leads to memory corruption (Herbert Xu) [659421]
- [sched] autogroup: Do not create autogroups for sessions if user has not enabled autogroups (Vivek Goyal) [656042]
- [virt] virtio_net: Add schedule check to napi_enable call (Michael S. Tsirkin) [676579]
- [netdrv] r8169: use RxFIFO overflow workaround and prevent RxFIFO induced infinite loops (Ivan Vecera) [630810]
- [netdrv] ehea: Increase the skb array usage (Steve Best) [676139]

* Mon Feb 14 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-116.el6]
- [fs] Btrfs: fix slot count logic in space info ioctl (Josef Bacik) [663749]
- [video] vgacon: check for efi machine (Dave Airlie) [609516]
- [dm] wipe dm-ioctl buffers (Milan Broz) [674813]
- [virt] xen/events.c: clean up section mismatch warning (Andrew Jones) [676346]
- [virt] xen: microcode: no backtrace on guest restore (Andrew Jones) [671161]
- [virt] xen: fix save/restore: unmask evtchn for IRQF_TIMER (Andrew Jones) [676009]
- [crypto] export DSA_verify as a gpl symbol (Jarod Wilson) [673577]
- [fs] NFS: Micro-optimize nfs4_decode_dirent() (Steve Dickson) [675815]
- [fs] NFS: construct consistent co_ownerid for v4.1 (Steve Dickson) [675815]
- [fs] NFS: fix the setting of exchange id flag (Steve Dickson) [675815]
- [fs] NFS: nfs_wcc_update_inode() should set nfsi->attr_gencount (Steve Dickson) [675815]
- [fs] NFS: improve pnfs_put_deviceid_cache debug print (Steve Dickson) [675815]
- [fs] NFS fix cb_sequence error processing (Steve Dickson) [675815]
- [fs] NFS do not find client in NFSv4 pg_authenticate (Steve Dickson) [675815]
- [fs] NFS: Prevent memory allocation failure in nfsacl_encode() (Steve Dickson) [675815]
- [fs] NFS: nfsacl_{encode, decode} should return signed integer (Steve Dickson) [675815]
- [fs] NFS: Fix "kernel BUG at fs/aio.c:554!" (Steve Dickson) [675815]
- [fs] NFS4: Avoid potential NULL pointer dereference in decode_and_add_ds() (Steve Dickson) [675815]
- [fs] NFS: fix handling of malloc failure during nfs_flush_multi() (Steve Dickson) [675815]
- [fs] GFS2: panics on quotacheck update (Abhijith Das) [675745]
- [fs] GFS2: Fails to clear glocks during unmount (Abhijith Das) [675270]
- [net] clear heap allocations for privileged ethtool actions (Jiri Pirko) [672435] {CVE-2010-4655}
- [netdrv] s2io: update to driver version 2.0.26.28 (Michal Schmidt) [611869]
- [x86] Include ACPI _DSM index and label support (Matthew Garrett) [639971]
- [mm] zram: simplify zram_make_request (Jerome Marchand) [661293]
- [mm] zram: make zram_read return a bio error if the device is not initialized (Jerome Marchand) [661293]
- [mm] zram: round up the disk size provided by user (Jerome Marchand) [661293]
- [mm] zram: make ZRAM depends on SYSFS (Jerome Marchand) [661293]
- [block] zram: fix up my fixup for some sysfs attribute permissions (Jerome Marchand) [661293]
- [block] zram: fix up some sysfs attribute permissions (Jerome Marchand) [661293]
- [block] zram: Makefile: replace the use of <module>-objs with <module>-y (Jerome Marchand) [661293]
- [block] zram: free device memory when init fails (Jerome Marchand) [661293]
- [block] zram: Update zram documentation (Jerome Marchand) [661293]
- [block] zram: Remove need for explicit device initialization (Jerome Marchand) [661293]
- [block] zram: Replace ioctls with sysfs interface (Jerome Marchand) [661293]
- [block] zram: fix build errors, depends on BLOCK (Jerome Marchand) [661293]
- [fs] Revert "inotify: rework inotify locking to prevent double free use when free in inotify" [674880 675299]

* Tue Feb 08 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-115.el6]
- [s390x] Fix hang on s390x while running LTP (Larry Woodman) [675294]
- [fs] make it possible to log all attempts to walk into a subtree (Alexander Viro) [661402]
- [x86] intel-iommu: Fix double lock in get_domain_for_dev() (Alex Williamson) [675304]
- [virt] fix WinXP BSOD when boot up with -cpu Penryn (John Cooper) [635539]
- [virt] KVM: Keep guest TSC synchronized across host suspend (Zachary Amsden) [651635]
- [virt] KVM: make cyc_to_nsec conversions more reliable (Zachary Amsden) [651635]
- [virt] KVM: Backport TSC catchup for KHZ rate change / unstable CPUs fixes (Zachary Amsden) [651635]
- [virt] KVM: Backport of math fixes (Zachary Amsden) [651635]
- [virt] KVM: Backport of backwards warp fixes (Zachary Amsden) [651635]
- [virt] KVM: Backport of pvclock scale_delta changes (Zachary Amsden) [651635]
- [virt] KVM: backport x86: Unify TSC logic (Zachary Amsden) [651635]
- [virt] KVM: Backport of TSC reset compensation changes (Zachary Amsden) [651635]
- [virt] KVM: backport Convert TSC writes to TSC offset writes (Zachary Amsden) [651635]
- [virt] KVM: backport of upstream TSC khz restructuring and fixes (Zachary Amsden) [651635]
- [virt] KVM: backport of SVM TSC init fixes (Zachary Amsden) [651635]
- [kernel] perf: Enable 'perf lock' for the perf user tool (Jason Baron) [593763]
- [kernel] tracing: Factorize lock events in a lock class (Jason Baron) [593763]
- [kernel] tracing: Drop the nested field from lock_release event (Jason Baron) [593763]
- [kernel] tracing: Drop lock_acquired waittime field (Jason Baron) [593763]
- [kernel] perf lock: Enhance information of lock trace events (Jason Baron) [593763]
- [kernel] tracing: Rename 'lockdep' event subsystem into 'lock' (Jason Baron) [593763]
- [kernel] perf: fix lock recursion (Jason Baron) [593763]
- [net] tcp thin streams kabi workaround (Jiri Pirko) [645793]
- [net] Add getsockopt support for TCP thin-streams (Jiri Pirko) [645793]
- [net] TCP thin dupack (Jiri Pirko) [645793]
- [net] TCP thin linear timeouts (Jiri Pirko) [645793]
- [net] TCP thin-stream detection (Jiri Pirko) [645793]
- [net] Corrected spelling error heurestics->heuristics (Jiri Pirko) [645793]
- [x86] kexec: Make sure to stop all CPUs before exiting the kernel (Paolo Bonzini) [667340]
- [x86] xen: don't bother to stop other cpus on shutdown/reboot (Paolo Bonzini) [667340]
- [virt] netfront: explicitly generate arp_notify event after migration (Paolo Bonzini) [622575]
- [net] arp_notify: allow drivers to explicitly request a notification event (Paolo Bonzini) [622575]
- [net] arp_notify: document that a gratuitous ARP request is sent when this option is enabled (Paolo Bonzini) [622575]
- [fs] Prevent freeing uninitialized pointer in compat_do_readv_writev (Jeff Moyer) [636906]
- [fs] compat_rw_copy_check_uvector: add missing compat_ptr call (Jeff Moyer) [636906]
- [fs] aio: fix the compat vectored operations (Jeff Moyer) [636906]
- [fs] compat: factor out compat_rw_copy_check_uvector from compat_do_readv_writev (Jeff Moyer) [636906]
- [powerpc] pseries: Fix VPHN build errors on non-SMP systems (Steve Best) [633513]
- [powerpc] pseries: Poll VPA for topology changes and update NUMA maps (Steve Best) [633513]
- [powerpc] Disable VPHN polling during a suspend operation (Steve Best) [633513]
- [powerpc] Add VPHN firmware feature (Steve Best) [633513]
- [fs] make block fiemap mapping length at least blocksize long (Josef Bacik) [663042]
- [fs] mmapping a read only file on a gfs2 filesystem incorrectly acquires an exclusive glock (Steven Whitehouse) [674286]
- [fs] improve remount,ro vs buffercache coherency (Dave Chinner) [665056]
- [kexec] include sysctl to disable (Eric Paris) [665169]
- [net] Backport receive flow steering (Neil Horman) [625487]
- [crypto] unmark gcm(aes) as fips_allowed (Jarod Wilson) [638133]
- [crypto] bring cprng in line with upstream (Neil Horman) [673385]
- [usb] iowarrior: don't trust report_size for buffer size (Don Zickus) [672422]
- [pci] enable_drhd_fault_handling() section mismatch cleanup (Prarit Bhargava) [674571]
- [x86] amd-iommu: Fix rounding-bug in __unmap_single (Frank Arnold) [636249]
- [x86] Use MWAIT to offline a processor (Luming Yu) [666493]
- [virt] virtio_blk: allow re-reading config space at runtime (Christoph Hellwig) [669744]

* Mon Feb 07 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-114.el6]
- [scsi] fix use-after-free in scsi_init_io() (Mike Christie) [674064]

* Fri Feb 04 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-113.el6]
- [fs] include missing header in fs.h (Aristeu Rozanski) [675102]

* Wed Feb 02 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-112.el6]
- [sched] Replace kernel command line option "noautogroup" with "autogroup" (Vivek Goyal) [656042]
- [sched] autogroup: Fix CONFIG_RT_GROUP_SCHED sched_setscheduler() failure (Vivek Goyal) [656042]
- [sched] Display autogroup names in /proc/sched_debug (Vivek Goyal) [656042]
- [sched] Reinstate group names in /proc/sched_debug (Vivek Goyal) [656042]
- [sched] Enable autogroup CONFIG_SCHED_AUTOGROUP=y in rhel6 (Vivek Goyal) [656042]
- [sched] Fix struct autogroup memory leak (Vivek Goyal) [656042]
- [sched] Mark autogroup_init() __init (Vivek Goyal) [656042]
- [sched] autogroup: Fix potential access to freed memory (Vivek Goyal) [656042]
- [sched] Add 'autogroup' scheduling feature: automated per session task groups (Vivek Goyal) [656042]
- [v4l] dvb/rc: fix IR setkeycode operations (Jarod Wilson) [663280]
- [v4l] dvb/rc: additional pending IR fixes (Jarod Wilson) [663280]
- [v4l] dvb/rc: pull in (most) changes up to 2.6.38-rc2 (Jarod Wilson) [663280 672404] {CVE-2011-0521}
- [v4l] configs: enable v4l/dvb/rc bits (Jarod Wilson) [663280]
- [v4l] dvb/rc: fix dvb_adapter kabi compliance (Jarod Wilson) [663280]
- [v4l] dvb/rc: fix dvb_demux kabi compliance (Jarod Wilson) [663280]
- [v4l] dvb/rc: add back support for get_umapped_area fop (Jarod Wilson) [663280]
- [v4l] dvb/rc: necessary dvb-usb rc support kabi fixes (Jarod Wilson) [663280]
- [v4l] dvb/rc: kabi work-arounds for internal structs (Jarod Wilson) [663280]
- [v4l] dvb/rc: revert constification and unlocked_ioctl changes (Jarod Wilson) [663280]
- [v4l] dvb/rc: backport to 2.6.32 interfaces (Jarod Wilson) [663280]
- [v4l] dvb/rc: pending IR driver fixes (Jarod Wilson) [663280]
- [v4l] dvb/rc: add remaining 2.6.38-rc1 v4l changes (Jarod Wilson) [663280]
- [v4l] dvb/rc: add webcam support from 2.6.38-rc1 (Jarod Wilson) [663280]
- [v4l] dvb/rc: add remote control core from 2.6.38-rc1 (Jarod Wilson) [663280]
- [v4l] dvb/rc: update to dvb code from 2.6.38-rc1 (Jarod Wilson) [663280]
- [v4l] dvb/rc: add 2.6.38-rc1 base tuner code (Jarod Wilson) [663280]

* Tue Feb 01 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-111.el6]
- [block] md: protect against NULL reference when waiting to start a raid10. (Doug Ledford) [633695 659623]
- [block] md/raid1: really fix recovery looping when single good device fails. (Doug Ledford) [633695 659623]
- [block] md: fix return value of rdev_size_change() (Doug Ledford) [633695 659623]
- [block] md: tidy up device searches in read_balance. (Doug Ledford) [633695 659623]
- [block] md/raid1: fix some typos in comments. (Doug Ledford) [633695 659623]
- [block] md/raid1: discard unused variable. (Doug Ledford) [633695 659623]
- [block] md: unplug writes to external bitmaps. (Doug Ledford) [633695 659623]
- [block] md: use separate bio pool for each md device. (Doug Ledford) [633695 659623]
- [block] md: change type of first arg to sync_page_io. (Doug Ledford) [633695 659623]
- [block] md/raid1: perform mem allocation before disabling writes during resync. (Doug Ledford) [633695 659623]
- [block] md: use bio_kmalloc rather than bio_alloc when failure is acceptable. (Doug Ledford) [633695 659623]
- [block] md: Fix possible deadlock with multiple mempool allocations. (Doug Ledford) [633695 659623]
- [block] md: fix and update workqueue usage (Doug Ledford) [633695 659623]
- [block] md: use sector_t in bitmap_get_counter (Doug Ledford) [633695 659623]
- [block] md: Fix regression with raid1 arrays without persistent metadata. (Doug Ledford) [633695 659623]
- [block] mm: strictly nested kmap_atomic() (Doug Ledford) [633695 659623]
- [block] move async raid6 test to lib/Kconfig.debug (Doug Ledford) [633695 659623]
- [block] md: check return code of read_sb_page (Doug Ledford) [633695 659623]
- [block] md/raid1: minor bio initialisation improvements. (Doug Ledford) [633695 659623]
- [block] md/raid1: avoid overflow in raid1 resync when bitmap is in use. (Doug Ledford) [633695 659623]
- [block] md: fix v1.x metadata update when a disk is missing. (Doug Ledford) [633695 659623]
- [block] md: call md_update_sb even for 'external' metadata arrays. (Doug Ledford) [633695 659623]
- [block] md: resolve confusion of MD_CHANGE_CLEAN (Doug Ledford) [633695 659623]
- [block] md: don't clear MD_CHANGE_CLEAN in md_update_sb() for external arrays (Doug Ledford) [633695 659623]
- [block] md: provide appropriate return value for spare_active functions. (Doug Ledford) [633695 659623]
- [block] md: Notify sysfs when RAID1/5/10 disk is In_sync. (Doug Ledford) [633695 659623]
- [block] Update recovery_offset even when external metadata is used. (Doug Ledford) [633695 659623]
- [block] Make lib/raid6/test build correctly. (Doug Ledford) [633695 659623]
- [block] md: clean up do_md_stop (Doug Ledford) [633695 659623]
- [block] md: fix another deadlock with removing sysfs attributes. (Doug Ledford) [633695 659623]
- [block] md: move revalidate_disk() back outside open_mutex (Doug Ledford) [633695 659623]
- [block] md/raid10: fix deadlock with unaligned read during resync (Doug Ledford) [633695 659623]
- [block] md/bitmap: separate out loading a bitmap from initialising the structures. (Doug Ledford) [633695 659623]
- [block] md/bitmap: prepare for storing write-intent-bitmap via dm-dirty-log. (Doug Ledford) [633695 659623]
- [block] md/bitmap: optimise scanning of empty bitmaps. (Doug Ledford) [633695 659623]
- [block] md/bitmap: clean up plugging calls. (Doug Ledford) [633695 659623]
- [block] md/bitmap: reduce dependence on sysfs. (Doug Ledford) [633695 659623]
- [block] md/bitmap: white space clean up and similar. (Doug Ledford) [633695 659623]
- [block] md/raid5: export raid5 unplugging interface. (Doug Ledford) [633695 659623]
- [block] md/plug: optionally use plugger to unplug an array during resync/recovery. (Doug Ledford) [633695 659623]
- [block] md/raid5: add simple plugging infrastructure. (Doug Ledford) [633695 659623]
- [block] md/raid5: export is_congested test (Doug Ledford) [633695 659623]
- [block] raid5: Don't set read-ahead when there is no queue (Doug Ledford) [633695 659623]
- [block] md: add support for raising dm events. (Doug Ledford) [633695 659623]
- [block] md: export various start/stop interfaces (Doug Ledford) [633695 659623]
- [block] md: split out md_rdev_init (Doug Ledford) [633695 659623]
- [block] md: be more careful setting MD_CHANGE_CLEAN (Doug Ledford) [633695 659623]
- [block] md/raid5: ensure we create a unique name for kmem_cache when mddev has no gendisk (Doug Ledford) [633695 659623]
- [block] md/raid5: factor out code for changing size of stripe cache. (Doug Ledford) [633695 659623]
- [block] md: reduce dependence on sysfs. (Doug Ledford) [633695 659623]
- [block] md/raid5: don't include 'spare' drives when reshaping to fewer devices. (Doug Ledford) [633695 659623]
- [block] md/raid5: add a missing 'continue' in a loop. (Doug Ledford) [633695 659623]
- [block] md/raid5: Allow recovered part of partially recovered devices to be in-sync (Doug Ledford) [633695 659623]
- [block] md/raid5: More careful check for "has array failed". (Doug Ledford) [633695 659623]
- [block] md: Don't update ->recovery_offset when reshaping an array to fewer devices. (Doug Ledford) [633695 659623]
- [block] md/raid5: avoid oops when number of devices is reduced then increased. (Doug Ledford) [633695 659623]
- [block] md: enable raid4->raid0 takeover (Doug Ledford) [633695 659623]
- [block] md: clear layout after ->raid0 takeover (Doug Ledford) [633695 659623]
- [block] md: fix raid10 takeover: use new_layout for setup_conf (Doug Ledford) [633695 659623]
- [block] md: fix handling of array level takeover that re-arranges devices. (Doug Ledford) [633695 659623]
- [block] md: raid10: Fix null pointer dereference in fix_read_error() (Doug Ledford) [633695 659623]
- [block] md: convert cpu notifier to return encapsulate errno value (Doug Ledford) [633695 659623]
- [block] md: Fix read balancing in RAID1 and RAID10 on drives > 2TB (Doug Ledford) [633695 659623]
- [block] md/linear: standardise all printk messages (Doug Ledford) [633695 659623]
- [block] md/raid0: tidy up printk messages. (Doug Ledford) [633695 659623]
- [block] md/raid10: tidy up printk messages. (Doug Ledford) [633695 659623]
- [block] md/raid1: improve printk messages (Doug Ledford) [633695 659623]
- [block] md/raid5: improve consistency of error messages. (Doug Ledford) [633695 659623]
- [block] md/raid4: permit raid0 takeover (Doug Ledford) [633695 659623]
- [block] md/raid1: delay reads that could overtake behind-writes. (Doug Ledford) [633695 659623]
- [block] md/raid1: fix confusing 'redirect sector' message. (Doug Ledford) [633695 659623]
- [block] md/raid5: small tidyup in raid5_align_endio (Doug Ledford) [633695 659623]
- [block] md: add support for raid5 to raid4 conversion (Doug Ledford) [633695 659623]
- [block] md: Add support for Raid0->Raid10 takeover (Doug Ledford) [633695 659623]
- [block] md: don't use mddev->raid_disks in raid0 or raid10 while array is active. (Doug Ledford) [633695 659623]
- [block] md/raid1: fix counting of write targets. (Doug Ledford) [633695 659623]
- [block] md/linear: avoid possible oops and array stop (Doug Ledford) [633695 659623]
- [block] async_tx: Move ASYNC_RAID6_TEST option to crypto/async_tx/, fix dependencies (Doug Ledford) [633695 659623]
- [block] md: Factor out RAID6 algorithms into lib/ (Doug Ledford) [633695 659623]

* Tue Feb 01 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-110.el6]
- [block] dm mpath: delay activate_path retry on SCSI_DH_RETRY (Mike Snitzer) [668852]
- [block] dm: remove superfluous irq disablement in dm_request_fn (Mike Snitzer) [668852]
- [block] dm log: use PTR_ERR value instead of ENOMEM (Mike Snitzer) [668852]
- [block] dm snapshot: avoid storing private suspended state (Mike Snitzer) [668852]
- [block] dm ioctl: suppress needless warning messages (Mike Snitzer) [668852]
- [block] dm log userspace: add version number to comms (Mike Snitzer) [668852]
- [block] dm log userspace: group clear and mark requests (Mike Snitzer) [668852]
- [block] dm log userspace: split flush queue (Mike Snitzer) [668852]
- [block] dm log userspace: trap all failed log construction errors (Mike Snitzer) [668852]
- [block] dm kcopyd: delay unplugging (Mike Snitzer) [668852]
- [block] dm io: remove BIO_RW_SYNCIO flag from kcopyd (Mike Snitzer) [668852]
- [block] dm crypt: set key size early (Mike Snitzer) [668852]
- [block] dm raid1: support discard (Mike Snitzer) [668852]
- [block] dm ioctl: allow rename to fill empty uuid (Mike Snitzer) [668852]
- [block] block: max hardware sectors limit wrapper (Mike Snitzer) [668852]
- [netdrv] bna: include new bna ethernet driver (Ivan Vecera) [475692]
- [cdrom] Fix NULL pointer dereference in cdrom driver (James Paradis) [673567]
- [mm] hugetlb: fix handling of parse errors in sysfs (Dean Nelson) [673203]
- [mm] hugetlb: do not allow pagesize >= MAX_ORDER pool (Dean Nelson) [673203]
- [mm] hugetlb: check the return value of string (Dean Nelson) [673203]
- [mm] hugetlb.c: fix error-path memory leak in (Dean Nelson) [673203]
- [mm] hugetlb: abort a hugepage pool resize if a signal (Dean Nelson) [673203]
- [block] improve detail in I/O error messages (Mike Snitzer) [431754]
- [block] dm mpath: propagate target errors immediately (Mike Snitzer) [431754]
- [scsi] Detailed I/O errors (Mike Snitzer) [431754]
- [scsi] always pass Unit Attention upwards from scsi_check_sense (Mike Snitzer) [431754]
- [scsi] make error handling more robust in the face of reservations (Mike Snitzer) [431754]
- [scsi] Return NEEDS_RETRY for eh commands with status BUSY (Mike Snitzer) [431754]
- [fs] Btrfs: btrfs_iget() returns ERR_PTR (Josef Bacik) [663749]
- [fs] Btrfs: handle error returns from btrfs_lookup_dir_item() (Josef Bacik) [663749]
- [fs] Btrfs: Fix null dereference in relocation.c (Josef Bacik) [663749]
- [fs] Btrfs: fix remap_file_pages error (Josef Bacik) [663749]
- [fs] Btrfs: The file argument for fsync() is never null (Josef Bacik) [663749]
- [fs] Btrfs: handle kzalloc() failure in open_ctree() (Josef Bacik) [663749]
- [fs] Btrfs: fix split_leaf double split corner case (Josef Bacik) [663749]
- [fs] Btrfs: handle ERR_PTR from posix_acl_from_xattr() (Josef Bacik) [663749]
- [fs] Btrfs: Fix BUG_ON for fs converted from extN (Josef Bacik) [663749]
- [fs] Fix btrfs b0rkage (Josef Bacik) [663749]
- [fs] Btrfs: prevent RAID level downgrades when space is low (Josef Bacik) [663749]
- [fs] Btrfs: account for missing devices in RAID allocation profiles (Josef Bacik) [663749]
- [fs] Btrfs: EIO when we fail to read tree roots (Josef Bacik) [663749]
- [fs] Btrfs: fix compiler warnings (Josef Bacik) [663749]
- [fs] Btrfs: Make async snapshot ioctl more generic (Josef Bacik) [663749]
- [fs] Btrfs: pwrite blocked when writing from the mmaped buffer of the same page (Josef Bacik) [663749]
- [fs] Btrfs: Fix a crash when mounting a subvolume (Josef Bacik) [663749]
- [fs] Btrfs: fix sync subvol/snapshot creation (Josef Bacik) [663749]
- [fs] Btrfs: Fix page leak in compressed writeback path (Josef Bacik) [663749]
- [fs] Btrfs: do not BUG if we fail to remove the orphan item for dead snapshots (Josef Bacik) [663749]
- [fs] Btrfs: fixup return code for btrfs_del_orphan_item (Josef Bacik) [663749]
- [fs] Btrfs: do not do fast caching if we are allocating blocks for tree_root (Josef Bacik) [663749]
- [fs] Btrfs: deal with space cache errors better (Josef Bacik) [663749]
- [fs] Btrfs: fix use after free in O_DIRECT (Josef Bacik) [663749]
- [fs] Btrfs: don't use migrate page without CONFIG_MIGRATION (Josef Bacik) [663749]
- [fs] Btrfs: deal with DIO bios that span more than one ordered extent (Josef Bacik) [663749]
- [fs] Btrfs: setup blank root and fs_info for mount time (Josef Bacik) [663749]
- [fs] Btrfs: fix fiemap (Josef Bacik) [663749]
- [fs] Btrfs - fix race between btrfs_get_sb() and umount (Josef Bacik) [663749]
- [fs] Btrfs: update inode ctime when using links (Josef Bacik) [663749]
- [fs] Btrfs: make sure new inode size is ok in fallocate (Josef Bacik) [663749]
- [fs] Btrfs: fix typo in fallocate to make it honor actual size (Josef Bacik) [663749]
- [fs] Btrfs: avoid NULL pointer deref in try_release_extent_buffer (Josef Bacik) [663749]
- [fs] Btrfs: make btrfs_add_nondir take parent inode as an argument (Josef Bacik) [663749]
- [fs] Btrfs: hold i_mutex when calling btrfs_log_dentry_safe (Josef Bacik) [663749]
- [fs] Btrfs: use dget_parent where we can UPDATED (Josef Bacik) [663749]
- [fs] Btrfs: fix more ESTALE problems with NFS (Josef Bacik) [663749]
- [fs] Btrfs: handle NFS lookups properly (Josef Bacik) [663749]
- [fs] btrfs: make 1-bit signed fileds unsigned (Josef Bacik) [663749]
- [fs] btrfs: Show device attr correctly for symlinks (Josef Bacik) [663749]
- [fs] btrfs: Set file size correctly in file clone (Josef Bacik) [663749]
- [fs] Btrfs: fix CLONE ioctl destination file size expansion to block boundary (Josef Bacik) [663749]
- [fs] btrfs: Check if dest_offset is block-size aligned before cloning file (Josef Bacik) [663749]
- [fs] Btrfs: handle the space_cache option properly (Josef Bacik) [663749]
- [fs] btrfs: Fix early enospc because 'unused' calculated with wrong sign. (Josef Bacik) [663749]
- [fs] btrfs: fix panic caused by direct IO (Josef Bacik) [663749]
- [fs] btrfs: cleanup duplicate bio allocating functions (Josef Bacik) [663749]
- [fs] btrfs: fix free dip and dip->csums twice (Josef Bacik) [663749]
- [fs] Btrfs: add migrate page for metadata inode (Josef Bacik) [663749]
- [fs] Btrfs: deal with errors from updating the tree log (Josef Bacik) [663749]
- [fs] Btrfs: allow subvol deletion by unprivileged user with -o user_subvol_rm_allowed (Josef Bacik) [663749]
- [fs] Btrfs: make SNAP_DESTROY async (Josef Bacik) [663749]
- [fs] Btrfs: add SNAP_CREATE_ASYNC ioctl (Josef Bacik) [663749]
- [fs] Btrfs: add START_SYNC, WAIT_SYNC ioctls (Josef Bacik) [663749]
- [fs] Btrfs: async transaction commit (Josef Bacik) [663749]
- [fs] Btrfs: fix deadlock in btrfs_commit_transaction (Josef Bacik) [663749]
- [fs] Btrfs: fix lockdep warning on clone ioctl (Josef Bacik) [663749]
- [fs] Btrfs: fix clone ioctl where range is adjacent to extent (Josef Bacik) [663749]
- [fs] Btrfs: fix delalloc checks in clone ioctl (Josef Bacik) [663749]
- [fs] Btrfs: drop unused variable in block_alloc_rsv (Josef Bacik) [663749]
- [fs] Btrfs: cleanup warnings from gcc 4.6 (nonbugs) (Josef Bacik) [663749]
- [fs] Btrfs: Fix variables set but not read (bugs found by gcc 4.6) (Josef Bacik) [663749]
- [fs] Btrfs: Use ERR_CAST helpers (Josef Bacik) [663749]
- [fs] Btrfs: use memdup_user helpers (Josef Bacik) [663749]
- [fs] Btrfs: fix raid code for removing missing drives (Josef Bacik) [663749]
- [fs] Btrfs: Switch the extent buffer rbtree into a radix tree (Josef Bacik) [663749]
- [fs] Btrfs: restructure try_release_extent_buffer() (Josef Bacik) [663749]
- [fs] Btrfs: use the flusher threads for delalloc throttling (Josef Bacik) [663749]
- [fs] Add new functions for triggering inode writeback (Josef Bacik) [663749]
- [fs] Btrfs: tune the chunk allocation to 5 of the FS as metadata (Josef Bacik) [663749]
- [fs] Btrfs: don't loop forever on bad btree blocks (Josef Bacik) [663749]
- [fs] Btrfs: let the user know space caching is enabled (Josef Bacik) [663749]
- [fs] Btrfs: Add a clear_cache mount option (Josef Bacik) [663749]
- [fs] Btrfs: add support for mixed data+metadata block groups (Josef Bacik) [663749]
- [fs] Btrfs: check cache->caching_ctl before returning if caching has started (Josef Bacik) [663749]
- [fs] Btrfs: load free space cache if it exists (Josef Bacik) [663749]
- [fs] Btrfs: write out free space cache (Josef Bacik) [663749]
- [fs] Btrfs: create special free space cache inode (Josef Bacik) [663749]
- [fs] Btrfs: remove warn_on from use_block_rsv (Josef Bacik) [663749]
- [fs] Btrfs: set trans to null in reserve_metadata_bytes if we commit the transaction (Josef Bacik) [663749]
- [fs] Btrfs: fix error handling in btrfs_get_sb (Josef Bacik) [663749]
- [fs] Btrfs: rework how we reserve metadata bytes (Josef Bacik) [663749]
- [fs] Btrfs: don't allocate chunks as aggressively (Josef Bacik) [663749]
- [fs] Btrfs: re-work delalloc flushing (Josef Bacik) [663749]
- [fs] Btrfs: fix reservation code for mixed block groups (Josef Bacik) [663749]
- [fs] Btrfs: fix df regression (Josef Bacik) [663749]
- [fs] Btrfs: fix the df ioctl to report raid types (Josef Bacik) [663749]
- [fs] Btrfs: stop trying to shrink delalloc if there are no inodes to reclaim (Josef Bacik) [663749]
- [fs] btrfs: remove junk sb_dirt change (Josef Bacik) [663749]
- [fs] ext4: serialize unaligned direct asynchronous IO (Eric Sandeen) [615309]
- [fs] ext4: fix inconsistency with EOFBLOCK_FL (Eric Sandeen) [657553]
- [fs] ext4: Use bitops to read/modify i_flags in struct ext4_inode_info (Eric Sandeen) [657553]
- [net] GRO: fix merging a paged skb after non-paged skbs (Michal Schmidt) [672541]
- [net] netfilter: create audit records for x_table changes (Thomas Graf) [665129]
- [block] Fix race during disk initialization (Eric Sandeen) [607605]
- [virt] fix xen hvm fullvirt guest boot failure (Stefan Assmann) [673496]
- [virt] virtio: console: Wake up outvq on host notifications (Amit Shah) [643750]
- [netdrv] sfc: update to fix rss_cpus and sync with upstream (Michal Schmidt) [673532]
- [mm] hugetlb: fix section mismatch with hugetlb_sysfs_add_hstate() (Dean Nelson) [672844]
- [mm] put_page: recheck PageHead after releasing the compound_lock (Andrea Arcangeli) [664772]
- [mm] unconditional setup_per_zone_wmarks in set_recommended_min_free_kbytes (Andrea Arcangeli) [664772]
- [mm] adjust compound_lock_irqsave interface to match upstream (Andrea Arcangeli) [664772]

* Sat Jan 29 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-109.el6]
- [fcoe] libfc: dereferencing ERR_PTR in fc_tm_done() (Mike Christie) [633915 663561]
- [fcoe] libfc: Cleanup return paths in fc_rport_error_retry (Mike Christie) [633915 663561]
- [fcoe] libfc: Return a valid return code in fc_fcp_pkt_abort() (Mike Christie) [633915 663561]
- [fcoe] libfc: always initialize the FCoE DDP exchange id for fsp as FC_XID_UNKNOWN (Mike Christie) [633915 663561]
- [fcoe] libfc: fix statistics for FCP input/output megabytes (Mike Christie) [633915 663561]
- [fcoe] libfcoe: change fip_select to return new FCF (Mike Christie) [633915 663561]
- [fcoe] libfcoe: reorder FCF list to put latest advertiser first (Mike Christie) [633915 663561]
- [fcoe] libfcoe: add debug message for FCF destination MAC (Mike Christie) [633915 663561]
- [fcoe] libfcoe: retry rejected FLOGI to another FCF if possible (Mike Christie) [633915 663561]
- [fcoe] libfcoe: fix checking of conflicting fabrics in fcoe_ctlr_select() (Mike Christie) [633915 663561]
- [fcoe] libfcoe: move some timer code to make it reusable (Mike Christie) [633915 663561]
- [fcoe] libfcoe: update FIP FCF announcements (Mike Christie) [633915 663561]
- [fcoe] libfc: fix fc_tm_done not freeing the allocated fsp pkt (Mike Christie) [633915 663561]
- [fcoe] libfc: the timeout for the REC itself is 2 * R_A_TOV_els (Mike Christie) [633915 663561]
- [fcoe] libfc: fix exchange being deleted when the abort itself is timed out (Mike Christie) [633915 663561]
- [fcoe] libfc: do not fc_io_compl on fsp w/o any scsi_cmnd associated (Mike Christie) [633915 663561]
- [fcoe] libfc: add print of exchange id for debugging fc_fcp (Mike Christie) [633915 663561]
- [fcoe] Update WARN uses (Mike Christie) [633915 663561]
- [fcoe] libfc: fix memory leakage in remote port (Mike Christie) [633915 663561]
- [fcoe] libfc: fix memory leakage in local port (Mike Christie) [633915 663561]
- [fcoe] libfc: fix memory leakage in local port (Mike Christie) [633915 663561]
- [fcoe] libfc: remove tgt_flags from fc_fcp_pkt struct (Mike Christie) [633915 663561]
- [fcoe] libfc: use rport timeout values for fcp recovery (Mike Christie) [633915 663561]
- [fcoe] libfc: incorrect scsi host byte codes returned to scsi-ml (Mike Christie) [633915 663561]
- [fcoe] libfc: fix stats computation in fc_queuecommand() (Mike Christie) [633915 663561]
- [fcoe] libfc: fix mem leak in fc_seq_assign() (Mike Christie) [633915 663561]
- [fcoe] libfc: tune fc_exch_em_alloc() to be O(2) (Mike Christie) [633915 663561]
- [fcoe] libfc: fix mem leak in fc_exch_recv_seq_resp() (Mike Christie) [633915 663561]
- [fcoe] libfc: fix NULL pointer dereference bug in fc_fcp_pkt_release (Mike Christie) [633915 663561]
- [fcoe] libfc: remove define of fc_seq_exch in fc_exch.c (Mike Christie) [633915 663561]
- [fcoe] libfcoe: VN2VN connection setup causing stack memory corruption (Mike Christie) [633915 663561]
- [fcoe] libfc: Do not let disc work cancel itself (Mike Christie) [633915 663561]
- [fcoe] libfc: use DID_TRANSPORT_DISRUPTED while lport not ready (Mike Christie) [633915 663561]
- [fcoe] libfc: fix setting of rport dev loss (Mike Christie) [633915 663561]
- [fcoe] libfc: don't require a local exchange for incoming requests (Mike Christie) [633915 663561]
- [fcoe] libfc: add interface to allocate a sequence for incoming requests (Mike Christie) [633915 663561]
- [fcoe] libfc: add fc_fill_reply_hdr() and fc_fill_hdr() (Mike Christie) [633915 663561]
- [fcoe] libfc: add fc_frame_sid() and fc_frame_did() functions (Mike Christie) [633915 663561]
- [fcoe] libfc: eliminate rport LOGO state (Mike Christie) [633915 663561]
- [fcoe] config via separate create_vn2vn module parameter (Mike Christie) [633915 663561]
- [fcoe] libfcoe: use correct FC-MAP for VN2VN mode (Mike Christie) [633915 663561]
- [fcoe] libfcoe: Fix FIP ELS encapsulation details for FLOGI responses (Mike Christie) [633915]
- [fcoe] libfcoe: fcoe: fnic: add FIP VN2VN point-to-multipoint support (Mike Christie) [633915 663561]
- [fcoe] lib/random32: export pseudo-random number generator for modules (Mike Christie) [633915 663561]
- [fcoe] libfcoe: add state change debugging (Mike Christie) [633915 663561]
- [fcoe] libfcoe: add protocol description of FIP VN2VN mode (Mike Christie) [633915 663561]
- [fcoe] libfc: track FIP exchanges (Mike Christie) [633915 663561]
- [fcoe] libfc: add FLOGI state to rport for VN2VN (Mike Christie) [633915 663561]
- [fcoe] libfc: Add local port point-to-multipoint flag (Mike Christie) [633915 663561]
- [fcoe] fnic: change fcoe_ctlr_init interface to specify mode (Mike Christie) [633915 663561]
- [fcoe] libfc: add discovery-private pointer for LLD (Mike Christie) [633915 663561]
- [fcoe] libfcoe: convert FIP to lock with mutex instead of spin lock (Mike Christie) [633915 663561]
- [fcoe] libfc: provide space for LLD after remote port structure (Mike Christie) [633915 663561]
- [fcoe] libfc: convert rport lookup to be RCU safe (Mike Christie) [633915 663561]
- [fcoe] make it possible to verify fcoe with sparse (Mike Christie) [633915 663561]
- [block] fix performance regression introduced by the blkio-throttle code (Jeff Moyer) [669398]
- [scsi] iscsi class: remove unused active variable (Mike Christie) [668632]
- [scsi] cxgbi: enable TEXT PDU support (Mike Christie) [668632]
- [scsi] cxgb3i: fixed connection problem with iscsi private ip (Mike Christie) [668632]
- [scsi] be2iscsi: fix null ptr when accessing task hdr (Mike Christie) [668632]
- [scsi] be2iscsi: fix gfp use in alloc_pdu (Mike Christie) [668632]
- [scsi] libiscsi: add more informative failure message during iscsi scsi eh (Mike Christie) [668632]
- [scsi] cxgbi: set ulpmode only if digest is on (Mike Christie) [636291]
- [scsi] cxgb4i: ignore informational act-open-rpl message (Mike Christie) [636291]
- [scsi] cxgb4i: connection and ddp setting update (Mike Christie) [636291]
- [scsi] cxgb3i: fixed connection over vlan (Mike Christie) [636291]
- [scsi] libcxgbi: pdu read fixes (Mike Christie) [636291]
- [scsi] cxgbi: rename alloc_cpl to alloc_wr (Mike Christie) [636291]
- [scsi] cxgb3i: change cxgb3i to use libcxgbi (Mike Christie) [636291]
- [scsi] cxgb4i iscsi driver (Mike Christie) [636291]
- [scsi] libcxgbi: common library for cxgb3i and cxgb4i (Mike Christie) [636291]
- [mm] avoid resetting wb_start after each writeback round (Josef Bacik) [638349]
- [fs] ext4: update writeback_index based on last page scanned (Josef Bacik) [638349]
- [fs] ext4: implement writeback livelock avoidance using page tagging (Josef Bacik) [638349]
- [lib] radix-tree: radix_tree_range_tag_if_tagged() can set incorrect tags (Josef Bacik) [638349]
- [lib] radix-tree: clear all tags in radix_tree_node_rcu_free (Josef Bacik) [638349]
- [lib] radix-tree.c: fix overflow in radix_tree_range_tag_if_tagged() (Josef Bacik) [638349]
- [lib] radix-tree: omplement function radix_tree_range_tag_if_tagged (Josef Bacik) [638349]
- [mm] implement writeback livelock avoidance using page tagging (Josef Bacik) [638349]
- [scsi] ibft/be2iscsi: update iscsi boot support and add be2iscsi boot support (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Remove premature free of cid (Mike Christie) [585751 635746]
- [scsi] be2iscsi: More time for FW (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Fix for Login failure (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Driver Version change (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Increase max sector (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Add support for iscsi boot (Mike Christie) [585751 635746]
- [scsi] be2iscsi: add Kconfig dependency on NET (Mike Christie) [585751 635746]
- [scsi] The extended shift must be 1 (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Fix for premature buffer free (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Remove debug print in IO path (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Limit max_xmit_length (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Maintain same ITT across login (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Adding crashdump support (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Free tags allocate (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Fix to handle request_irq failure (Mike Christie) [585751 635746]
- [scsi] be2iscsi: No return value for hwi_enable_intr (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Fix for freeing cid (Mike Christie) [585751 635746]
- [scsi] be2iscsi: pass the return from beiscsi_open_conn (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Fixing the return type of functions (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Fixing return value (Mike Christie) [585751 635746]
- [scsi] be2iscsi: Fix warnings from new checkpatch.pl (Mike Christie) [585751 635746]
- [scsi] be2iscsi: fix null dereference on error path (Mike Christie) [585751 635746]
- [scsi] be2iscsi: fix memory leak on error path (Mike Christie) [585751 635746]
- [scsi] be2iscsi: fix disconnection cleanup (Mike Christie) [585751 635746]
- [scsi] be2iscsi: correct return value in mgmt_invalidate_icds (Mike Christie) [585751 635746]
- [scsi] ibft: convert iscsi_ibft module to iscsi boot lib (Mike Christie) [585751 635746]
- [scsi] ibft: separate ibft parsing from sysfs interface (Mike Christie) [585751 635746]
- [scsi] ibft: Use IBFT_SIGN instead of open-coding the search string (Mike Christie) [585751 635746]
- [scsi] ibft: For UEFI machines actually do scan ACPI for iBFT (Mike Christie) [585751 635746]
- [scsi] ibft: Update iBFT handling for v1.03 of the spec (Mike Christie) [585751 635746]
- [scsi] iscsi_ibft.c: remove NIPQUAD_FMT, use pI4 (Mike Christie) [585751 635746]
- [scsi] iscsi_ibft.c: use pM to show MAC address (Mike Christie) [585751 635746]
- [scsi] ibft, x86: Change reserve_ibft_region() to find_ibft_region() (Mike Christie) [585751 635746]
- [fs] inotify: rework inotify locking to prevent double free use when free in inotify (Eric Paris) [582109]
- [s390x] kernel: Enhanced node affinity support (Hendrik Brueckner) [632315]
- [netdrv] qeth: support for priority tags and VLAN-ID 0 tags (Hendrik Brueckner) [633570]
- [net] enable VLAN NULL tagging (Neil Horman) [633571]
- [s390x] qeth: fix online setting of OSN-devices (Hendrik Brueckner) [669218]
- [s390x] qeth: wait for recovery finish in open function (Hendrik Brueckner) [668845]
- [s390x] qdio: prevent race for shared indicators (Hendrik Brueckner) [668835]
- [s390x] qeth: l3 hw tx csum circumvent hw bug (Hendrik Brueckner) [663984]
- [s390x] mm: add devmem_is_allowed() for STRICT_DEVMEM checking (Hendrik Brueckner) [647365]
- [s390x] qeth: l3 add vlan hdr in passthru frames (Hendrik Brueckner) [659825]
- [s390x] kernel: nohz vs cpu hotplug system hang (Hendrik Brueckner) [668470]
- [s390x] qdio: use proper QEBSM operand for SIGA-R and SIGA-S (Hendrik Brueckner) [668468]
- [s390x] cio: prevent kernel panic when path to network device is lost (Hendrik Brueckner) [662747]
- [s390x] qeth: enable VIPA add/remove for offline devices (Hendrik Brueckner) [660688]
- [s390x] hvc_iucv: do not call iucv_unregister if iucv_register has failed (Hendrik Brueckner) [661108]
- [s390x] zcrypt: Handling of 4096 bit RSA keys in CRT format (Hendrik Brueckner) [633458]
- [s390x] zcrypt: cope with cca restriction of cex3 (Hendrik Brueckner) [633458]
- [s390x] zcrypt: support for 4096 bit keys for cex3c (Hendrik Brueckner) [633458]
- [s390x] zcrypt: support for 4096 bit keys for cex3a (Hendrik Brueckner) [633458]
- [s390x] zcrypt: Introduce check for 4096 bit support (Hendrik Brueckner) [633458]
- [s390x] dasd: Improve handling of stolen DASD reservation (Hendrik Brueckner) [644942]
- [s390x] dasd: add High Performance FICON multitrack support (Hendrik Brueckner) [632332]
- [s390x] cio: reduce memory consumption of itcw structures (Hendrik Brueckner) [632332]
- [s390x] cio: obtain mdc value per channel path (Hendrik Brueckner) [632332]
- [s390x] kernel: display capacity adjustment indicator in /proc/sysinfo (Hendrik Brueckner) [632023]
- [s390x] dasd: provide a Sense Path Group ID ioctl (Hendrik Brueckner) [644928]
- [s390x] dasd: Add tunable default grace period for missing interrupts (Hendrik Brueckner) [633386]
- [s390x] dasd: Add dasd part of cio internal unit check handling (Hendrik Brueckner) [633384]
- [s390x] dasd: add dynamic PAV toleration (Hendrik Brueckner) [631518]
- [s390x] zfcpdump: Add prefix registers to dump header (Hendrik Brueckner) [633454]
- [s390x] zfcp: HBA API completion to support events (Hendrik Brueckner) [633413]
- [s390x] dasd: improve error recovery for internal I/O (Hendrik Brueckner) [631497]
- [s390x] s390_hypfs: Add new binary attributes (Hendrik Brueckner) [631533]
- [s390x] memory hotplug: set phys_device (Hendrik Brueckner) [659474]
- [memory] allow setting of phys_device (memory hotplug) (Hendrik Brueckner) [659474]
- [s390x] kernel: fix clock comparator revalidation (Hendrik Brueckner) [658578]
- [s390x] vmlogrdr: purge after recording is switched off (Hendrik Brueckner) [653477]
- [s390x] zfcp: Cancel gid_pn work when removing port (Hendrik Brueckner) [653482]
- [s390x] smsgiucv_app: deliver z/VM CP special messages as uevents (Hendrik Brueckner) [632318]
- [s390x] qeth: exploit HW TX checksumming (Hendrik Brueckner) [633531]
- [s390x] qeth: NAPI support for l2 and l3 discipline (Hendrik Brueckner) [633525]
- [s390x] qdio: extend API to allow polling (Hendrik Brueckner) [633525]
- [s390x] cio: improve resume handling (Hendrik Brueckner) [633468]
- [s390x] cio: unit check handling during internal I/O (Hendrik Brueckner) [633384]
- [s390x] zfcp: Trigger logging in FCP channel on qdio error conditions (Hendrik Brueckner) [632331]
- [s390x] cio: add CHSC SIOSL Support (Hendrik Brueckner) [632331]
- [s390x] cio: introduce cio_settle (Hendrik Brueckner) [631517]

* Fri Jan 28 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-108.el6]
- [watchdog] hpwdt: Make NMI decoding a compile-time option (Tony Camuso) [462945]
- [watchdog] hpwdt: move NMI-decoding init and exit to seperate functions (Tony Camuso) [462945]
- [watchdog] hpwdt: Use "decoding" instead of "sourcing" (Tony Camuso) [462945]
- [watchdog] hpwdt: hpwdt_pretimeout reorganization (Tony Camuso) [462945]
- [watchdog] hpwdt: implement WDIOC_GETTIMELEFT (Tony Camuso) [462945]
- [watchdog] hpwdt: allow full range of timer values supported by hardware (Tony Camuso) [462945]
- [watchdog] hpwdt: Introduce SECS_TO_TICKS() macro (Tony Camuso) [462945]
- [watchdog] hpwdt: Make x86 assembly ifdef guard more strict (Tony Camuso) [462945]
- [watchdog] hpwdt: Despecificate driver from iLO2 (Tony Camuso) [462945]
- [watchdog] hpwdt: Group NMI sourcing specific items together (Tony Camuso) [462945]
- [watchdog] hpwdt: Group options that affect watchdog behavior together (Tony Camuso) [462945]
- [watchdog] hpwdt: clean-up include-files (Tony Camuso) [462945]
- [watchdog] hpwdt: formatting of pointers in printk() (Tony Camuso) [462945]
- [watchdog] hpwdt: fix lower timeout limit (Tony Camuso) [462945]
- [watchdog] hpwdt: make the watchdog_info struct const where possible (Tony Camuso) [462945]
- [scsi] fix id computation in scsi_eh_target_reset (Mike Christie) [643236]
- [scsi] fix the return value of scsi_target_queue_read() (Mike Christie) [643236]
- [fs] cifs: add cruid= mount option (Jeff Layton) [667654]
- [fs] ext3, ext4: update ctime when changing the file's permission by setfacl (Eric Sandeen) [668915]
- [net] update igbvf driver (Stefan Assmann) [636327]
- [scsi] fix locking around blk_abort_request() (Stanislaw Gruszka) [620391]
- [scsi] megaraid: update to version 5.29 (Tomas Henzl) [642052]
- [virt] MMU: only write protect mappings at pagetable level (Marcelo Tosatti) [634100]
- [virt] xen: disable ACPI NUMA for PV guests (Andrew Jones) [669773]
- [virt] xen: unplug the emulated devices at resume time (Paolo Bonzini) [667356]
- [virt] xenfs: enable for HVM domains too (Paolo Bonzini) [667361]
- [virt] KVM: Activate Virtualization On Demand (Avi Kivity) [616042]
- [pci] Fix KABI breakage (Prarit Bhargava) [661301]
- [pci] PCIe/AER: Disable native AER service if BIOS has precedence (Prarit Bhargava) [661301]
- [pci] aerdrv: fix uninitialized variable warning (Prarit Bhargava) [661301]
- [pci] hotplug: Fix build with CONFIG_ACPI unset (Prarit Bhargava) [661301]
- [pci] PCIe: Ask BIOS for control of all native services at once (Prarit Bhargava) [661301]
- [pci] PCIe: Introduce commad line switch for disabling port services (Prarit Bhargava) [661301]
- [pci] ACPI/PCI: Negotiate _OSC control bits before requesting them (Prarit Bhargava) [661301]
- [pci] ACPI/PCI: Make acpi_pci_query_osc() return control bits (Prarit Bhargava) [661301]
- [x86] ACPI: cleanup pci_root _OSC code (Prarit Bhargava) [661301]
- [pci] PCIe AER: Introduce pci_aer_available() (Prarit Bhargava) [661301]
- [pci] aerdrv: fix annoying warnings (Prarit Bhargava) [661301]
- [pci] aerdrv: trivial cleanup for aerdrv_core.c (Prarit Bhargava) [661301]
- [pci] aerdrv: trivial cleanup for aerdrv.c (Prarit Bhargava) [661301]
- [pci] aerdrv: introduce default_downstream_reset_link (Prarit Bhargava) [661301]
- [pci] aerdrv: rework find_aer_service (Prarit Bhargava) [661301]
- [pci] aerdrv: remove is_downstream (Prarit Bhargava) [661301]
- [pci] aerdrv: remove magical ROOT_ERR_STATUS_MASKS (Prarit Bhargava) [661301]
- [pci] aerdrv: redefine PCI_ERR_ROOT_*_SRC (Prarit Bhargava) [661301]
- [pci] aerdrv: rework do_recovery (Prarit Bhargava) [661301]
- [pci] aerdrv: rework get_e_source() (Prarit Bhargava) [661301]
- [pci] aerdrv: rework aer_isr_one_error() (Prarit Bhargava) [661301]
- [pci] aerdrv: rework add_error_device (Prarit Bhargava) [661301]
- [pci] aerdrv: remove compare_device_id (Prarit Bhargava) [661301]
- [pci] aerdrv: introduce is_error_source (Prarit Bhargava) [661301]
- [pci] aerdrv: rework find_source_device (Prarit Bhargava) [661301]
- [pci] aerdrv: make aer_{en, dis}able_rootport static (Prarit Bhargava) [661301]
- [pci] aerdrv: cleanup inconsistent functions (Prarit Bhargava) [661301]
- [pci] aerdrv: RsvdP of PCI_ERR_ROOT_COMMAND (Prarit Bhargava) [661301]
- [pci] aerdrv: use correct bit defines and add 2ms delay to aer_root_reset (Prarit Bhargava) [661301]
- [pci] change PCI nomenclature in drivers/pci/ (non-comment changes) (Prarit Bhargava) [661301]
- [pci] change PCI nomenclature in drivers/pci/ (comment changes) (Prarit Bhargava) [661301]
- [pci] remove ifdefed pci_cleanup_aer_correct_error_status (Prarit Bhargava) [661301]
- [pci] Remove unnecessary struct pcie_port_data (Prarit Bhargava) [661301]
- [pci] Backport upstream PCIE interrupt assignment code (Prarit Bhargava) [661301]
- [pci] PCIe AER: use pci_is_pcie() (Prarit Bhargava) [661301]
- [pci] introduce pci_is_pcie() (Prarit Bhargava) [661301]
- [pci] PCIe AER: use pci_pcie_cap() (Prarit Bhargava) [661301]
- [pci] fix memory leak in aer_inject (Prarit Bhargava) [661301]
- [pci] use better error return values in aer_inject (Prarit Bhargava) [661301]
- [pci] add support for PCI domains to aer_inject (Prarit Bhargava) [661301]

* Thu Jan 27 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-107.el6]
- [x86] lockup detector: enable config options (Don Zickus) [669808]
- [x86] lockup detector: Kconfig fixes to seperate hard and soft lockup options (Don Zickus) [669808]
- [x86] NMI: Add back unknown_nmi_panic and nmi_watchdog sysctls (Don Zickus) [669808]
- [x86] perf, arch: Cleanup perf-pmu init vs lockup-detector (Don Zickus) [669808]
- [x86] nmi: Add in new nmi_watchdog/softlockup changes (Don Zickus) [669808]
- [x86] Move notify_die from nmi.c to traps.c (Don Zickus) [669808]
- [kernel] perf_event backport (Peter Zijlstra) [672264]
- [scsi] fnic: Bumping up fnic version from 1.4.0.145 to 1.5.0.1 (Mike Christie) [663222]
- [scsi] fnic: fix memory leak (Mike Christie) [663222]
- [irq] Add new IRQ flag IRQF_NO_SUSPEND (Andrew Jones) [671147]
- [virt] xen: events: do not unmask event channels on resume (Andrew Jones) [671147]
- [virt] xen: Do not suspend IPI IRQs (Andrew Jones) [671147]
- [virt] ixp4xx-beeper: Use IRQF_NO_SUSPEND not IRQF_TIMER for non-timer interrupt (Andrew Jones) [671147]
- [fs] ext3: avoid WARN() messages when failing to write the superblock (Edward Shishkin) [591466]
- [fs] ext3: unify log messages (Edward Shishkin) [591466]
- [kernel] add 'make rh-perf' target (Jason Baron) [644991]
- [kernel] perf: .spec file updates (Jason Baron) [644991]
- [kernel] perf: updates from 2.6.34 -> 2.6.37 (Jason Baron) [644991]
- [kernel] perf: sync to 2.6.34 (Jason Baron) [644991]
- [x86] Westmere apicid fix (George Beshers) [635808]
- [x86] Fix a hard coded limit of a maximum of 16 cpu's per socket (George Beshers) [635808]
- [x86] uv: More Westmere support on SGI UV (George Beshers) [635808]
- [x86] uv: Enable Westmere support on SGI UV (George Beshers) [635808]
- [scsi] scsi_dh: propagate SCSI device deletion (Mike Snitzer) [669411]
- [scsi] scsi_dh_hp_sw: fix deadlock in start_stop_endio (Mike Snitzer) [652024]
- [scsi] scsi_dh_alua: add scalable ONTAP lun to dev list (Mike Snitzer) [667661]
- [scsi] scsi_dh_alua: Add Promise VTrak to dev list (Mike Snitzer) [652024]
- [scsi] scsi_dh_alua: fix stpg_endio group state reporting (Mike Snitzer) [652024]
- [scsi] scsi_dh_alua: fix deadlock in stpg_endio (Mike Snitzer) [652024]
- [scsi] scsi_dh_alua: fix submit_stpg return (Mike Snitzer) [652024]
- [pci] Fix mmap address check in pci_mmap_fits (Prarit Bhargava) [645287]
- [pci] fix size checks for mmap() on /proc/bus/pci files (Prarit Bhargava) [645287]
- [fs] GFS2: recovery stuck on transaction lock (Robert S Peterson) [672600]
- [fs] nfs4: fix units bug causing hang on recovery (J. Bruce Fields) [672345]
- [fs] ext4: Update ext4 documentation (Lukas Czerner) [519467]
- [fs] jbd2: fix /proc/fs/jbd2/<dev> when using an external (Lukas Czerner) [655875]
- [net] netfilter: nf_conntrack snmp helper (Jiri Olsa) [638176]
- [net] netfilter: audit target to record accepted/dropped packets (Thomas Graf) [642391]
- [net] packet_mmap: expose hw packet timestamps to network packet capture utilities (Thomas Graf) [645800]
- [scsi] bfa rebase reflecting scsi-misc bfa (Rob Evers) [641052]
- [scsi] libsas: Don't issue commands to devices that have been hot-removed (David Milburn) [669154]
- [security] crypto: mark ghash as fips_allowed (Jarod Wilson) [638133]
- [kernel] Fix over-scheduling bug (Jane Lv) [666484]
- [kernel] trace: add several tracepoints/scripts for analyzing network stack (Neil Horman) [611700]
- [sound] disable NVIDIA HDMI PCI device for Lenovo T410 models (Jaroslav Kysela) [662660]
- [sound] Update the ALSA HDA audio driver from upstream (Jaroslav Kysela) [583745 618797 619430 636922 637240 646771 663946 667460]
- [x86] UEFI IBM boot regression (Bob Picco) [668825]
- [netdrv] ehea: Add some info messages and fix an issue (Steve Best) [658185]

* Wed Jan 26 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-106.el6]
- [crypto] mark xts(aes) as fips_allowed (Jarod Wilson) [625489]
- [fs] nfsd: break lease on unlink, link, and rename (J. Bruce Fields) [626814]
- [fs] nfsd4: break lease on nfsd setattr (J. Bruce Fields) [626814]
- [fs] nfsd: remove some unnecessary dropit handling (J. Bruce Fields) [626814]
- [fs] nfsd: stop translating EAGAIN to nfserr_dropit (J. Bruce Fields) [626814]
- [fs] svcrpc: simpler request dropping (J. Bruce Fields) [626814]
- [fs] svcrpc: avoid double reply caused by deferral race (J. Bruce Fields) [626814]
- [fs] nfsd: don't drop requests on -ENOMEM (J. Bruce Fields) [626814]
- [x86] numa: Cacheline aliasing makes for_each_populated_zone extremely expensive (George Beshers) [635850]
- [scsi] mptas: version string change 3.04.18 (Tomas Henzl) [642618]
- [scsi] mptsas: Incorrect return value in mptscsih_dev_reset (Tomas Henzl) [642618]
- [scsi] mptsas: inDMD deleted (Tomas Henzl) [642618]
- [scsi] mptsas: remove bus reset (Tomas Henzl) [642618]
- [scsi] mptsas: 3gbps - 6gbps (Tomas Henzl) [642618]
- [scsi] mptsas: sysfs sas addr handle (Tomas Henzl) [642618]
- [scsi] mptsas: fix warning when not using procfs (Tomas Henzl) [642618]
- [scsi] mptsas: Fix 32 bit platforms with 64 bit resources (Tomas Henzl) [642618]
- [scsi] mptsas: convert to seq_file (Tomas Henzl) [642618]
- [scsi] mptsas: use module_param in drivers/message/fusion/mptbase.c (Tomas Henzl) [642618]
- [scsi] mptsas: drivers/message/fusion: Adjust confusing indentation (Tomas Henzl) [642618]
- [scsi] mptsas: print Doorbell register in a case of hard reset and timeout (Tomas Henzl) [642618]
- [scsi] mptsas: fixed hot-removal processing (Tomas Henzl) [642618]
- [scsi] mptsas: Cleanup some duplicate calls in mptbase.c (Tomas Henzl) [642618]
- [scsi] mptsas: Added missing reset for ioc_reset_in_progress in SoftReset (Tomas Henzl) [642618]
- [scsi] mptsas: Proper error handling is added after mpt_config timeout (Tomas Henzl) [642618]
- [scsi] mptsas: Event data alignment with 4 byte (Tomas Henzl) [642618]
- [scsi] mptsas: Check for command status is added after completion (Tomas Henzl) [642618]
- [scsi] mptsas: Task abort is not supported for Volumes (Tomas Henzl) [642618]
- [scsi] mptsas: sanity check for vdevice pointer is added (Tomas Henzl) [642618]
- [scsi] mptsas: Setting period, offset and width for SPI driver (Tomas Henzl) [642618]
- [scsi] mptsas: Proper bus_type check is added (Tomas Henzl) [642618]
- [scsi] mptsas: mpt_detach is called properly at the time of rmmod (Tomas Henzl) [642618]
- [scsi] mptsas: mpt config will do Hard Reset based upon retry counts (Tomas Henzl) [642618]
- [scsi] mptsas: Updated SCSI IO IOCTL error handling (Tomas Henzl) [642618]
- [scsi] mptsas: Added new less expensive RESET (Message Unit Reset) (Tomas Henzl) [642618]
- [scsi] mptsas: modify mptctl_exit() to call proper deregister functions (Tomas Henzl) [642618]
- [scsi] mptsas: hold off error recovery while alternate ioc is initializing (Tomas Henzl) [642618]
- [scsi] mptsas: corrected if condition check for SCSIIO and PASSTHROUGH commands (Tomas Henzl) [642618]
- [scsi] mptsas: block device when target is being removed by FW (Tomas Henzl) [642618]
- [scsi] mptsas: Added sysfs expander manufacture information (Tomas Henzl) [642618]
- [scsi] mptsas: Added-MPI_SCSIIO_CONTROL_HEADOFQ-priority (Tomas Henzl) [642618]
- [fs] ext4: Add FITRIM ioctl to handle ext4 batched discard (Lukas Czerner) [651021]
- [fs] ext4: Add batched discard support for ext4 (Lukas Czerner) [651021]
- [fs] ext4: Create ext4 helper for sb_issue_discard (Lukas Czerner) [651021]
- [fs] Added a #include to eliminate a compilation failure (Steve Dickson) [479351]
- [fs] pnfs: layout roc code (Steve Dickson) [479351]
- [fs] pnfs: update nfs4_callback_recallany to handle layouts (Steve Dickson) [479351]
- [fs] pnfs: add CB_LAYOUTRECALL handling (Steve Dickson) [479351]
- [fs] pnfs: CB_LAYOUTRECALL xdr code (Steve Dickson) [479351]
- [fs] pnfs: change lo refcounting to atomic_t (Steve Dickson) [479351]
- [fs] pnfs: check that partial LAYOUTGET return is ignored (Steve Dickson) [479351]
- [fs] pnfs: add layout to client list before sending rpc (Steve Dickson) [479351]
- [fs] pnfs: serialize LAYOUTGET(openstateid) (Steve Dickson) [479351]
- [fs] pnfs: layoutget rpc code cleanup (Steve Dickson) [479351]
- [fs] pnfs: change how lsegs are removed from layout list (Steve Dickson) [479351]
- [fs] pnfs: change layout state seqlock to a spinlock (Steve Dickson) [479351]
- [fs] pnfs: add prefix to struct pnfs_layout_hdr fields (Steve Dickson) [479351]
- [fs] pnfs: add prefix to struct pnfs_layout_segment fields (Steve Dickson) [479351]
- [fs] pnfs: remove unnecessary field lgp->status (Steve Dickson) [479351]
- [fs] pnfs: fix incorrect comment in destroy_lseg (Steve Dickson) [479351]
- [fs] NFS: rename client back channel transport field (Steve Dickson) [479351]
- [fs] NFS: add session back channel draining (Steve Dickson) [479351]
- [fs] NFS: RPC_AUTH_GSS unsupported on v4.1 back channel (Steve Dickson) [479351]
- [fs] NFS refactor nfs_find_client and reference client across callback processing (Steve Dickson) [479351]
- [fs] nfs41: do not allocate unused back channel pages (Steve Dickson) [479351]
- [fs] NFS associate sessionid with callback connection (Steve Dickson) [479351]
- [fs] NFS implement v4.0 callback_ident (Steve Dickson) [479351]
- [fs] NFS: do not clear minor version at nfs_client free (Steve Dickson) [479351]
- [fs] NFS: use svc_create_xprt for NFSv4.1 callback service (Steve Dickson) [479351]
- [fs] SUNRPC: register and unregister the back channel transport (Steve Dickson) [479351]
- [fs] SUNRPC: new transport for the NFSv4.1 shared back channel (Steve Dickson) [479351]
- [fs] SUNRPC: fix bc_send print (Steve Dickson) [479351]
- [fs] SUNRPC: move svc_drop to caller of svc_process_common (Steve Dickson) [479351]
- [netdrv] qlge: Fix deadlock when cancelling worker (Chad Dupuis) [635703]
- [netdrv] qlge: New release P27 (Chad Dupuis) [635703]
- [netdrv] qlge: Generate the coredump to ethtool user buffer (Chad Dupuis) [635703]
- [netdrv] qlge: pull NULL check ahead of dereference (Chad Dupuis) [635703]
- [netdrv] qlge: Fix a deadlock when the interface is going down (Chad Dupuis) [635703]
- [netdrv] qlge: reset the chip before freeing the buffers (Chad Dupuis) [635703]
- [netdrv] qlge: Restoring the vlan setting during ql_adapter_up (Chad Dupuis) [635703]
- [netdrv] qlge: New release P25 (Chad Dupuis) [635703]
- [netdrv] qlge: fix a eeh handler to not add a pending timer (Chad Dupuis) [635703]
- [netdrv] qlge: New release P24 (Chad Dupuis) [635703]
- [netdrv] qlge: Remove all error packet flags and enable tcp/udp and ip csum error (Chad Dupuis) [635703]
- [netdrv] qlge: Restoring the promiscuous setting in ql_adapter_up (Chad Dupuis) [635703]
- [netdrv] qlge: Changing cpu_to_be16 to htons for udp checksum (Chad Dupuis) [635703]
- [netdrv] qlge: Eliminate firmware dependency for MPI coredump (Chad Dupuis) [635703]
- [kernel] driver core: Convert link_mem_sections to use find_memory_block_hinted (George Beshers) [635866]
- [kernel] driver core: Introduce find_memory_block_hinted which utilizes kset_find_obj_hinted (George Beshers) [635866]
- [kernel] kobject: Introduce kset_find_obj_hinted (George Beshers) [635866]
- [x86] UV: memory_block_size_bytes for x86_64 when CONFIG_X86_UV (George Beshers) [635866]
- [ppc] add dynamic dma window support (Steve Best) [632770]
- [ppc] add memory_hotplug_max (Steve Best) [632770]
- [ppc] dma: Add optional platform override of dma_set_mask() (Steve Best) [632770]
- [x86] therm_throt.c: Trivial printk message fix for a unsuitable abbreviation of 'thermal' (Prarit Bhargava) [666859]
- [x86] mce: Notify about corrected events too (Prarit Bhargava) [666859]
- [x86] asm: Introduce and use percpu_inc() (Prarit Bhargava) [666859]
- [mm] memory hotplug: fix notifier's return value check (Steve Best) [632694]
- [powerpc] Make the CMM memory hotplug aware (Steve Best) [632694]
- [mm] Add notifier in pageblock isolation for balloon drivers (Steve Best) [632694]
- [kernel] tracing: Allow to disable cmdline recording (Jiri Olsa) [632065]
- [kernel] tracing: Combine event filter_active and enable into single flags field (Jiri Olsa) [632065]
- [fs] GFS2: [RFE] glock scalability patches (Abhijith Das) [656939]
- [net] bonding: prevent sysfs from allowing arp monitoring with alb/tlb (Andy Gospodarek) [605189]
- [net] fix oops in RPS when netdevice has no parent dev (Neil Horman) [670907]
- [scsi] libsas: fix bug for vacant phy (David Milburn) [668754]
- [scsi] sr: fix sr_drive_status handling when initialization required (Tomas Henzl) [663159]

* Tue Jan 25 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-105.el6]
- [ppc] Export memstart_addr and kernstart_addr on ppc64 (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] fix compiling problem with i386 (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4: add ConnectX-3 PCI IDs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4: fix mc usage after IBoE addition (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3/t3_hw.c: use new hex_to_bin() method (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] uverbs: Handle large number of entries in poll CQ (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: fix MAC address hash filter (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Fix information leak in marshalling code (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] pack: Remove some unused code added by the IBoE patches (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] mlx4: Fix IBoE link state (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] mlx4: Fix IBoE reported link rate (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_core: Workaround firmware bug in query dev cap (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] mlx4: Fix memory ordering of VLAN insertion control bits (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: Integer overflow in RDS cmsg handling (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: Fix rds message leak in rds_message_map_pages (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: Remove kfreed tcp conn from list (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: Lost locking in loop connection freeing (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: remove call to stop TX queues at load time (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3: remove call to stop TX queues at load time (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Let rds_message_alloc_sgs() return NULL (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Copy rds_iovecs into kernel memory instead of rereading from userspace (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Clean up error handling in rds_cmsg_rdma_args (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Return -EINVAL if rds_rdma_pages returns an error (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] fix rds_iovec page count overflow (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3: Fix panic in free_tx_desc() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3: fix crash due to manipulating queues before registration (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [kernel] kernel.h: add {min,max}3 macros (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: clean up properly if pci_set_consistent_dma_mask() fails (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Allow driver to load if PCIe AER fails (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Fix uninitialized pointer if CONFIG_PCI_MSI not set (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Fix extra log level in qib_early_err() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Remove unnecessary KERN_<level> use (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb3: Remove unnecessary KERN_<level> use (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Fix out of bounds array access (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3: fix device opening error path (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] core: Add link layer type information to sysfs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] mlx4: Add VLAN support for IBoE (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] core: Add VLAN support for IBoE (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] mlx4: Add support for IBoE (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Change multicast promiscuous mode to support IBoE (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_core: Update data structures and constants for IBoE (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_core: Allow protocol drivers to find corresponding interfaces (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] uverbs: Return link layer type to userspace for query port operation (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] srp: Sync buffer before posting send (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] srp: Use list_first_entry() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] srp: Reduce number of BUSY conditions (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] srp: Eliminate two forward declarations (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: fix crash due to manipulating queues before registration (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4: make functions local and remove dead code (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] mlx4: Signal node desc changes to SM by using FW to generate trap 144 (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Replace EXTRA_CFLAGS with ccflags-y (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [kernel] kernel.h: add BUILD_BUG_ON_NOT_POWER_OF_2() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] ucma: Allow tuning the max listen backlog (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Set dev_id field of net_device (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] srp: Implement SRP_CRED_REQ and SRP_AER_REQ (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] srp: Preparation for transmit ring response allocation (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Process RDMA WRITE ONLY with IMMEDIATE properly (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb3: When a user QP is marked in error, also mark the CQs in error (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Use cxgb4 service for packet gl to skb (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Export T4 TCP MIB (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3: function namespace cleanup (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: make local functions/variables static (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: function namespace cleanup (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] fix mlx4 kconfig dependency warning (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] pack: IBoE UD packet packing support (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cm: Add RDMA CM support for IBoE devices (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] mad: IBoE supports only QP1 (no QP0) (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Skip IBoE ports (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] iwcm: Fix hang in uninterruptible wait on cm_id destroy (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Use simple_read_from_buffer() for debugfs handlers (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Add default_llseek to debugfs files (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] mlx4: Limit size of fast registration WRs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Turn carrier off on ifdown (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Report correct port state if interface is down (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] ehca: Fix driver on relocatable kernel (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: remove a bogus PCI function number check (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] umad: Make user_mad semaphore a real one (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] amso1100: Remove KERN_<level> from pr_<level> use (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Remove unneeded variable (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Set pkt_type correctly for multicast packets (fix IGMP breakage) (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Fastreg NSMR fixes (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Don't set completion flag for read requests (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Set the default TCP send window to 128KB (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Use a mutex for QP and EP state transitions (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Support on-chip SQs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Centralize the wait logic (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: debugfs files for dumping active stags (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Log HW lack-of-resource errors (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Handle CPL_RDMA_TERMINATE messages (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Ignore TERMINATE CQEs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Ignore positive return values from cxgb4_*_send() functions (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Zero out ISGL padding (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Don't use null ep ptr (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Fix cast-to-pointer warnings on 32-bit (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] core: Add link layer property to ports (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Revert "[infiniband] Add IBoE support" (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Revert "[infiniband] mlx4: enable IBoE feature" (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Fix warnings about casts to/from pointers of different sizes (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb3: Turn off RX coalescing for iWARP connections (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] fix a lockdep splat (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Remove unnecessary casts of private_data (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: spin_lock_irq() is not nestable (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: double unlock in rds_ib_cm_handle_connect() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: signedness bug (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3/cxgb3_main.c: prevent reading uninitialized stack memory (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3: remove undefined operations (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Implement masked atomic operations (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] print string constants in more places (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: cancel connection work structs as we shut down (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: don't call rds_conn_shutdown() from rds_conn_destroy() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: have sockets get transport module references (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: remove old rs_transport comment (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: lock rds_conn_count decrement in rds_conn_destroy() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] protect the list of IB devices (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] print IB event strings as well as their number (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: flush fmrs before allocating new ones (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: properly use sg_init_table (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] track signaled sends (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: remove __init and __exit annotation (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Use SLAB_HWCACHE_ALIGN flag for kmem_cache_create() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] always process recv completions (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: return to a single-threaded krdsd (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] create a work queue for FMR flushing (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] destroy connections on rmmod (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] wait for IB dev freeing work to finish during rmmod (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Make ib_recv_refill return void (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Remove unused XLIST_PTR_TAIL and xlist_protect() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: whitespace (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: use delayed work for the FMR flushes (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: more FMRs are faster (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: recycle FMRs through lockless lists (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: fix rds_send_xmit() serialization (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: block ints when acquiring c_lock in rds_conn_message_info() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: remove unused rds_send_acked_before() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: use friendly gfp masks for prefill (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Add caching of frags and incs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Remove ib_recv_unmap_page() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Assume recv->r_frag is always NULL in refill_one() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Use page_remainder_alloc() for recv bufs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] disconnect when IB devices are removed (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: introduce rds_conn_connect_if_down() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] add refcount tracking to struct rds_ib_device (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] get the xmit max_sge from the RDS IB device on the connection (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] rds_ib_cm_handle_connect() forgot to unlock c_cm_lock (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: Fix reference counting on the for xmit_atomic and xmit_rdma (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: use RCU to protect the connection hash (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: use locking on the connection hash list (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: Fix RDMA message reference counting (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: don't let RDS shutdown a connection while senders are present (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: Use RCU for the bind lookup searches (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] add _to_node() macros for numa and use {k, v}malloc_node() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Remove unused variable in ib_remove_addr() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: rcu-ize rds_ib_get_device() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: per-rm flush_wait waitq (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: switch to rwlock on bind_lock (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Update comments in rds_send_xmit() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Use a generation counter to avoid rds_send_xmit loop (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Get pong working again (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Do wait_event_interruptible instead of wait_event (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Remove send_quota from send_xmit() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Move atomic stats from general to ib-specific area (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: rds_message_unmapped() doesn't need to check if queue active (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Fix locking in send on m_rs_lock (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Use NOWAIT in message_map_pages() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Bypass workqueue when queueing cong updates (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Call rds_send_xmit() directly from sendmsg() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: rds_send_xmit() locking/irq fixes (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Change send lock from a mutex to a spinlock (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Refill recv ring directly from tasklet (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Stop supporting old cong map sending method (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Do not wait for send ring to be empty on conn shutdown (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Perform unmapping ops in stages (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Make sure cmsgs aren't used in improper ways (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Add flag for silent ops. Do atomic op before RDMA (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Move some variables around for consistency (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: queue failure notifications for dropped atomic ops (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Add a warning if trying to allocate 0 sgs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Do not set op_active in r_m_copy_from_user() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Rewrite rds_send_xmit (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Rename data op members prefix from m_ to op_ (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Remove struct rds_rdma_op (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: purge atomic resources too in rds_message_purge() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Inline rdma_prepare into cmsg_rdma_args (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Implement silent atomics (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Move loop-only function to loop.c (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Make all flow control code conditional on i_flowctl (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Remove unsignaled_bytes sysctl (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: rewrite rds_ib_xmit (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Remove ib_[header/data]_sge() functions (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Remove dead code (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Disallow connections less than RDS 3.1 (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] eliminate duplicate code (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: inc_purge() transport function unused - remove it (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Whitespace (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Do not mask address when pinning pages (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Base init_depth and responder_resources on hw values (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Implement atomic operations (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Clear up some confusing code in send_remove_from_sock (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: make sure all sgs alloced are initialized (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: make m_rdma_op a member of rds_message (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: fold rdma.h into rds.h (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Explicitly allocate rm in sendmsg() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: cleanup/fix rds_rdma_unuse (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: break out rdma and data ops into nested structs in rds_message (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: cleanup: remove "== NULL"s and "!= NULL"s in ptr comparisons (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: move rds_shutdown_worker impl. to rds_conn_shutdown (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Fix locking in send on m_rs_lock (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Rewrite rds_send_drop_to() for clarity (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Fix corrupted rds_mrs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Fix BUG_ONs to not fire when in a tasklet (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Fix hang with modified FIN handling on A0 cards (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Change state to closing after FIN (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Fix double CLOSE event indication crash (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Write correct register write to set TX pause param (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Fixed Ethtool statistics report (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Consider napi_get_frags() failure (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb3: Don't exceed the max HW CQ depth (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4: use bitmap library (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Fix build warning in mlx4_en_create_rx_ring (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: updated driver version (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Moving to work with GRO (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: reconfiguring mac address (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: get/set ringsize uses actual ring size (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Fixing report in Ethtool get_settings (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Added self diagnostics test implementation (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Validate port up prior to transmitting (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Reporting link state with KERN_INFO (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Fixed MAX_TX_RINGS definition (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: performing CLOSE_PORT at the end of tear-down process (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Setting dev->perm_addr field (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Setting actual RX ring size (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: Fixed incorrect unmapping on RX flow (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: update PCI ids (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: fix setting of the function number in transmit descriptors (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: support eeprom read/write on functions other than 0 (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: handle Rx/Tx queue ranges not starting at 0 (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4: remove num_lro parameter (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: fix a leak of kernel memory (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] Convert unbounded kzalloc calls to kcalloc (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Obtain RDMA QID ranges from LLD/FW (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Add missing <linux/slab.h> include (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] ehca: Drop unnecessary NULL test (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Fix confusing if statement indentation (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3: do not use PCI resources before pci_enable_device() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Fix misindented code (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Fix showing wqm_quanta (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Get rid of "set but not used" variables (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Read firmware version from correct place (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] srp: Export req_lim via sysfs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] srp: Make receive buffer handling more robust (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] srp: Use print_hex_dump() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Rename RAW_ETY to RAW_ETHERTYPE (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Fix two sparse warnings (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb3: Make needlessly global iwch_l2t_send() static (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Add timeouts when waiting for FW responses (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Fix race between qib_error_qp() and receive packet processing (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Limit the number of packets processed per interrupt (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Allow writes to the diag_counters to be able to clear them (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Set cfgctxts to number of CPUs by default (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Set/reset the EP timer inside EP lock (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Use correct control txq (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Fix race in fini path (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: update driver version (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: add new PCI IDs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: fix wrong shift direction (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: support running the driver on PCI functions besides 0 (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: advertise NETIF_F_TSO_ECN (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: get on-chip queue info from FW and create a memory window for them (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: fix TSO descriptors (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: don't offload Rx checksums for IPv6 fragments (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: disable an interrupt that is neither used nor serviced (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cm: Check LAP state before sending an MRA (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Fix hangs on ifdown (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Store and print eeprom version (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Convert pci_table entries to PCI_VDEVICE (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Allow PSM to select from multiple port assignment algorithms (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Turn off IB latency mode (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Use generic_file_llseek (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Support variable sized work requests (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb3: Clean up signed check of unsigned variable (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Remove dependency on __GFP_NOFAIL (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Add module option to tweak delayed ack (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] ipath: Fix probe failure path (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Remove unnecessary casts of private_data (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Avoid variable-length array (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Remove unneeded NULL check (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Remove unneeded assignment (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Rewrite expression to avoid undefined semantics (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] umad: Remove unused-but-set variable 'already_dead' (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: exclude registers with read side effects from register dumps (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: avoid duplicating some resource freeing code (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: move the choice of interrupt type before net_device registration (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Use request_firmware() to load SD7220 firmware (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: Use kfree_skb for skb pointers (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Fix world-writable child interface control sysfs attributes (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Clean up properly if qib_init() fails (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Completion queue callback needs to be single threaded (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Update 7322 serdes tables (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Clear 6120 hardware error register (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Clear eager buffer memory for each new process (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Mask hardware error during link reset (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Don't mark VL15 bufs as WC to avoid a rare 7322 chip problem (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Derive smac_idx from port viid (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Avoid false GTS CIDX_INC overflows (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Don't call abort_connection() for active connect failures (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4vf: Add code to provision T4 PCI-E SR-IOV Virtual Functions with hardware resources (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4vf: Add new macros and definitions for hardware constants (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4vf: update to latest T4 firmware API file (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4vf: small changes to message processing structures/macros (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3: request 7.10 firmware (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: minor cleanup (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: update FW definitions (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: add a missing error interrupt (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: propagate link initialization errors to .ndo_open's callers (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: set dev_id to the port number (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: implement EEH (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: rearrange initialization code in preparation for EEH (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: dynamically determine flash size and FW image location (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] fix the deadlock in qib_fs (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_en: use net_device dev_id to indicate port number (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb3: Use memdup_user (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: Add missing mutex_unlock (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Remove DCA support until feature is finished (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] ehca: convert cpu notifier to return encapsulate errno value (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Use a single txselect module parameter for serdes tuning (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Don't rely on (undefined) order of function parameter evaluation (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] ucm: Use memdup_user() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Fix undefined symbol error when CONFIG_PCI_MSI=n (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Fix incorrect unlock in nes_process_mac_intr() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Async event for closed QP causes crash (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Have ethtool read hardware registers for rx/tx stats (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Only insert sq qid in lookup table (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Support IB_WR_READ_WITH_INV opcode (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Set fence flag for inv-local-stag work requests (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Update some HW limits (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Don't limit fastreg page list depth (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Return proper errors in fastreg mr/pbl allocation (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Fix overflow bug in CQ arm (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Optimize CQ overflow detection (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: CQ size must be IQ size - 2 (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Register RDMA provider based on LLD state_change events (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Detach from the LLD after unregistering RDMA device (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] ipath: Remove support for QLogic PCIe QLE devices (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] qib: Add new qib driver for QLogic PCIe InfiniBand adapters (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] mad: Make needlessly global mad_sendq_size/mad_recvq_size static (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] core: Allow device-specific per-port sysfs files (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_core: Clean up mlx4_alloc_icm() a bit (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] mlx4_core: Fix possible chunk sg list overflow in mlx4_alloc_icm() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: notify upper drivers if the device is already up when they load (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: keep interrupts available when the ports are brought down (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: fix initial addition of MAC address (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] core: Use kmemdup() instead of kmalloc()+memcpy() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: report GRO stats with ethtool -S (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: configure HW VLAN extraction through FW (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] MAINTAINERS: Add cxgb4 and iw_cxgb4 entries (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb3: Shrink .text with compile-time init of handlers arrays (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: increase serial number length (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: Make unnecessarily global functions static (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [netdrv] cxgb4: Use ntohs() on __be16 value instead of htons() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Allow disabling/enabling TSO on the fly through ethtool (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] mlx4: Add support for masked atomic operations (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] core: Add support for masked atomic operations (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cma: Randomize local port allocation (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Make unnecessarily global functions static (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] nes: Make nesadapter->phy_lock usage consistent (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [kernel] Enable the new kfifo API (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [kernel] kfifo: add the new generic kfifo API (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb4: Add driver for Chelsio T4 RNIC (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] cxgb3: Don't free skbs on NET_XMIT_* indications from LLD (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Explicitly rule out llseek to avoid BKL in default_llseek() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] rds: cleanup: remove unneeded variable (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] ipoib: remove addrlen check for mc addresses (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] convert multiple drivers to use netdev_for_each_mc_addr (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Enable per-cpu workqueue threads (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Do not call set_page_dirty() with irqs off (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Properly unmap when getting a remote access error (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: only put sockets that have seen congestion on the poll_waitq (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Fix locking in rds_send_drop_to() (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Turn down alarming reconnect messages (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Workaround for in-use MRs on close causing crash (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Fix send locking issue (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Fix congestion issues for loopback (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS/TCP: Wait to wake thread when write space available (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: update copy_to_user state in tcp transport (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: sendmsg() should check sndtimeo, not rcvtimeo (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [net] RDS: Do not BUG() on error returned from ib_post_send (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] Fix typos in comments (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}
- [infiniband] ib_qib: back out driver entirely (Doug Ledford) [607396 633157 633329 633875 635914 660674 660680] {CVE-2010-3296}

* Tue Jan 25 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-104.el6]
- [ppc] fix oops in device_pm_remove (Steve Best) [632683]
- [fs] Allow gfs2 to update quota usage through the quotactl interface (Steven Whitehouse) [671267]
- [x86] thp: pte alloc trans splitting (John Villalovos) [464222]
- [x86] Enable CONFIG_INTEL_TXT so that Intel Trusted Execution Technology can work (John Villalovos) [464222]
- [scsi] pmcraid: disable msix and expand device config entry (Rob Evers) [633880]
- [scsi] pmcraid: add support for set timestamp command and other fixes (Rob Evers) [633880]
- [scsi] pmcraid: MSI-X support and other changes (Rob Evers) [633880]
- [kprobes] x86, alternative: Call stop_machine_text_poke() on all cpus (Jiri Olsa) [464658]
- [kprobes] Remove redundant text_mutex lock in optimize (Jiri Olsa) [464658]
- [kprobes] Add sparse context annotations (Jiri Olsa) [464658]
- [kprobes] Remove __dummy_buf (Jiri Olsa) [464658]
- [kprobes] Make functions static (Jiri Olsa) [464658]
- [kprobes] Verify jprobe entry point (Jiri Olsa) [464658]
- [kprobes] Remove redundant address check (Jiri Olsa) [464658]
- [kprobes] x86: Fix the return address of multiple kretprobes (Jiri Olsa) [464658]
- [kprobes] x86: fix swapped segment registers in kretprobe (Jiri Olsa) [464658]
- [kprobes] Move enable/disable_kprobe() out from debugfs code (Jiri Olsa) [464658]
- [kprobes] Calculate the index correctly when freeing the out-of-line execution slot (Jiri Olsa) [464658]
- [kprobes] x86: Issue at least one memory barrier in stop_machine_text_poke() (Jiri Olsa) [464658]
- [kprobes] x86: Support kprobes jump optimization on x86 (Jiri Olsa) [464658]
- [kprobes] x86: Add text_poke_smp for SMP cross modifying code (Jiri Olsa) [464658]
- [kprobes] x86: Cleanup save/restore registers (Jiri Olsa) [464658]
- [kprobes] x86: Boost probes when reentering (Jiri Olsa) [464658]
- [kprobes] Jump optimization sysctl interface (Jiri Olsa) [464658]
- [kprobes] Introduce kprobes jump optimization (Jiri Olsa) [464658]
- [kprobes] Introduce generic insn_slot framework (Jiri Olsa) [464658]
- [kprobes] x86: Cleanup RELATIVEJUMP_INSTRUCTION to RELATIVEJUMP_OPCODE (Jiri Olsa) [464658]
- [kprobes] Add mcount to the kprobes blacklist (Jiri Olsa) [464658]
- [kprobes] Check probe address is reserved (Jiri Olsa) [464658]
- [kprobes] x86/alternatives: Fix build warning (Jiri Olsa) [464658]
- [kprobes] ftrace/alternatives: Introducing *_text_reserved functions (Jiri Olsa) [464658]
- [kprobes] Disable booster when CONFIG_PREEMPT=y (Jiri Olsa) [464658]
- [kprobes] Fix distinct type warning (Jiri Olsa) [464658]
- [kprobes] Sanitize struct kretprobe_instance allocations (Jiri Olsa) [464658]
- [kprobes] x86: use kernel_stack_pointer() in kprobes.c (Jiri Olsa) [464658]
- [kprobes] Prevent re-registration of the same kprobe (Jiri Olsa) [464658]
- [kprobes] x86-32: Move irq-exit functions to kprobes section (Jiri Olsa) [464658]
- [kprobes] Prohibit to probe native_get_debugreg (Jiri Olsa) [464658]
- [kprobes] x86-64: Allow to reenter probe on post_handler (Jiri Olsa) [464658]
- [kprobes] x86: Call BUG() when reentering probe into KPROBES_HIT_SS (Jiri Olsa) [464658]
- [kprobes] tracing: Dump the culprit kprobe in case of kprobe recursion (Jiri Olsa) [464658]
- [kprobes] Cleanup fix_riprel() using insn decoder on x86 (Jiri Olsa) [464658]
- [kprobes] Checks probe address is instruction boudary on x86 (Jiri Olsa) [464658]
- [fs] fix kernel panic at __rpc_create_common() when mounting nfs (Takashi Sato) [670734]
- [fs] inotify: stop kernel memory leak on file creation failure (Eric Paris) [656832] {CVE-2010-4250}
- [fs] GFS2: remove iopen glocks from cache on failed deletes (Benjamin Marzinski) [669877]
- [fs] ext2, ext3: directory handling speedups for smaller blocksizes (Eric Sandeen) [520462]
- [powerpc] add support for new hcall H_BEST_ENERGY (Steve Best) [630086]
- [mm] filemap: fix race condition in xip_file_fault (Hendrik Brueckner) [623251]
- [fs] nfs4: set source address when callback is generated (J. Bruce Fields) [662589]
- [net] ipv4: correct IGMP behavior on v2/v3 query responses (Jiri Pirko) [671153]
- [net] Fix definition of netif_vdbg() when VERBOSE_DEBUG is not defined (Michal Schmidt) [669749]
- [net] sctp: fix kernel panic resulting from mishandling of icmp dest unreachable msg (Neil Horman) [667029]
- [net] backport Receive Packet Steering (Neil Horman) [620680]
- [scsi] scsi_dh_alua: fix overflow in alua_rtpg port group id check (Mike Snitzer) [670572]
- [scsi] libsas: fix definition of wideport, include local sas address (David Milburn) [669782]
- [kernel] tracing: fix recursive user stack trace (Jiri Olsa) [602804]
- [security] audit: include subject in login records (Eric Paris) [670328]
- [security] audit: consistent naming of field types in tty audit logs (Eric Paris) [670556]
- [security] audit: capture mmap arguments in audit logs (Eric Paris) [661398]
- [perf] sched: Use PTHREAD_STACK_MIN to avoid pthread_attr_setstacksize() fail (Jiri Pirko) [663891]
- [kernel] lib: fix vscnprintf() if @size is == 0 (Anton Arapov) [667328]
- [usb] EHCI: AMD periodic frame list table quirk (Don Zickus) [651332]
- [kernel] tracing: Shrink max latency ringbuffer if unnecessary (Jarod Wilson) [632063]
- [edac] i7core_edac: return -ENODEV if no MC is found (Mauro Carvalho Chehab) [646505]
- [block] mmc: Add support for O2Micro SD/MMC (John Feeney) [637243]
- [sound] ALSA: add snd-aloop module (Jaroslav Kysela) [647012]
- [x86] Add ACPI APEI support (Matthew Garrett) [641036]
- [x86] Enabling/Fixing Warm reboots on Dell UEFI systems (Shyam Iyer) [641434]
- [x86] Add Intel Intelligent Power Sharing driver (Matthew Garrett) [513536]
- [x86] Include support for DMI OEM flag to set pci=bfsort in future Dell systems (Shyam Iyer) [658537]
- [x86] Add support for Sandybridge temperature monitoring and thermal/power throttling (Matthew Garrett) [638254]
- [x86] cpuidle: Add a repeating pattern detector to the menu governor (Matthew Garrett) [638259]
- [virt] virtio: remove virtio-pci root device (Michael S. Tsirkin) [583064]
- [virt] xen/events: change to using fasteoi (Andrew Jones) [667359]
- [virt] x86/pvclock: Zero last_value on resume (Andrew Jones) [663755]
- [netdrv] e1000: prevent unhandled IRQs from taking down virtual machines (Dean Nelson) [655521]
- [netdrv] ixgbevf: update to upstream version 1.0.19-k0 (Andy Gospodarek) [636329]
- [netdrv] enic: update to upstream version 1.4.1.10 (Andy Gospodarek) [641092]
- [netdrv] sfc: update to current upstream version with SFC9000 support (Michal Schmidt) [556563]
- [netdrv] ath9k: fix inconsistent lock state (Stanislaw Gruszka) [669373]
- [mm] writeback: write_cache_pages doesn't terminate at nr_to_write <= 0 (Josef Bacik) [638349]
- [mm] allow MMCONFIG above 4GB (Seiji Aguchi) [635753]
- [mm] install_special_mapping skips security_file_mmap check (Frantisek Hrbata) [662199] {CVE-2010-4346}
- [mm] KSM on THP (Andrea Arcangeli) [647334]
- [mm] performance optimization to retry page fault when blocking on disk transfer (Larry Woodman) [667186]
- [mm] allocate memory in khugepaged outside of mmap_sem write mode (Andrea Arcangeli) [647849]
- [mm] make exclusively owned pages belong to the local anon_vma on swapin (Rik van Riel) [617199]

* Sat Jan 22 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-103.el6]
- [security] selinux: include vmalloc.h for vmalloc_user (Eric Paris) [667225]
- [security] selinux: implement mmap on /selinux/policy (Eric Paris) [667225]
- [security] SELinux: allow userspace to read policy back out of the kernel (Eric Paris) [667225]
- [security] kernel: rounddown helper function (Eric Paris) [667225]
- [security] SELinux: drop useless (and incorrect) AVTAB_MAX_SIZE (Eric Paris) [667225]
- [security] SELinux: break ocontext reading into a separate function (Eric Paris) [667225]
- [security] SELinux: move genfs read to a separate function (Eric Paris) [667225]
- [security] selinux: fix error codes in symtab_init() (Eric Paris) [667225]
- [security] selinux: fix error codes in cond_policydb_init() (Eric Paris) [667225]
- [security] selinux: fix error codes in cond_read_node() (Eric Paris) [667225]
- [security] selinux: fix error codes in cond_read_av_list() (Eric Paris) [667225]
- [security] selinux: propagate error codes in cond_read_list() (Eric Paris) [667225]
- [security] selinux: fix up style problem on /selinux/status (Eric Paris) [667500]
- [security] selinux: fast status update interface (Eric Paris) [667500]
- [scsi] qla4xxx: Update driver version to 5.02.00-k5 (Chad Dupuis) [516846]
- [scsi] qla4xxx: Updated the Copyright header (Chad Dupuis) [516846]
- [scsi] qla4xxx: do not reset hba if ql4xdontresethba is set (Chad Dupuis) [516846]
- [scsi] qla4xxx: do not check for fw hung if reset retry is in progress (Chad Dupuis) [516846]
- [scsi] qla4xxx: cache new IP address acquired via DHCP (Chad Dupuis) [516846]
- [scsi] qla4xxx: Fail initialization if qla4_8xxx_pci_mem_write_2M fails (Chad Dupuis) [516846]
- [scsi] qla4xxx: put device in FAILED state for 82XX initialization failure (Chad Dupuis) [516846]
- [scsi] qla4xxx: do not process interrupt unconditionally (Chad Dupuis) [516846]
- [scsi] qla4xxx: use correct fw_ddb_index in abort task (Chad Dupuis) [516846]
- [scsi] qla4xxx: memory wedge with peg_halt test in loop (Chad Dupuis) [516846]
- [scsi] qla4xxx: initialize MSI in correct way (Chad Dupuis) [516846]
- [scsi] qla4xxx: Drop use of IRQF_DISABLE (Chad Dupuis) [516846]
- [scsi] qla4xxx: Fix cmd check in qla4xxx_cmd_wait (Chad Dupuis) [516846]
- [scsi] qla4xxx: Update driver version to 5.02.00-k4 (Chad Dupuis) [516846]
- [scsi] qla4xxx: grab hardware_lock in eh_abort before accessing srb (Chad Dupuis) [516846]
- [scsi] qla4xxx: remove unwanted check for bad spd (Chad Dupuis) [516846]
- [scsi] qla4xxx: update AER support for ISP82XX (Chad Dupuis) [516846]
- [scsi] qla4xxx: Clear the rom lock if the firmware died while holding it (Chad Dupuis) [516846]
- [scsi] qla4xxx: use CRB Register for Request Queue in-pointer (Chad Dupuis) [516846]
- [scsi] qla4xxx: dump mailbox registers on System Error (Chad Dupuis) [516846]
- [scsi] qla4xxx: Add support for 8130/8131 AENs (Chad Dupuis) [516846]
- [scsi] qla4xxx: Reset seconds_since_last_heartbeat correctly (Chad Dupuis) [516846]
- [scsi] qla4xxx: On firmware hang do not wait for the outstanding commands to complete (Chad Dupuis) [516846]
- [scsi] qla4xxx: free_irqs on failed initialize_adapter (Chad Dupuis) [516846]
- [scsi] qla4xxx: correct data type of sense_len in qla4xxx_status_cont_entry (Chad Dupuis) [516846]
- [scsi] qla4xxx: remove "ha->retry_reset_ha_cnt" from wait_for_hba_online (Chad Dupuis) [516846]
- [scsi] qla4xxx: honor return status of qla4xxx_hw_reset (Chad Dupuis) [516846]
- [scsi] qla4xxx: Trivial cleanup (Chad Dupuis) [516846]
- [scsi] qla4xxx: fix build on PPC (Chad Dupuis) [516846]
- [scsi] qla4xxx: fix build (Chad Dupuis) [516846]
- [scsi] qla4xxx: fix compilation warning (Chad Dupuis) [516846]
- [scsi] qla4xxx: Update driver version to 5.02.00-k3 (Chad Dupuis) [516846]
- [scsi] qla4xxx: Added AER support for ISP82xx (Chad Dupuis) [516846]
- [scsi] qla4xxx: Handle outstanding mbx cmds on hung f/w scenarios (Chad Dupuis) [516846]
- [scsi] qla4xxx: updated mbx_sys_info struct to sync with FW 4.6.x (Chad Dupuis) [516846]
- [scsi] qla4xxx: clear AF_DPC_SCHEDULED flage when exit from do_dpc (Chad Dupuis) [516846]
- [scsi] qla4xxx: Stop firmware before doing init firmware (Chad Dupuis) [516846]
- [scsi] qla4xxx: Use the correct request queue (Chad Dupuis) [516846]
- [scsi] qla4xxx: set correct value in sess->recovery_tmo (Chad Dupuis) [516846]
- [scsi] qla4xxx: fix typos concerning "initiali[zs]e" (Chad Dupuis) [516846]
- [scsi] qla4xxx: Update driver version to 5.02.00-k2 (Chad Dupuis) [516846]
- [scsi] qla4xxx: wait for device_ready before device discovery (Chad Dupuis) [516846]
- [scsi] qla4xxx: replace all dev_info, dev_warn, dev_err with ql4_printk (Chad Dupuis) [516846]
- [scsi] qla4xxx: Added support for ISP82XX (Chad Dupuis) [516846]
- [scsi] qla4xxx: Handle one H/W Interrupt at a time (Chad Dupuis) [516846]
- [scsi] qla4xxx: Fix the freeing of the buffer allocated for DMA (Chad Dupuis) [516846]
- [scsi] qla4xxx: correct return status in function qla4xxx_fw_ready (Chad Dupuis) [516846]
- [scsi] qla4xxx: unblock iscsi session after setting ddb state online (Chad Dupuis) [516846]
- [scsi] qla4xxx: set driver ddb state correctly in process_ddb_changed (Chad Dupuis) [516846]
- [hwmon] config: enable k10temp module (Michal Schmidt) [623968]
- [hwmon] k10temp: add hwmon driver for AMD family 10h/11h CPUs (Michal Schmidt) [623968]
- [x86] Calgary: Limit the max PHB number to 256 (James Takahashi) [579480]
- [x86] Calgary: Increase max PHB number (James Takahashi) [579480]
- [tracing] wakeup latency tracer graph support (Jiri Olsa) [667519]
- [tracing] Have graph flags passed in to ouput functions (Jiri Olsa) [667519]
- [tracing] Add ftrace events for graph tracer (Jiri Olsa) [667519]
- [uv] sgi-xpc: XPC fails to discover partitions (George Beshers) [662996]
- [uv] sgi-xpc: Incoming XPC channel messages (George Beshers) [662996]
- [uv] x86: Use allocated buffer in tlb_uv.c:tunables_read() (George Beshers) [662722]
- [uv] x86: Initialize BAU hub map (George Beshers) [662722]
- [uv] x86: Initialize BAU MMRs only on hubs with cpus (George Beshers) [662722]
- [scsi] bsg: correct fault if queue object removed while dev_t open (Mike Christie) [619818 658248]
- [scsi] fc class: add fc host dev loss sysfs file (Mike Christie) [619818 658248]
- [scsi] lpfc: prep for fc host dev loss tmo support (Mike Christie) [619818 658248]
- [scsi] qla2xxx: prep for fc host dev loss tmo support (Mike Christie) [619818 658248]
- [scsi] ibmvfc: prep for fc host dev loss tmo support (Mike Christie) [619818 658248]
- [scsi] fnic: prep for fc host dev loss tmo support (Mike Christie) [619818 658248]
- [scsi] scsi_transport_fc: fix blocked bsg request when fc object deleted (Mike Christie) [619818 658248]
- [scsi] ibmvfc: do not reset dev_loss_tmo in slave callout (Mike Christie) [619818 658248]
- [scsi] fnic: do not reset dev_loss_tmo in slave callout (Mike Christie) [619818 658248]
- [scsi] lpfc: do not reset dev_loss_tmo in slave callout (Mike Christie) [619818 658248]
- [scsi] qla2xxx: do not reset dev_loss_tmo in slave callout (Mike Christie) [619818 658248]
- [scsi] fc class: add fc host default default dev loss setting (Mike Christie) [619818 658248]
- [scsi] scsi_transport_fc: Protect against overflow in dev_loss_tmo (Mike Christie) [619818 658248]
- [md] fix bug with re-adding of partially recovered device (Mike Snitzer) [663783]
- [md] fix possible deadlock in handling flush requests (Mike Snitzer) [663783]
- [md] move code in to submit_flushes (Mike Snitzer) [663783]
- [md] remove handling of flush_pending in md_submit_flush_data (Mike Snitzer) [663783]
- [virt] enable CONFIG_DEBUG_SECTION_MISMATCH=y (Stefan Assmann) [614455]
- [virt] xen: fix section mismatch in reference from the function xen_hvm_init_shared_info() (Stefan Assmann) [614455]
- [powerpc] Don't use kernel stack with translation off (Steve Best) [628951]
- [powerpc] Initialise paca->kstack before early_setup_secondary (Steve Best) [628951]
- [edac] i7core_edac: return -ENODEV when devices were already probed (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: use edac's own way to print errors (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Avoid PCI refcount to reach zero on successive load/reload (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Fix refcount error at PCI devices (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: it is safe to i7core_unregister_mci() when mci=NULL (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Fix an oops at i7core probe (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Remove unused member channels in i7core_pvt (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Remove unused arg csrow from get_dimm_config (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Reduce args of i7core_register_mci (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Introduce i7core_unregister_mci (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Use saved pointers (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Check probe counter in i7core_remove (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Call pci_dev_put() when alloc_i7core_dev() failed (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Fix error path of i7core_register_mci (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Fix order of lines in i7core_register_mci (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Always do get/put for all devices (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Introduce i7core_pci_ctl_create/release (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Introduce free_i7core_dev (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Introduce alloc_i7core_dev (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Reduce args of i7core_get_onedevice (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Fix the logic in i7core_remove() (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Don't do the legacy PCI probe by default (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: don't use a freed mci struct (Mauro Carvalho Chehab) [603124]
- [edac] edac_core: Print debug messages at release calls (Mauro Carvalho Chehab) [603124]
- [edac] edac_core: Don't let free(mci) happen while using it (Mauro Carvalho Chehab) [603124]
- [edac] edac_core: Do a better job with node removal (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: explicitly remove PCI devices from the devices list (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: MCE NMI handling should stop first (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Initialize all priv vars before start polling (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Improve debug to seek for register/remove errors (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: move #if PAGE_SHIFT to edac_core.h (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: properly terminate the group of udimm counters (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Properly mark const static vars as such (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: move static vars to the beginning of the file (Mauro Carvalho Chehab) [603124]
- [edac] i7core_edac: Be sure that the edac pci handler will be properly released (Mauro Carvalho Chehab) [603124]
- [net] bonding: prevent oopsing on calling pskb_may_pull on shared skb (Andy Gospodarek) [665110]

* Fri Jan 21 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-102.el6]
- [netdrv] e1000: Add support for the CE4100 reference platform (Dean Nelson) [636330]
- [netdrv] Intel Wired LAN drivers: Use static const (Dean Nelson) [636330]
- [netdrv] e1000: use vzalloc() (Dean Nelson) [636330]
- [netdrv] e1000: fix screaming IRQ (Dean Nelson) [636330]
- [netdrv] e1000: fix return value not set on error (Dean Nelson) [636330]
- [netdrv] e1000: make e1000_reinit_safe local (Dean Nelson) [636330]
- [netdrv] vlan: Don't check for vlan group before vlan_tx_tag_present (Dean Nelson) [636330]
- [netdrv] e1000: return operator cleanup (Dean Nelson) [636330]
- [netdrv] e1000: use GRO for receive (Dean Nelson) [636330]
- [netdrv] e1000: fix occasional panic on unload (Dean Nelson) [636330]
- [netdrv] e1000: use work queues (Dean Nelson) [636330]
- [netdrv] e1000: set NETIF_F_HIGHDMA for VLAN feature flags (Dean Nelson) [636330]
- [netdrv] e1000: fix Tx hangs by disabling 64-bit DMA (Dean Nelson) [636330]
- [netdrv] e1000: Remove address use from assignments of function pointers (Dean Nelson) [636330]
- [netdrv] e1000: Add missing read memory barrier (Dean Nelson) [636330]
- [netdrv] e1000: use netif_<level> instead of netdev_<level> (Dean Nelson) [636330]
- [netdrv] e1000: allow option to limit number of descriptors down to 48 per ring (Dean Nelson) [636330]
- [netdrv] e1000: Fix message logging defect (Dean Nelson) [636330]
- [netdrv] e1000: Remove unnecessary returns from void function()s (Dean Nelson) [636330]
- [netdrv] e1000: Use new function for copybreak tests (Dean Nelson) [636330]
- [netdrv] e1000: fix WARN_ON with mac-vlan (Dean Nelson) [636330]
- [netdrv] e1000: Use netdev_<level>, pr_<level> and dev_<level> (Dean Nelson) [636330]
- [netdrv] e1000: use DMA API instead of PCI DMA functions (Dean Nelson) [636330]
- [netdrv] e1000: use skb_headlen() (Dean Nelson) [636330]
- [netdrv] e1000: do not modify tx_queue_len on link speed change (Dean Nelson) [636330]
- [netdrv] intel: remove trailing space in messages (Dean Nelson) [636330]
- [netdrv] e1000: Fix DMA mapping error handling on RX (Dean Nelson) [636330]
- [netdrv] e1000: correct wrong coding style for "else" (Dean Nelson) [636330]
- [netdrv] e1000: convert to use netdev_for_each_mc_addr (Dean Nelson) [636330]
- [netdrv] e1000: call pci_save_state after pci_restore_state (Dean Nelson) [636330]
- [netdrv] e1000: Report link status in ethtool when interface is down (Dean Nelson) [636330]
- [netdrv] e1000: Fix tests of unsigned in *_tx_map() (Dean Nelson) [636330]
- [netdrv] use DEFINE_PCI_DEVICE_TABLE() (Dean Nelson) [636330]
- [netdrv] drivers/net: Move && and || to end of previous line (Dean Nelson) [636330]
- [netdrv] request_irq - Remove unnecessary leading & from second arg (Dean Nelson) [636330]
- [netdrv] net: Use netdev_alloc_skb_ip_align() (Dean Nelson) [636330]
- [netdrv] e1000: Fix erroneous display of stats by ethtool -S (Dean Nelson) [636330]
- [netdrv] e1000: Use the instance of net_device_stats from net_device (Dean Nelson) [636330]
- [net] dcb: use after free in dcb_flushapp() (John Villalovos) [634003 634008]
- [net] dcb: unlock on error in dcbnl_ieee_get() (John Villalovos) [634003 634008]
- [net] dcbnl: more informed return values for new dcbnl routines (John Villalovos) [634003 634008]
- [net] dcbnl: cleanup (John Villalovos) [634003 634008]
- [net] dcbnl: adding DCBX feature flags get-set (John Villalovos) [634003 634008]
- [x86] dcbnl: adding DCBX engine capability (John Villalovos) [634003 634008]
- [net] net_dcb: add application notifiers (John Villalovos) [634003 634008]
- [dbc] dcbnl: add appliction tlv handlers (John Villalovos) [634003 634008]
- [net] Fix KABI breakage caused by backport of commit 3e29027af43728c2a91fe3f735ab2822edaf54a8 (John Villalovos) [634003 634008]
- [x86] dcbnl: add support for ieee8021Qaz attributes (John Villalovos) [634003 634008]
- [ata] ahci: Fix bug in storing EM messages (David Milburn) [653789]
- [ata] ahci: add em_buffer attribute for AHCI hosts (David Milburn) [653789]
- [ata] ahci: EM message type auto detect (David Milburn) [653789]
- [x86] ACPICA: Optimization: Reduce the number of namespace walks (George Beshers) [635866]
- [x86] ACPICA: Performance enhancement for namespace search and access (George Beshers) [635866]
- [x86] ACPICA: Update flags for operand object (George Beshers) [635866]
- [net] cxgb4: fix GRO stats counting (Michal Schmidt) [669737]
- [net] gro: make gro_result_t a separate type for the sparse checker (Michal Schmidt) [669737]
- [net] gro: add receive functions that return GRO result codes (Michal Schmidt) [669737]
- [net] gro: Name the GRO result enumeration type (Michal Schmidt) [669737]
- [virt] xen/events: use locked set|clear_bit() for cpu_evtchn_mask (Andrew Jones) [667359]
- [virt] xen: synch event channels delivery on HVM (Andrew Jones) [667359]
- [virt] xen: dynamically allocate irq & event structures (Andrew Jones) [667359]
- [virt] xen: improvements to VIRQ_DEBUG output (Andrew Jones) [667359]
- [virt] xen/evtchn: clear secondary CPUs' cpu_evtchn_mask[] after restore (Andrew Jones) [667359]
- [virt] xen: ensure that all event channels start off bound to VCPU 0 (Andrew Jones) [667359]
- [virt] xen: use dynamic_irq_init_keep_chip_data (Andrew Jones) [667359]
- [virt] xen: set up IRQ before binding virq to evtchn (Andrew Jones) [667359]
- [virt] xen: statically initialize cpu_evtchn_mask_p (Andrew Jones) [667359]
- [scsi] mpt2sas: version upgrade (Tomas Henzl) [642590]
- [scsi] mpt2sas: DIF Type 2 Protection Support (Tomas Henzl) [642590]
- [scsi] mpt2sas: Call the_scsih_ir_shutdown prior to reporting the volumes missing from the OS (Tomas Henzl) [642590]
- [scsi] mpt2sas: Basic code cleanup in mpt2sas_base (Tomas Henzl) [642590]
- [scsi] mpt2sas: Prevent access to freed memory from port enable process (Tomas Henzl) [642590]
- [scsi] mpt2sas: Fix the race between broadcast asyn event (Tomas Henzl) [642590]
- [scsi] mpt2sas: Add support for customer specific branding messages (Tomas Henzl) [642590]
- [scsi] mpt2sas: Revision P-MPI header update (Tomas Henzl) [642590]
- [scsi] mpt2sas: Correct resizing calculation for max_queue_depth (Tomas Henzl) [642590]
- [scsi] mpt2sas: Internal device reset complete event is not supported for older firmware prior to MPI Rev-K (Tomas Henzl) [642590]
- [scsi] mpt2sas: Device removal handshake even though the PHYSTATUS_VACANT bit is set in the PhyStatus (Tomas Henzl) [642590]
- [scsi] mpt2sas: Debug string changes from target to device (Tomas Henzl) [642590]
- [scsi] mpt2sas: Sanity check for phy count is added using maxphy (Tomas Henzl) [642590]
- [scsi] mpt2sas: Remove code for TASK_SET_FULL from-driver (Tomas Henzl) [642590]
- [scsi] mpt2sas: MPI2.0 header updated (Tomas Henzl) [642590]
- [scsi] mpt2sas: Modify code to support Expander switch (Tomas Henzl) [642590]
- [scsi] mpt2sas: Create a pool of chain buffer instead of dedicated (Tomas Henzl) [642590]
- [scsi] mpt2sas: Added loadtime parameters for IOMissingDelay and parameters (Tomas Henzl) [642590]
- [scsi] mpt2sas: Added sanity check for cb_idx and smid access (Tomas Henzl) [642590]
- [scsi] mpt2sas: Copy message frame before releasing to free pool to have a local reference (Tomas Henzl) [642590]
- [scsi] mpt2sas: Copy sense buffer instead of working on direct memory location (Tomas Henzl) [642590]
- [scsi] mpt2sas: Adding additional message to error escalation callback (Tomas Henzl) [642590]
- [scsi] mpt2sas: Add additional check for responding volumes after Host Reset (Tomas Henzl) [642590]
- [scsi] mpt2sas: Added ENOMEM return type when allocation fails (Tomas Henzl) [642590]
- [scsi] mpt2sas: Redesign raid devices event handling using pd_handles per HBA (Tomas Henzl) [642590]
- [scsi] mpt2sas: Tie a log info message to a specific PHY (Tomas Henzl) [642590]
- [scsi] mpt2sas: print level KERN_DEBUG is replaced by KERN_INFO (Tomas Henzl) [642590]
- [scsi] mpt2sas: Added sysfs support for tracebuffer (Tomas Henzl) [642590]
- [scsi] mpt2sas: MPI header version N is updated (Tomas Henzl) [642590]
- [scsi] mpt2sas: Added sysfs counter for ioc reset (Tomas Henzl) [642590]
- [scsi] mpt2sas: Added expander phy control support (Tomas Henzl) [642590]
- [scsi] mpt2sas: Added expander phy counter support (Tomas Henzl) [642590]
- [scsi] mpt2sas: Staged device discovery disable_discovery module parameter is added (Tomas Henzl) [642590]
- [scsi] mpt2sas: Hold Controller reset when another reset is in progress (Tomas Henzl) [642590]
- [netdrv] bnx2: Free IRQ before freeing status block memory (John Feeney) [635889]
- [netdrv] bnx2: remove cancel_work_sync() from remove_one (John Feeney) [635889]
- [netdrv] bnx2: Use static const (John Feeney) [635889]
- [netdrv] bnx2: don't use flush_scheduled_work() (John Feeney) [635889]
- [netdrv] bnx2: Remove config access to non-standard registers (John Feeney) [635889]
- [netdrv] bnx2: Fix reset bug on 5709 (John Feeney) [635889]
- [netdrv] Update to firmware 6.0.x (John Feeney) [635889]
- [netdrv] bnx2: Enable AER on PCIE devices only (John Feeney) [635889]
- [netdrv] bnx2: Add PCI Advanced Error Reporting support (John Feeney) [635889]
- [netdrv] bnx2: Update version to 2.0.17 (John Feeney) [635889]
- [netdrv] bnx2: Remove some unnecessary smp_mb() in tx fast path (John Feeney) [635889]
- [netdrv] bnx2: Call pci_enable_msix() with actual number of vectors (John Feeney) [635889]
- [netdrv] bnx2: Use proper counter for net_device_stats->multicast (John Feeney) [635889]
- [netdrv] bnx2: use device model DMA API (John Feeney) [635889]
- [netdrv] bnx2: allocate with GFP_KERNEL flag on RX path init (John Feeney) [635889]
- [netdrv] bnx2: Update version to 2.0.16 (John Feeney) [635889]
- [netdrv] bnx2: Dump some config space registers during TX timeout (John Feeney) [635889]
- [netdrv] bnx2: fix dma_get_ops compilation breakage (John Feeney) [635889]
- [netdrv] bnx2: Use netif_carrier_off() to prevent timeout (John Feeney) [635889]
- [netdrv] bnx2: Fix register printouts during NETEV_WATCHDOG (John Feeney) [635889]
- [netdrv] bnx2: Add prefetches to rx path (John Feeney) [635889]
- [netdrv] bnx2: Add GRO support (John Feeney) [635889]
- [netdrv] bnx2: Update version to 2.0.9 (John Feeney) [635889]
- [netdrv] bnx2: Remove now useless VPD code (John Feeney) [635889]
- [netdrv] bnx2: Add helper to search for VPD keywords (John Feeney) [635889]
- [netdrv] bnx2: Add VPD information field helper functions (John Feeney) [635889]
- [netdrv] bnx2: Add helper to find a VPD resource data type (John Feeney) [635889]
- [netdrv] bnx2: Add large and small resource data type code (John Feeney) [635889]
- [netdrv] pci: Add PCI LRDT tag size and section size (John Feeney) [635889]
- [netdrv] bnx2: convert multiple drivers to use netdev_for_each_mc_addr (John Feeney) [635889]
- [netdrv] bnx2: Use (pr|netdev|netif)_<level> macro helpers (John Feeney) [635889]
- [netdrv] be2net: update be2net driver to version 2.103.298r (Ivan Vecera) [635741]
- [netdrv] ixgbe: update to upstream version 3.0.12-k2 (Andy Gospodarek) [561359 617193 622640 629909 632598 637332]
- [netdrv] igb driver update (Stefan Assmann) [636322]
- [netdrv] e1000e: upstream to upstream version 1.2.20 (Andy Gospodarek) [636325]
- [pci] Fix warnings when CONFIG_DMI unset (Jon Masters) [639965]
- [pci] export SMBIOS provided firmware instance and label to sysfs (Jon Masters) [639965]
- [fs] xfs: don't block on buffer read errors (Dave Chinner) [581838]
- [fs] xfs: serialise unaligned direct IOs (Dave Chinner) [669272]
- [fs] xfs: ensure sync write errors are returned (Dave Chinner) [669272]
- [netdrv] hostap_cs: fix sleeping function called from invalid context (Stanislaw Gruszka) [621103]
- [netdrv] p54usb: New USB ID for Gemtek WUBI-100GW (Stanislaw Gruszka) [621103]
- [netdrv] p54usb: add 5 more USBIDs (Stanislaw Gruszka) [621103]
- [netdrv] orinoco: clear countermeasure setting on commit (Stanislaw Gruszka) [621103]
- [netdrv] orinoco: fix TKIP countermeasure behaviour (Stanislaw Gruszka) [621103]
- [netdrv] p54/eeprom.c: Return -ENOMEM on memory allocation failure (Stanislaw Gruszka) [621103]
- [netdrv] p54usb: add five more USBIDs (Stanislaw Gruszka) [621103]
- [netdrv] p54usb: fix off-by-one on !CONFIG_PM (Stanislaw Gruszka) [621103]
- [netdrv] wext: fix potential private ioctl memory content leak (Stanislaw Gruszka) [621103]
- [netdrv] hostap_pci: set dev->base_addr during probe (Stanislaw Gruszka) [621103]
- [netdrv] ath5k: check return value of ieee80211_get_tx_rate (Stanislaw Gruszka) [621103]
- [netdrv] p54: fix tx feedback status flag check (Stanislaw Gruszka) [621103]
- [netdrv] ath9k_hw: fix parsing of HT40 5 GHz CTLs (Stanislaw Gruszka) [621103]
- [netdrv] ath5k: disable ASPM L0s for all cards (Stanislaw Gruszka) [621103]
- [netdrv] cfg80211: don't get expired BSSes (Stanislaw Gruszka) [621103]
- [netdrv] ath9k: fix yet another buffer leak in the tx aggregation code (Stanislaw Gruszka) [621103]
- [netdrv] ath9k: fix TSF after reset on AR913x (Stanislaw Gruszka) [621103]
- [netdrv] cfg80211: ignore spurious deauth (Stanislaw Gruszka) [621103]
- [netdrv] ath9k_hw: fix an off-by-one error in the PDADC boundaries calculation (Stanislaw Gruszka) [621103]
- [netdrv] ath9k: enable serialize_regmode for non-PCIE AR9160 (Stanislaw Gruszka) [621103]
- [netdrv] ath5k: initialize ah->ah_current_channel (Stanislaw Gruszka) [621103]
- [netdrv] mac80211: fix supported rates IE if AP doesn't give us it's rates (Stanislaw Gruszka) [621103]
- [netdrv] libertas/sdio: 8686: set ECSI bit for 1-bit transfers (Stanislaw Gruszka) [621103]
- [netdrv] mac80211: do not wip out old supported rates (Stanislaw Gruszka) [621103]
- [netdrv] p54pci: add Symbol AP-300 minipci adapters pciid (Stanislaw Gruszka) [621103]
- [netdrv] hostap: Protect against initialization interrupt (Stanislaw Gruszka) [621103]
- [netdrv] ath9k: Avoid corrupt frames being forwarded to mac80211 (Stanislaw Gruszka) [621103]
- [netdrv] ath9k: re-enable ps by default for new single chip families (Stanislaw Gruszka) [621103]
- [netdrv] ath5k: drop warning on jumbo frames (Stanislaw Gruszka) [621103]
- [netdrv] wl1251: fix a memory leak in probe (Stanislaw Gruszka) [621103]
- [netdrv] ath9k: add support for 802.11n bonded out AR2427 (Stanislaw Gruszka) [621103]
- [netdrv] wireless: report reasonable bitrate for MCS rates through wext (Stanislaw Gruszka) [621103]
- [netdrv] p54usb: Add device ID for Dell WLA3310 USB (Stanislaw Gruszka) [621103]
- [netdrv] ath5k: retain promiscuous setting (Stanislaw Gruszka) [621103]
- [netdrv] mac80211: fix rts threshold check (Stanislaw Gruszka) [621103]
- [netdrv] mac80211: Fix robust management frame handling (MFP) (Stanislaw Gruszka) [621103]
- [netdrv] ar9170usb: fix panic triggered by undersized rxstream buffer (Stanislaw Gruszka) [621103]
- [netdrv] ar9170usb: add a couple more USB IDs (Stanislaw Gruszka) [621103]
- [netdrv] rtl8180: fix tx status reporting (Stanislaw Gruszka) [621103]
- [drm] fix writeback on rn50 powerpc (Dave Airlie) [667565]
- [net] backport of vlan_get_protocol() (Andy Gospodarek) [669787]
- [mm] backport vzalloc() and vzalloc_node() (Andy Gospodarek) [669787]

* Thu Jan 20 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-101.el6]
- [block] blk-cgroup: Allow creation of hierarchical cgroups (Vivek Goyal) [658482]
- [netdrv] tg3: Provide EEE support (John Feeney) [632105]
- [netdrv] tg3: Disable TSS except for 5719 (John Feeney) [634316]
- [netdrv] tg3: Raise the jumbo frame BD flag threshold (John Feeney) [635078]
- [netdrv] tg3: Enable phy APD for 5717 and later asic revs (John Feeney) [635078]
- [netdrv] tg3: Enable mult rd DMA engine on 5719 (John Feeney) [635078]
- [netdrv] tg3: Fix 5719 internal FIFO overflow problem (John Feeney) [635078]
- [netdrv] tg3: Assign correct tx margin for 5719 (John Feeney) [635078]
- [netdrv] tg3: Apply 10Mbps fix to all 57765 revisions (John Feeney) [635078]
- [netdrv] tg3: Add extend rx ring sizes for 5717 and 5719 (John Feeney) [635078]
- [netdrv] tg3: Prepare for larger rx ring sizes (John Feeney) [635078]
- [netdrv] tg3: 5719: Prevent tx data corruption (John Feeney) [635078]
- [netdrv] tg3: Unlock 5717 B0+ support (John Feeney) [635078]
- [netdrv] tg3: Fix read DMA FIFO overruns on recent devices (John Feeney) [635078]
- [netdrv] tg3: Update version to 3.113 (John Feeney) [635078]
- [netdrv] tg3: Migrate tg3_flags to phy_flags (John Feeney) [635078]
- [netdrv] tg3: Create phy_flags and migrate phy_is_low_power (John Feeney) [635078]
- [netdrv] tg3: Add phy-related preprocessor constants (John Feeney) [635078]
- [netdrv] tg3: Add error reporting to tg3_phydsp_write() (John Feeney) [635078]
- [netdrv] tg3: Improve small packet performance (John Feeney) [635078]
- [netdrv] tg3: Remove 5720, 5750, and 5750M (John Feeney) [635078]
- [netdrv] tg3: Detect APE firmware types (John Feeney) [635078]
- [netdrv] tg3: Restrict ASPM workaround devlist (John Feeney) [635078]
- [netdrv] tg3: Manage gphy power for CPMU-less devs only (John Feeney) [635078]
- [netdrv] tg3: Don't access phy test ctrl reg for 5717+ (John Feeney) [635078]
- [netdrv] tg3: Create TG3_FLG3_5717_PLUS flag (John Feeney) [635078]
- [netdrv] tg3: Disable TSS also during tg3_close() (John Feeney) [635078]
- [netdrv] tg3: Add 5784 ASIC rev to earlier PCIe MPS fix (John Feeney) [635078]
- [netdrv] tg3: Update version to 3.112 (John Feeney) [635078]
- [netdrv] tg3: Fix some checkpatch errors (John Feeney) [635078]
- [netdrv] tg3: Revert PCIe tx glitch fix (John Feeney) [635078]
- [netdrv] tg3: Report driver version to firmware (John Feeney) [635078]
- [netdrv] tg3: Relax 5717 serdes restriction (John Feeney) [635078]
- [netdrv] tg3: Fix single MSI-X vector coalescing (John Feeney) [635078]
- [netdrv] tg3: Revert RSS indir tbl setup change (John Feeney) [635078]
- [netdrv] tg3: allow TSO on vlan devices (John Feeney) [635078]
- [netdrv] tg3: Update version to 3.111 (John Feeney) [635078]
- [netdrv] tg3: 5717: Allow serdes link via parallel detect (John Feeney) [635078]
- [netdrv] tg3: Allow single MSI-X vector allocations (John Feeney) [635078]
- [netdrv] tg3: Off-by-one error in RSS setup (John Feeney) [635078]
- [netdrv] tg3: Enable GRO by default. (John Feeney) [635078]
- [netdrv] tg3: Update version to 3.110 (John Feeney) [635078]
- [netdrv] tg3: Remove function errors flagged by checkpatch (John Feeney) [635078]
- [netdrv] tg3: Unify max pkt size preprocessor constants (John Feeney) [635078]
- [netdrv] tg3: Re-inline VLAN tags when appropriate (John Feeney) [635078]
- [netdrv] tg3: Optimize rx double copy test (John Feeney) [635078]
- [netdrv] tg3: Update version to 3.109 (John Feeney) [635078]
- [netdrv] tg3: Remove tg3_dump_state() (John Feeney) [635078]
- [netdrv] tg3: Cleanup if codestyle (John Feeney) [635078]
- [netdrv] tg3: The case of switches (John Feeney) [635078]
- [netdrv] tg3: Whitespace, constant, and comment updates (John Feeney) [635078]
- [netdrv] tg3: Use VPD fw version when present (John Feeney) [635078]
- [netdrv] tg3: Prepare FW version code for VPD versioning (John Feeney) [635078]
- [netdrv] tg3: Fix message 80 char violations (John Feeney) [635078]
- [netdrv] tg3: netdev_err() => dev_err() (John Feeney) [635078]
- [netdrv] tg3: Replace pr_err with sensible alternatives (John Feeney) [635078]
- [netdrv] tg3: Restore likely() check in tg3_poll_msix() (John Feeney) [635078]
- [netdrv] drivers/net/tg3.c: change the field used with the TG3_FLAG_10_100_ONLY constant (John Feeney) [635078]
- [netdrv] tg3: Remove now useless VPD code (John Feeney) [635078]
- [netdrv] pci: Add helper to search for VPD keywords (John Feeney) [635078]
- [netdrv] pci: Add VPD information field helper functions (John Feeney) [635078]
- [netdrv] pci: Add helper to find a VPD resource data type (John Feeney) [635078]
- [netdrv] pci: Add large and small resource data type code (John Feeney) [635078]
- [netdrv] pci: Add PCI LRDT tag size and section size (John Feeney) [635078]
- [netdrv] net: convert multiple drivers to use netdev_for_each_mc_addr, part6 (John Feeney) [635078]
- [netdrv] drivers/net/tg3.c: Use (pr|netdev)_<level> macro helpers (John Feeney) [635078]
- [kdump] vt-d: Handle previous faults after enabling fault handling (Takao Indoh) [617137]
- [kdump] Enable the intr-remap fault handling after local apic setup (Takao Indoh) [617137]
- [kdump] vt-d: Fix the vt-d fault handling irq migration in the x2apic mode (Takao Indoh) [617137]
- [kdump] vt-d: Quirk for masking vtd spec errors to platform error handling logic (Takao Indoh) [617137]
- [netdrv] return operator cleanup (Dean Nelson) [636331]
- [netdrv] e100: Add missing read memory barrier (Dean Nelson) [636331]
- [net] trans_start cleanups (Dean Nelson) [636331]
- [netdrv] e100: Fix the TX workqueue race (Dean Nelson) [636331]
- [netdrv] Use pr_<level> and netif_<level> (Dean Nelson) [636331]
- [net] convert multiple drivers to use netdev_for_each_mc_addr, part4 (Dean Nelson) [636331]
- [net] use netdev_mc_count and netdev_mc_empty when appropriate (Dean Nelson) [636331]
- [netdrv] use DEFINE_PCI_DEVICE_TABLE() (Dean Nelson) [636331]
- [netdrv] e100: Fix to allow systems with FW based cards to resume from STD (Dean Nelson) [636331]
- [net] Use netdev_alloc_skb_ip_align() (Dean Nelson) [636331]
- [netdrv] qlcnic: change module parameter permissions (Chad Dupuis) [667192]
- [netdrv] qlcnic: fix ethtool diagnostics test (Chad Dupuis) [667192]
- [netdrv] qlcnic: fix flash fw version read (Chad Dupuis) [667192]
- [netdrv] Use static const (Chad Dupuis) [667192]
- [netdrv] qlcnic: reset pci function unconditionally during probe (Chad Dupuis) [667192]
- [netdrv] qlcnic: fix ocm window register offset calculation (Chad Dupuis) [667192]
- [netdrv] qlcnic: fix LED test when interface is down (Chad Dupuis) [667192]
- [netdrv] qlcnic: Updated driver version to 5.0.13 (Chad Dupuis) [667192]
- [netdrv] qlcnic: LICENSE file for qlcnic (Chad Dupuis) [667192]
- [netdrv] qlcnic: validate eswitch config values for PF (Chad Dupuis) [667192]
- [netdrv] qlcnic: Disable loopback support (Chad Dupuis) [667192]
- [netdrv] qlcnic: avoid using reset_devices as it may become obsolete (Chad Dupuis) [667192]
- [netdrv] qlcnic: Bumped up driver version to 5.0.12 (Chad Dupuis) [667192]
- [netdrv] qlcnic: fix panic on load (Chad Dupuis) [667192]
- [netdrv] qlcnic: lro off message log from set rx checsum (Chad Dupuis) [667192]
- [netdrv] qlcnic: Add description for CN1000Q adapter (Chad Dupuis) [667192]
- [netdrv] qlcnic: Fix for kdump (Chad Dupuis) [667192]
- [netdrv] qlcnic: Allow minimum bandwidth of zero (Chad Dupuis) [667192]
- [netdrv] qlcnic: define valid vlan id range (Chad Dupuis) [667192]
- [netdrv] qlcnic: reduce rx ring size (Chad Dupuis) [667192]
- [netdrv] qlcnic: fix mac learning (Chad Dupuis) [667192]
- [netdrv] qlcnic: update ethtool stats (Chad Dupuis) [667192]
- [scsi] QLogic's qlcnic driver (Bob Picco) [562921]
- [mm] notifier_from_errno() cleanup (Prarit Bhargava) [669041]
- [x86] convert cpu notifier to return encapsulate errno value (Prarit Bhargava) [669041]
- [kernel] notifier: change notifier_from_errno(0) to return NOTIFY_OK (Prarit Bhargava) [669041]
- [netdrv] netxen: update driver version 4.0.75 (Chad Dupuis) [667194]
- [netdrv] netxen: enable LRO based on NETIF_F_LRO (Chad Dupuis) [667194]
- [netdrv] netxen: update module description (Chad Dupuis) [667194]
- [netdrv] drivers/net: Use static const (Chad Dupuis) [667194]
- [netdrv] netxen: avoid using reset_devices as it may become obsolete (Chad Dupuis) [667194]
- [netdrv] netxen: remove unused firmware exports (Chad Dupuis) [667194]
- [netdrv] netxen_nic: Fix the tx queue manipulation bug in netxen_nic_probe (Chad Dupuis) [667194]
- [netdrv] netxen: fix kdump (Chad Dupuis) [667194]
- [netdrv] netxen: make local function static (Chad Dupuis) [667194]
- [netdrv] netxen: mask correctable error (Chad Dupuis) [667194]
- [netdrv] netxen: fix race in tx stop queue (Chad Dupuis) [667194]
- [netdrv] net: return operator cleanup (Chad Dupuis) [667194]
- [mm] page-types.c: fix name of unpoison interface (Dean Nelson) [667686]
- [mm] Documentation/vm: fix spelling in page-types.c (Dean Nelson) [667686]
- [mm] page-types: exit early when invoked with -d|--describe (Dean Nelson) [667686]
- [mm] page-types: whitespace alignment (Dean Nelson) [667686]
- [mm] page-types: learn to describe flags directly from command line (Dean Nelson) [667686]
- [mm] page-types: unsigned cannot be less than 0 in add_page() (Dean Nelson) [667686]
- [mm] page-types: constify read only arrays (Dean Nelson) [667686]
- [mm] tree-wide: fix assorted typos all over the place (Dean Nelson) [667686]
- [kernel] kmsg_dump: use stable variable to dump kmsg buffer (Jarod Wilson) [632041]
- [kernel] kmsg_dump: build fixups (Jarod Wilson) [632041]
- [kernel] kmsg_dump: Dump on crash_kexec as well (Jarod Wilson) [632041]
- [kernel] core: Add kernel message dumper to call on oopses and panics (Jarod Wilson) [632041]
- [mm] shmem: put_super must percpu_counter_destroy (Jeff Moyer) [667550]
- [fs] tmpfs: make tmpfs scalable with percpu_counter for used blocks (Jeff Moyer) [667550]
- [fs] tmpfs: add accurate compare function to percpu_counter library (Jeff Moyer) [667550]
- [netdrv] iwlagn: enable only rfkill interrupt when device is down (Stanislaw Gruszka) [593566]
- [netdrv] wireless: use a dedicated workqueue for cfg80211 (Stanislaw Gruszka) [593566]
- [netdrv] mac80211: do not requeue scan work when not needed (Stanislaw Gruszka) [593566]
- [netdrv] mac80211: compete scan to cfg80211 if deferred scan fail to start (Stanislaw Gruszka) [593566]
- [netdrv] mac80211: fix scan locking wrt. hw scan (Stanislaw Gruszka) [593566]
- [netdrv] mac80211: flush workqueue before restarting device (Stanislaw Gruszka) [593566]
- [drm] Backport AGP/DRM from 2.6.37-rc8 (Dave Airlie) [667565]
- [drm] vga_switcheroo: backport (Dave Airlie) [667281]
- [drm] fbcon: fix situation where fbcon gets deinitialised and can't reinit (Dave Airlie) [667281]
- [char] vt: fix issue when fbcon wants to takeover a second time (Dave Airlie) [667281]
- [drm] fb/kms: fix kABI issue in the aperture code (Dave Airlie) [667281]
- [drm] fbdev: updates needed for drm backport (Dave Airlie) [667281]
- [kernel] Revert "debug_locks: set oops_in_progress if we will log messages." (Dave Airlie) [667281]
- [i2c] i2c-algo-bit: Add pre- and post-xfer hooks (Dave Airlie) [667281]
- [x86] io-mapping: move asm include inside the config option (Dave Airlie) [667281]
- [drm] io-mapping: Specify slot to use for atomic mappings (Dave Airlie) [667281]
- [x86] Add array variants for setting memory to wc caching (Dave Airlie) [667281]

* Wed Jan 19 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-100.el6]
- [x86] xsave: Use xsaveopt in context-switch path when supported (John Villalovos) [492912]
- [x86] cpu: Enumerate xsaveopt (John Villalovos) [492912]
- [x86] cpu: Add xsaveopt cpufeature (John Villalovos) [492912]
- [x86] cpu: Make init_scattered_cpuid_features() consider cpuid subleaves (John Villalovos) [492912]
- [x86] xsave: Sync xsave memory layout with its header for user handling (John Villalovos) [492912]
- [x86] xsave: Track the offset, size of state in the xsave layout (John Villalovos) [492912]
- [x86] fpu: Use static_cpu_has() to implement use_xsave() (John Villalovos) [492912]
- [x86] Add new static_cpu_has() function using alternatives (John Villalovos) [492912]
- [x86] fpu: Use the proper asm constraint in use_xsave() (John Villalovos) [492912]
- [x86] Eliminate TS_XSAVE (John Villalovos) [492912]
- [x86] cpu: Make APERF/MPERF a normal table-driven flag (John Villalovos) [492912]
- [x86] Unify APERF/MPERF support (John Villalovos) [492912]
- [x86] x86, cpu: Add AMD core boosting feature flag to /proc/cpuinfo (John Villalovos) [492912]
- [scsi] lpfc: Update lpfc version for 8.3.5.30 driver release (Rob Evers) [663119]
- [scsi] lpfc: Turned parity and serr bits back on after performing sli4 board reset PCI access (Rob Evers) [663119]
- [scsi] lpfc: Use VPI for ALL ELS commands and allocate RPIs at node creation (Rob Evers) [663119]
- [scsi] lpfc: Correct bit-definitions in SLI4 data structures (Rob Evers) [663119]
- [scsi] lpfc: Update lpfc version for 8.3.5.29 driver release (Rob Evers) [663119]
- [scsi] lpfc: Implement new SLI4 initialization procedures based on if_type (Rob Evers) [663119]
- [scsi] lpfc: Implement the FC and SLI async event handlers (Rob Evers) [663119]
- [scsi] lpfc: Comment update, minor re-order to sync w/ upstream (Rob Evers) [663119]
- [scsi] lpfc: Fixed panic in the __lpfc_sli_get_sglq (Rob Evers) [663119]
- [scsi] lpfc: Fixed management command context setting (Rob Evers) [663119]
- [netdrv] vxge: make functions local and remove dead code (Bob Picco) [636869]
- [netdrv] drivers/net: Convert unbounded kzalloc calls to kcalloc (Bob Picco) [636869]
- [netdrv] vxge-main.c: Use pr_<level> and netdev_<level> (Bob Picco) [636869]
- [netdrv] vxge: Version update (Bob Picco) [636869]
- [netdrv] vxge: Update copyright information (Bob Picco) [636869]
- [netdrv] vxge: NETIF_F_LLTX removal (Bob Picco) [636869]
- [netdrv] vxge: Fix multicast issues (Bob Picco) [636869]
- [netdrv] vxge: Remove queue_state references (Bob Picco) [636869]
- [netdrv] vxge: show startup message with KERN_INFO (Bob Picco) [636869]
- [netdrv] drivers/net: Remove unnecessary returns from void function()s (Bob Picco) [636869]
- [x86] additional LPC Controller DeviceID for Intel Patsburg PCH for TCO Watchdog (David Milburn) [464257]
- [x86] additional LPC Controller DeviceID for Intel Patsburg PCH (David Milburn) [464257]
- [i2c] i2c-i801: Add Intel Patsburg device ID (David Milburn) [464257]
- [pci] update Intel Patsburg defines (David Milburn) [464257]
- [pci] irq and pci_ids patch for Intel Patsburg DeviceIDs (David Milburn) [464257]
- [sound] ALSA HD Audio patch for Intel Patsburg DeviceIDs (David Milburn) [464257]
- [x86] watchdog: TCO Watchdog patch for Intel Patsburg DeviceIDs (David Milburn) [464257]
- [x86] ahci: AHCI and RAID mode SATA patch for Intel Patsburg DeviceIDs (David Milburn) [464257]
- [ata] ata_piix: IDE Mode SATA patch for Intel Patsburg DeviceIDs (David Milburn) [464257]
- [netdrv] ibmveth: Free irq on error path (Steve Best) [632706]
- [netdrv] ibmveth: Cleanup error handling inside ibmveth_open (Steve Best) [632706]
- [netdrv] ibmveth: Update module information and version (Steve Best) [632706]
- [netdrv] ibmveth: Remove some unnecessary include files (Steve Best) [632706]
- [netdrv] ibmveth: Convert driver specific assert to BUG_ON (Steve Best) [632706]
- [netdrv] ibmveth: Return -EINVAL on all ->probe errors (Steve Best) [632706]
- [netdrv] ibmveth: Coding style fixes (Steve Best) [632706]
- [netdrv] ibmveth: Some formatting fixes (Steve Best) [632706]
- [netdrv] ibmveth: Convert driver specific error functions to netdev_err (Steve Best) [632706]
- [netdrv] ibmveth: Convert driver specific debug to netdev_dbg (Steve Best) [632706]
- [netdrv] ibmveth: Remove redundant function prototypes (Steve Best) [632706]
- [netdrv] ibmveth: Convert to netdev_alloc_skb (Steve Best) [632706]
- [netdrv] ibmveth: remove procfs code (Steve Best) [632706]
- [netdrv] ibmveth: Enable IPv6 checksum offload (Steve Best) [632706]
- [netdrv] ibmveth: Remove duplicate checksum offload setup code (Steve Best) [632706]
- [netdrv] ibmveth: Add optional flush of rx buffer (Steve Best) [632706]
- [netdrv] ibmveth: Add scatter-gather support (Steve Best) [632706]
- [netdrv] ibmveth: Use lighter weight read memory barrier in ibmveth_poll (Steve Best) [632706]
- [netdrv] ibmveth: Add rx_copybreak (Steve Best) [632706]
- [netdrv] ibmveth: Add tx_copybreak (Steve Best) [632706]
- [netdrv] ibmveth: Remove LLTX (Steve Best) [632706]
- [netdrv] ibmveth: batch rx buffer replacement (Steve Best) [632706]
- [netdrv] ibmveth: Remove integer divide caused by modulus (Steve Best) [632706]
- [scsi] ibmvfc: version 1.0.9 (Steve Best) [632710]
- [scsi] ibmvfc: Handle Virtual I/O Server reboot (Steve Best) [632710]
- [scsi] ibmvfc: Log link up/down events (Steve Best) [632710]
- [scsi] ibmvfc: Fix terminate_rport_io (Steve Best) [632710]
- [scsi] ibmvfc: Fix rport add/delete race resulting in oops (Steve Best) [632710]
- [scsi] ibmvfc: Add support for fc_block_scsi_eh (Steve Best) [632710]
- [scsi] ibmvfc: Add FC Passthru support (Steve Best) [632710]
- [scsi] ibmvfc: Fix adapter cancel flags for terminate_rport_io (Steve Best) [632710]
- [scsi] ibmvfc: Remove unnecessary parameter to ibmvfc_init_host (Steve Best) [632710]
- [scsi] ibmvfc: Fix locking in ibmvfc_remove (Steve Best) [632710]
- [scsi] ibmvfc: Fixup TMF response handling (Steve Best) [632710]
- [ppc64] Enable PM_SLEEP on POWER w/o KABI changes (Steve Best) [632683]
- [ppc64] pseries: Partition hibernation support for RHEL6.1 (Steve Best) [632683]
- [ppc64] pseries: Partition hibernation support (Steve Best) [632683]
- [ppc64] ibmvscsi: Fix softlockup on resume (Steve Best) [632683]
- [ppc64] ibmvfc: Fix soft lockup on resume (Steve Best) [632683]
- [ppc64] ibmvscsi: Add suspend/resume support (Steve Best) [632683]
- [ppc64] ibmvfc: Add suspend/resume support (Steve Best) [632683]
- [ppc64] ibmveth: Add suspend/resume support (Steve Best) [632683]
- [ppc64] vio: Add power management support (Steve Best) [632683]
- [ppc64] pseries: Migration code reorganization / hibernation prep (Steve Best) [632683]
- [configs] redhat: added CONFIG_SECURITY_DMESG_RESTRICT option (Frantisek Hrbata) [653245]
- [kernel] restrict unprivileged access to kernel syslog (Frantisek Hrbata) [653245]
- [edac] i7300_edac: Fix an error with RHEL6 build (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Add it to x86 RHEL6 build (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Properly initialize per-csrow memory size (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: better initialize page counts (Mauro Carvalho Chehab) [638237]
- [edac] MAINTAINERS: Add maintainer for i7300-edac driver (Mauro Carvalho Chehab) [638237]
- [edac] i7300-edac: CodingStyle cleanup (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Improve comments (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Cleanup: reorganize the file contents (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Properly detect channel on CE errors (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: enrich FBD error info for corrected errors (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: enrich FBD error info for fatal errors (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: pre-allocate a buffer used to prepare err messages (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Fix MTR x4/x8 detection logic (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Make the debug messages coherent with the others (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Cleanup: remove get_error_info logic (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Add a code to cleanup error registers (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Add support for reporting FBD errors (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Properly detect the type of error correction (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Detect if the device is on single mode (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Adds detection for enhanced scrub mode on x8 (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Clear the error bit after reading (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Add error detection code for global errors (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Better name PCI devices (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: Add a FIXME note about the error correction type (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: add global error registers (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: display info if ECC is enabled or not (Mauro Carvalho Chehab) [638237]
- [edac] i7300_edac: start a driver for i7300 chipset (Mauro Carvalho Chehab) [638237]
- [net] ipsec: fragment locally generated tunnel-mode IPSec6 packets as needed (Herbert Xu) [661113]
- [dma] Fix incorrect iommu in ioatdma (John Feeney) [611884]
- [pci] sysfs: Update ROM to include default owner write access (Alex Williamson) [668478]
- [x86] tboot: Add support for S3 memory integrity protection (John Villalovos) [464222]
- [x86] Fix checking of SRAT when node 0 ram is not from 0 (Amerigo Wang) [668340]
- [virt] VMX: when entering real mode align segment base to 16 bytes (Gleb Natapov) [665970]
- [virt] xenbus: implement O_NONBLOCK (Paolo Bonzini) [607262]
- [virt] x86: Push potential exception error code on task switches (Gleb Natapov) [654284]
- [virt] VMX: add module parameter to avoid trapping HLT instructions (Gleb Natapov) [661540]
- [netdrv] QLogic nextxen driver updates (Bob Picco) [562940]
- [scsi] libsas: fix NCQ mixing with non-NCQ (David Milburn) [621606]

* Fri Jan 14 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-99.el6]
- [netdrv] BNX2I: Updated version, copyright, and maintainer info (Mike Christie) [635894]
- [netdrv] BNX2I: Added iSCSI text pdu support for iSCSI offload (Mike Christie) [635894]
- [netdrv] BNX2I: Added jumbo MTU support for the no shost case (Mike Christie) [635894]
- [netdrv] BNX2I: Added support for the 57712(E) devices (Mike Christie) [635894]
- [netdrv] BNX2I: Added handling for unsupported iSCSI offload hba (Mike Christie) [635894]
- [netdrv] BNX2I: Fixed the 32-bit swapping of the LUN field for nopouts for 5771X (Mike Christie) [635894]
- [netdrv] BNX2I: Allow ep CONNECT_FAILED condition to go through proper cleanup (Mike Christie) [635894]
- [netdrv] BNX2I: Added reconnect fix connecting against Lefthand targets (Mike Christie) [635894]
- [netdrv] BNX2I: Cleaned up various error conditions in ep_connect/disconnect (Mike Christie) [635894]
- [netdrv] BNX2I: Added return code check for chip kwqe submission request (Mike Christie) [635894]
- [netdrv] BNX2I: Modified the bnx2i stop path to compensate for in progress ops (Mike Christie) [635894]
- [netdrv] BNX2I: Removed the dynamic registration of CNIC (Mike Christie) [635894]
- [netdrv] BNX2I: Added mutex lock protection to conn_get_param (Mike Christie) [635894]
- [netdrv] BNX2I: Allow to abort the connection if connect request times out (Mike Christie) [635894]
- [netdrv] BNX2I: Fixed the remote TCP RST handling for the 570X (1g) (Mike Christie) [635894]
- [netdrv] BNX2I: Fixed a cid leak issue for 5771X (10g) (Mike Christie) [635894]
- [netdrv] BNX2I: Fixed the endian bug in the TMF LUN cmd send (Mike Christie) [635894]
- [netdrv] BNX2I: Added chip cleanup for the remove module path (Mike Christie) [635894]
- [netdrv] BNX2I: Recouple the CFC delete cleanup with cm_abort/close completion (Mike Christie) [635894]
- [netdrv] BNX2I: Added support for other TMFs besides ABORT_TASK (Mike Christie) [635894]
- [netdrv] BNX2I: Fixed a protocol violation on nopout responses (Mike Christie) [635894]
- [netdrv] BNX2I: Added host param ISCSI_HOST_PARAM_IPADDRESS (Mike Christie) [635894]
- [netdrv] BNX2I: Fixed the TCP graceful termination initiation (Mike Christie) [635894]
- [netdrv] BNX2I: Fine tuned conn destroy and context destroy timeout values (Mike Christie) [635894]
- [netdrv] cnic: Fix the type field in SPQ messages (Mike Christie) [635892]
- [netdrv] cnic: Do not call bnx2i when bnx2i is calling cnic_unregister_driver() (Mike Christie) [635892]
- [netdrv] cnic: Do not allow iSCSI and FCoE on bnx2x multi-function mode (Mike Christie) [635892]
- [netdrv] cnic: fix mem leak on allocation failures in cnic_alloc_uio_rings() (Mike Christie) [635892]
- [netdrv] cnic: Add FCoE support on 57712 (Mike Christie) [635892]
- [netdrv] cnic: Add kcq2 support on 57712 (Mike Christie) [635892]
- [netdrv] cnic: Call cm_connect_complete() immediately on error (Mike Christie) [635892]
- [netdrv] cnic: Check device state before reading the kcq pointer in IRQ (Mike Christie) [635892]
- [netdrv] cnic: Support NIC Partition mode (Mike Christie) [635892]
- [netdrv] cnic: Use proper client and connection IDs on iSCSI ring (Mike Christie) [635892]
- [netdrv] cnic: Improve ->iscsi_nl_msg_send() (Mike Christie) [635892]
- [netdrv] cnic: Prevent "scheduling while atomic" when calling ->cnic_init() (Mike Christie) [635892]
- [netdrv] cnic: Fix iSCSI TCP port endian order (Mike Christie) [635892]
- [netdrv] drivers/net/cnic.c: Remove unnecessary semicolons (Mike Christie) [635892]
- [netdrv] cnic: Add support for 57712 device (Mike Christie) [635892]
- [netdrv] cnic: Decouple uio close from cnic shutdown (Mike Christie) [635892]
- [netdrv] cnic: Add cnic_uio_dev struct (Mike Christie) [635892]
- [netdrv] cnic: Add cnic_free_uio() (Mike Christie) [635892]
- [netdrv] cnic: Defer iscsi connection cleanup (Mike Christie) [635892]
- [netdrv] cnic: Add cnic_bnx2x_destroy_ramrod() (Mike Christie) [635892]
- [netdrv] cnic: Convert ctx_flags to bit fields (Mike Christie) [635892]
- [netdrv] cnic: Add common cnic_request_irq() (Mike Christie) [635892]
- [netdrv] bnx2x, cnic: Fix SPQ return credit (Mike Christie) [635892]
- [netdrv] bnx2x, cnic, bnx2i: use new FW/HSI (Mike Christie) [635892]
- [netdrv] cnic: Fine-tune ring init code (Mike Christie) [635892]
- [netdrv] cnic: Use pfid for internal memory offsets (Mike Christie) [635892]
- [netdrv] cnic: Pass cp pointer to BNX2X_HW_CID (Mike Christie) [635892]
- [netdrv] drivers/net: Convert unbounded kzalloc calls to kcalloc (Mike Christie) [635892]
- [netdrv] cnic: Update version to 2.1.3 (Mike Christie) [635892]
- [netdrv] cnic: Further unify kcq handling code (Mike Christie) [635892]
- [netdrv] cnic: Restructure kcq processing (Mike Christie) [635892]
- [netdrv] cnic: Unify kcq allocation for all devices (Mike Christie) [635892]
- [netdrv] cnic: Unify IRQ code for all hardware types (Mike Christie) [635892]
- [netdrv] cnic: Fine-tune CID memory space calculation (Mike Christie) [635892]
- [netdrv] cnic: Fix cnic_cm_abort() error handling (Mike Christie) [635892]
- [netdrv] cnic: Refactor and fix cnic_ready_to_close() (Mike Christie) [635892]
- [netdrv] cnic: Refactor code in cnic_cm_process_kcqe() (Mike Christie) [635892]
- [netdrv] cnic: Return error code in cnic_cm_close() if unsuccessful (Mike Christie) [635892]
- [netdrv] cnic: Return SPQ credit to bnx2x after ring setup and shutdown (Mike Christie) [635892]
- [netdrv] cnic: Convert cnic_local_flags to atomic ops (Mike Christie) [635892]
- [netdrv] drivers/net: Remove unnecessary returns from void function()s (Mike Christie) [635892]
- [netdrv] bnx2x: update version to 1.62.00-2 (Mike Christie) [635942]
- [netdrv] bnx2x: replace FW to 6.2.5 (Mike Christie) [635942]
- [netdrv] bnx2x: add FW 6.2.5 files (Mike Christie) [635942]
- [netdrv] bnx2x: Add DCB/PFC support - link layer (Mike Christie) [635942]
- [netdrv] bnx2x: add DCB support (Mike Christie) [635942]
- [netdrv] bnx2x: add a select queue callback (Mike Christie) [635942]
- [netdrv] bnx2x: Take the distribution range definition out of skb_tx_hash() (Mike Christie) [635942]
- [netdrv] bnx2x: add FCoE ring (Mike Christie) [635942]
- [netdrv] bnx2x: Update version number and a date (Mike Christie) [635942]
- [netdrv] bnx2x: Fixed a compilation warning (Mike Christie) [635942]
- [netdrv] bnx2x: Use dma_alloc_coherent() semantics for ILT memory allocation (Mike Christie) [635942]
- [netdrv] bnx2x: LSO code was broken on BE platforms (Mike Christie) [635942]
- [netdrv] bnx2x: Add Nic partitioning mode (57712 devices) (Mike Christie) [635942]
- [netdrv] bnx2x: Use helpers instead of direct access to the shinfo(skb) fields (Mike Christie) [635942]
- [netdrv] bnx2x: Do interrupt mode initialization and NAPIs adding before register_netdev() (Mike Christie) [635942]
- [netdrv] bnx2x: Disable local BHes to prevent a dead-lock situation (Mike Christie) [635942]
- [netdrv] net: bnx2x: fix error value sign (Mike Christie) [635942]
- [netdrv] drivers/net/bnx2x: Remove unnecessary semicolons (Mike Christie) [635942]
- [netdrv] bnx2x: Update version number (Mike Christie) [635942]
- [netdrv] bnx2x: Reset 8073 phy during common init (Mike Christie) [635942]
- [netdrv] bnx2x: Do not enable CL37 BAM unless it is explicitly enabled (Mike Christie) [635942]
- [netdrv] bnx2x: Fix resetting BCM8726 PHY during common init (Mike Christie) [635942]
- [netdrv] bnx2x: Clear latch indication on link reset (Mike Christie) [635942]
- [netdrv] bnx2x: Fix port selection in case of E2 (Mike Christie) [635942]
- [netdrv] bnx2x: Fix waiting for reset complete on BCM848x3 PHYs (Mike Christie) [635942]
- [netdrv] bnx2x: Restore appropriate delay during BMAC reset (Mike Christie) [635942]
- [netdrv] bnx2x: make local function static and remove dead code (Mike Christie) [635942]
- [netdrv] bnx2x: Don't check for vlan group before vlan_tx_tag_present (Mike Christie) [635942]
- [netdrv] bnx2x: update version to 1.60.00-3 (Mike Christie) [635942]
- [netdrv] bnx2x: prevent false parity error in MSI-X memory of HC block (Mike Christie) [635942]
- [netdrv] bnx2x: fix possible deadlock in HC hw block (Mike Christie) [635942]
- [netdrv] bnx2x: update version to 1.60.00-2 (Mike Christie) [635942]
- [netdrv] bnx2x: remove unnecessary FUNC_FLG_RSS flag and related (Mike Christie) [635942]
- [netdrv] bnx2x: Use correct FW constant for header padding (Mike Christie) [635942]
- [netdrv] bnx2x: do not deal with power if no capability (Mike Christie) [635942]
- [netdrv] bnx2x: remove redundant commands during error handling (Mike Christie) [635942]
- [netdrv] bnx2x: Optimized the branching in the bnx2x_rx_int() (Mike Christie) [635942]
- [netdrv] bnx2x: Fixing a typo: added a missing RSS enablement (Mike Christie) [635942]
- [netdrv] bnx2x: update version to 1.60.00-1 (Mike Christie) [635942]
- [netdrv] bnx2x: properly initialize FW stats (Mike Christie) [635942]
- [netdrv] bnx2x: code beautify (Mike Christie) [635942]
- [netdrv] bnx2x, cnic: Fix SPQ return credit (Mike Christie) [635942]
- [netdrv] bnx2x: move msix table initialization to probe() (Mike Christie) [635942]
- [netdrv] bnx2x: use L1_CACHE_BYTES instead of magic number (Mike Christie) [635942]
- [netdrv] bnx2x: remove unused fields in main driver structure (Mike Christie) [635942]
- [netdrv] bnx2x: remove unused parameter in reuse_rx_skb() (Mike Christie) [635942]
- [netdrv] bnx2x: Add 57712 support (Mike Christie) [635942]
- [netdrv] bnx2x: change type of spq_left to atomic (Mike Christie) [635942]
- [netdrv] bnx2x: rename MF related fields (Mike Christie) [635942]
- [netdrv] bnx2x: remove old FW files (Mike Christie) [635942]
- [netdrv] bnx2x, cnic, bnx2i: use new FW/HSI (Mike Christie) [635942]
- [netdrv] bnx2x: add 6.0.34 fw files (Mike Christie) [635942]
- [netdrv] bnx2x: create folder for bnx2x firmware files (Mike Christie) [635942]
- [netdrv] bnx2x: Moved enabling of MSI to the bnx2x_set_num_queues() (Mike Christie) [635942]
- [netdrv] bnx2x: Use netif_set_real_num_{rx, tx}_queues() (Mike Christie) [635942]
- [netdrv] bnx2x: return operator cleanup (Mike Christie) [635942]
- [netdrv] bnx2x: Spread rx buffers between allocated queues (Mike Christie) [635942]
- [netdrv] drivers/net/bnx2x: use ARRAY_SIZE macro in bnx2x_main.c (Mike Christie) [635942]
- [netdrv] bnx2x: Update bnx2x version to 1.52.53-6 (Mike Christie) [635942]
- [netdrv] bnx2x: Change LED scheme for dual-media (Mike Christie) [635942]
- [netdrv] bnx2x: Add dual-media changes (Mike Christie) [635942]
- [netdrv] bnx2x: Organize PHY functions (Mike Christie) [635942]
- [netdrv] bnx2x: Apply logic changes for the new scheme (Mike Christie) [635942]
- [netdrv] bnx2x: Move common function into aggregated function (Mike Christie) [635942]
- [netdrv] bnx2x: Adjust flow-control with the new scheme (Mike Christie) [635942]
- [netdrv] bnx2x: Adjust alignment of split PHY functions (Mike Christie) [635942]
- [netdrv] bnx2x: Split PHY functions (Mike Christie) [635942]
- [netdrv] bnx2x: Unify PHY attributes (Mike Christie) [635942]
- [netdrv] bnx2x: avoid skb->ip_summed initialization (Mike Christie) [635942]
- [netdrv] skbuff.h: add skb_checksum_none_assert() (Mike Christie) [635942]
- [netdrv] bnx2x: Update version to 1.52.53-5 (Mike Christie) [635942]
- [netdrv] bnx2x: Add BCM84823 to the supported PHYs (Mike Christie) [635942]
- [netdrv] bnx2x: Change BCM848xx LED configuration (Mike Christie) [635942]
- [netdrv] bnx2x: Remove unneeded setting of XAUI low power to BCM8727 (Mike Christie) [635942]
- [netdrv] bnx2x: Change BCM848xx configuration according to IEEE (Mike Christie) [635942]
- [netdrv] bnx2x: Reset link before any new link settings (Mike Christie) [635942]
- [netdrv] bnx2x: Fix potential link issue In BCM8727 based boards (Mike Christie) [635942]
- [netdrv] bnx2x: Fix potential link issue of BCM8073/BCM8727 (Mike Christie) [635942]
- [netdrv] bnx2x: fix wrong return from bnx2x_trylock_hw_lock (Mike Christie) [635942]
- [netdrv] bnx2x: small fix in stats handling (Mike Christie) [635942]
- [netdrv] bnx2x: Update bnx2x version to 1.52.53-4 (Mike Christie) [635942]
- [netdrv] bnx2x: Fix PHY locking problem (Mike Christie) [635942]
- [netdrv] drivers/net/bnx2x: Adjust confusing if indentation (Mike Christie) [635942]
- [netdrv] bnx2x: Load firmware in open() instead of probe() (Mike Christie) [635942]
- [netdrv] bnx2x: Protect statistics ramrod and sequence number (Mike Christie) [635942]
- [netdrv] bnx2x: Protect a SM state change (Mike Christie) [635942]
- [netdrv] net: bnx2x_cmn.c needs net/ip6_checksum.h for csum_ipv6_magic (Mike Christie) [635942]
- [netdrv] bnx2x: update driver version to 1.52.53-3 (Mike Christie) [635942]
- [netdrv] bnx2x: Move statistics handling code to bnx2x_stats.* (Mike Christie) [635942]
- [netdrv] bnx2x: Create separate file for ethtool routines (Mike Christie) [635942]
- [netdrv] bnx2x: Create bnx2x_cmn.* files (Mike Christie) [635942]
- [netdrv] bnx2x: move global variable load_count to bnx2x.h (Mike Christie) [635942]
- [netdrv] bnx2x: store module parameters in driver main structure (Mike Christie) [635942]
- [netdrv] bnx2x: Create separate folder for bnx2x driver (Mike Christie) [635942]
- [netdrv] bnx2x: Set RXHASH for LRO packets (Mike Christie) [635942]
- [netdrv] bnx2x: Make ethtool_ops::set_flags() return -EINVAL for unsupported flags (Mike Christie) [635942]
- [netdrv] bnx2x: fail when try to setup unsupported features (Mike Christie) [635942]
- [netdrv] bnx2x: Fix link problem with some DACs (Mike Christie) [635942]
- [netdrv] bnx2x: avoid TX timeout when stopping device (Mike Christie) [635942]
- [netdrv] bnx2x: Remove two prefetch() (Mike Christie) [635942]
- [netdrv] bnx2x: add support for receive hashing (Mike Christie) [635942]
- [netdrv] bnx2x: Date and version (Mike Christie) [635942]
- [netdrv] bnx2x: Rework power state handling code (Mike Christie) [635942]
- [netdrv] bnx2x: use mask in test_registers() to avoid parity error (Mike Christie) [635942]
- [netdrv] bnx2x: Fixed MSI-X enabling flow (Mike Christie) [635942]
- [netdrv] bnx2x: Added new statistics (Mike Christie) [635942]
- [netdrv] bnx2x: White spaces (Mike Christie) [635942]
- [netdrv] bnx2x: Protect code with NOMCP (Mike Christie) [635942]
- [netdrv] bnx2x: Increase DMAE max write size for 57711 (Mike Christie) [635942]
- [netdrv] bnx2x: Parity errors handling for 57710 and 57711 (Mike Christie) [635942]
- [netdrv] Revert "[netdrv] bnx2x: fix system hung after netdev watchdog" (Mike Christie) [635942]
- [netdrv] bnx2x: Added GRO support (Mike Christie) [635942]
- [netdrv] bnx2x: remove trailing space in messages (Mike Christie) [635942]
- [netdrv] bnx2x: fix typo (Mike Christie) [635942]
- [netdrv] bnx2x: convert to use netdev_for_each_mc_addr (Mike Christie) [635942]
- [netdrv] drivers/net/bnx2x: Use (pr|netdev|netif)_<level> macro helpers (Mike Christie) [635942]
- [netdrv] bnx2x: use netdev_mc_count and netdev_mc_empty when appropriate (Mike Christie) [635942]
- [netdrv] bnx2x: remove HAVE_ leftovers (Mike Christie) [635942]
- [netdrv] bnx2x: use DEFINE_PCI_DEVICE_TABLE() (Mike Christie) [635942]
- [netdrv] bnx2x: fix typos (Mike Christie) [635942]
- [netdrv] bnx2x: Move && and || to end of previous line (Mike Christie) [635942]
- [netdrv] bnx2x: Convert ethtool {get_stats, self_test}_count() ops to get_sset_count() (Mike Christie) [635942]

* Thu Jan 13 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-98.el6]
- [virt] kvm: fast-path msi injection with irqfd (Michael S. Tsirkin) [658442]
- [fs] cifs: make cifs_set_oplock_level() take a cifsInodeInfo pointer (Jeff Layton) [656461]
- [fs] cifs: Add cifs_set_oplock_level (Jeff Layton) [656461]
- [fs] cifs: eliminate cifsInodeInfo->write_behind_rc (Jeff Layton) [656461]
- [fs] cifs: Fix checkpatch warnings and bump cifs version number (Jeff Layton) [656461]
- [fs] cifs: wait for writeback to complete in cifs_flush (Jeff Layton) [656461]
- [fs] cifs: convert cifsFileInfo->count to non-atomic counter (Jeff Layton) [656461]
- [fs] cifs: move close processing from cifs_close to cifsFileInfo_put (Jeff Layton) [656461]
- [fs] cifs: move cifsFileInfo_put to file.c (Jeff Layton) [656461]
- [fs] cifs: convert GlobalSMBSeslock from a rwlock to regular spinlock (Jeff Layton) [656461]
- [fs] cifs: Fix minor checkpatch warning and update cifs version (Jeff Layton) [656461]
- [fs] cifs: move cifs_new_fileinfo to file.c (Jeff Layton) [656461]
- [fs] cifs: eliminate pfile pointer from cifsFileInfo (Jeff Layton) [656461]
- [fs] cifs: cifs_write argument change and cleanup (Jeff Layton) [656461]
- [fs] cifs: clean up cifs_reopen_file (Jeff Layton) [656461]
- [fs] cifs: eliminate the inode argument from cifs_new_fileinfo (Jeff Layton) [656461]
- [fs] cifs: eliminate oflags option from cifs_new_fileinfo (Jeff Layton) [656461]
- [fs] cifs: fix flags handling in cifs_posix_open (Jeff Layton) [656461]
- [fs] cifs: eliminate cifs_posix_open_inode_helper (Jeff Layton) [656461]
- [fs] cifs: don't use vfsmount to pin superblock for oplock breaks (Jeff Layton) [656461]
- [fs] cifs: keep dentry reference in cifsFileInfo instead of inode reference (Jeff Layton) [656461]
- [fs] Fix f_flags/f_mode in case of lookup_instantiate_filp() from open(pathname, 3) (Jeff Layton) [656461]
- [fs] Kill path_lookup_open() (Jeff Layton) [656461]
- [fs] add OPEN_FMODE definition (Jeff Layton) [656461]
- [fs] cifs: allow calling cifs_build_path_to_root on incomplete cifs_sb (Jeff Layton) [646223]
- [fs] cifs: fix check of error return from is_path_accessable (Jeff Layton) [646223]
- [fs] cifs: don't take extra tlink reference in initiate_cifs_search (Jeff Layton) [646223]
- [fs] cifs: make cifs_ioctl handle NULL filp->private_data correctly (Jeff Layton) [646223]
- [fs] cifs: remove unneeded NULL tests (Jeff Layton) [646223]
- [fs] cifs: convert tlink_tree to a rbtree (Jeff Layton) [646223]
- [fs] cifs: store pointer to master tlink in superblock (Jeff Layton) [646223]
- [fs] cifs: on multiuser mount, set ownership to current_fsuid/current_fsgid (Jeff Layton) [646223]
- [fs] cifs: initialize tlink_tree_lock and tlink_tree (Jeff Layton) [646223]
- [fs] cifs: unregister as a user of slow work on module removal (Jeff Layton) [646223]
- [fs] cifs: implement recurring workqueue job to prune old tcons (Jeff Layton) [646223]
- [fs] cifs: on multiuser mount, set ownership to current_fsuid/current_fsgid (Jeff Layton) [646223]
- [fs] cifs: add "multiuser" mount option (Jeff Layton) [646223]
- [fs] cifs: add routines to build sessions and tcons on the fly (Jeff Layton) [646223]
- [fs] cifs: fix cifs_show_options to show "username=" or "multiuser" (Jeff Layton) [646223]
- [fs] cifs: have find_readable/writable_file filter by fsuid (Jeff Layton) [646223]
- [fs] cifs: have cifsFileInfo hold a reference to a tlink rather than tcon pointer (Jeff Layton) [646223]
- [fs] cifs: add refcounted and timestamped container for holding tcons (Jeff Layton) [646223]
- [fs] cifs: add kfree() on error path (Jeff Layton) [646223]
- [fs] cifs: fix handling of signing with writepages (Jeff Layton) [646223]
- [fs] cifs: have cifs_new_fileinfo take a tcon arg (Jeff Layton) [646223]
- [fs] cifs: add cifs_sb_master_tcon and convert some callers to use it (Jeff Layton) [646223]
- [fs] cifs: temporarily rename cifs_sb->tcon to ptcon to catch stragglers (Jeff Layton) [646223]
- [fs] cifs: add function to get a tcon from cifs_sb (Jeff Layton) [646223]
- [fs] cifs: make various routines use the cifsFileInfo->tcon pointer (Jeff Layton) [646223]
- [fs] cifs: Remove unnecessary casts of private_data (Jeff Layton) [646223]
- [fs] cifs: add tcon field to cifsFileInfo struct (Jeff Layton) [646223]
- [fs] cifs: eliminate redundant xdev check in cifs_rename (Jeff Layton) [646223]
- [fs] cifs: consolidate error handling in several functions (Jeff Layton) [646223]
- [fs] cifs: add "mfsymlinks" mount option (Jeff Layton) [651878]
- [fs] cifs: use Minshall+French symlink functions (Jeff Layton) [651878]
- [fs] cifs: implement CIFSCreateMFSymLink() (Jeff Layton) [651878]
- [fs] cifs: implement CIFSFormatMFSymlink() (Jeff Layton) [651878]
- [fs] cifs: implement CIFSQueryMFSymLink() (Jeff Layton) [651878]
- [fs] cifs: implement CIFSCouldBeMFSymlink() and CIFSCheckMFSymlink() (Jeff Layton) [651878]
- [fs] cifs: implement CIFSParseMFSymlink() (Jeff Layton) [651878]
- [fs] cifs: set CONFIG_CIFS_FSCACHE to 'no' for now (Jeff Layton) [651865]
- [fs] cifs: fix another memleak, in cifs_root_iget (Jeff Layton) [651865]
- [fs] cifs: cancel_delayed_work() + flush_scheduled_work() -> cancel_delayed_work_sync() (Jeff Layton) [651865]
- [fs] cifs: cifs_convert_address() returns zero on error (Jeff Layton) [651865]
- [fs] cifs: handle FindFirst failure gracefully (Jeff Layton) [651865]
- [fs] cifs: prevent infinite recursion in cifs_reconnect_tcon (Jeff Layton) [651865]
- [fs] cifs: Cannot allocate memory error on mount (Jeff Layton) [651865]
- [fs] cifs: Remove obsolete header (Jeff Layton) [651865]
- [fs] cifs: Allow binding to local IP address (Jeff Layton) [651865]
- [fs] cifs: fix broken oplock handling (Jeff Layton) [651865]
- [fs] cifs: use type __u32 instead of int for the oplock parameter (Jeff Layton) [651865]
- [fs] cifs: reduce false positives with inode aliasing serverino autodisable (Jeff Layton) [651865]
- [fs] cifs: don't allow cifs_iget to match inodes of the wrong type (Jeff Layton) [651865]
- [fs] cifs: remove redundant path walking in dfs_do_refmount (Jeff Layton) [651865]
- [fs] cifs: ignore the "mand", "nomand" and "_netdev" mount options (Jeff Layton) [651865]
- [fs] cifs: update README to include details about 'fsc' option (Jeff Layton) [651865]
- [fs] cifs: Fix ordering of cleanup on module init failure (Jeff Layton) [651865]
- [fs] cifs: relinquish fscache cookie before freeing CIFSTconInfo (Jeff Layton) [651865]
- [fs] cifs: Missing ifdef (Jeff Layton) [651865]
- [fs] cifs: Missing line from previous commit (Jeff Layton) [651865]
- [fs] cifs: Fix build break when CONFIG_CIFS_FSCACHE disabled (Jeff Layton) [651865]
- [fs] cifs: fsc should not default to "on" (Jeff Layton) [651865]
- [fs] cifs: add mount option to enable local caching (Jeff Layton) [651865]
- [fs] cifs: read pages from FS-Cache (Jeff Layton) [651865]
- [fs] cifs: store pages into local cache (Jeff Layton) [651865]
- [fs] cifs: FS-Cache page management (Jeff Layton) [651865]
- [fs] cifs: define inode-level cache object and register them (Jeff Layton) [651865]
- [fs] cifs: define superblock-level cache index objects and register them (Jeff Layton) [651865]
- [fs] cifs: define server-level cache index objects and register them (Jeff Layton) [651865]
- [fs] cifs: register CIFS for caching (Jeff Layton) [651865]
- [fs] cifs: add kernel config option for CIFS Client caching support (Jeff Layton) [651865]
- [fs] cifs: guard cifsglob.h against multiple inclusion (Jeff Layton) [651865]
- [fs] cifs: map NT_STATUS_ERROR_WRITE_PROTECTED to -EROFS (Jeff Layton) [618175]
- [fs] cifs: allow matching of tcp sessions in CifsNew state (Jeff Layton) [629085]
- [fs] cifs: fix potential double put of TCP session reference (Jeff Layton) [629085]
- [fs] cifs: prevent possible memory corruption in cifs_demultiplex_thread (Jeff Layton) [629085]
- [fs] cifs: eliminate some more premature cifsd exits (Jeff Layton) [629085]
- [fs] cifs: prevent cifsd from exiting prematurely (Jeff Layton) [629085]
- [fs] CIFS: Make cifs_convert_address() take a const src pointer and a length (Jeff Layton) [629085]
- [x86] oprofile: Add support for 6 counters for AMD family 15h (Robert Richter) [647750]
- [x86] oprofile: Add support for AMD family 15h (Robert Richter) [647750]
- [x86] GART: Disable GART table walk probes, add warning (Frank Arnold) [633479 633916]
- [x86] amd_nb: Enable GART support for AMD family 0x15 CPUs (Frank Arnold) [633479 633916]
- [x86] cacheinfo: Unify AMD L3 cache index disable checking (Frank Arnold) [633479]
- [x86] powernow-k8: Limit Pstate transition latency check (Frank Arnold) [633479]
- [x86] AMD: Extend support to future families (Frank Arnold) [633479]
- [x86] amd: Use compute unit information to determine thread siblings (Frank Arnold) [633479 633922]
- [x86] amd: Extract compute unit information for AMD CPUs (Frank Arnold) [633479 633922]
- [x86] amd: Add support for CPUID topology extension of AMD CPUs (Frank Arnold) [633479 633922]
- [x86] cpu: Fix renamed, not-yet-shipping AMD CPUID feature bit (Frank Arnold) [633479]
- [x86] cpu: Update AMD CPUID feature bits (Frank Arnold) [633479]
- [x86] nmi: Support NMI watchdog on newer AMD CPU families (Frank Arnold) [633479]
- [virt] vhost: get/put_user -> __get/__put_user (Michael S. Tsirkin) [665360]
- [virt] vhost: copy_to_user -> __copy_to_user (Michael S. Tsirkin) [665360]
- [virt] vhost: fix log ctx signalling (Michael S. Tsirkin) [665360]
- [virt] vhost: fix return code for log_access_ok() (Michael S. Tsirkin) [665360]
- [virt] vhost-net: batch use/unuse mm (Michael S. Tsirkin) [665360]
- [virt] drivers/vhost/vhost.c: delete double assignment (Michael S. Tsirkin) [665360]
- [virt] vhost: put mm after thread stop (Michael S. Tsirkin) [665360]
- [virt] vhost-net: replace workqueue with a kthread (Michael S. Tsirkin) [665360]

* Wed Jan 12 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-97.el6]
- [mm] do not keep kswapd awake for an unreclaimable zone (Johannes Weiner) [633825]
- [netdrv] iwlwifi: Convert to new PCI PM framework (John Linville) [611075]
- [virt] Add AES to CPUID ext_features recognized by kvm (John Cooper) [663538]
- [net] tcp: Increase TCP_MAXSEG socket option minimum to TCP_MIN_MSS (Frantisek Hrbata) [652511] {CVE-2010-4165}
- [net] tproxy: use the interface primary IP address as a default value for --on-ip (Thomas Graf) [591335]
- [net] tproxy: Add missing CAP_NET_ADMIN check to ipv6 side (Thomas Graf) [591335]
- [net] tproxy: added IPv6 support to the socket match (Thomas Graf) [591335]
- [net] tproxy: split off ipv6 defragmentation to a separate module (Thomas Graf) [591335]
- [net] tproxy: check for transparent flag in ip_route_newports (Thomas Graf) [591335]
- [net] netfilter: tproxy: nf_tproxy_assign_sock() can handle tw sockets (Thomas Graf) [591335]
- [net] tproxy: added IPv6 support to the TPROXY target (Thomas Graf) [591335]
- [net] tproxy: allow non-local binds of IPv6 sockets if IP_TRANSPARENT is enabled (Thomas Graf) [591335]
- [net] tproxy: added IPv6 socket lookup function to nf_tproxy_core (Thomas Graf) [591335]
- [net] tproxy: added const specifiers to udp lookup functions (Thomas Graf) [591335]
- [net] tproxy: added tproxy sockopt interface in the IPV6 layer (Thomas Graf) [591335]
- [net] tproxy: added udp6_lib_lookup function (Thomas Graf) [591335]
- [net] tproxy: add lookup type checks for UDP in nf_tproxy_get_sock_v4() (Thomas Graf) [591335]
- [net] tproxy: kick out TIME_WAIT sockets in case a new connection comes in with th (Thomas Graf) [591335]
- [net] tproxy: fix hash locking issue when using port redirection in __inet_inherit_port() (Thomas Graf) [591335]
- [net] netfilter: use NFPROTO_IPV4 instead of AF_INET (Thomas Graf) [591335]
- [net] netfilter: xt_TPROXY: the length of lines should be within 80 (Thomas Graf) [591335]
- [mm] fix memory-failure hugetlbfs vs THP collision (Dean Nelson) [531476]
- [mm] mm/hugetlb.c: avoid double unlock_page() in hugetlb_fault() (Dean Nelson) [531476]
- [mm] mm/hugetlb.c: add missing spin_lock() to hugetlb_cow() (Dean Nelson) [531476]
- [mm] Fix migration.c compilation on s390 (Dean Nelson) [531476]
- [mm] HWPOISON/signalfd: add support for addr_lsb (Dean Nelson) [531476]
- [mm] Encode huge page size for VM_FAULT_HWPOISON errors (Dean Nelson) [531476]
- [mm] Fix build error with !CONFIG_MIGRATION (Dean Nelson) [531476]
- [mm] HWPOISON: Remove retry loop for try_to_unmap (Dean Nelson) [531476]
- [mm] HWPOISON: Turn addr_valid from bitfield into char (Dean Nelson) [531476]
- [mm] HWPOISON: Disable DEBUG by default (Dean Nelson) [531476]
- [mm] HWPOISON: Convert pr_debugs to pr_info (Dean Nelson) [531476]
- [mm] HWPOISON: Improve comments in memory-failure.c (Dean Nelson) [531476]
- [mm] x86: HWPOISON: Report correct address granuality for huge hwpoison faults (Dean Nelson) [531476]
- [mm] hugepage: move is_hugepage_on_freelist inside ifdef to avoid warning (Dean Nelson) [531476]
- [mm] Clean up __page_set_anon_rmap (Dean Nelson) [531476]
- [mm] HWPOISON, hugetlb: fix unpoison for hugepage (Dean Nelson) [531476]
- [mm] HWPOISON, hugetlb: soft offlining for hugepage (Dean Nelson) [531476]
- [mm] HWPOSION, hugetlb: recover from free hugepage error when !MF_COUNT_INCREASED (Dean Nelson) [531476]
- [mm] hugetlb: move refcounting in hugepage allocation inside hugetlb_lock (Dean Nelson) [531476]
- [mm] HWPOISON, hugetlb: add free check to dequeue_hwpoison_huge_page() (Dean Nelson) [531476]
- [mm] hugetlb: hugepage migration core (Dean Nelson) [531476]
- [mm] mm/migrate.c: kill anon local variable from migrate_page_copy (Dean Nelson) [531476]
- [mm] hugetlb: redefine hugepage copy functions (Dean Nelson) [531476]
- [mm] hugetlb: add allocate function for hugepage migration (Dean Nelson) [531476]
- [mm] hugetlb: fix metadata corruption in hugetlb_fault() (Dean Nelson) [531476]
- [mm] HWPOISON: Stop shrinking at right page count (Dean Nelson) [531476]
- [mm] HWPOISON: Report correct address granuality for AO huge page errors (Dean Nelson) [531476]
- [mm] HWPOISON: Copy si_addr_lsb to user (Dean Nelson) [531476]
- [mm] hugetlb, rmap: add BUG_ON(!PageLocked) in hugetlb_add_anon_rmap() (Dean Nelson) [531476]
- [mm] hugetlb, rmap: fix confusing page locking in hugetlb_cow() (Dean Nelson) [531476]
- [mm] hugetlb, rmap: use hugepage_add_new_anon_rmap() in hugetlb_cow() (Dean Nelson) [531476]
- [mm] hugetlb, rmap: always use anon_vma root pointer (Dean Nelson) [531476]
- [mm] hugetlb: call mmu notifiers on hugepage cow (Dean Nelson) [531476]
- [mm] hugetlb: add missing unlock in avoidcopy path in hugetlb_cow() (Dean Nelson) [531476]
- [mm] hwpoison: rename CONFIG (Dean Nelson) [531476]
- [mm] HWPOISON, hugetlb: support hwpoison injection for hugepage (Dean Nelson) [531476]
- [mm] HWPOISON, hugetlb: detect hwpoison in hugetlb code (Dean Nelson) [531476]
- [mm] HWPOISON, hugetlb: isolate corrupted hugepage (Dean Nelson) [531476]
- [mm] HWPOISON, hugetlb: maintain mce_bad_pages in handling hugepage error (Dean Nelson) [531476]
- [mm] HWPOISON, hugetlb: set/clear PG_hwpoison bits on hugepage (Dean Nelson) [531476]
- [mm] HWPOISON, hugetlb: enable error handling path for hugepage (Dean Nelson) [531476]
- [mm] hugetlb, rmap: add reverse mapping for hugepage (Dean Nelson) [531476]
- [mm] hugetlb: move definition of is_vm_hugetlb_page() to hugepage_inline.h (Dean Nelson) [531476]
- [mm] HWPOISON: Add PROC_FS dependency to hwpoison injector (Dean Nelson) [531476]
- [mm] hugetlb: acquire the i_mmap_lock before walking the prio_tree to unmap a page (Dean Nelson) [531476]
- [mm] hugetlb: prevent deadlock in __unmap_hugepage_range() when alloc_huge_page() fails (Dean Nelson) [531476]
- [mm] nodemask: fix the declaration of NODEMASK_ALLOC() (Dean Nelson) [630170]
- [mm] add gfp flags for NODEMASK_ALLOC slab allocations (Dean Nelson) [630170]
- [mm] hugetlb: add generic definition of NUMA_NO_NODE (Dean Nelson) [630170]
- [mm] hugetlb: offload per node attribute registrations (Dean Nelson) [630170]
- [mm] hugetlb: use only nodes with memory for huge pages (Dean Nelson) [630170]
- [mm] hugetlb: handle memory hot-plug events (Dean Nelson) [630170]
- [mm] hugetlb: update hugetlb documentation for NUMA controls (Dean Nelson) [630170]
- [mm] hugetlb: add per node hstate attributes (Dean Nelson) [630170]
- [mm] hugetlb: derive huge pages nodes allowed from task mempolicy (Dean Nelson) [630170]
- [mm] hugetlb: add nodemask arg to huge page alloc, free and surplus adjust functions (Dean Nelson) [630170]
- [mm] hugetlb: rework hstate_next_node_* functions (Dean Nelson) [630170]
- [mm] hugetlb: factor init_nodemask_of_node() (Dean Nelson) [630170]
- [mm] nodemask: make NODEMASK_ALLOC more general (Dean Nelson) [630170]

* Tue Jan 11 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-96.el6]
- [netdrv] be2net: Avoid firmware update when interface is not open (Ivan Vecera) [651952]
- [netdrv] be2net: use mutex instead of spin lock for mbox_lock (Ivan Vecera) [623201]
- [netdrv] rhel config: changes for 2.6.37-era iwlwifi backport (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] mac80211: add ieee80211_alloc_hw2 (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: remove skb_linearize for rx frames" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] iwlwifi: misc backporting fixups for 2.6.37-era iwlwifi (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlagn: use mutex for aggregation" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: dump firmware build info in error case" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: send PAN parameters" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlagn: send RXON timing before associating" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert iwlwifi bits of "cfg80211: convert bools into flags" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: fix regulatory" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: provide firmware version" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert iwlwifi bits of "mac80211: use cipher suite selectors" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: debugfs file for txfifo command testing" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert iwlwifi bits of "mac80211: move QoS-enable to BSS info" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: use new mac80211 SMPS" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: manage IBSS station properly" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: use the DMA state API instead of the pci equivalents" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: remove mac_addr assignment" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: support channel switch offload in driver" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: remove priv->mac_addr" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: add mac80211 flush callback support" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: add support for device tx flush request" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] revert "iwlwifi: read multiple MAC addresses" (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] iwlwifi: resync bits from 2.6.37 (John Linville) [616104 637888 637897 638219 638230 648841]
- [netdrv] mac80211: improve IBSS scanning (John Linville) [653978]
- [netdrv] mac80211: allow scan to complete from any context (John Linville) [653978]
- [netdrv] mac80211: split hardware scan by band (John Linville) [653978]
- [netdrv] mac80211: Fix sta_mtx unlocking on insert STA failure path (John Linville) [653978]
- [netdrv] mac80211: explicitly disable/enable QoS (John Linville) [653978]
- [netdrv] mac80211: allow station add/remove to sleep (John Linville) [653978]
- [netdrv] mac80211: async station powersave handling (John Linville) [653978]
- [netdrv] mac80211: remove sent_ps_buffered (John Linville) [653978]
- [kernel] lib: add EXPORT_SYMBOL_GPL for debug_locks (John Linville) [653974]
- [firmware] firmware_class: make request_firmware_nowait more useful (John Linville) [653974]
- [kernel] sched: Update rq->clock for nohz balanced cpus (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Change nohz idle load balancing logic to push model (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Avoid side-effect of tickless idle on update_cpu_load (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Reduce update_group_power() calls (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix the place where group powers are updated (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Add enqueue/dequeue flags (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove AFFINE_WAKEUPS feature (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove ASYM_GRAN feature (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove SYNC_WAKEUPS feature (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove WAKEUP_SYNC feature (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove FAIR_SLEEPERS feature (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove NORMALIZED_SLEEPER (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Cleanup/optimize clock updates (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove avg_overlap (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove avg_wakeup (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Discard some old bits (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Clean up check_preempt_wakeup() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Move update_curr() in check_preempt_wakeup() to avoid redundant call (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] mutex: Improve the scalability of optimistic spinning (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Pre-compute cpumask_weight(sched_domain_span(sd)) (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix select_idle_sibling() logic in select_task_rq_fair() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix select_idle_sibling() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: More generic WAKE_AFFINE vs select_idle_sibling() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix rq->clock synchronization when migrating tasks (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove the cfs_rq dependency from set_task_cpu() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Add pre and post wakeup hooks (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove forced2_migrations stats (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove rq->clock coupling from set_task_cpu() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove unused cpu_nr_migrations() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] rcu: apply RCU protection to wake_affine() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Remove unnecessary RCU exclusion (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix nr_uninterruptible count (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Optimize task_rq_lock() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix TASK_WAKING vs fork deadlock (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Make select_fallback_rq() cpuset friendly (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: _cpu_down(): Don't play with current->cpus_allowed (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: sched_exec(): Remove the select_fallback_rq() logic (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: move_task_off_dead_cpu(): Remove retry logic (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: move_task_off_dead_cpu(): Take rq->lock around select_fallback_rq() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Kill the broken and deadlockable cpuset_lock/cpuset_cpus_allowed_locked code (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: set_cpus_allowed_ptr(): Don't use rq->migration_thread after unlock (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Queue a deboosted task to the head of the RT prio queue (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Implement head queueing for sched_rt (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Extend enqueue_task to allow head queueing (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix race between ttwu() and task_rq_lock() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix incorrect sanity check (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix fork vs hotplug vs cpuset namespaces (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix hotplug hang (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix broken assertion (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Make warning less noisy (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix select_task_rq() vs hotplug issues (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Fix sched_exec() balancing (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Ensure set_task_cpu() is never called on blocked tasks (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Use TASK_WAKING for fork wakups (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Use rcu in sched_get_rr_param() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Use rcu in sched_get/set_affinity() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Use rcu in sys_sched_getscheduler/sys_sched_getparam() (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Make wakeup side and atomic variants of completion API irq safe (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Sanitize fork() handling (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Clean up ttwu() rq locking (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Consolidate select_task_rq() callers (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Protect sched_rr_get_param() access to task->sched_class (Larry Woodman) [557364 611867 613812 635558 635562]
- [kernel] sched: Protect task->cpus_allowed access in sched_getaffinity() (Larry Woodman) [557364 611867 613812 635558 635562]

* Fri Jan 07 2011 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-95.el6]
- [virt] KVM: x86: zero kvm_vcpu_events->interrupt.pad (Marcelo Tosatti) [665409] {CVE-2010-4525}
- [x86] KVM: enlarge number of possible CPUID leaves (Robert Richter) [663295]
- [x86] apic, amd: Make firmware bug messages more meaningful (Robert Richter) [647750]
- [x86] mce, amd: Remove goto in threshold_create_device() (Robert Richter) [647750]
- [x86] mce, amd: Add helper functions to setup APIC (Robert Richter) [647750]
- [x86] mce, amd: Shorten local variables mci_misc_{hi, lo} (Robert Richter) [647750]
- [x86] mce, amd: Implement mce_threshold_block_init() helper function (Robert Richter) [647750]
- [x86] AMD, MCE thresholding: Fix the MCi_MISCj iteration order (Robert Richter) [647750]
- [x86] mcheck: Avoid duplicate sysfs links/files for thresholding banks (Robert Richter) [647750]
- [x86] oprofile: Fix uninitialized variable use in debug printk (Robert Richter) [647750]
- [x86] oprofile: Add support for IBS periodic op counter extension (Robert Richter) [647750]
- [x86] oprofile: Add support for IBS branch target address reporting (Robert Richter) [647750]
- [x86] oprofile: Introduce struct ibs_state (Robert Richter) [647750]
- [x86] oprofile: Check IBS capability bits 1 and 2 (Robert Richter) [647750]
- [x86] oprofile: Add support for AMD family 14h (Robert Richter) [647750]
- [x86] oprofile: Add support for AMD family 12h (Robert Richter) [647750]
- [x86] apic: Use BIOS settings for IBS and MCE threshold interrupt LVT offsets (Robert Richter) [647750]
- [x86] apic: Check if EILVT APIC registers are available (AMD only) (Robert Richter) [647750]
- [x86] kernel.h: add pr_warn for symmetry to dev_warn, netdev_warn (Robert Richter) [647750]
- [x86] oprofile: disable write access to oprofilefs while profiler is running (Robert Richter) [647750]
- [x86] oprofile: Remove duplicate code around __oprofilefs_create_file() (Robert Richter) [647750]
- [x86] oprofile: Simplify init/exit functions (Robert Richter) [647750]
- [x86] oprofile: Adding backtrace dump for 32bit process in compat mode (Robert Richter) [647750]
- [x86] oprofile: Using struct stack_frame for 64bit processes dump (Robert Richter) [647750]
- [x86] Unify dumpstack.h and stacktrace.h (Robert Richter) [647750]
- [x86] perf: Fix unsafe frame rewinding with hot regs fetching (Robert Richter) [647750]
- [x86] oprofile: Add Support for Intel CPU Family 6 / Model 29 (Robert Richter) [647750]
- [x86] oprofile: Add Support for Intel CPU Family 6 / Model 22 (Intel Celeron 540) (Robert Richter) [647750]
- [x86] oprofile: fix init_sysfs() function stub (Robert Richter) [647750]
- [x86] oprofile: don't call arch exit code from init code on failure (Robert Richter) [647750]
- [x86] oprofile: fix init_sysfs error handling (Robert Richter) [647750]
- [x86] oprofile: fix crash when accessing freed task structs (Robert Richter) [647750]
- [x86] oprofile: add support for Intel processor model 30 (Robert Richter) [647750]
- [x86] oprofile: make event buffer nonseekable (Robert Richter) [647750]
- [x86] Oprofile: Change CPUIDS from decimal to hex, and add some comments (Robert Richter) [647750]
- [x86] oprofile: make AMD IBS hotplug capable (Robert Richter) [647750]
- [x86] oprofile: notify cpus only when daemon is running (Robert Richter) [647750]
- [x86] oprofile: reordering some functions (Robert Richter) [647750]
- [x86] oprofile: stop disabled counters in nmi handler (Robert Richter) [647750]
- [x86] oprofile: protect cpu hotplug sections (Robert Richter) [647750]
- [x86] oprofile: remove CONFIG_SMP macros (Robert Richter) [647750]
- [x86] oprofile: fix uninitialized counter usage during cpu hotplug (Robert Richter) [647750]
- [x86] oprofile: remove duplicate IBS capability check (Robert Richter) [647750]
- [x86] oprofile: move IBS code (Robert Richter) [647750]
- [x86] oprofile: return -EBUSY if counters are already reserved (Robert Richter) [647750]
- [x86] oprofile: moving shutdown functions (Robert Richter) [647750]
- [x86] oprofile: reserve counter msrs pairwise (Robert Richter) [647750]
- [x86] oprofile: rework error handler in nmi_setup() (Robert Richter) [647750]
- [x86] oprofile: protect from not being in an IRQ context (Robert Richter) [647750]
- [x86] oprofile: convert oprofile from timer_hook to hrtimer (Robert Richter) [647750]
- [x86] oprofile: add comment to counter-in-use warning (Robert Richter) [647750]
- [x86] oprofile: warn user if a counter is already active (Robert Richter) [647750]
- [x86] oprofile: implement randomization for IBS periodic op counter (Robert Richter) [647750]
- [x86] oprofile: implement lsfr pseudo-random number generator for IBS (Robert Richter) [647750]
- [x86] oprofile: implement IBS cpuid feature detection (Robert Richter) [647750]
- [x86] oprofile: remove OPROFILE_IBS config option (Robert Richter) [647750]
- [kbuild] fixes for using make 3.82 (Don Zickus) [663994]
- [kbuild] powerpc: fix build with make 3.82 (Don Zickus) [663994]
- [scsi] qla2xxx: Update driver version to 8.03.05.01.06.1-k0 (Chad Dupuis) [635710]
- [scsi] qla2xxx: Properly set the return value in function qla2xxx_eh_abort (Chad Dupuis) [635710]
- [scsi] qla2xxx: Correct issue where NPIV-config data was not being allocated for 82xx parts (Chad Dupuis) [635710]
- [scsi] qla2xxx: Update copyright banner (Chad Dupuis) [635710]
- [scsi] qla2xxx: Add flash read/update support using BSG interface (Chad Dupuis) [635710]
- [scsi] qla2xxx: Change MSI initialization from using incorrect request_irq parameter (Chad Dupuis) [635710]
- [scsi] qla2xxx: Populate Command Type 6 LUN field properly (Chad Dupuis) [635710]
- [scsi] qla2xxx: list cursors are not null (Chad Dupuis) [635710]
- [scsi] qla2xxx: Avoid depending on SCSI host_lock in queuecommand function (Chad Dupuis) [635710]
- [scsi] qla2xxx: Correct PRLI failure response code handling (Chad Dupuis) [635710]
- [scsi] qla2xxx: Drop srb reference before waiting for completion (Chad Dupuis) [635710]
- [scsi] qla2xxx: Addition of shutdown callback handler (Chad Dupuis) [635710]
- [scsi] qla2xxx: Initialize the vport_slock spinlock (Chad Dupuis) [635710]
- [scsi] qla2xxx: Remove scsi_cmnd->serial_number from debug traces (Chad Dupuis) [635710]
- [scsi] qla2xxx: Group CS_RESET return status with other link level event statuses (Chad Dupuis) [635710]
- [scsi] qla2xxx: Remove port down retry count (Chad Dupuis) [635710]
- [scsi] qla2xxx: locking problem in qla2x00_init_rings() (Chad Dupuis) [635710]
- [scsi] qla2xxx: AER Support-Return recovered from mmio_enable function for 82XX (Chad Dupuis) [635710]
- [scsi] qla2xxx: Update to AER support, do early abort commands (Chad Dupuis) [635710]
- [scsi] qla2xxx: Increase SG table size to support large IO size per scsi command (Chad Dupuis) [635710]
- [scsi] qla2xxx: Clear local references of rport on device loss timeout notification from FC transport (Chad Dupuis) [635710]
- [scsi] qla2xxx: Handle MPI timeout indicated by AE8002 (Chad Dupuis) [635710]
- [scsi] qla2xxx: Added AER support for ISP82xx (Chad Dupuis) [635710]
- [scsi] qla2xxx: Cover UNDERRUN case where SCSI status is set (Chad Dupuis) [635710]
- [scsi] qla2xxx: Correctly set fw hung and complete only waiting mbx (Chad Dupuis) [635710]
- [scsi] qla2xxx: Reset seconds_since_last_heartbeat correctly. (Chad Dupuis) [635710]
- [scsi] qla2xxx: Change del_timer_sync() to del_timer() in qla2x00_ctx_sp_free() (Chad Dupuis) [635710]
- [scsi] qla2xxx: make rport deletions explicit during vport removal (Chad Dupuis) [635710]
- [scsi] qla2xxx: Fix vport delete issues (Chad Dupuis) [635710]
- [scsi] qla2xxx: Pass first 64 bytes of MBX information when vendor commands fail (Chad Dupuis) [635710]
- [scsi] qla2xxx: Return proper fabric name based on device state (Chad Dupuis) [635710]
- [scsi] qla2xxx: Don't issue set or get port param MBC if port is not online (Chad Dupuis) [635710]
- [scsi] qla2xxx: Add module parameter to enable GFF_ID device type check (Chad Dupuis) [635710]
- [scsi] qla2xxx: Cleanup some dead-code and make some functions static. (Chad Dupuis) [635710]
- [scsi] qla2xxx: Do not allow ELS Passthru commands for ISP23xx adapters (Chad Dupuis) [635710]
- [scsi] qla2xxx: Don't issue set or get port param MBC if remote port is not logged in (Chad Dupuis) [635710]
- [scsi] qla2xxx: Don't issue set or get port param MBC if invalid port loop id (Chad Dupuis) [635710]
- [scsi] qla2xxx: Fix flash write failure on ISP82xx (Chad Dupuis) [635710]
- [scsi] qla2xxx: Handle outstanding mbx cmds on hung f/w scenarios. (Chad Dupuis) [635710]
- [scsi] qla2xxx: Support for loading Unified ROM Image (URI) format firmware file. (Chad Dupuis) [635710]
- [scsi] qla2xxx: Add internal loopback support for ISP81xx. (Chad Dupuis) [635710]
- [scsi] qla2xxx: Appropriately log FCP priority data messages (Chad Dupuis) [635710]
- [scsi] qla2xxx: Rearranged and cleaned up the code for processing the pending commands (Chad Dupuis) [635710]
- [scsi] qla2xxx: Updates for ISP82xx. (Chad Dupuis) [635710]
- [scsi] qla2xxx: Add qla2x00_free_fcports() function (Chad Dupuis) [635710]
- [scsi] qla2xxx: Check for golden firmware and show version if available (Chad Dupuis) [635710]
- [scsi] qla2xxx: Use GFF_ID to check FCP-SCSI FC4 type before logging into Nx_Ports (Chad Dupuis) [635710]
- [scsi] qla2xxx: Correct extended sense-data handling. (Chad Dupuis) [635710]
- [scsi] qla2xxx: Stop firmware before doing init firmware. (Chad Dupuis) [635710]
- [scsi] qla2xxx: T10 DIF Type 2 support (Chad Dupuis) [520855]
- [scsi] qla2xxx: T10 DIF enablement for 81XX (Chad Dupuis) [520855]
- [scsi] qla2xxx: T10 DIF support added (Chad Dupuis) [520855]

* Tue Dec 28 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-94.el6]
- [fs] nfsd: Fix possible BUG_ON firing in set_change_info (Steve Dickson) [663448]
- [fs] sunrpc: prevent use-after-free on clearing XPT_BUSY (Steve Dickson) [663448]
- [fs] nfsd: fix BUG at fs/nfsd/nfsfh.h:199 on unlink (Steve Dickson) [663448]
- [fs] nfsd4: typo fix in find_any_file (Steve Dickson) [663448]
- [fs] sunrpc: Correct a misapplied patch (Steve Dickson) [663448]
- [fs] nfs: Make new aop kABI friendly (Steve Dickson) [662782]
- [fs] NFS: Fix panic after nfs_umount() (Steve Dickson) [662782]
- [fs] nfs: remove extraneous and problematic calls to nfs_clear_request (Steve Dickson) [662782]
- [fs] nfs: kernel should return EPROTONOSUPPORT when not support NFSv4 (Steve Dickson) [662782]
- [fs] NFS: Fix fcntl F_GETLK not reporting some conflicts (Steve Dickson) [662782]
- [fs] nfs: Discard ACL cache on mode update (Steve Dickson) [662782]
- [fs] NFS: Readdir cleanups (Steve Dickson) [662782]
- [fs] NFS: nfs_readdir_search_for_cookie() don't mark as eof if cookie not found (Steve Dickson) [662782]
- [fs] NFS: Fix a memory leak in nfs_readdir (Steve Dickson) [662782]
- [fs] Call the filesystem back whenever a page is removed from the page cache (Steve Dickson) [662782]
- [fs] NFS: Ensure we use the correct cookie in nfs_readdir_xdr_filler (Steve Dickson) [662782]
- [fs] NFS: Fix a readdirplus bug (Steve Dickson) [662782]
- [fs] NFS: Ensure we return the dirent->d_type when it is known (Steve Dickson) [662782]
- [fs] NFS: Correct the array bound calculation in nfs_readdir_add_to_array (Steve Dickson) [662782]
- [fs] NFS: Don't ignore errors from nfs_do_filldir() (Steve Dickson) [662782]
- [fs] NFS: Fix the error handling in "uncached_readdir()" (Steve Dickson) [662782]
- [fs] NFS: Fix a page leak in uncached_readdir() (Steve Dickson) [662782]
- [fs] NFS: Fix a page leak in nfs_do_filldir() (Steve Dickson) [662782]
- [fs] NFS: Assume eof if the server returns no readdir records (Steve Dickson) [662782]
- [fs] NFS: Buffer overflow in ->decode_dirent() should not be fatal (Steve Dickson) [662782]
- [fs] Pure nfs client performance using odirect (Steve Dickson) [662782]
- [fs] SUNRPC: Fix an infinite loop in call_refresh/call_refreshresult (Steve Dickson) [662782]
- [fs] nfs: Ignore kmemleak false positive in nfs_readdir_make_qstr (Steve Dickson) [662782]
- [fs] SUNRPC: Simplify rpc_alloc_iostats by removing pointless local variable (Steve Dickson) [662782]
- [fs] nfs: trivial: remove unused nfs_wait_event macro (Steve Dickson) [662782]
- [fs] NFS: readdir shouldn't read beyond the reply returned by the server (Steve Dickson) [662782]
- [fs] NFS: Fix a couple of regressions in readdir (Steve Dickson) [662782]
- [usb] teach "devices" file about Wireless and SuperSpeed USB (Don Zickus) [642206]
- [perf] perf_events: Fix perf_counter_mmap() hook in mprotect() (Oleg Nesterov) [651673]
- [usb] changes to make local suspend/resume work (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Don't let the USB core disable SuperSpeed ports (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Setup array of USB2 and USB3 ports (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Fix reset-device and configure-endpoint commands (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Fix command ring replay after resume (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: fix wMaxPacketSize mask (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: release spinlock when setup interrupt (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Remove excessive printks with shared IRQs (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] Fix linker errors with CONFIG_PM=n (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Fix compile error when CONFIG_PM=n (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: PCI power management implementation (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: bus power management implementation (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: port remote wakeup implementation (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI port power management implementation (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] core: use kernel assigned address for devices under xHCI (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: change xhci_reset_device() to allocate new device (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: Add pointer to udev in struct xhci_virt_device (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: update ring dequeue pointer when process missed tds (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Remove buggy assignment in next_trb() (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Set DMA mask for host (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Don't flush doorbell writes (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Reduce reads and writes of interrupter registers (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Make xhci_set_hc_event_deq() static (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Minimize HW event ring dequeue pointer writes (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Make xhci_handle_event() static (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Remove unnecessary reads of IRQ_PENDING register (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Performance - move xhci_work() into xhci_irq() (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Performance - move interrupt handlers into xhci-ring.c (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Performance - move functions that find ep ring (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: Isoc urb enqueue (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: allocate bigger ring for isochronous endpoint (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: Isochronous transfer implementation (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: Introduce urb_priv structure (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: Missed Service Error Event process (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: adds new cases to trb_comp_code switch (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: remove redundant print messages (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] USB xHCI: handle_tx_event() refactor: process_bulk_intr_td (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: handle_tx_event() refactor: process_ctrl_td (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: handle_tx_event() refactor: finish_td (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: Supporting MSI/MSI-X (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: trivial: use ARRAY_SIZE (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Remove obsolete debugging printk (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Set Mult field in endpoint context correctly (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Set EP0 dequeue ptr after reset of configured device (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: Fix another bug in link TRB activation change (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] clean up some host controller sparse warnings (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] Support for allocating USB 3.0 streams (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] split hub.h into ch11.h and merge-in hcd.h (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] make hub.h public (drivers dependency) (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] make hcd.h public (drivers dependency) (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] Add parsing of SuperSpeed endpoint companion descriptor (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: Fix bug in link TRB activation change (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Print NEC firmware version (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Wait for host to start running (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Wait for controller to be ready after reset (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: fix compiler warning (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Remove the arbitrary limit of 15 xHCI ports (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xHCI: Fix wrong usage of macro TRB_TYPE (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Transfer ring link TRB activation change (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Set stream ID to 0 after cleaning up stalls (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Avoid double free after streams are disabled (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Correct assumptions about number of rings per endpoint (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Add memory allocation for USB3 bulk streams (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Fix check for room on the ring (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Limit bus sg_tablesize to 62 TRBs (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Fix issue with set interface after stall (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Make endpoint interval debugging clearer (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] usb-storage: use max_hw_sectors instead of max_sectors (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] rearrange code in usb_probe_interface (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] Use bInterfaceNumber in bandwidth allocations (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Fix compile issues with xhci_get_slot_state() (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: No GFP_KERNEL in block error handling (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] retain USB device power/wakeup setting across reconfiguration (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] Add call to notify xHC of a device reset (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Notify the xHC when a device is reset (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Allow roothub ports to be disabled (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Refactor code to clear port change bits (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Refactor test for vendor-specific completion codes (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Allow allocation of commands without input contexts (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Refactor code to free or cache endpoint rings (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Fix error path when configuring endpoints (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] check the endpoint type against the pipe type (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] Fix duplicate sysfs problem after device reset (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] USB core: fix recent kernel-doc warnings (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] fix section mismatch in early ehci dbgp (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] Check bandwidth when switching alt settings (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] Refactor code to find alternate interface settings (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Fix command completion after a drop endpoint (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Make reverting an alt setting "unfailable" (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci-mem.c: introduce missing kfree (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] add remove_id sysfs attr for usb drivers (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Handle errors that cause endpoint halts (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Return success for vendor-specific info codes (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Return -EPROTO on a split transaction error. (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Set transfer descriptor size field correctly (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Add tests for TRB address translation (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] fix a bug in the scatter-gather library (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] add a "remove hardware" sysfs attribute (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] don't use a fixed DMA mapping for hub status URBs (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Remove unused HCD statistics code. (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Add watchdog timer for URB cancellation (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Re-purpose xhci_quiesce() (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] xhci: Handle URB cancel, complete and resubmit race (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] whci-hcd: correctly handle sg lists longer than QTD_MAX_XFER_SIZE (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] whci-hcd: fix type and format warnings in sg code (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] make urb scatter-gather support more generic (Don Zickus) [591794 591796 591797 624615 637237]
- [usb] whci-hcd: support urbs with scatter-gather lists (Don Zickus) [591794 591796 591797 624615 637237]
- [virt] vhost: max s/g to match qemu (Jason Wang) [619002]
- [x86] eliminate mcp55 quirk boot chattiness (Bob Picco) [661172]
- [security] SELinux: define permissions for DCB netlink messages (Eric Paris) [662125]
- [net] bonding: add feature to support output port selection steering (Neil Horman) [601849]
- [net] clarify documentation for net.ipv4.igmp_max_memberships (Jiri Pirko) [593397]
- [ppc64] Remove CDTRDSR warning from ppc64 compile (Prarit Bhargava) [597333]
- [ata] libata-scsi passthru: fix bug which truncated LBA48 return values (David Milburn) [663679]
- [fs] ext4: speed up ext4_rec_len_(from|to)_disk for smaller blocksizes (Eric Sandeen) [653213]
- [dlm] reduce cond_resched during send (David Teigland) [663372]
- [dlm] use TCP_NODELAY (David Teigland) [663372]
- [dlm] Handle application limited situations properly (David Teigland) [663372]
- [virt] vhost-net: fix range checking in mrg bufs case (Jason Wang) [616660 632745]
- [virt] vhost-net: mergeable buffers support (Jason Wang) [616660 632745]
- [virt] vhost-net: minor cleanup (Jason Wang) [616660 632745]
- [virt] vhost: Storage class should be before const qualifier (Jason Wang) [616660 632745]
- [netdrv] tun: add ioctl to modify vnet header size (Jason Wang) [616660 632745]
- [virt] vhost: fix sparse warnings (Jason Wang) [616660 632745]

* Fri Dec 17 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-93.el6]
- [s390x] kernel: virtualization aware cpu measurement (Hendrik Brueckner) [631483]
- [s390x] kernel: Add breaking event address for user space (Hendrik Brueckner) [632322]
- [scsi] qla2xxx: Removed dependency for SRB structure for Marker processing (Chad Dupuis) [635707]
- [scsi] qla2xxx: Support for asynchronous TM and Marker IOCBs (Chad Dupuis) [635707]
- [scsi] qla2xxx: Add CT passthru support for ISP23xx adapters (Chad Dupuis) [635707]
- [scsi] qla2xxx: Provide common framework for BSG and IOCB commands (Chad Dupuis) [635707]
- [scsi] qla2xxx: Enable CRB based doorbell posting for request queue as default for ISP 82xx (Chad Dupuis) [516845]
- [scsi] qla2xxx: Check for empty slot in request queue before posting Command type 6 request (Chad Dupuis) [516845]
- [scsi] qla2xxx: Clear drive active CRB register when not in use (Chad Dupuis) [516845]
- [scsi] qla2xxx: Optionally disable target reset (Chad Dupuis) [516845]
- [scsi] qla2xxx: Remove HSRX_RISC_PAUSED check for ISP82XX (Chad Dupuis) [516845]
- [scsi] qla2xxx: Avoid infinite abort-isps when chip reset fails (Chad Dupuis) [516845]
- [scsi] qla2xxx: Allow transition to NEED RESET state only from READY state for ISP82xx (Chad Dupuis) [516845]
- [scsi] qla2xxx: Cleanup and rearrange ISP 82xx specific code (Chad Dupuis) [516845]
- [scsi] qla2xxx: Remove comments having reference to netxen_nic (Chad Dupuis) [516845]
- [scsi] qla2xxx: Remove duplicate initialization during configuring rings (Chad Dupuis) [516845]
- [scsi] qla2xxx: Remove non P3P code and reference (Chad Dupuis) [516845]
- [scsi] qla2xxx: IDC: Check firmware alive prior to initialization (Chad Dupuis) [516845]
- [scsi] qla2xxx: Avoid transitioning to RESET state during initializing (Chad Dupuis) [516845]
- [scsi] qla2xxx: Disable fw_dump operations on ISP82xx (Chad Dupuis) [516845]
- [scsi] qla2xxx: Implement a quick (FCoE context only) reset (Chad Dupuis) [516845]
- [scsi] qla2xxx: Corrected the logic to avoid continuous ISP reset (Chad Dupuis) [516845]
- [scsi] qla2xxx: Add ISP82XX support (Chad Dupuis) [516845]

* Wed Dec 15 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-92.el6]
- [fs] xfs: ensure we mark all inodes in a freed cluster XFS_ISTALE (Dave Chinner) [654294]
- [fs] xfs: fix race in inode cluster freeing failing to stale inodes (Dave Chinner) [654294]
- [block] change BARRIER referenced in error message and comments (Mike Snitzer) [657046]
- [md] Call blk_queue_flush() to establish flush/fua support (Mike Snitzer) [657046]
- [scsi] scsi_debug: Update thin provisioning support (Mike Snitzer) [646552]
- [scsi] scsi_debug: fix map_region and unmap_region oops (Mike Snitzer) [646552]
- [scsi] scsi_debug: Block Limits VPD page fixes (Mike Snitzer) [646552]
- [scsi] scsi_debug: add max_queue + no_uld parameters (Mike Snitzer) [646552]
- [scsi] scsi_debug: fix Thin provisioning support (Mike Snitzer) [646552]
- [scsi] sd: Update thin provisioning support (Mike Snitzer) [646552]
- [scsi] Fix VPD inquiry page wrapper (Mike Snitzer) [646552]
- [scsi] sd: quiet spurious error messages in READ_CAPACITY(16) (Mike Snitzer) [646552]
- [block] fix problem with sending down discard that isn't of correct granularity (Mike Snitzer) [646552]
- [block] blk-throttle: Correct the placement of smp_rmb() (Vivek Goyal) [636022]
- [block] blk-throttle: Trim/adjust slice_end once a bio has been dispatched (Vivek Goyal) [636022]
- [block] Enable block bio throttling (Vivek Goyal) [636022]
- [block] fix use-after-free bug in blk throttle code (Vivek Goyal) [636022]
- [block] blkio-throttle: Fix possible multiplication overflow in iops calculations (Vivek Goyal) [636022]
- [block] blkio-throttle: limit max iops value to UINT_MAX (Vivek Goyal) [636022]
- [block] blkio-throttle: There is no need to convert jiffies to milli seconds (Vivek Goyal) [636022]
- [block] blkio-throttle: Fix link failure failure on i386 (Vivek Goyal) [636022]
- [block] blkio: Recalculate the throttled bio dispatch time upon throttle limit change (Vivek Goyal) [636022]
- [block] blkio: Add root group to td->tg_list (Vivek Goyal) [636022]
- [block] blkio: deletion of a cgroup was causes oops (Vivek Goyal) [636022]
- [block] blkio: Do not export throttle files if CONFIG_BLK_DEV_THROTTLING=n (Vivek Goyal) [636022]
- [block] blkio: Implementation of IOPS limit logic (Vivek Goyal) [636022]
- [block] blk-cgroup: cgroup changes for IOPS limit support (Vivek Goyal) [636022]
- [block] blkio: Core implementation of throttle policy (Vivek Goyal) [636022]
- [block] blk-cgroup: Introduce cgroup changes for throttling policy (Vivek Goyal) [636022]
- [block] blk-cgroup: Prepare the base for supporting more than one IO control policies (Vivek Goyal) [636022]
- [block] blk-cgroup: Kill the header printed at the start of blkio.weight_device file (Vivek Goyal) [636022]
- [block] blk-cgroup: Fix an RCU warning in blkiocg_create() (Vivek Goyal) [636022]
- [block] kill some useless goto's in blk-cgroup.c (Vivek Goyal) [636022]
- [kernel] ptrace: fix exit_ptrace() vs ptrace_report_signal() races (Oleg Nesterov) [631968]
- [kernel] ptrace: introduce PTRACE_O_DETACHED to mark the self-detaching engine (Oleg Nesterov) [631968]
- [kernel] ptrace: don't assume resume != UTRACE_RESUME means stepping (Oleg Nesterov) [631968]
- [kernel] ptrace: the tracee shouldn never change ctx->resume (Oleg Nesterov) [631968]
- [kernel] ptrace: ptrace_reuse_engine()->utrace_barrier() should ignore ERESTARTSYS (Oleg Nesterov) [631968]
- [fs] fsck.gfs2 reported statfs error after gfs2_grow (Robert S Peterson) [661048]
- [fs] ext4: 2 writeback perf fixes (Eric Sandeen) [648632]
- [powerpc] Correct smt_enabled=X boot option for > 2 threads per core (Steve Best) [659807]
- [watchdog] iTCO wdt: Cleanup warning messages (Prarit Bhargava) [616268]
- [md] dm mpath: revert "dm: Call blk_abort_queue on failed paths" (Mike Snitzer) [636771]
- [x86] UV: Address interrupt/IO port operation conflict (George Beshers) [659480]
- [x86] Fix x2apic preenabled system with kexec (Gleb Natapov) [657261]
- [virt] vhost: correctly set bits of dirty pages (Jason Wang) [658437]
- [mm] guard page for stacks that grow upwards (Johannes Weiner) [630562]
- [mm] fix numa khugepaged memcg memleak (Andrea Arcangeli) [659119]
- [mm] Enable extraction of hugepage pfn(s) from /proc/<pid>/pagemap (Larry Woodman) [644987]

* Tue Dec 14 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-91.el6]
- [s390x] dasd: Fix unimplemented DIAG function (Hendrik Brueckner) [646951]
- [s390x] dasd: fix unsolicited interrupt recognition (Hendrik Brueckner) [635021]
- [s390x] dasd: fix dump_sense_dbf (Hendrik Brueckner) [643998]
- [s390x] dasd: let recovery cqr inherit flags from failed cqr (Hendrik Brueckner) [635021]
- [s390x] qeth: tolerate OLM-limitation (Hendrik Brueckner) [633568]
- [s390x] qdio: convert global statistics to per-device stats (Hendrik Brueckner) [633308]
- [s390x] cio: use all paths for some internal I/O (Hendrik Brueckner) [623248]
- [s390x] dasd: allocate fallback cqr for reserve/release (Hendrik Brueckner) [619515]
- [s390x] qeth: OSX message for z/VM specific authorization failure (Hendrik Brueckner) [619508]
- [s390x] qeth: avoid loop if ipa command response is missing (Hendrik Brueckner) [619506]
- [s390x] dasd: fix refcounting for sysfs entry (Hendrik Brueckner) [529362]
- [s390x] dasd: remove uid from devmap (Hendrik Brueckner) [529362]
- [fs] ext4: improve llseek error handling for overly large seek offsets (Eric Sandeen) [652013]
- [fs] ext4: fix EFBIG edge case when writing to large non-extent file (Eric Sandeen) [646498]
- [fs] procfs: fix numbering in /proc/locks (Jerome Marchand) [637846]
- [scsi] enable state transistions from OFFLINE to RUNNING (Mike Christie) [643237]
- [scsi] set queue limits no_cluster for stacked devices (Mike Snitzer) [658293]
- [scsi] scsi_dh_rdac: Add two new SUN devices to rdac_dev_list (Rob Evers) [643820]
- [kernel] utrace: move user_disable_single_step() logic from utrace_control() to utrace_reset() (Oleg Nesterov) [635853]
- [block] cfq-iosched: fix a kernel OOPs when usb key is inserted (Vivek Goyal) [639427]
- [x86] tsc, sched: Recompute cyc2ns_offset's during resume from sleep states (Matthew Garrett) [635560]
- [virt] virtio: console: Don't block entire guest if host doesn't read data (Amit Shah) [643751]
- [mm] memcg: handle charge moving race with hugepage split (Johannes Weiner) [615860]
- [mm] Out-of-memory under memory cgroup can call both of oom-killer-for-memcg and oom-killer-for-page-fault (Larry Woodman) [592879]
- [mm] only return EIO once on msync/fsync after IO failure (Rik van Riel) [652371]
- [mm] Backport upstream code it avoid side-effect of tickless idle on update_cpu_load() (Larry Woodman) [635558]
- [virtio] console: fix memory leak (Amit Shah) [656835]
- [virt] KVM: VMX: Really clear cr0.ts when giving the guest ownership of the fpu (Avi Kivity) [655718]
- [virt] SVM: Initialize fpu_active in init_vmcb() (Avi Kivity) [654532]
- [x86] Look for IA32_ENERGY_PERF_BIAS support (Matthew Garrett) [464655]
- [x86] Disable paranoid check in ACPI power meter driver (Matthew Garrett) [634640]
- [pci] dma-mapping: dma-mapping.h: add dma_set_coherent_mask (Stefan Assmann) [650960]
- [block] Allow third party modules to use blk_queue_ordered() (Vivek Goyal) [657046]
- [security] audit: add support to match lsm labels on user audit messages (Eric Paris) [634303]
- [cpufreq] Fix ondemand to not request targets outside policy limits (Matthew Garrett) [651339]
- [scsi] libfc: possible race could panic system due to NULL fsp->cmd (Mike Christie) [638297]
- [fs] gfs: Use 512 B block sizes to communicate with userland quota tools (Abhijith Das) [658590]
- [fs] GFS2: support for growing a full filesytem (Benjamin Marzinski) [659137]
- [kernel] div64_u64(): improve precision on 32bit platforms (Oleg Nesterov) [616105]
- [kernel] exec: copy-and-paste the fixes into compat_do_execve() paths (Oleg Nesterov) [625695] {CVE-2010-4243}
- [kernel] exec: make argv/envp memory visible to oom-killer (Oleg Nesterov) [625695] {CVE-2010-4243}
- [ata] sata_via: apply magic FIFO fix to vt6420 too (David Milburn) [659748]
- [ata] sata_via: explain the magic fix (David Milburn) [659748]
- [ata] sata_via: magic vt6421 fix for transmission problems w/ WD drives (David Milburn) [659748]
- [virt] KVM: create aggregate kvm_total_used_mmu_pages value (Marcelo Tosatti) [632772]
- [virt] KVM: replace x86 kvm n_free_mmu_pages with n_used_mmu_pages (Marcelo Tosatti) [632772]
- [virt] KVM: rename x86 kvm->arch.n_alloc_mmu_pages (Marcelo Tosatti) [632772]
- [virt] KVM: abstract kvm x86 mmu->n_free_mmu_pages (Marcelo Tosatti) [632772]

* Fri Dec 10 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-90.el6]
- [scsi] sd: Fix overflow with big physical blocks (Mike Snitzer) [632644]
- [block] Ensure physical block size is unsigned int (Mike Snitzer) [632644]
- [fs] Turn on the NFSv4.1 kernel config (Steve Dickson) [479351]
- [fs] NFS: rename nfs.upcall -> nfsidmap (Steve Dickson) [479351]
- [fs] NFS: Fix a compile issue in nfs_root (Steve Dickson) [479351]
- [fs] sunrpc: Use static const char arrays (Steve Dickson) [479351]
- [fs] nfs4: fix channel attribute sanity-checks (Steve Dickson) [479351]
- [fs] NFSv4.1: Use more sensible names for 'initialize_mountpoint' (Steve Dickson) [479351]
- [fs] NFSv4.1: pnfs: filelayout: add driver's LAYOUTGET and GETDEVICEINFO infrastructure (Steve Dickson) [479351]
- [fs] NFSv4.1: pnfs: add LAYOUTGET and GETDEVICEINFO infrastructure (Steve Dickson) [479351]
- [fs] NFS: client needs to maintain list of inodes with active layouts (Steve Dickson) [479351]
- [fs] NFS: create and destroy inode's layout cache (Steve Dickson) [479351]
- [fs] NFSv4.1: pnfs: filelayout: introduce minimal file layout driver (Steve Dickson) [479351]
- [fs] NFSv4.1: pnfs: full mount/umount infrastructure (Steve Dickson) [479351]
- [fs] NFS: set layout driver (Steve Dickson) [479351]
- [fs] NFS: ask for layouttypes during v4 fsinfo call (Steve Dickson) [479351]
- [fs] NFS: change stateid to be a union (Steve Dickson) [479351]
- [fs] NFSv4.1: pnfsd, pnfs: protocol level pnfs constants (Steve Dickson) [479351]
- [fs] SUNRPC: define xdr_decode_opaque_fixed (Steve Dickson) [479351]
- [fs] NFSD: remove duplicate NFS4_STATEID_SIZE (Steve Dickson) [479351]
- [fs] Revert "NFSv4: Fall back to ordinary lookup if nfs4_atomic_open() returns EISDIR" (Steve Dickson) [653066]
- [fs] Regression: fix mounting NFS when NFSv3 support is not compiled (Steve Dickson) [653066]
- [fs] NLM: Fix a regression in lockd (Steve Dickson) [653066]
- [fs] nfs4: The difference of 2 pointers is ptrdiff_t (Steve Dickson) [653066]
- [fs] nfs: testing the wrong variable (Steve Dickson) [653066]
- [fs] nfs: handle lock context allocation failures in nfs_create_request (Steve Dickson) [653066]
- [fs] Fixed Regression in NFS Direct I/O path (Steve Dickson) [653066]
- [fs] nfsd4: fix 4.1 connection registration race (Steve Dickson) [653068]
- [fs] lib: introduce common method to convert hex digits (Steve Dickson) [653068]
- [fs] Keep the deprecated nfsd system call interface (Steve Dickson) [653068]
- [fs] svcrpc: svc_tcp_sendto XPT_DEAD check is redundant (Steve Dickson) [653068]
- [fs] svcrpc: no need for XPT_DEAD check in svc_xprt_enqueue (Steve Dickson) [653068]
- [fs] svcrpc: assume svc_delete_xprt() called only once (Steve Dickson) [653068]
- [fs] svcrpc: never clear XPT_BUSY on dead xprt (Steve Dickson) [653068]
- [fs] nfsd4: fix connection allocation in sequence() (Steve Dickson) [653068]
- [fs] nfsd4: only require krb5 principal for NFSv4.0 callbacks (Steve Dickson) [653068]
- [fs] nfsd4: move minorversion to client (Steve Dickson) [653068]
- [fs] nfsd4: delay session removal till free_client (Steve Dickson) [653068]
- [fs] nfsd4: separate callback change and callback probe (Steve Dickson) [653068]
- [fs] nfsd4: callback program number is per-session (Steve Dickson) [653068]
- [fs] nfsd4: track backchannel connections (Steve Dickson) [653068]
- [fs] nfsd4: confirm only on succesful create_session (Steve Dickson) [653068]
- [fs] nfsd4: make backchannel sequence number per-session (Steve Dickson) [653068]
- [fs] nfsd4: use client pointer to backchannel session (Steve Dickson) [653068]
- [fs] nfsd4: move callback setup into session init code (Steve Dickson) [653068]
- [fs] nfsd4: don't cache seq_misordered replies (Steve Dickson) [653068]
- [fs] SUNRPC: Properly initialize sock_xprt.srcaddr in all cases (Steve Dickson) [653068]
- [fs] SUNRPC: Use conventional switch statement when reclassifying sockets (Steve Dickson) [653068]
- [fs] sunrpc: Turn list_for_each-s into the ..._entry-s (Steve Dickson) [653068]
- [fs] sunrpc: Remove dead "else" branch from bc xprt creation (Steve Dickson) [653068]
- [fs] sunrpc: Don't return NULL from rpcb_create (Steve Dickson) [653068]
- [fs] sunrpc: Remove useless if (task == NULL) from xprt_reserve_xprt (Steve Dickson) [653068]
- [fs] sunrpc: Remove UDP worker wrappers (Steve Dickson) [653068]
- [fs] sunrpc: Remove TCP worker wrappers (Steve Dickson) [653068]
- [fs] sunrpc: Pass family to setup_socket calls (Steve Dickson) [653068]
- [fs] sunrpc: Merge xs_create_sock code (Steve Dickson) [653068]
- [fs] sunrpc: Merge the xs_bind code (Steve Dickson) [653068]
- [fs] sunrpc: Call xs_create_sockX directly from setup_socket (Steve Dickson) [653068]
- [fs] sunrpc: Factor out v6 sockets creation (Steve Dickson) [653068]
- [fs] sunrpc: Factor out v4 sockets creation (Steve Dickson) [653068]
- [fs] sunrpc: Factor out udp sockets creation (Steve Dickson) [653068]
- [fs] sunrpc: Remove duplicate xprt/transport arguments from calls (Steve Dickson) [653068]
- [fs] sunrpc: Get xprt pointer once in xs_tcp_setup_socket (Steve Dickson) [653068]
- [fs] sunrpc: Remove unused sock arg from xs_next_srcport (Steve Dickson) [653068]
- [fs] sunrpc: Remove unused sock arg from xs_get_srcport (Steve Dickson) [653068]
- [fs] svcrdma: Cleanup DMA unmapping in error paths (Steve Dickson) [653068]
- [fs] svcrdma: Change DMA mapping logic to avoid the page_address kernel API (Steve Dickson) [653068]
- [fs] nfsd4: expire clients more promptly (Steve Dickson) [653068]
- [fs] sunrpc: Use helper to set v4 mapped addr in ip_map_parse (Steve Dickson) [653068]
- [fs] sunrpc/cache: centralise handling of size limit on deferred list (Steve Dickson) [653068]
- [fs] sunrpc: Simplify cache_defer_req and related functions (Steve Dickson) [653068]
- [fs] nfsd4: return expired on unfound stateid's (Steve Dickson) [653068]
- [fs] nfsd4: add new connections to session (Steve Dickson) [653068]
- [fs] nfsd4: refactor connection allocation (Steve Dickson) [653068]
- [fs] nfsd4: use callbacks on svc_xprt_deletion (Steve Dickson) [653068]
- [fs] nfsd: provide callbacks on svc_xprt deletion (Steve Dickson) [653068]
- [fs] nfsd4: keep per-session list of connections (Steve Dickson) [653068]
- [fs] nfsd4: clean up session allocation (Steve Dickson) [653068]
- [fs] nfsd4: fix alloc_init_session return type (Steve Dickson) [653068]
- [fs] nfsd4: fix alloc_init_session BUILD_BUG_ON() (Steve Dickson) [653068]
- [fs] nfsd4: Move callback setup to callback queue (Steve Dickson) [653068]
- [fs] nfsd4: remove separate cb_args struct (Steve Dickson) [653068]
- [fs] nfsd4: use generic callback code in null case (Steve Dickson) [653068]
- [fs] nfsd4: generic callback code (Steve Dickson) [653068]
- [fs] nfsd4: rename nfs4_rpc_args->nfsd4_cb_args (Steve Dickson) [653068]
- [fs] nfsd4: combine nfs4_rpc_args and nfsd4_cb_sequence (Steve Dickson) [653068]
- [fs] nfsd4: minor variable renaming (cb -> conn) (Steve Dickson) [653068]
- [fs] sunrpc: fix race in new cache_wait code. (Steve Dickson) [653068]
- [fs] sunrpc: Create sockets in net namespaces (Steve Dickson) [653068]
- [net] Export __sock_create (Steve Dickson) [653068]
- [fs] sunrpc: Tag rpc_xprt with net (Steve Dickson) [653068]
- [fs] sunrpc: Add net to xprt_create (Steve Dickson) [653068]
- [fs] sunrpc: Add net to rpc_create_args (Steve Dickson) [653068]
- [fs] sunrpc: Pull net argument downto svc_create_socket (Steve Dickson) [653068]
- [fs] sunrpc: Add net argument to svc_create_xprt (Steve Dickson) [653068]
- [fs] sunrpc: Factor out rpc_xprt freeing (Steve Dickson) [653068]
- [fs] sunrpc: Factor out rpc_xprt allocation (Steve Dickson) [653068]
- [fs] nfsd4: adjust buflen for encoded attrs bitmap based on actual bitmap length (Steve Dickson) [653068]
- [fs] sunrpc: fix up rpcauth_remove_module section mismatch (Steve Dickson) [653068]
- [fs] sunrpc: Tag svc_xprt with net (Steve Dickson) [653068]
- [fs] sunrpc: Add routines that allow registering per-net caches (Steve Dickson) [653068]
- [fs] sunrpc: Add net to pure API calls (Steve Dickson) [653068]
- [fs] sunrpc: Pass xprt to cached get/put routines (Steve Dickson) [653068]
- [fs] sunrpc: Make xprt auth cache release work with the xprt (Steve Dickson) [653068]
- [fs] sunrpc: Pass the ip_map_parse's cd to lower calls (Steve Dickson) [653068]
- [fs] nfsd: fix /proc/net/rpc/nfsd.export/content display (Steve Dickson) [653068]
- [fs] nfsd: Export get_task_comm for nfsd (Steve Dickson) [653068]
- [fs] nfsd: allow deprecated interface to be compiled out (Steve Dickson) [653068]
- [fs] nfsd: formally deprecate legacy nfsd syscall interface (Steve Dickson) [653068]
- [fs] sunrpc/cache: fix recent breakage of cache_clean_deferred (Steve Dickson) [653068]
- [fs] lockd: Mostly remove BKL from the server (Steve Dickson) [653068]
- [fs] sunrpc/cache: don't use custom hex_to_bin() converter (Steve Dickson) [653068]
- [fs] sunrpc/cache: change deferred-request hash table to use hlist (Steve Dickson) [653068]
- [fs] svcauth_gss: replace a trivial 'switch' with an 'if' (Steve Dickson) [653068]
- [fs] nfsd/idmap: drop special request deferal in favour of improved default (Steve Dickson) [653068]
- [fs] nfsd: disable deferral for NFSv4 (Steve Dickson) [653068]
- [fs] sunrpc: close connection when a request is irretrievably lost (Steve Dickson) [653068]
- [fs] nfsd4: fix hang on fast-booting nfs servers (Steve Dickson) [653068]
- [fs] svcrpc: cache deferral cleanup (Steve Dickson) [653068]
- [fs] svcrpc: minor cache cleanup (Steve Dickson) [653068]
- [fs] sunrpc/cache: allow threads to block while waiting for cache update (Steve Dickson) [653068]
- [net] sunrpc: use seconds since boot in expiry cache (Steve Dickson) [653068]
- [fs] sunrpc: extract some common sunrpc_cache code from nfsd (Steve Dickson) [653068]
- [kernel] kernel.h: add printk_ratelimited and pr_<level>_rl (Steve Dickson) [653066]
- [fs] Set new kernel configs (Steve Dickson) [653066]
- [fs] SUNRPC: Cleanup duplicate assignment in rpcauth_refreshcred (Steve Dickson) [653066]
- [fs] nfs: fix unchecked value (Steve Dickson) [653066]
- [fs] Ask for time_delta during fsinfo probe (Steve Dickson) [653066]
- [fs] Revalidate caches on lock (Steve Dickson) [653066]
- [fs] SUNRPC: After calling xprt_release(), we must restart from call_reserve (Steve Dickson) [653066]
- [fs] NFSv4: Fix up the 'dircount' hint in encode_readdir (Steve Dickson) [653066]
- [fs] NFSv4: Clean up nfs4_decode_dirent (Steve Dickson) [653066]
- [fs] NFSv4: nfs4_decode_dirent must clear entry->fattr->valid (Steve Dickson) [653066]
- [fs] NFSv4: Fix a regression in decode_getfattr (Steve Dickson) [653066]
- [fs] NFSv4: Fix up decode_attr_filehandle() to handle the case of empty fh pointer (Steve Dickson) [653066]
- [fs] NFS: Ensure we check all allocation return values in new readdir code (Steve Dickson) [653066]
- [fs] NFS: Readdir plus in v4 (Steve Dickson) [653066]
- [fs] NFS: introduce generic decode_getattr function (Steve Dickson) [653066]
- [fs] NFS: check xdr_decode for errors (Steve Dickson) [653066]
- [fs] NFS: nfs_readdir_filler catch all errors (Steve Dickson) [653066]
- [fs] NFS: readdir with vmapped pages (Steve Dickson) [653066]
- [fs] NFS: remove page size checking code (Steve Dickson) [653066]
- [fs] NFS: decode_dirent should use an xdr_stream (Steve Dickson) [653066]
- [fs] SUNRPC: Add a helper function xdr_inline_peek (Steve Dickson) [653066]
- [fs] NFS: remove readdir plus limit (Steve Dickson) [653066]
- [fs] NFS: re-add readdir plus (Steve Dickson) [653066]
- [fs] NFS: Optimise the readdir searches (Steve Dickson) [653066]
- [fs] NFS: add readdir cache array (Steve Dickson) [653066]
- [fs] nfs: include ratelimit.h, fix nfs4state build error (Steve Dickson) [653066]
- [fs] NFSv4: The state manager must ignore EKEYEXPIRED (Steve Dickson) [653066]
- [fs] NFSv4: Don't ignore the error return codes from nfs_intent_set_file (Steve Dickson) [653066]
- [fs] NFSv4: Don't call nfs4_reclaim_complete() on receiving NFS4ERR_STALE_CLIENTID (Steve Dickson) [653066]
- [fs] NFS: Don't SIGBUS if nfs_vm_page_mkwrite races with a cache invalidation (Steve Dickson) [653066]
- [fs] NFS: new idmapper (Steve Dickson) [653066]
- [fs] NFS: Use kernel DNS resolver (Steve Dickson) [653066]
- [fs] NFS: We must use list_for_each_entry_safe in nfs_access_cache_shrinker (Steve Dickson) [653066]
- [fs] NFS: don't use FLUSH_SYNC on WB_SYNC_NONE COMMIT calls (Steve Dickson) [653066]
- [fs] NFS: Really fix put_nfs_open_context() (Steve Dickson) [653066]
- [fs] NFSv4.1: keep seq_res.sr_slot as pointer rather than an index (Steve Dickson) [653066]
- [fs] add a couple of mntget+dget -> path_get in nfs4proc (Steve Dickson) [653066]
- [fs] nfs: show "local_lock" mount option in /proc/mounts (Steve Dickson) [653066]
- [fs] NFS: handle inode==NULL in __put_nfs_open_context (Steve Dickson) [653066]
- [fs] nfs: introduce mount option '-olocal_lock' to make locks local (Steve Dickson) [653066]
- [fs] SUNRPC: Refactor logic to NUL-terminate strings in pages (Steve Dickson) [653066]
- [fs] SUNRPC: Correct an rpcbind debugging message (Steve Dickson) [653066]
- [fs] NFS: Fix NFSv3 debugging messages in fs/nfs/nfs3proc.c (Steve Dickson) [653066]
- [fs] NFSv4.1: Fix the slotid initialisation in nfs_async_rename() (Steve Dickson) [653066]
- [fs] NFS: Fix a use-after-free case in nfs_async_rename() (Steve Dickson) [653066]
- [fs] nfs: make sillyrename an async operation (Steve Dickson) [653066]
- [fs] nfs: move nfs_sillyrename to unlink.c (Steve Dickson) [653066]
- [fs] nfs: standardize the rename response container (Steve Dickson) [653066]
- [fs] nfs: standardize the rename args container (Steve Dickson) [653066]
- [fs] NFS: Add an 'open_context' element to struct nfs_rpc_ops (Steve Dickson) [653066]
- [fs] NFS: Clean up nfs4_proc_create() (Steve Dickson) [653066]
- [fs] NFSv4: Further cleanups for nfs4_open_revalidate() (Steve Dickson) [653066]
- [fs] NFSv4: Clean up nfs4_open_revalidate (Steve Dickson) [653066]
- [fs] NFSv4: Further minor cleanups for nfs4_atomic_open() (Steve Dickson) [653066]
- [fs] NFSv4: Clean up nfs4_atomic_open (Steve Dickson) [653066]
- [fs] Switch alloc_nfs_open_context() to struct path (Steve Dickson) [653066]
- [fs] SUNRPC: Remove rpcb_getport_sync() (Steve Dickson) [653066]
- [fs] NFS: Allow NFSROOT debugging messages to be enabled dynamically (Steve Dickson) [653066]
- [fs] NFS: Clean up nfsroot.c (Steve Dickson) [653066]
- [fs] NFS: Use super.c for NFSROOT mount option parsing (Steve Dickson) [653066]
- [fs] NFS: Clean up NFSROOT command line parsing (Steve Dickson) [653066]
- [fs] NFS: Remove \t from mount debugging message (Steve Dickson) [653066]
- [fs] SUNRPC: Don't truncate tail data unnecessarily in xdr_shrink_pagelen (Steve Dickson) [653066]
- [fs] sunrpc: simplify xdr_shrink_pagelen use of "copy" (Steve Dickson) [653066]
- [fs] sunrpc: don't use the copy variable in nested block (Steve Dickson) [653066]
- [fs] sunrpc: clean up xdr_shrink_pagelen use of temporary pointer (Steve Dickson) [653066]
- [fs] sunrpc: don't shorten buflen twice in xdr_shrink_pagelen (Steve Dickson) [653066]

* Tue Dec 07 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-89.el6]
- [netdrv] igb: only use vlan_gro_receive if vlans are registered (Stefan Assmann) [660192] {CVE-2010-4263}

* Tue Dec 07 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-88.el6]
- [net] core: neighbour update Oops (Jiri Pirko) [658518]
- [scsi] lpfc: Update lpfc version for 8.3.5.28 driver release (Rob Evers) [655935]
- [scsi] lpfc: Added support for ELS RRQ command (Rob Evers) [655935]
- [scsi] lpfc: Init VFI and VPI for the physical port (Lancer SLI4 FC Support) (Rob Evers) [655935]
- [scsi] lpfc: Set heartbeat timer off by default (Rob Evers) [655935]
- [scsi] lpfc: Update lpfc version for 8.3.5.27 driver release (Rob Evers) [655935]
- [scsi] lpfc: Implement doorbell register changes for new hardware support (Rob Evers) [655935]
- [scsi] lpfc: Fixed a NULL pointer dereference duing memory allocation failure (Rob Evers) [655935]
- [scsi] lpfc: Modified the return status of unsupport ELS commands (Rob Evers) [655935]
- [scsi] lpfc: Implement READ_TOPOLOGY mailbox command and add new 16G speeds (Rob Evers) [655935]
- [scsi] lpfc: Implement the new SLI 4 SLI_INTF register definitions (Rob Evers) [655935]
- [scsi] lpfc: Fix bug with remote SLI4 firmware download data not being transmitted (Rob Evers) [655935]
- [scsi] lpfc: Added PCI ID definitions for new hardware support (Rob Evers) [655935]
- [scsi] lpfc: Updated driver to handle CVL after Nameserver PLOGI timeouts (Rob Evers) [655935]
- [scsi] lpfc: Fix for failure to log into FDMI_DID after link bounce (Rob Evers) [655935]
- [scsi] lpfc: Cleanup mailbox commands in mboxq_cmpl when CVL is received (Rob Evers) [655935]
- [scsi] lpfc: Add new SLI4 WQE support (Rob Evers) [655935]
- [scsi] lpfc: Update lpfc version for 8.3.5.26 driver release (Rob Evers) [635733]
- [scsi] lpfc: Fix locking issue for security mailbox commands (Rob Evers) [635733]
- [scsi] lpfc: Properly handle devloss timeout during various phases of FIP engine state transactions (Rob Evers) [635733]
- [scsi] lpfc: Abort all I/Os and wait XRI exchange busy complete before function reset ioctl in SLI4 driver unload (Rob Evers) [635733]
- [scsi] lpfc: Prevent lock_irqsave from being called twice in a row (Rob Evers) [635733]
- [scsi] lpfc: Fix regression error for handling SLI4 unsolicted ELS (Rob Evers) [635733]
- [scsi] lpfc: Fix regression error for handling ECHO response support (Rob Evers) [635733]
- [scsi] lpfc: Fix regression error for handling SLI4 unsolicted ELS (Rob Evers) [635733]
- [scsi] lpfc: Fix internal loopback causing kernel panic (Rob Evers) [635733]
- [scsi] lpfc: Fixed crashes for NULL pnode dereference (Rob Evers) [635733]

* Sun Dec 05 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-87.el6]
- [block] cfq: fix recursive call in cfq_blkiocg_update_completion_stats() (Vivek Goyal) [626989]

* Fri Dec 03 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-86.el6]
- [kernel] posix-cpu-timers: workaround to suppress the problems with mt exec (Oleg Nesterov) [656268]
- [fs] bio: take care not overflow page count when mapping/copying user data (Danny Feng) [652531] {CVE-2010-4162}
- [net] can-bcm: fix minor heap overflow (Danny Feng) [651847] {CVE-2010-3874}
- [net] filter: make sure filters dont read uninitialized memory (Jiri Pirko) [651705] {CVE-2010-4158}
- [net] inet_diag: Make sure we actually run the same bytecode we audited (Jiri Pirko) [651269]
- [v4l] ivtvfb: prevent reading uninitialized stack memory (Mauro Carvalho Chehab) [648833] {CVE-2010-4079}
- [drm] via/ioctl.c: prevent reading uninitialized stack memory (Dave Airlie) [648719] {CVE-2010-4082}
- [char] nozomi: clear data before returning to userspace on TIOCGICOUNT (Mauro Carvalho Chehab) [648706] {CVE-2010-4077}
- [serial] clean data before filling it on TIOCGICOUNT (Mauro Carvalho Chehab) [648703] {CVE-2010-4075}

* Wed Dec 01 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-85.el6]
- [fs] configs: enable CONFIG_PRINT_QUOTA_WARNING (Aristeu Rozanski) [579638]
- [net] af_unix: limit unix_tot_inflight (Neil Horman) [656762]
- [block] check for proper length of iov entries in blk_rq_map_user_iov() (Danny Feng) [652959] {CVE-2010-4163}
- [net] Limit sendto()/recvfrom()/iovec total length to INT_MAX (Jiri Pirko) [651895] {CVE-2010-4160}
- [netdrv] mlx4: Add OFED-1.5.2 patch to increase log_mtts_per_seg (Jay Fenlason) [637284]
- [kernel] kbuild: fix external module compiling (Aristeu Rozanski) [655231]
- [mm] Fix broken use of end variable in remap_file_pages() system call (Larry Woodman) [637049]
- [virt] virtio: console: Disable lseek(2) for port file operations (Amit Shah) [635537]
- [virt] virtio: console: Prevent userspace from submitting NULL buffers (Amit Shah) [635535]
- [virt] virtio: console: Fix poll blocking even though there is data to read (Amit Shah) [634232]
- [virt] virtio: console: Send SIGIO in case of port unplug (Amit Shah) [624628]
- [virt] virtio: console: Send SIGIO on new data arrival on ports (Amit Shah) [624628]
- [virt] virtio: console: Send SIGIO to processes that request it for host events (Amit Shah) [624628]
- [block] cfq-iosched: blktrace print per slice sector stats (Vivek Goyal) [626989]
- [block] cfq-iosched: Implement tunable group_idle (Vivek Goyal) [626989]
- [block] cfq-iosched: Do group share accounting in IOPS when slice_idle=0 (Vivek Goyal) [626989]
- [block] cfq-iosched: Fixed boot warning with BLK_CGROUP=y and CFQ_GROUP_IOSCHED=n (Vivek Goyal) [626989]
- [block] blk-cgroup: Fix RCU correctness warning in cfq_init_queue() (Vivek Goyal) [626989]
- [netdrv] ixgbe: add registers etc. printout code just before resetting adapters (Dean Nelson) [611696]
- [netdrv] e1000e: suppress compile warnings on certain archs (Dean Nelson) [611696]
- [netdrv] e1000e: add registers etc. printout code just before resetting adapters (Dean Nelson) [611696]
- [net] bluetooth: Fix missing NULL check (Jarod Wilson) [655668]
- [v4l] Fix garbled image with zc3xx-based webcam (Jay Fenlason) [590404]
- [mm] Backport missing kmemleak check into kmem_cache_create() (Larry Woodman) [654761]
- [x86] acpi: mark hardware unsupported on x86 32bit cpu hot add events (Prarit Bhargava) [625585]
- [x86] UEFI/EFI x86_64 pagetable initialization (Bob Picco) [654665]
- [kernel] add RSS and swap size information to /proc/sysvipc/shm (Jerome Marchand) [634994]
- [kernel] fix integer overflow in groups_search (Jerome Marchand) [629629]
- [kernel] ipc: initialize structure memory to zero for compat functions (Danny Feng) [648695] {CVE-2010-4073}
- [kernel] shm: fix information leak to userland (Danny Feng) [648689] {CVE-2010-4072}
- [kernel] Prevent panic caused by divide by zero in find_busiest_group() (Larry Woodman) [644903]
- [kernel] Backport upstream fix for a race in pid generation that causes pids to be reused immediately (Larry Woodman) [646321]
- [scsi] megaraid: fix make legacy i/o ports free (Tomas Henzl) [632558]
- [net] ipv6: balance pernet_operations [de]registration (Neil Horman) [625173]
- [kdump] kexec: accelerate vmcore copies by marking oldmem in /proc/vmcore as cached (Neil Horman) [641315]
- [mm] use compaction for GFP_ATOMIC order > 0 (Andrea Arcangeli) [622327 642570]
- [kernel] module: initialize module dynamic debug later (Jason Baron) [627648]
- [kernel] dynamic debug: move ddebug_remove_module() down into free_module() (Jason Baron) [627648]
- [md] dm: remove extra locking when changing device size (Mike Snitzer) [644380]
- [block] read i_size with i_size_read() (Mike Snitzer) [644380]

* Fri Nov 19 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-84.el6]
- [scsi] lpfc: Update lpfc version for 8.3.5.25 driver release (Rob Evers) [645882]
- [scsi] lpfc: Fix mailbox handling for UNREG_RPI_ALL case (Rob Evers) [645882]
- [scsi] lpfc: Fixed a race condition that can cause driver send FDISC to un-initialized VPI (Rob Evers) [645882]
- [scsi] lpfc: Update lpfc version for 8.3.5.24 driver release (Rob Evers) [645882]
- [scsi] lpfc: Used PCI function reset ioctl mbox command to clean up CNA during driver unload (Rob Evers) [645882]
- [scsi] lpfc: Fixed crashes for BUG_ONs hit in the lpfc_abort_handler (Rob Evers) [645882]
- [scsi] lpfc: Fail I/O when adapter detects a lost frame and target reports a check condition (Rob Evers) [645882]
- [scsi] lpfc: Fixed abort WQEs for FIP frames (Rob Evers) [645882]
- [scsi] lpfc: Update lpfc version for 8.3.5.23 driver release (Rob Evers) [645882]
- [scsi] lpfc: Instantiate iocb_stat so compiler does not error out (Rob Evers) [645882]
- [scsi] lpfc: Added unreg all rpi mailbox command before unreg vpi (Rob Evers) [645882]
- [scsi] lpfc: Make all error values negative (Rob Evers) [645882]
- [scsi] lpfc: Remove duplicate code from lpfc_els_retry routine (Rob Evers) [645882]
- [scsi] lpfc: Fixed circular spinlock dependency between low-level driver and SCSI midlayer (Rob Evers) [645882]
- [scsi] lpfc: Update lpfc version for 8.3.5.22 driver release (Rob Evers) [645882]
- [scsi] lpfc: Fixed cases of skipping possible roundrobin fail over of multiple eligible FCFs (Rob Evers) [645882]
- [scsi] lpfc: Fixed FC-AL bit set issue in FLOGI rejected by McData4700 FC swich in NPV setup (Rob Evers) [645882]
- [scsi] lpfc: Fixed driver not able to unregister unused FCF upon devloss timeout to all nodes (Rob Evers) [645882]
- [scsi] lpfc: Fix bug with external loopback testing not becoming ready (Rob Evers) [645882]
- [scsi] lpfc: Fixed heartbeat timeout during controller pause test (Rob Evers) [645882]
- [scsi] lpfc: Update lpfc version for 8.3.5.21 driver release (Rob Evers) [645882]
- [scsi] lpfc: Added support for Falcon firmware download authentication and SLI authentication (Rob Evers) [645882]
- [scsi] lpfc: Add support for bsg MBX_SLI4_CONFIG (Rob Evers) [645882]
- [scsi] lpfc: adjust lpfc_els_retry delay/retry for PLOGI, attr remove owner (Rob Evers) [645882]
- [scsi] lpfc: Replaced some unnecessary spin_lock_irqsave with spin_lock_irq (Rob Evers) [645882]
- [scsi] lpfc: Fixed lpfc_initial_flogi not returning failure in one of failure condition (Rob Evers) [645882]
- [scsi] lpfc: Fixed r8828 stray state update in case a new FCF matched in-use FCF (Rob Evers) [645882]
- [scsi] lpfc: Treated firmware matching FCF property with different index as error condition (Rob Evers) [645882]
- [scsi] lpfc: Update lpfc version for 8.3.5.20 driver release (Rob Evers) [645882]
- [scsi] lpfc: Move Unload flag earlier in vport delete (Rob Evers) [645882]
- [scsi] lpfc: Fix for IOCB leak on FDISC completion (Rob Evers) [645882]
- [scsi] lpfc: Start looking at the return code for fc_block_scsi_eh (Rob Evers) [645882]
- [scsi] lpfc: Update lpfc version for 8.3.5.19 driver release (Rob Evers) [645882]
- [scsi] lpfc: Remove unused variables that were removed from upstream submission (Rob Evers) [645882]
- [scsi] lpfc: Change log message 0318 from an error to a warning as it is not an error (Rob Evers) [645882]
- [scsi] lpfc: Add Security Crypto support to CONFIG_PORT mailbox command (Rob Evers) [645882]
- [scsi] lpfc: Switch call to memcpy_toio to __write32_copy to prevent unaligned 64 bit copy (Rob Evers) [645882]
- [scsi] lpfc: Fix bug with cable swap and nodelist not empty message on console after rmmod (Rob Evers) [645882]
- [scsi] lpfc: Fixed failure to roundrobin on all available FCFs when FLOGI to in-use FCF rejected by switch (Rob Evers) [645882]
- [scsi] lpfc: Fixed heartbeat timeout during fabric reconfiguration (Rob Evers) [645882]
- [scsi] lpfc: Update lpfc version for 8.3.5.18 driver release (Rob Evers) [645882]
- [scsi] lpfc: Fixed failure to recover from back-to-back Clear Virtual Link with a single FCF (Rob Evers) [645882]
- [scsi] lpfc: Clear VFI_REGISTERED flag when UNREG_VFI completes (Rob Evers) [645882]
- [scsi] lpfc: r8088 had to be backed out temporary because it was part of a larger patch that was rejected, now put r8088 back with r8608 (Rob Evers) [645882]
- [scsi] lpfc: Added code to ignore the failure of REG_VPI mailbox with UPD bit set on older tigershark firmware (Rob Evers) [645882]
- [scsi] lpfc: Added code to support UPD bit of REG_VPI mailbox command (Rob Evers) [645882]
- [scsi] lpfc: Fix bug with cable swap and ndlp not becoming active (Rob Evers) [645882]
- [virt] virtio: console: Reference counting portdev structs is not needed (Amit Shah) [628805]
- [virt] virtio: console: Add reference counting for port struct (Amit Shah) [628805]
- [virt] virtio: console: Use cdev_alloc() instead of cdev_init() (Amit Shah) [628805]
- [virt] virtio: console: Add a find_port_by_devt() function (Amit Shah) [628805]
- [virt] virtio: console: Add a list of portdevs that are active (Amit Shah) [628805]
- [virt] virtio: console: open: Use a common path for error handling (Amit Shah) [628805]
- [virt] virtio: console: remove_port() should return void (Amit Shah) [628805]
- [virt] virtio: console: Make write() return -ENODEV on hot-unplug (Amit Shah) [628805]
- [virt] virtio: console: Make read() return -ENODEV on hot-unplug (Amit Shah) [628805]
- [virt] virtio: console: Unblock poll on port hot-unplug (Amit Shah) [628805]
- [virt] virtio: console: Un-block reads on chardev close (Amit Shah) [628805]
- [virt] virtio: console: Check if portdev is valid in send_control_msg() (Amit Shah) [628805]
- [virt] virtio: console: Remove control vq data only if using multiport support (Amit Shah) [628805]
- [virt] virtio: console: Reset vdev before removing device (Amit Shah) [628805]
- [pci] Add FW_WARN to warn_invalid_dmar() (Prarit Bhargava) [588638]
- [pci] Clean up warn_invalid_dmar() (Prarit Bhargava) [588638]
- [pci] intel-iommu: Combine the BIOS DMAR table warning messages (Prarit Bhargava) [588638]
- [kernel] Really add TAINT_FIRMWARE_WORKAROUND (Prarit Bhargava) [588638]
- [x86] ACPI: create "processor.bm_check_disable" boot param (Matthew Garrett) [635572]
- [fs] Fix nfsv4 client lock reclaim behaviour (Sachin Prabhu) [638269]
- [fs] ext4: Don't error out the fs if the user tries to make a file too big (Eric Sandeen) [645824]
- [fs] xfs: prevent reading uninitialized stack memory (Dave Chinner) [630809] {CVE-2010-3078}
- [s390x] cio: prevent kernel panic in I/O cancel function (Hendrik Brueckner) [647825]
- [s390x] qeth: timeout on connection isolation configuration errors (Hendrik Brueckner) [635053]
- [kernel] etr clock synchronization race (Hendrik Brueckner) [619511]
- [net] tc: Ignore noqueue_qdisc default qdisc when dumping (Thomas Graf) [627142]
- [net] fix rds_iovec page count overflow (Jiri Pirko) [647424] {CVE-2010-3865}
- [net] netfilter: Avoid freeing pointers representing an error value (Thomas Graf) [608980]
- [scsi] Fix megaraid_sas driver SLAB memory leak detected with CONFIG_DEBUG_SLAB (Shyam Iyer) [633836]
- [scsi] scsi_dh_alua: Handle all states correctly (Mike Snitzer) [636994]
- [scsi] ibmvscsi: Fix oops when an interrupt is pending during probe (Steve Best) [624169]
- [usb] serial/mos*: prevent reading uninitialized stack memory (Don Zickus) [648698] {CVE-2010-4074}
- [kbuild] don't sign out-of-tree modules (Aristeu Rozanski) [653507]
- [kernel] tracing: Fix circular dead lock in stack trace (Jiri Olsa) [601047]
- [watchdog] iTCO wdt: remove extra pci_dev_put()'s from init code (Prarit Bhargava) [574546]
- [kernel] ecryptfs_uid_hash() buffer overflow (Jerome Marchand) [611388] {CVE-2010-2492}
- [sound] seq/oss - Fix double-free at error path of snd_seq_oss_open() (Jaroslav Kysela) [630555] {CVE-2010-3080}
- [x86] ACPI: allow C3 > 1000usec (Matthew Garrett) [572821]
- [virt] virtio-net: init link state correctly (Jason Wang) [646369]
- [virt] i8259: fix migration (Gleb Natapov) [629197]
- [netdrv] prevent reading uninitialized memory in hso driver (Thomas Graf) [633144] {CVE-2010-3298}

* Tue Nov 16 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-83.el6]
- [virt] KVM: x86: Use unlazy_fpu() for host FPU (Avi Kivity) [651005]
- [fs] GFS2: reserve more blocks for transactions (Benjamin Marzinski) [637972]
- [fs] core_pattern: fix truncation by core_pattern handler with long parameters (Danny Feng) [618602]
- [fs] Do not mix FMODE_ and O_ flags with break_lease() and may_open() (Harshula Jayasuriya) [642677]
- [fs] GFS2: fallocate support (Benjamin Marzinski) [626561]
- [fs] GFS2: fix filesystem consistency error on rename (Robert S Peterson) [638657]
- [fs] aio: check for multiplication overflow in do_io_submit (Jeff Moyer) [629451]
- [x86] Backport several upstream CONFIG_DEBUG_RODATA optimizations and bugfixes from Intel (Larry Woodman) [557364]
- [fs] GFS2: Fix typo in stuffed file data copy handling (Abhijith Das) [619810]
- [powerpc] Remove redundant xics badness warning (Steve Best) [641932]
- [ppc] Account time using timebase rather than PURR (Steve Best) [633515]
- [ppc] pseries: Increase cpu die timeout (Steve Best) [636230]
- [s390x] zfcp: Fix reference counter for point-to-point port (Hendrik Brueckner) [644005]
- [powerpc] ibmveth: lost IRQ while closing/opening device leads to service loss (Steve Best) [620799]
- [net] fix info leak from kernel in ethtool operation (Neil Horman) [646728] {CVE-2010-3861}
- [net] drop_monitor: add EAGAIN return code to detect duplicate state changes (Neil Horman) [615788 616919]
- [net] packet: fix information leak to userland (Jiri Pirko) [649900] {CVE-2010-3876}
- [net] Fix stack corruption in icmp_send() (James Paradis) [629590]
- [net] clean up info leak in act_police (Neil Horman) [636394]
- [net] bonding: introduce primary_reselect option (Jiri Pirko) [628492]
- [net] bonding: check if clients MAC addr has changed (Flavio Leitner) [610237]
- [scsi] mpt2sas: driver fails to recover from injected PCIe bus errors (Steve Best) [612584]
- [kernel] sys_semctl: fix kernel stack leakage (Danny Feng) [648724] {CVE-2010-4083}
- [security] Fix install_process_keyring error handling (David Howells) [647440]
- [kernel] sysctl: fix min/max handling in __do_proc_doulongvec_minmax() (Amerigo Wang) [643290]
- [kernel] kbuild: Really don't clean bounds.h and asm-offsets.h (Danny Feng) [594065]
- [kernel] execve: improve interactivity and respond to SIGKILL with large arguments (Dave Anderson) [629178]
- [kernel] kbuild: respect LDFLAGS when linking module signatures (Johannes Weiner) [629423]
- [kernel] kbuild: fix modpost segfault (Johannes Weiner) [629418]
- [fs] CIFS: Remove __exit mark from cifs_exit_dns_resolver() (David Howells) [619752]
- [block] Range check cpu in blk_cpu_to_group (Steve Best) [636981]
- [sound] sound/pci/rme9652: prevent reading uninitialized stack memory (Stanislaw Gruszka) [648711 648716]
- [pci] add pci_get_domain_bus_and_slot function (Chad Dupuis) [641132]
- [pci] intr-remap: allow disabling source id checking (Alex Williamson) [530618]
- [x86] Add native Intel cpuidle driver (Matthew Garrett) [637899]
- [x86] add quirk to fixup mcp55 interrupt routing to let kdump work (Neil Horman) [562134]
- [virt] KVM: VMX: Disallow NMI while blocked by STI (Avi Kivity) [616296]
- [virt] KVM: x86: fix information leak to userland (Marcelo Tosatti) [649840]
- [virt] kvm: write protect memory after slot swap (Michael S. Tsirkin) [647367]
- [net] generic get_drvinfo() fallback in "ethtool.c" (Laszlo Ersek) [649248]
- [virt] Revert "vhost: max s/g to match qemu" (Jason Wang) [623915]
- [virt] KVM: Fix reboot on Intel hosts (Avi Kivity) [637520]
- [virt] KVM: SVM: init_vmcb should reset vcpu->efer (Marcelo Tosatti) [554506]
- [virt] fix vhost_net lanana violation (Bob Picco) [602499]
- [virt] KVM: x86 emulator: Allow LOCK prefix for NEG and NOT (Avi Kivity) [618202]
- [mm] Prevent Out Of Memory when changing cpuset's mems on NUMA (Larry Woodman) [597127]
- [kernel] tracing: fix recursive user stack trace (Jiri Olsa) [602804]
- [mm] revalidate page->mapping after locking page in do_generic_file_read() (Johannes Weiner) [651373]
- [fs] introduce GLF_QUEUED flag (Abhijith Das) [629920]
- [fs] dlm: Don't send callback to node making lock request when "try 1cb" fails (David Teigland) [629920]
- [virt] KVM: Set cr0.et when the guest writes cr0 (Avi Kivity) [645898]
- [virt] KVM: VMX: Give the guest ownership of cr0.ts when the fpu is active (Avi Kivity) [645898]
- [virt] KVM: Lazify fpu activation and deactivation (Avi Kivity) [645898]
- [virt] KVM: VMX: Allow the guest to own some cr0 bits (Avi Kivity) [645898]
- [virt] KVM: Replace read accesses of vcpu->arch.cr0 by an accessor (Avi Kivity) [645898]
- [virt] KVM: VMX: trace clts and lmsw instructions as cr accesses (Avi Kivity) [645898]
- [x86] mce: Use HW_ERR in MCE handler (Bob Picco) [641039]
- [x86] mce: Add HW_ERR printk prefix for hardware error logging (Bob Picco) [641039]
- [dm] sync trivial changes from 2.6.36 (Mike Snitzer) [641432]
- [dm] crypt: simplify crypt_ctr (Mike Snitzer) [641432]
- [dm] crypt: simplify crypt_config destruction logic (Mike Snitzer) [641432]
- [dm] ioctl: refactor dm_table_complete (Mike Snitzer) [641432]
- [dm] snapshot: persistent use define for disk header chunk size (Mike Snitzer) [641432]
- [dm] crypt: use kstrdup (Mike Snitzer) [641432]
- [dm] ioctl: use nonseekable_open (Mike Snitzer) [641432]
- [virt] Xen PV-HVM: Enable xen pv hvm always for Xen HVM guests (Don Dutile) [632021]
- [virt] Xen PV-HVM: skip vnif cfg if match 8139 macaddr (Don Dutile) [632021]
- [virt] Xen PV-HVM: Synch unplug to upstream and tweak for rhel (Don Dutile) [632021]
- [virt] Xen PV-HVM: change xen_pv_hvm param from _setup to early_param (Don Dutile) [632021]
- [virt] KVM: Send SRAR SIGBUS directly (Dean Nelson) [550938]
- [virt] KVM: Add MCG_SER_P into KVM_MCE_CAP_SUPPORTED (Dean Nelson) [550938]
- [virt] KVM: Return EFAULT from kvm ioctl when guest accesses bad area (Dean Nelson) [550938]
- [virt] KVM: define hwpoison variables static (Dean Nelson) [550938]
- [virt] KVM: Fix a race condition for usage of is_hwpoison_address() (Dean Nelson) [550938]
- [virt] KVM: Avoid killing userspace through guest SRAO MCE on unmapped pages (Dean Nelson) [550938]
- [virt] KVM: make double/triple fault promotion generic to all exceptions (Dean Nelson) [550938]
- [virt] xen: handle events as edge-triggered (Andrew Jones) [550724]
- [virt] xen: use percpu interrupts for IPIs and VIRQs (Andrew Jones) [550724]
- [hwmon] coretemp: get TjMax value from MSR (Dean Nelson) [580700]
- [hwmon] coretemp: detect the thermal sensors by CPUID (Dean Nelson) [580700]
- [x86] mtrr: Use stop machine context to rendezvous all the cpus (Prarit Bhargava) [612659]
- [kernel] Backport linux-2.6 stop_machine code (Prarit Bhargava) [612659]
- [netdrv] ibmveth: Fix opps during MTU change on an active device (Steve Best) [644959]
- [netdrv] ehea: Fix synchronization between HW and SW send queue (Steve Best) [620792]
- [netdrv] be2net: remove a BUG_ON in be_cmds.c (Ivan Vecera) [627958]
- [netdrv] e1000e: don't inadvertently re-set INTX_DISABLE (Dean Nelson) [627926]
- [mm] fix mbind_range() vma merge problem (Larry Woodman) [643942]
- [mm] kernel: possible integer overflow in mm/fremap.c (Larry Woodman) [637049]
- [mm] fix BUG() in do_coredump when out of memory (Rik van Riel) [623007]

* Thu Nov 11 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-82.el6]
- [block] Re-introduce blk_queue_flushing() (Vivek Goyal) [635199]
- [fs] SUNRPC: Fix the NFSv4 and RPCSEC_GSS Kconfig dependencies (Steve Dickson) [637278]
- [fs] statfs() gives ESTALE error (Steve Dickson) [637278]
- [fs] NFS: Fix a typo in nfs_sockaddr_match_ipaddr6 (Steve Dickson) [637278]
- [fs] sunrpc: increase MAX_HASHTABLE_BITS to 14 (Steve Dickson) [637278]
- [fs] gss:spkm3 miss returning error to caller when import security context (Steve Dickson) [637278]
- [fs] gss:krb5 miss returning error to caller when import security context (Steve Dickson) [637278]
- [fs] Remove incorrect do_vfs_lock message (Steve Dickson) [637278]
- [fs] SUNRPC: cleanup state-machine ordering (Steve Dickson) [637278]
- [fs] SUNRPC: Fix a race in rpc_info_open (Steve Dickson) [637278]
- [fs] SUNRPC: Fix race corrupting rpc upcall (Steve Dickson) [637278]
- [fs] Fix null dereference in call_allocate (Steve Dickson) [637278]
- [fs] NFS: Fix the selection of security flavours in Kconfig (Steve Dickson) [637278]
- [fs] NFS: NFS_V4 is no longer an EXPERIMENTAL feature (Steve Dickson) [637278]
- [fs] NFS: fix the return value of nfs_file_fsync() (Steve Dickson) [637278]
- [fs] rpcrdma: Fix SQ size calculation when memreg is FRMR (Steve Dickson) [637278]
- [fs] xprtrdma: Do not truncate iova_start values in frmr registrations (Steve Dickson) [637278]
- [fs] nfs: Remove redundant NULL check upon kfree() (Steve Dickson) [637278]
- [fs] nfs: Add "lookupcache" to displayed mount options (Steve Dickson) [637278]
- [fs] NFS: allow close-to-open cache semantics to apply to root of NFS filesystem (Steve Dickson) [637278]
- [fs] SUNRPC: fix NFS client over TCP hangs due to packet loss (Steve Dickson) [637278]
- [fs] NFS: Ensure that writepage respects the nonblock flag (Steve Dickson) [637278]
- [fs] nfs: include space for the NUL in root path (Steve Dickson) [637278]
- [fs] nfsd4: mask out non-access bits in nfs4_access_to_omode (Steve Dickson) [637279]
- [fs] nfsd4: fix downgrade/lock logic (Steve Dickson) [637279]
- [fs] nfsd4: bad BUG() in preprocess_stateid_op (Steve Dickson) [637279]
- [fs] nfsd4: fix file open accounting for RDWR opens (Steve Dickson) [637279]
- [fs] NFSv4: Ensure the lockowners are labelled using the fl_owner and/or fl_pid (Harshula Jayasuriya) [621304 624069]
- [fs] NFSv4: Add support for the RELEASE_LOCKOWNER operation (Harshula Jayasuriya) [621304 624069]
- [fs] NFSv4: Clean up for lockowner XDR encoding (Harshula Jayasuriya) [621304 624069]
- [fs] NFSv4: Ensure that we track the NFSv4 lock state in read/write requests (Harshula Jayasuriya) [621304 624069]
- [fs] NFSv4: Clean up struct nfs4_state_owner (Harshula Jayasuriya) [621304 624069]
- [fs] Add back dentry argument to ->fsync (Steve Dickson) [624069]
- [fs] NFS: kswapd must not block in nfs_release_page (Steve Dickson) [624069]
- [fs] NFS: Fix the locking in nfs4_callback_getattr (Steve Dickson) [624069]
- [net] NFSv4: Remember to clear NFS_DELEGATED_STATE in nfs_delegation_claim_opens (Steve Dickson) [624069]
- [net] SUNRPC: Defer deleting the security context until gss_do_free_ctx() (Steve Dickson) [624069]
- [net] SUNRPC: prevent task_cleanup running on freed xprt (Steve Dickson) [624069]
- [net] SUNRPC: Reduce asynchronous RPC task stack usage (Steve Dickson) [624069]
- [net] SUNRPC: Move the bound cred to struct rpc_rqst (Steve Dickson) [624069]
- [net] SUNRPC: Clean up of rpc_bindcred() (Steve Dickson) [624069]
- [net] SUNRPC: Move remaining RPC client related task initialisation into clnt.c (Steve Dickson) [624069]
- [net] SUNRPC: Ensure that rpc_exit() always wakes up a sleeping task (Steve Dickson) [624069]
- [net] SUNRPC: Make the credential cache hashtable size configurable (Steve Dickson) [624069]
- [net] SUNRPC: Store the hashtable size in struct rpc_cred_cache (Steve Dickson) [624069]
- [fs] NFS: Ensure the AUTH_UNIX credcache is allocated dynamically (Steve Dickson) [624069]
- [fs] NFS: Fix the NFS users of rpc_restart_call() (Steve Dickson) [624069]
- [net] SUNRPC: The function rpc_restart_call() should return success/failure (Steve Dickson) [624069]
- [fs] NFSv4: Get rid of the bogus RPC_ASSASSINATED(task) checks (Steve Dickson) [624069]
- [fs] NFSv4: Clean up the process of renewing the NFSv4 lease (Steve Dickson) [624069]
- [fs] NFSv4.1: Handle NFS4ERR_DELAY on SEQUENCE correctly (Steve Dickson) [624069]
- [fs] NFS: nfs_rename() should not have to flush out writebacks (Steve Dickson) [624069]
- [fs] NFS: Clean up the callers of nfs_wb_all() (Steve Dickson) [624069]
- [fs] NFS: Fix up the fsync code (Steve Dickson) [624069]
- [fs] NFSv4.1: There is no need to init the session more than once (Steve Dickson) [624069]
- [fs] NFSv41: Cleanup for nfs4_alloc_session (Steve Dickson) [624069]
- [fs] NFSv41: Clean up exclusive create (Steve Dickson) [624069]
- [fs] NFSv41: Deprecate nfs_client->cl_minorversion (Steve Dickson) [624069]
- [fs] NFSv41: Fix nfs_async_inode_return_delegation() ugliness (Steve Dickson) [624069]
- [fs] NFSv41: Convert the various reboot recovery ops etc to minor version ops (Steve Dickson) [624069]
- [fs] NFSv41: Clean up the NFSv4.1 minor version specific operations (Steve Dickson) [624069]
- [fs] nfs: kill renewd before clearing client minor version (Steve Dickson) [624069]
- [fs] NFSv41: Don't store session state in the nfs_client->cl_state (Steve Dickson) [624069]
- [fs] NFSv41: Further cleanup for nfs4_sequence_done (Steve Dickson) [624069]
- [fs] NFSv4.1: Make nfs4_setup_sequence take a nfs_server argument (Steve Dickson) [624069]
- [fs] NFSv4.1: Merge the nfs41_proc_async_sequence() and nfs4_proc_sequence() (Steve Dickson) [624069]
- [fs] NFSv4: Kill nfs4_async_handle_error() abuses by NFSv4.1 (Steve Dickson) [624069]
- [fs] NFSv4.1: Simplify nfs41_sequence_done() (Steve Dickson) [624069]
- [fs] NFSv4.1: Clean up nfs4_setup_sequence (Steve Dickson) [624069]
- [fs] NFSv41: Fix a memory leak in nfs41_proc_async_sequence() (Steve Dickson) [624069]
- [fs] nfsd41: Fix a crash when a callback is retried (Steve Dickson) [624081]
- [fs] nfsd: minor nfsd read api cleanup (Steve Dickson) [624081]
- [fs] gcc-4.6: nfsd: fix initialized but not read warnings (Steve Dickson) [624081]
- [fs] nfsd4: share file descriptors between stateid's (Steve Dickson) [624081]
- [fs] nfsd4: fix openmode checking on IO using lock stateid (Steve Dickson) [624081]
- [fs] nfsd4: miscellaneous process_open2 cleanup (Steve Dickson) [624081]
- [fs] nfsd4: don't pretend to support write delegations (Steve Dickson) [624081]
- [fs] nfsd: bypass readahead cache when have struct file (Steve Dickson) [624081]
- [fs] nfsd: remove unused assignment from nfsd_link (Steve Dickson) [624081]
- [fs] NFSD: Fill in WCC data for REMOVE, RMDIR, MKNOD, and MKDIR (Steve Dickson) [624081]
- [fs] nfsd4: comment nitpick (Steve Dickson) [624081]
- [net] sunrpc: make the cache cleaner workqueue deferrable (Steve Dickson) [624081]
- [fs] nfsd4: fix delegation recall race use-after-free (Steve Dickson) [624081 637278]
- [fs] nfsd4: fix deleg leak on callback error (Steve Dickson) [624081 637278]
- [fs] nfsd4: remove some debugging code (Steve Dickson) [624081 637278]
- [fs] nfsd: nfs4callback encode_stateid helper function (Steve Dickson) [624081 637278]
- [fs] nfsd4: translate memory errors to delay, not serverfault (Steve Dickson) [624081 637278]
- [fs] nfsd4; fix session reference count leak (Steve Dickson) [624081 637278]
- [fs] nfsd4: don't bother storing callback reply tag (Steve Dickson) [624081 637278]
- [fs] nfsd4: fix use of op_share_access (Steve Dickson) [624081 637278]
- [fs] nfsd4: treat more recall errors as failures (Steve Dickson) [624081 637278]
- [fs] nfsd4: remove extra put() on callback errors (Steve Dickson) [624081 637278]
- [virt] xen-blkfront: disable barrier/flush write support (Mike Snitzer) [635199]
- [block] revert to old blkdev_issue_discard to preserve kABI (Mike Snitzer) [635199]
- [block] revert to old blkdev_issue_flush to preserve kABI (Mike Snitzer) [635199]
- [block] revert bio flag changes to preserve kABI (Jeff Moyer) [635199]
- [block] restore rq_flag_bits to their original values (Mike Snitzer) [635199]
- [block] initialize old barrier members of request_queue (Mike Snitzer) [635199]
- [block] reintroduce blk_queue_ordered to maintain compatibility (Vivek Goyal) [635199]
- [block] Documentation: fix block api docbook documentation (Mike Snitzer) [635199]
- [block] remove BLKDEV_IFL_WAIT (Mike Snitzer) [635199]
- [block] remove the BLKDEV_IFL_BARRIER flag (Mike Snitzer) [635199]
- [mm] swap: do not send discards as barriers (Mike Snitzer) [635199]
- [fs] fat: do not send discards as barriers (Mike Snitzer) [635199]
- [fs] ext4: do not send discards as barriers (Mike Snitzer) [635199]
- [fs] jbd2: replace barriers with explicit flush and FUA usage (Mike Snitzer) [635199]
- [fs] jbd2: Modify ASYNC_COMMIT code to not rely on queue draining on barrier (Mike Snitzer) [635199]
- [fs] jbd: replace barriers with explicit flush and FUA usage (Mike Snitzer) [635199]
- [fs] gfs2: replace barriers with explicit flush and FUA usage (Mike Snitzer) [635199]
- [fs] btrfs: replace barriers with explicit flush and FUA usage (Mike Snitzer) [635199]
- [fs] xfs: replace barriers with explicit flush and FUA usage (Mike Snitzer) [635199]
- [block] pass gfp_mask and flags to sb_issue_discard (Mike Snitzer) [635199]
- [block] disallow FS recursion from sb_issue_discard allocation (Mike Snitzer) [635199]
- [dm] convey that all flushes are processed as empty (Mike Snitzer) [635199]
- [dm] fix locking context in queue_io() (Mike Snitzer) [635199]
- [dm] relax ordering of bio-based flush implementation (Mike Snitzer) [635199]
- [dm] implement REQ_FLUSH/FUA support for request-based dm (Mike Snitzer) [635199]
- [dm] implement REQ_FLUSH/FUA support for bio-based dm (Mike Snitzer) [635199]
- [block] make __blk_rq_prep_clone() copy most command flags (Mike Snitzer) [635199]
- [md] implment REQ_FLUSH/FUA support (Mike Snitzer) [635199]
- [virt] virtio_blk: drop REQ_HARDBARRIER support (Mike Snitzer) [635199]
- [block] loop: implement REQ_FLUSH/FUA support (Mike Snitzer) [635199]
- [block] use REQ_FLUSH in blkdev_issue_flush() (Mike Snitzer) [635199]
- [block] update documentation for REQ_FLUSH / REQ_FUA (Mike Snitzer) [635199]
- [block] make sure FSEQ_DATA request has the same rq_disk as the original (Mike Snitzer) [635199]
- [block] kick queue after sequencing REQ_FLUSH/FUA (Mike Snitzer) [635199]
- [block] initialize flush request with WRITE_FLUSH instead of REQ_FLUSH (Mike Snitzer) [635199]
- [block] simplify queue_next_fseq (Mike Snitzer) [635199]
- [block] filter flush bio's in __generic_make_request() (Mike Snitzer) [635199]
- [block] preserve RHEL6.0 struct request_queue kABI (Mike Snitzer) [635199]
- [block] implement REQ_FLUSH/FUA based interface for FLUSH/FUA requests (Mike Snitzer) [635199]
- [fs] replace internal uses of SWRITE I/O types by sync_dirty_buffer() (Mike Snitzer) [635199]
- [fs] removing the use of the BH_Ordered flag (Mike Snitzer) [635199]
- [block] rename barrier/ordered to flush (Mike Snitzer) [635199]
- [block] rename blk-barrier.c to blk-flush.c (Mike Snitzer) [635199]
- [block] blkdev: check for valid request queue before issuing flush (Mike Snitzer) [635199]
- [block] blkdev: move blkdev_issue helper functions to separate file (Mike Snitzer) [635199]
- [block] blkdev: allow async blkdev_issue_flush requests (Mike Snitzer) [635199]
- [block] blkdev: generalize flags for blkdev_issue_fn functions (Mike Snitzer) [635199]
- [fs] ext4: check missed return value in ext4_sync_file() (Mike Snitzer) [635199]
- [fs] ext4, jbd2: Add barriers for file systems with exernal journals (Mike Snitzer) [635199]
- [block] drop barrier ordering by queue draining (Mike Snitzer) [635199]
- [block] misc cleanups in barrier code (Mike Snitzer) [635199]
- [block] remove spurious uses of REQ_HARDBARRIER (Mike Snitzer) [635199]
- [block] deprecate barrier and replace blk_queue_ordered() with blk_queue_flush() (Mike Snitzer) [635199]
- [block] kill QUEUE_ORDERED_BY_TAG (Mike Snitzer) [635199]
- [xen] blkfront: update use of barriers to ease flush+fua backport (Mike Snitzer) [635199]
- [block] loop: queue ordered mode should be DRAIN_FLUSH (Mike Snitzer) [635199]
- [ide] remove unnecessary blk_queue_flushing() test in do_ide_request() (Mike Snitzer) [635199]
- [block] remove q->prepare_flush_fn completely (Mike Snitzer) [635199]
- [scsi] use REQ_TYPE_FS for flush request (Mike Snitzer) [635199]
- [block] set up rq->rq_disk properly for flush requests (Mike Snitzer) [635199]
- [block] set REQ_TYPE_FS on flush requests (Mike Snitzer) [635199]
- [virt] virtio_blk: stop using q->prepare_flush_fn (Mike Snitzer) [635199]
- [dm] stop using q->prepare_flush_fn (Mike Snitzer) [635199]
- [block] osdblk: stop using q->prepare_flush_fn (Mike Snitzer) [635199]
- [scsi] stop using q->prepare_flush_fn (Mike Snitzer) [635199]
- [block] permit PREFLUSH and POSTFLUSH without prepare_flush_fn (Mike Snitzer) [635199]
- [block] introduce REQ_FLUSH flag (Mike Snitzer) [635199]
- [md] raid-1/10 Fix bio_rw bit manipulations again (Mike Snitzer) [635199]
- [block] fixup missing conversion from BIO_RW_DISCARD to REQ_DISCARD (Mike Snitzer) [635199]
- [block] define READA constant in terms of unified flag (Mike Snitzer) [635199]
- [fs] bio: separate out blk_types.h (Mike Snitzer) [635199]
- [block] unify flags for struct bio and struct request (Mike Snitzer) [635199]
- [block] BARRIER request should imply SYNC (Mike Snitzer) [635199]
- [block] fix some more cmd_type cleanup fallout (Mike Snitzer) [635199]
- [block] remove wrappers for request type/flags (Mike Snitzer) [635199]
- [scsi] scsi_dh_emc: request flag cleanup (Mike Snitzer) [635199]
- [ide] Fix IDE taskfile with cfq scheduler (Mike Snitzer) [635199]

* Thu Oct 28 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-81.el6]
- [mm] remove false positive THP pmd_present BUG_ON (Andrea Arcangeli) [646384]

* Tue Oct 26 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-80.el6]
- [drm] ttm: fix regression introduced in dfb4a4250168008c5ac61e90ab2b86f074a83a6c (Dave Airlie) [644896]

* Wed Oct 20 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-79.el6]
- [block] fix a potential oops for callers of elevator_change (Jeff Moyer) [641408]

* Tue Oct 19 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-78.el6]
- [security] IMA: require command line option to enabled (Eric Paris) [643667]

* Tue Oct 19 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-77.el6]
- [net] Fix priv escalation in rds protocol (Neil Horman) [642900] {CVE-2010-3904}
- [v4l] Remove compat code for VIDIOCSMICROCODE (Mauro Carvalho Chehab) [642473] {CVE-2010-2963}
- [kernel] tracing: do not allow llseek to set_ftrace_filter (Jiri Olsa) [631626]
- [virt] xen: hold mm->page_table_lock in vmalloc_sync (Andrew Jones) [643371]
- [fs] xfs: properly account for reclaimed inodes (Dave Chinner) [641764]
- [drm] fix ioctls infoleak (Danny Feng) [621437] {CVE-2010-2803}
- [netdrv] wireless extensions: fix kernel heap content leak (John Linville) [628438] {CVE-2010-2955}
- [netdrv] niu: buffer overflow for ETHTOOL_GRXCLSRLALL (Danny Feng) [632072] {CVE-2010-3084}
- [mm] add debug checks for mapcount related invariants (Andrea Arcangeli) [622327 642570]
- [mm] move VM_BUG_ON inside the page_table_lock of zap_huge_pmd (Andrea Arcangeli) [622327 642570]
- [mm] compaction: handle active and inactive fairly in too_many_isolated (Andrea Arcangeli) [622327 642570]
- [mm] start_khugepaged after setting transparent_hugepage_flags (Andrea Arcangeli) [622327 642570]
- [mm] fix hibernate memory corruption (Andrea Arcangeli) [633344 642570]
- [mm] ksmd wait_event_freezable (Andrea Arcangeli) [622327 642570]
- [mm] khugepaged wait_event_freezable (Andrea Arcangeli) [622327 625875 642570]
- [mm] unlink_anon_vmas in __split_vma in case of error (Andrea Arcangeli) [622327 642570]
- [mm] fix memleak in copy_huge_pmd (Andrea Arcangeli) [622327 642570]
- [mm] fix hang on anon_vma->root->lock (Andrea Arcangeli) [622327 642570]
- [mm] avoid breaking huge pmd invariants in case of vma_adjust failures (Andrea Arcangeli) [622327 642570]

* Mon Oct 11 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-76.el6]
- [scsi] fcoe: set default FIP mode as FIP_MODE_FABRIC (Mike Christie) [636233]

* Sun Oct 10 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-75.el6]
- [virt] KVM: Fix fs/gs reload oops with invalid ldt (Avi Kivity) [639885] {CVE-2010-3698}
- [drm] i915: prevent arbitrary kernel memory write (Jerome Marchand) [637691] {CVE-2010-2962}
- [scsi] libfc: adds flogi retry in case DID is zero in RJT (Mike Christie) [633907]
- [kernel] prevent heap corruption in snd_ctl_new() (Jerome Marchand) [638486] {CVE-2010-3442}
- [scsi] lpfc: lpfc driver oops during rhel6 installation with snapshot 12/13 and emulex FC (Rob Evers) [634703]
- [fs] ext4: Always journal quota file modifications (Eric Sandeen) [624909]
- [mm] fix split_huge_page error like mapcount 3 page_mapcount 2 (Andrea Arcangeli) [622327 640611]
- [block] Fix pktcdvd ioctl dev_minor range check (Jerome Marchand) [638089] {CVE-2010-3437}
- [drm] ttm: Fix two race conditions + fix busy codepaths (Dave Airlie) [640871]
- [drm] Prune GEM vma entries (Dave Airlie) [640870]
- [virt] ksm: fix bad user data when swapping (Andrea Arcangeli) [640579]
- [virt] ksm: fix page_address_in_vma anon_vma oops (Andrea Arcangeli) [640576]
- [net] sctp: Fix out-of-bounds reading in sctp_asoc_get_hmac() (Jiri Pirko) [640462] {CVE-2010-3705}
- [mm] Move vma_stack_continue into mm.h (Mike Snitzer) [638525]
- [net] sctp: Do not reset the packet during sctp_packet_config() (Jiri Pirko) [637682] {CVE-2010-3432}
- [mm] vmstat incorrectly reports disk IO as swap in (Steve Best) [636978]
- [scsi] fcoe: Fix NPIV (Neil Horman) [631246]

* Thu Sep 30 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-74.el6]
- [block] prevent merges of discard and write requests (Mike Snitzer) [637805]
- [drm] nouveau: correct INIT_DP_CONDITION subcondition 5 (Ben Skeggs) [636678]
- [drm] nouveau: enable enhanced framing only if DP display supports it (Ben Skeggs) [636678]
- [drm] nouveau: fix required mode bandwidth calculation for DP (Ben Skeggs) [636678]
- [drm] nouveau: disable hotplug detect around DP link training (Ben Skeggs) [636678]
- [drm] nouveau: set DP display power state during DPMS (Ben Skeggs) [636678]
- [mm] remove "madvise" from possible /sys/kernel/mm/redhat_transparent_hugepage/enabled options (Larry Woodman) [634500]
- [netdrv] cxgb3: don't flush the workqueue if we are called from the workqueue (Doug Ledford) [631547]
- [netdrv] cxgb3: deal with fatal parity error status in interrupt handler (Doug Ledford) [631547]
- [netdrv] cxgb3: now that we define fatal parity errors, make sure they are cleared (Doug Ledford) [631547]
- [netdrv] cxgb3: Add define for fatal parity error bit manipulation (Doug Ledford) [631547]
- [virt] Emulate MSR_EBC_FREQUENCY_ID (Jes Sorensen) [629836]
- [virt] Define MSR_EBC_FREQUENCY_ID (Jes Sorensen) [629836]
- [redhat] s390x: kdump: allow zfcpdump to mount and write to ext4 file systems [628676]
- [kernel] initramfs: Fix initramfs size calculation (Hendrik Brueckner) [626956]
- [kernel] initramfs: Generalize initramfs_data.xxx.S variants (Hendrik Brueckner) [626956]
- [drm] radeon/kms: fix sideport detection on newer rs880 boards (Dave Airlie) [626454]

* Wed Sep 22 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-73.el6]
- [x86] kernel: fix IA32 System Call Entry Point Vulnerability (Danny Feng) [634452] {CVE-2010-3301}
- [kernel] compat: Make compat_alloc_user_space() incorporate the access_ok() (Danny Feng) [634466] {CVE-2010-3081}
- [block] switch s390 tape_block and mg_disk to elevator_change() (Mike Snitzer) [632631]
- [block] add function call to switch the IO scheduler from a driver (Mike Snitzer) [632631]

* Mon Sep 13 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-72.el6]
- [security] Make kernel panic in FIPS mode if modsign check fails (David Howells) [625914]
- [virt] Guests on AMD with CPU type 6 and model >= 8 trigger errata read of MSR_K7_CLK_CTL (Jes Sorensen) [629066]
- [x86] UV: use virtual efi on SGI systems (George Beshers) [627653]

* Wed Sep 01 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-71.el6]
- [fs] nfsd: initialize nfsd versions before creating svc (J. Bruce Fields) [628084]
- [fs] nfsd: fix startup/shutdown order bug (J. Bruce Fields) [628084]
- [security] KEYS: Fix bug in keyctl_session_to_parent() if parent has no session keyring (David Howells) [627808] {CVE-2010-2960}
- [security] KEYS: Fix RCU no-lock warning in keyctl_session_to_parent() (David Howells) [627808] {CVE-2010-2960}

* Wed Aug 25 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-70.el6]
- [x86] Disable AMD IOMMU by default (Matthew Garrett) [593787]
- [netdrv] Revert "iwlwifi: disable hardware scanning by default" (Stanislaw Gruszka) [625981]
- [s390x] kernel: fix tlb flushing vs. concurrent /proc accesses (Hendrik Brueckner) [587587]
- [s390x] kernel: prepare mm_context_t for new tlb flush handling (Hendrik Brueckner) [587587]
- [fs] NFS: Fix an Oops in the NFSv4 atomic open code (Jeff Layton) [625718]
- [net] can: add limit for nframes and clean up signed/unsigned variables (Danny Feng) [625702] {CVE-2010-2959}
- [fs] aio: bump i_count instead of using igrab (Jeff Moyer) [626595]
- [fs] cifs: check for NULL session password (Jeff Layton) [625583]
- [fs] cifs: fix NULL pointer dereference in cifs_find_smb_ses (Jeff Layton) [625583]

* Tue Aug 24 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-69.el6]
- [mm] make stack guard page logic use vm_prev pointer (Mike Snitzer) [607859]
- [mm] make the mlock() stack guard page checks stricter (Mike Snitzer) [607859]
- [mm] make the vma list be doubly linked (Mike Snitzer) [607859]
- [drm] nv50: insert a delay before fb change to prevent display engine hang (Ben Skeggs) [618225]
- [mm] fix up some user-visible effects of the stack guard page (Mike Snitzer) [607859]
- [net] sched: fix some kernel memory leaks (Jiri Pirko) [624637] {CVE-2010-2942}

* Mon Aug 23 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-68.el6]
- [virt] xen pvhvm: don't start xenbus w/out pvhvm (Andrew Jones) [624665]
- [virt] xen pvhvm: don't unplug emulated devs w/out pvhvm (Andrew Jones) [625460]
- [virt] xen pvhvm: export xen_pv_hvm_enable (Andrew Jones) [625460]
- [fs] ext4: fix one more tracing oops (Eric Sandeen) [619013]
- [drm] Provide for HDMI output on NVIDIA GPUs (John Feeney) [619877]
- [netdrv] iwlwifi: disable aspm by default (John Linville) [611075]
- [x86] acpi: Update battery information on notification 0x81 (Matthew Garrett) [606388]

* Fri Aug 20 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-67.el6]
- [x86] acpi: Update battery information on notification 0x81 (Matthew Garrett) [606388]
- [mm] fix up some user-visible effects of the stack guard page (Mike Snitzer) [607859]
- [mm] fix page table unmap for stack guard page properly (Mike Snitzer) [607859]
- [x86] don't send SIGBUS for kernel page faults (Mike Snitzer) [607859]
- [mm] fix missing page table unmap for stack guard page failure case (Mike Snitzer) [607859]
- [mm] keep a guard page below a grow-down stack segment (Mike Snitzer) [607859]
- [fs] xfs: fix untrusted inode number lookup (Dave Chinner) [624860]
- [kernel] init, sched: Fix race between init and kthreadd (Gleb Natapov) [624329]
- [net] Fix IGMP3 report parsing (Aristeu Rozanski) [621431]

* Tue Aug 17 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-66.el6]
- [netdrv] be2net: maintain multicast packet count in driver (Ivan Vecera) [621287]
- [scsi] hpsa: don't use doorbel reset (Tomas Henzl) [612486]
- [x86] Fix the kdump kernel OOMs caused by passthrough mode setting (Bhavna Sarathy) [624059]
- [acpi] Force "pci=noacpi" on HP xw9300 (Prarit Bhargava) [615276]
- [mm] Revert mm-vmstat-Actively-update-vmstat-counters-in-low-memory-situations (Larry Woodman) [622328]
- [x86] Run EFI in physical mode to enable kdump on EFI-booted system (Takao Indoh) [593111]
- [fs] ext4: protect inode bitmap clearing w/ spinlock (Eric Sandeen) [623666]
- [scsi] libfc: call fc_remote_port_chkready under the host lock (Mike Christie) [623786]
- [x86] Ensure that we provide per-cpu ACPI support (Matthew Garrett) [623874]
- [fs] ext4: consolidate in_range() definitions (Eric Sandeen) [621829]
- [fs] ext4: fix NULL pointer dereference in tracing (Eric Sandeen) [619013]
- [block] O_DIRECT: fix the splitting up of contiguous I/O (Jeff Moyer) [622504]

* Mon Aug 16 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-65.el6]
- [fs] ext4: fix discard failure detection (Eric Sandeen) [608731]
- [x86] Avoid potential NULL dereference in pcc-cpufreq (Matthew Garrett) [623768]
- [scsi] bfa: vport create/delete fix (Rob Evers) [619226]
- [net] tcp: fix crash in tcp_xmit_retransmit_queue (Jerome Marchand) [618386]
- [build] Skip depmod when installing to non-standard INSTALL_MOD_PATH (Jon Masters) [609170]
- [sound] disable NVIDIA HDMI PCI device for Lenovo T410 (Jaroslav Kysela) [605742]
- [scsi] increase flush timeout (Mike Christie) [605322]
- [x86] local_irq_save/restore when issuing IPI in early bootup (Prarit Bhargava) [602823]

* Fri Aug 13 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-64.el6]
- [kernel] Revert "[kernel] sched: Fix a race between ttwu() and migrate_task()" (Matthew Garrett) [620883]
- [fs] btrfs: fix checks in BTRFS_IOC_CLONE_RANGE (Eugene Teo) [617003] {CVE-2010-2537 CVE-2010-2538}
- [kernel] Makefile.build: make KBUILD_SYMTYPES work again (Don Zickus) [617749]
- [netdrv] iwlwifi: disable hardware scanning by default (Stanislaw Gruszka) [593566]
- [scsi] Revert: qla2xxx: Propogate transport disrupted status for cable pull conditions for faster failover (Chad Dupuis) [622041]
- [drm] radeon: Don't limit vram size to aperture size (Matthew Garrett) [622039]
- [fs] xfs: don't walk AGs that can't hold inodes (Dave Chinner) [621044]
- [mmc] add Ricoh e822 support (Stanislaw Gruszka) [619900]
- [scsi] mvsas: fix hot plug handling and IO issues (David Milburn) [616178]
- [dm] mpath: enable discard support (Mike Snitzer) [619196]
- [block] update request stacking methods to support discards (Mike Snitzer) [619196]
- [dm] stripe: enable discard support (Mike Snitzer) [619196]
- [dm] stripe: optimize sector division (Mike Snitzer) [619196]
- [dm] stripe: move sector translation to a function (Mike Snitzer) [619196]
- [dm] error: return error for discards (Mike Snitzer) [619196]
- [dm] delay: enable discard support (Mike Snitzer) [619196]
- [dm] zero: silently drop discards (Mike Snitzer) [619196]
- [dm] split discard requests on target boundaries (Mike Snitzer) [619196]
- [dm] use dm_target_offset macro (Mike Snitzer) [619196]
- [dm] factor out max_io_len_target_boundary (Mike Snitzer) [619196]
- [dm] use common __issue_target_request for flush and discard support (Mike Snitzer) [619196]
- [dm] rename map_info flush_request to target_request_nr (Mike Snitzer) [619196]
- [dm] remove the DM_TARGET_SUPPORTS_DISCARDS feature flag (Mike Snitzer) [619196]
- [dm] introduce num_discard_requests in dm_target structure (Mike Snitzer) [619196]

* Tue Aug 10 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-63.el6]
- [fs] ext4: protect io completion lists with locking (Eric Sandeen) [621660]
- [trace] Packport new mm tracepoint Documentation to RHEL6 (Larry Woodman) [618305]
- [virt] KVM: Trace exception injection (Gleb Natapov) [616427]
- [s390x] qeth: Clear mac_bits field when switching between l2/l3 (Hendrik Brueckner) [621333]
- [net] ethtool: Fix potential kernel buffer overflow in ETHTOOL_GRXCLSRLALL (Jiri Pirko) [608953] {CVE-2010-2478}
- [infiniband] Update QLogic QIB InfiniBand driver to version OFED 1.5.2 (Jay Fenlason) [572401]
- [fs] update RWA_MASK, READA and SWRITE to match the corresponding BIO_RW_ bits (Jeff Moyer) [621693]

* Tue Aug 10 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-62.el6]
- [drm] Revert matroxfb support for G200EV chip (Peter Bogdanovic) [604830]
- [drm] i915: more DP/eDP backport fixes (Dave Airlie) [615058]
- [drm] correctly update connector DPMS status in drm_fb_helper (Dave Airlie) [615058]
- [x86] ACPI/PM: Move ACPI video resume to a PM notifier (Dave Airlie) [615058]
- [virt] x86: preset lpj values when on VMware (Zachary Amsden) [617390]
- [virt] Revert "vhost-net: utilize PUBLISH_USED_IDX feature" (Michael S. Tsirkin)
- [virt] Revert "virtio: put last seen used index into ring itself" (Michael S. Tsirkin) [616503]
- [virt] Revert "virtio: net: Remove net-specific advertising of PUBLISH_USED feature" (Michael S. Tsirkin) [616503]
- [virt] vhost: max s/g to match qemu (Michael S. Tsirkin) [619002]
- [kernel] sched: Fix set_cpu_active() in cpu_down() (Danny Feng) [620807]
- [dm] separate device deletion from dm_put (Mike Snitzer) [619199]
- [dm] prevent access to md being deleted (Mike Snitzer) [619199]
- [dm] ioctl: release _hash_lock between devices in remove_all (Mike Snitzer) [619199]

* Fri Aug 06 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-61.el6]
- [netdrv] r8169: disable PCIe ASPM (Michal Schmidt) [619880]
- [fusion] mptfusion: fix DMA boudary (Tomas Henzl) [618625]
- [fusion] mptfusion: Bump version to 3.04.16 (Tomas Henzl) [618625]
- [fusion] mptfusion: Added code for occationally SATA hotplug failure (Tomas Henzl) [618625]
- [fusion] mptfusion: schedule_target_reset from all Reset context (Tomas Henzl) [618625]
- [fusion] mptfusion: Added sanity to check B_T mapping for device before adding to OS (Tomas Henzl) [618625]
- [fusion] mptfusion: Corrected declaration of device_missing_delay (Tomas Henzl) [618625]
- [fusion] mptfusion: Set fw_events_off to 1 at driver load time (Tomas Henzl) [618625]
- [net] s2io: fixing DBG_PRINT() macro (Danny Feng) [619097]
- [trace] backport file writeback tracepoints from upstream to RHEL6 (Larry Woodman) [618305]
- [virt] vhost: thread per device attached to owner cgroups (Alex Williamson) [615118]
- [cgroups] fix API thinko (Alex Williamson) [615118]
- [cgroup] Revert: "workqueue: API to create a workqueue in cgroup" (Alex Williamson) [615118]
- [net] bonding: allow arp_ip_targets on separate vlans to use arp validation (Andy Gospodarek) [581657]
- [x86] Revert "[x86] kernel performance optimization with CONFIG_DEBUG_RODATA" (Aristeu Rozanski)

* Fri Aug 06 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-60.el6]
- [security] selinux: convert the policy type_attr_map to flex_array (Eric Paris) [617255]
- [net] bridge: Fix IGMPv3 report parsing (Herbert Xu) [621431]
- [kernel] CRED: Fix get_task_cred() and task_state() to not resurrect dead credentials (Jiri Olsa) [620380]
- [net] bonding: set device in RLB ARP packet handler (Andy Gospodarek) [619450]
- [x86] Remove warning in p4-clockmod driver (Prarit Bhargava) [618415]
- [trace] Back port upstream mm/vmscan.c tracepoints to RHEL6 (Larry Woodman) [618305]
- [net] bridge: Fix skb leak when multicast parsing fails on TX (Jiri Pirko) [617505]
- [x86] Retract nmi-stacktrace patch (George Beshers) [598586]
- [fs] cifs: account for new creduid parameter in spnego upcall string (Jeff Layton) [618608]
- [fs] cifs: add separate cred_uid field to sesInfo (Jeff Layton) [618608]
- [fs] cifs: check kmalloc() result (Jeff Layton) [618608]
- [fs] cifs: remove unused cifsUidInfo struct (Jeff Layton) [618608]
- [fs] cifs: clean up cifs_find_smb_ses (Jeff Layton) [618608]
- [fs] cifs: match secType when searching for existing tcp session (Jeff Layton) [618608]
- [fs] cifs: move address comparison into separate function (Jeff Layton) [618608]
- [fs] cifs: set the port in sockaddr in a more clearly defined fashion (Jeff Layton) [618608]
- [fs] cifs: remove an potentially confusing, obsolete comment (Jeff Layton) [618608]
- [fs] cifs: remove unused ip_address field in struct TCP_Server_Info (Jeff Layton) [618608]
- [fs] cifs: have decode_negTokenInit set flags in server struct (Jeff Layton) [618608]
- [fs] cifs: break negotiate protocol calls out of cifs_setup_session (Jeff Layton) [618608]
- [fs] cifs: eliminate "first_time" parm to CIFS_SessSetup (Jeff Layton) [618608]
- [fs] cifs: save the dialect chosen by server (Jeff Layton) [618608]
- [fs] cifs: change && to || (Jeff Layton) [618608]
- [fs] cifs: rename "extended_security" to "global_secflags" (Jeff Layton) [618608]
- [fs] cifs: move tcon find/create into separate function (Jeff Layton) [618608]
- [fs] cifs: move SMB session creation code into separate function (Jeff Layton) [618608]
- [fs] cifs: track local_nls in volume info (Jeff Layton) [618608]
- [drm] nouveau: support fetching LVDS EDID from ACPI (Ben Skeggs) [616860]
- [drm] ACPI: Export EDID blocks to the kernel (Ben Skeggs) [616860]
- [fs] Fix for stuck recovery issue in GFS2 (Steven Whitehouse) [590878]
- [powerpc] fix unsupported hardware to only be power5 (Steve Best) [619501]
- [scsi] megaraid: fix sas expander issue (Tomas Henzl) [607930]
- [virt] Default Xen PV-HVM to off (Don Dutile) [618172]
- [mm] Correctly assign the number of MIGRATE_RESERVE pageblocks (Andrea Arcangeli) [614427]
- [fs] return EINVAL when thawing unfrozen filesystems (Eric Sandeen) [601324]
- [fs] GFS2: Fix problem where try locks were trying too hard (Steven Whitehouse) [585299]
- [scsi] bnx2i: Fix iscsi connection cleanup (Mike Christie) [616939]
- [scsi] bfa: fix sysfs crash while reading error_frames stats (Rob Evers) [594882]
- [fusion] Block Error handling for deleting devices or Device in DMD (Tomas Henzl) [615866]
- [netdrv] tun: avoid BUG, dump packet on GSO errors (Herbert Xu) [616845]
- [netdr] rt2500usb: Fix WEP Enterprise (Stanislaw Gruszka) [609721]
- [kernel] cmdline disable real time scheduler (George Beshers) [607587]
- [fs] ext4: re-inline ext4_rec_len_(to|from)_disk functions (Eric Sandeen) [522808]
- [netdrv] be2net: include latest upstream fixes (Ivan Vecera) [617187]

* Wed Aug 04 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-59.el6]
- [virt] Revert "[virt] vhost: create a vhost thread per device" (Aristeu Rozanski) [615118]

* Tue Aug 03 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-58.el6]
- [scsi] Update lpfc version for 8.3.5.17 driver release (Rob Evers) [612235]
- [scsi] Fix endian conversion for BlockGuard in IOCB response (Rob Evers) [612235]
- [scsi] Fixed a driver discovery issue where driver was unable to discover a target after Eveready back link bounce test (Rob Evers) [612235]
- [scsi] Update lpfc version for 8.3.5.16 driver release (Rob Evers) [612235]
- [scsi] Fixed BlockGuard endian conversion problem for supporting PowerPC EEH (Rob Evers) [612235]
- [scsi] Fixed VLAN ID 0xFFF set to reg_fcfi mailbox command on FCF empty FCF VLAN bitmap (Rob Evers) [612235]
- [scsi] Update lpfc version for 8.3.5.15 driver release (Rob Evers) [612235]
- [scsi] Fixed a race condition causing FLOGI issued from dual processes (Rob Evers) [612235]
- [scsi] Fix bug with ct response data not being sent with sli4 (Rob Evers) [612235]
- [scsi] Fixed RoundRobin FCF failover due to mis-interpretation of kernel find_next_bit (Rob Evers) [612235]
- [scsi] Enhanced round-robin FCF failover algorithm to re-start on new FCF async event (Rob Evers) [612235]
- [scsi] Clear Ignore Reg Login Flag when purging mailbox queue (Rob Evers) [612235]
- [scsi] Fix for ELS commands stuck on txq (Rob Evers) [612235]
- [scsi] Fix bug with unsolicited CT event command not setting a flag (Rob Evers) [612235]
- [drm] radeon/kms: fix possible mis-detection of sideport on rs690/rs740 (Jerome Glisse) [614583]
- [scsi] fcoe: remove check for zero fabric name (Mike Christie) [614264]
- [scsi] libfc: Add retry logic to lport state machine when receiving LS_RJT (Mike Christie) [614264]
- [scsi] fcoe: fix offload feature flag change from netdev (Mike Christie) [614264]
- [scsi] fcoe: adds src and dest mac address checking for fcoe frames (Mike Christie) [614264]
- [scsi] fcoe: cleans up fcoe_disable and fcoe_enable (Mike Christie) [614264]
- [scsi] lpfc Update from 8.3.5.13 to 8.3.5.14 FC/FCoE (Rob Evers) [603808]
- [fusion] mptfusion: release resources in error return path (Tomas Henzl) [618560]
- [scsi] IO error on SuperTrak EX4650 (Muuhh IKEDA) [593969]
- [virt] vhost: create a vhost thread per device (Michael S. Tsirkin) [615118]
- [kernel] workqueue: API to create a workqueue in cgroup (Michael S. Tsirkin) [615118]
- [cgroup] Add an API to attach a task to current task's cgroup (Michael S. Tsirkin) [615118]

* Tue Aug 03 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-57.el6]
- [mm] avoid stalling allocations by introducing watermark_wait (Rik van Riel) [589604]
- [mm] scale nr_rotated to balance memory pressure (Rik van Riel) [619384]
- [mm] fix anon memory statistics with transparent hugepages (Rik van Riel) [619384]
- [pci] avoid compiler warning in quirks.c (Alex Williamson) [619525]
- [pci] Fix build if quirks are not enabled (Alex Williamson) [619525]
- [pci] add Intel 82599 Virtual Function specific reset method (Alex Williamson) [619525]
- [pci] add Intel USB specific reset method (Alex Williamson) [619525]
- [pci] support device-specific reset methods (Alex Williamson) [619525]
- [kernel] Documentation: Update memory-hotplug documentation (Steve Best) [612579]
- [powerpc] Define memory_block_size_bytes() for ppc/pseries (Steve Best) [612579]
- [kernel] Update the node sysfs code (Steve Best) [612579]
- [kernel] Allow memory_block to span multiple memory sections (Steve Best) [612579]
- [kernel] Add section count to memory_block (Steve Best) [612579]
- [kernel] Add new phys_index properties (Steve Best) [612579]
- [kernel] Move the find_memory_block() routine up (Steve Best) [612579]
- [usb] xhci: rename driver to xhci_hcd (Don Zickus) [617217]
- [usb] kabi placeholders for xhci (Don Zickus) [617217]
- [fs] nfsd: minor nfsd_svc() cleanup (Jeff Layton) [599675]
- [fs] nfsd: move more into nfsd_startup() (Jeff Layton) [599675]
- [fs] nfsd: just keep single lockd reference for nfsd (Jeff Layton) [599675]
- [fs] nfsd: clean up nfsd_create_serv error handling (Jeff Layton) [599675]
- [fs] nfsd: fix error handling in __write_ports_addxprt (Jeff Layton) [599675]
- [fs] nfsd: fix error handling when starting nfsd with rpcbind down (Jeff Layton) [599675]
- [fs] nfsd4: fix v4 state shutdown error paths (Jeff Layton) [599675]
- [mm] page allocator: Update free page counters after pages are placed on the free list (Andrea Arcangeli) [614427]
- [mm] page allocator: Drain per-cpu lists after direct reclaim allocation fails (Andrea Arcangeli) [614427]
- [mm] vmstat: Actively update vmstat counters in low memory situations (Andrea Arcangeli) [614427]
- [kernel] mem-hotplug: fix potential race while building zonelist for new populated zone (John Villalovos) [581557]
- [kernel] mem-hotplug: avoid multiple zones sharing same boot strapping boot_pageset (John Villalovos) [581557]
- [kernel] cpu/mem hotplug: enable CPUs online before local memory online (John Villalovos) [581557]
- [mm] remove khugepaged young bit check (Andrea Arcangeli) [615381]

* Fri Jul 30 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-56.el6]
- [fs] GFS2: Backup plan for "vmalloc is slow" (Steven Whitehouse) [619331]
- [s390x] zfcp: Do not try "forced close" when port is already closed (Hendrik Brueckner) [612594]
- [s390x] zfcp: Do not unblock rport from REOPEN_PORT_FORCED (Hendrik Brueckner) [612597]
- [s390x] zfcp: Fix retry after failed "open port" erp action (Hendrik Brueckner) [612601]
- [s390x] zfcp: Fail erp after timeout (Hendrik Brueckner) [612618]
- [s390x] zfcp: Use forced_reopen in terminate_rport_io callback (Hendrik Brueckner) [612621]
- [s390x] zfcp: Register SCSI devices after fc_remote_port_add (Hendrik Brueckner) [612586]
- [scsi] sg: fix bio leak with a detached device (Matthew Garrett) [619103]
- [powerpc] hash_huge_page: pte_insert failed (Steve Best) [618831]
- [block] md: fix lock ordering problem (Doug Ledford) [616103]
- [fs] sysfs: add attribute to indicate hw address assignment type (Stefan Assmann) [614786]
- [infiniband] ehca: init irq tasklet before irq can happen (Steve Best) [617741]
- [netdrv] iwlwifi: fix scan abort (Stanislaw Gruszka) [619686]
- [powerpc] ONLINE to OFFLINE CPU state transition during removal (Steve Best) [619212]
- [fs] ext4: fix potential NULL dereference while tracing (Eric Sandeen) [619013]
- [infiniband] ehca: Catch failing ioremap() (Steve Best) [617747]
- [netdrv] Add missing read memory barrier to Intel Ethernet device (Steve Best) [617279]
- [netdrv] igb: Fix Tx hangs seen when loading igb with max_vfs > 7 (Stefan Assmann) [617214]
- [pci] Revert "[pci] update bridge resources to get more big ranges in PCI assign unssigned" (Shyam Iyer) [617007]
- [netdrv] cnic: Fix context memory init on 5709 (Stanislaw Gruszka) [616952]
- [virt] vmxnet3: fix network connectivity issues (Andy Gospodarek) [616252]
- [drm] i915: eDP/DP fixes from upstream (Dave Airlie) [615058]
- [ata] ata_piix: fix locking around SIDPR access (David Milburn) [608542]
- [md] Fix md raid partition detection update (Doug Ledford) [607477]
- [netdrv] e1000e: 82577/82578 PHY register access issues (Andy Gospodarek) [592480]
- [s390x] Remove PSF order/suborder check for dasd ioctl (John Feeney) [566183]
- [x86] kernel performance optimization with CONFIG_DEBUG_RODATA (Danny Feng) [557364]
- [netdrv] Revert "[Fedora] [e1000] add quirk for ich9" (Andy Gospodarek) [613196]
- [block] cfq: always return false from should_idle if slice_idle is set to zero (Jeff Moyer) [616904]
- [block] cfq/jbd: Fix fsync performance for small files (Jeff Moyer) [578515]

* Thu Jul 29 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-55.el6]
- [kernel] Add -Werror and WAR for bogus array bounds warnings (Prarit Bhargava) [603733]
- [pci] Remove pci_bus_dump_resources() (Prarit Bhargava) [613972]
- [fs] CIFS: Compile fix for malicious redirect fix (David Howells) [612136] {CVE-2010-2524}

* Tue Jul 27 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-54.el6]
- [block] Disable async multicore raid xor function (Doug Ledford) [596490]
- [kernel] taint: Add mark_hardware_unsupported() (Prarit Bhargava) [600509]
- [kernel] panic: Allow warnings to set different taint flags (Prarit Bhargava) [600509]
- [kernel] taint: Add taint padding and TAINT_HARDWARE_UNSUPPORTED (Prarit Bhargava) [600509]
- [mm] disable transparent hugepages by default on small systems (Rik van Riel) [618444]
- [net] Kernel lockups with bonding and IPV6 (Shyam Iyer) [614240]
- [x86] ACPI: Improve C3 residency (Matthew Garrett) [583792]
- [x86] cpufreq: pcc driver should check for pcch method before calling _OSC (Matthew Garrett) [616908]
- [x86] Add PCC Cpufreq driver (Matthew Garrett) [465354]
- [x86] Disable IOMMU graphics on Cantiga chipset (John Villalovos) [602207]
- [fs] vfsmount: pad for future fanotify support (Eric Paris) [320631]
- [ipmi] Run a dummy command before submitting a new command (Matthew Garrett) [616089]
- [block] mmc: Avoid hangs with mounted SD cards (Matthew Garrett) [615318]
- [md] Fix md raid partition detection (Doug Ledford) [607477]
- [ipmi] Make sure drivers were registered before unregistering them (Matthew Garrett) [601376]
- [s390x] Enhanced qeth for new network device type support (Hendrik Brueckner) [599650]
- [fs] cifs: fix security issue with dns_resolver upcall (David Howells) [612136] {CVE-2010-2524}

* Mon Jul 26 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-53.el6]
- [fs] xfs: track AGs with reclaimable inodes in per-ag radix tree (Dave Chinner) [617035]
- [fs] xfs: convert inode shrinker to per-filesystem contexts (Dave Chinner) [617035]
- [mm] add context argument to shrinker callback (Dave Chinner) [617035]
- [netdrv] enic: bug fix: make the set/get netlink VF_PORT support symmetrical (Andy Gospodarek) [609635]
- [netdrv] enic: Use random mac addr when associating port-profile (Andy Gospodarek) [609635]
- [netdrv] enic: bug fix: sprintf UUID to string as u8 rather than u16 array (Andy Gospodarek) [609635]
- [net] netlink: bug fix: don't overrun skbs on vf_port dump (Andy Gospodarek) [609635]
- [netdrv] enic: Bug Fix: Handle surprise hardware removals (Andy Gospodarek) [609635]
- [netdrv] enic: Bug Fix: Change hardware ingress vlan rewrite mode (Andy Gospodarek) [609635]
- [drm] nouveau: cleanup connector/encoder creation (Ben Skeggs) [612402]
- [drm] nouveau: move LVDS detection back to connector detect() time (Ben Skeggs) [612402]
- [net] add missing header needed for sunrpc tracepoints (Steve Dickson) [567741]
- [drm] nouveau: fix race condition when under memory pressure (Ben Skeggs) [602663]
- [tty] fix tty->pgrp races (Jiri Olsa) [586022] {CVE-2009-4895}
- [scsi] Log msg when getting Unit Attention (Mike Christie) [585432]
- [scsi] be2iscsi: Fix for 64K data (Mike Christie) [608795]
- [cgroups] Fix device cgroup not allowing access to a partition (Vivek Goyal) [589662]
- [audit] fix for audit misreporting return code on amd64 if we had to reschedule (Alexander Viro) [604993]
- [x86] Fix ioremap() so will boot on IA-32 system with PAE (John Feeney) [607029]
- [netdrv] macvtap: Limit packet queue length (Herbert Xu) [614119]
- [virt] vhost: avoid pr_err on condition guest can trigger (Michael S. Tsirkin) [607177]
- [mm] ksmd and khugepaged freezing (Andrea Arcangeli) [617430]
- [pci] Allow read/write access to sysfs I/O port resources (Alex Williamson) [616174]
- [netdrv] improve ipv6 pkt throughput with TSO (John Feeney) [613770]
- [netdrv] ixgbe: use GFP_ATOMIC when allocating FCoE DDP context from the dma pool (Andy Gospodarek) [614243]
- [netdrv] ixgbe: properly toggling netdev feature flags when disabling FCoE (Andy Gospodarek) [614243]
- [scsi] fcoe: remove vlan ID from WWPN (Neil Horman) [611974]
- [fs] xfs: fix corruption case for block size < page size (Dave Chinner) [581432]
- [fs] xfs: unregister inode shrinker before freeing filesystem structures (Dave Chinner) [607750]
- [drm] i915: add 'reclaimable' to i915 self-reclaimable page allocations (Dave Airlie) [616614]
- [drm] i915: fix 945GM stability issues on Lenovo T60 laptops (Dave Airlie) [568780]
- [security] SELinux: check OPEN on truncate calls (Eric Paris) [578841]
- [fs] ext4: Fix buffer dirtying in data=journal mode (Eric Sandeen) [602251]
- [fs] ext3: Fix buffer dirtying in data=journal mode (Eric Sandeen) [602251]

* Tue Jul 20 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-52.el6]
- [virt] Call mask notifiers from pic (Gleb Natapov) [608613]
- [virt] Convert mask notifiers to use irqchip/pin instead of gsi (Gleb Natapov) [608613]
- [virt] Reenter guest after instruction emulation failure if emulation was due to access to non-mmio address (Gleb Natapov) [608595]
- [virt] Return EFAULT from kvm ioctl when guest access bad area (Gleb Natapov) [608595]
- [drm] nouveau: fix dual-link displays when plugged into single-link outputs (Ben Skeggs) [615154]
- [drm] nv50: obey dcb->duallink_possible (Ben Skeggs) [615154]
- [drm] nv50: fix duallink_possible calculation for DCB 4.0 cards (Ben Skeggs) [615154]
- [mm] Rename ramzswap to zram in documentation (Jerome Marchand) [578641]
- [mm] Rename ramzswap to zram in code (Jerome Marchand) [578641]
- [mm] Rename ramzswap files to zram (Jerome Marchand) [578641]
- [mm] ramzswap: Support generic I_O requests (Jerome Marchand) [578641]
- [mm] ramzswap: Handler for swap slot free callback (Jerome Marchand) [578641]
- [mm] swap: Add swap slot free callback to block_device_operations (Jerome Marchand) [578641]
- [mm] swapfile: Add flag to identify block swap devices (Jerome Marchand) [578641]
- [mm] ramzswap: Remove backing swap support (Jerome Marchand) [578641]
- [drm] i915: Output IRQ setup fixes (Adam Jackson) [591709]
- [drm] nouveau: fix oops on chipsets that only have a single crtc (Ben Skeggs) [602290]
- [drm] i915: fix oops on single crtc devices (Dave Airlie) [610002]
- [drm] radeon: check/restore sanity before doing anything else with GPU (Dave Airlie) [612767]
- [fs] jbd2: Fix I/O hang in jbd2_journal_release_jbd_inode (Steve Best) [607254]
- [fs] GFS2: rename causes kernel Oops (Robert S Peterson) [614642]
- [ipmi] Provide kipmid_max_busy_us parameter to cap CPU usage (Shyam Iyer) [609156]
- [kernel] kprobes: "repz ret" causes bad EIP value crash (Dave Anderson) [607215]
- [pci] panic on access to hot-removed device's proc fs (Don Zickus) [612024]
- [pci] don't reassign to ROM res if it is not going to be enabled (Peter Bogdanovic) [612950]
- [x86] i386: Update CPU & Memory Hot Add Not Supported messages (Prarit Bhargava) [600435]
- [x86] nmi: limit hrtimer to lapic or ioapic mode (Don Zickus) [581722]
- [virt] emulator: inc/dec can have lock prefix (Gleb Natapov) [615925]
- [virt] Implement xen_panic_block notifier for RHEL6 Xen guests (Don Dutile) [614476]
- [virt] KVM: MMU: fix conflict access permissions in direct sp (Avi Kivity) [607650]
- [virt] vhost-net: avoid flush under lock (Michael S. Tsirkin) [612421]
- [netdrv] bnx2x: Don't report link down if has been already down (Stanislaw Gruszka) [610311]
- [netdrv] mac80211: improve error checking if WEP fails to init (John Linville) [608704]
- [netdrv] ath9k: cleanup init error path (John Linville) [610224]
- [mm] memcontrol: never oom when charging huge pages (Andrea Arcangeli) [608996]
- [mm] memcontrol: prevent endless loop with huge pages and near-limit group (Andrea Arcangeli) [608996]
- [virt] Xen PV-on-HVM: prevent null chip data ref ptr on newer xen hv (Don Dutile) [523134]
- [virt] Xen PV-on-HVM: modularize platform-pci support (Don Dutile) [523134]
- [virt] HPET: Do not disable hpet if not initialized (Don Dutile) [523134]
- [virt] Xen PV-on-HVM: suspend-resume-support (Don Dutile) [523134]
- [virt] Xen PV-on-HVM: refactor platform-pci, grant-table, enlighten support (Don Dutile) [523134 600360]
- [virt] Xen PV-on-HVM: update evtchn delivery on HVM (Don Dutile) [523134]
- [virt] Xen PV-on-HVM: update hvm_op hypercall & related h files to upstream (Don Dutile) [523134]

* Tue Jul 20 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-51.el6]
- [block] cciss: bump version 3626RH (Tomas Henzl) [609522]
- [block] cciss: cleanup compiletime warnings (Tomas Henzl) [609522]
- [block] cciss: do not reset 640x boards (Tomas Henzl) [609522]
- [block] cciss: fix hard reset (Tomas Henzl) [609522]
- [block] cciss: factor out reset devices code (Tomas Henzl) [609522]
- [block] cciss: factor out cciss find cfg addrs (Tomas Henzl) [609522]
- [block] cciss: factor out cciss wait for mode change ack (Tomas Henzl) [609522]
- [block] cciss: factor out cciss disable dma prefetch on p600 (Tomas Henzl) [609522]
- [block] cciss: factor out cciss enable scsi prefetch (Tomas Henzl) [609522]
- [block] cciss: factor out CISS signature present (Tomas Henzl) [609522]
- [block] cciss: factor out cciss find board params (Tomas Henzl) [609522]
- [block] cciss: factor out cciss find cfgtables (Tomas Henzl) [609522]
- [block] cciss: factor out cciss wait for board ready (Tomas Henzl) [609522]
- [block] cciss: factor out cciss find memory BAR (Tomas Henzl) [609522]
- [block] cciss: remove board-id param from cciss interrupt mode (Tomas Henzl) [609522]
- [block] cciss: factor out cciss_board_disabled (Tomas Henzl) [609522]
- [block] cciss: factor out cciss lookup board id (Tomas Henzl) [609522]
- [block] cciss: save pdev early to avoid passing it around (Tomas Henzl) [609522]
- [audit] dynamically allocate audit_names when not enough space is in the names array (Eric Paris) [586108]
- [mm] mmu notifier index huge spte fix (Andrea Arcangeli) [606131]
- [x86] Update x86 MCE code part 2 (Prarit Bhargava) [580587]
- [kernel] execshield: respect disabled randomization (Roland McGrath) [605516]
- [scsi] mpt2sas: Fix to use sas device list instead of enclosure list (Tomas Henzl) [599049]
- [kernel] disable kmemleak by default for -debug kernels (Jason Baron) [612244]

* Thu Jul 15 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-50.el6]
- [net] CHECKSUM: header export and fixup (Michael S. Tsirkin) [605555]
- [pci] iommu/intel: Disable IOMMU for graphics if BIOS is broken (Adam Jackson) [593516]
- [fs] xfs: remove block number from inode lookup code (Jiri Pirko) [607031]
- [fs] xfs: rename XFS_IGET_BULKSTAT to XFS_IGET_UNTRUSTED (Jiri Pirko) [607031]
- [fs] xfs: validate untrusted inode numbers during lookup (Jiri Pirko) [607031]
- [fs] xfs: always use iget in bulkstat (Jiri Pirko) [607031]
- [igb] avoid platform reset and MCE with DCA (Stefan Assmann) [572732 606687]
- [drm] nouveau: downgrade severity of most init table parser errors (Ben Skeggs) [596679]
- [drm] nouveau: INIT_CONFIGURE_PREINIT/CLK/MEM on newer BIOSes is not an error (Ben Skeggs) [596679]
- [netdrv] enic: Replace LRO with GRO (Andy Gospodarek) [609635]
- [net] decreasing real_num_tx_queues needs to flush qdisc (Andy Gospodarek) [609260]
- [net] sched: qdisc_reset_all_tx is calling qdisc_reset without qdisc_lock (Andy Gospodarek) [609260]
- [fs] inotify: send IN_UNMOUNT events (Eric Paris) [580825]
- [fs] inotify: fix inotify oneshot support (Eric Paris) [614595]
- [s390x] zfcp: Zero memory for gpn_ft and adisc requests (Hendrik Brueckner) [609537]
- [s390x] zfcp: Do not escalate scsi eh after fast_io_fail_tmo fired (Hendrik Brueckner) [606365]
- [s390x] zfcp: Remove SCSI device during unit_remove (Hendrik Brueckner) [589278]
- [scsi] Allow FC LLD to fast-fail scsi eh by introducing new eh return (Hendrik Brueckner) [606365]
- [s390x] zfcp: Do not wait for SBALs on stopped queue (Hendrik Brueckner) [606359]
- [x86] efi: Fill all reserved memmap entries if add_efi_memmap specified (George Beshers) [607386]

* Wed Jul 14 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-49.el6]
- [edac] i7core_edac: Avoid doing multiple probes for the same card (Mauro Carvalho Chehab) [604564]
- [edac] i7core_edac: Properly discover the first QPI device (Mauro Carvalho Chehab) [604564]
- [usb] Disable XHCI (USB 3) HCD module autoloading (Matthew Garrett) [608343]
- [fs] xfs: prevent swapext from operating on write-only files (Jiri Pirko) [605162] {CVE-2010-2226}
- [powerpc] Add symbols to kernel to allow makedumpfile to filter on ppc64 (Neil Horman) [611710]
- [net] netfilter: add CHECKSUM target (Michael S. Tsirkin) [605555]
- [security] audit: dynamically allocate audit_names when not enough space is in the names array (Eric Paris) [586108]
- [pci] iommu/intel: Disable IOMMU for graphics if BIOS is broken (Adam Jackson) [593516]
- [virt] stop vpit before irq_routing freed (Gleb Natapov) [612648]
- [netdrv] Allow for BCM5709S to dump vmcore via NFS (John Feeney) [577809]
- [netdrv] igb: drop support for UDP hashing w/ RSS (Stefan Assmann) [613782]
- [netdrv] mac80211: remove wep dependency (John Linville) [608704]
- [mm] fix swapin race conditions (Andrea Arcangeli) [606131]
- [crypto] authenc: Add EINPROGRESS check (Stanislaw Gruszka) [604611]
- [fs] inotify: don't leak user struct on inotify release (Stanislaw Gruszka) [592399 604611]
- [x86] amd: Check X86_FEATURE_OSVW bit before accessing OSVW MSRs (Stanislaw Gruszka) [604611]
- [kernel] profile: fix stats and data leakage (Stanislaw Gruszka) [604611]
- [sound] ice1724: Fix ESI Maya44 capture source control (Stanislaw Gruszka) [604611]
- [mm] hugetlbfs: kill applications that use MAP_NORESERVE with SIGBUS instead of OOM-killer (Stanislaw Gruszka) [604611]
- [dma] dma-mapping: fix dma_sync_single_range_* (Stanislaw Gruszka) [604611]
- [hwmon] hp_accel: fix race in device removal (Stanislaw Gruszka) [604611]
- [net] ipv4: udp: fix short packet and bad checksum logging (Stanislaw Gruszka) [604611]

* Tue Jul 13 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-48.el6]
- [scsi] SCSI: Retry commands with UNIT_ATTENTION sense codes to fix ext3/ext4 I/O error (Stanislaw Gruszka) [604610]
- [scsi] Enable retries for SYNCRONIZE_CACHE commands to fix I/O error (Stanislaw Gruszka) [604610]
- [scsi] debug: virtual_gb ignores sector_size (Stanislaw Gruszka) [604610]
- [x86] acpi power_meter: acpi_device_class "power_meter_resource" too long (Stanislaw Gruszka) [604610]
- [v4l] budget: Oops: "BUG: unable to handle kernel NULL pointer dereference" (Stanislaw Gruszka) [604610]
- [virt] virtio: initialize earlier (Stanislaw Gruszka) [604610]
- [security] testing the wrong variable in create_by_name() (Stanislaw Gruszka) [604610]
- [netdrv] r8169: more broken register writes workaround (Stanislaw Gruszka) [604610]
- [netdrv] r8169: fix broken register writes (Stanislaw Gruszka) [604610]
- [netdrv] r8169: use correct barrier between cacheable and non-cacheable memory (Stanislaw Gruszka) [604610]
- [kernel] kgdb: don't needlessly skip PAGE_USER test for Fsl booke (Stanislaw Gruszka) [604610]
- [kernel] initramfs: handle unrecognised decompressor when unpacking (Stanislaw Gruszka) [604610]
- [sound] snd-meastro3: Ignore spurious HV interrupts during suspend / resume (Stanislaw Gruszka) [604610]
- [sound] snd-meastro3: Add amp_gpio quirk for Compaq EVO N600C (Stanislaw Gruszka) [604610]
- [x86] Disable large pages on CPUs with Atom erratum AAE44 (Stanislaw Gruszka) [604610]
- [x86] x86-64: Clear a 64-bit FS/GS base on fork if selector is nonzero (Stanislaw Gruszka) [604610]
- [edac] mce: Fix wrong mask and macro usage (Stanislaw Gruszka) [604610]
- [netdrv] p54pci: fix bugs in p54p_check_tx_ring (Stanislaw Gruszka) [604610]
- [netdrv] dm9601: fix phy/eeprom write routine (Stanislaw Gruszka) [604610]
- [block] ensure jiffies wrap is handled correctly in blk_rq_timed_out_timer (Stanislaw Gruszka) [604610]
- [serial] 8250_pnp: add Fujitsu Wacom device (Stanislaw Gruszka) [604610]
- [block] raid6: fix recovery performance regression (Stanislaw Gruszka) [604610]
- [fs] procfs: fix tid fdinfo (Stanislaw Gruszka) [604610]
- [usb] xhci: properly set endpoint context fields for periodic eps (Stanislaw Gruszka) [604610]
- [usb] xhci: properly set the "Mult" field of the endpoint context (Stanislaw Gruszka) [604610]
- [usb] OHCI: don't look at the root hub to get the number of ports (Stanislaw Gruszka) [604610]
- [usb] don't choose configs with no interfaces (Stanislaw Gruszka) [604610]
- [usb] fix testing the wrong variable in fs_create_by_name() (Stanislaw Gruszka) [604610]
- [usb] Add id for HP ev2210 a.k.a Sierra MC5725 miniPCI-e Cell Modem (Stanislaw Gruszka) [604610]
- [usb] fix remote wakeup settings during system sleep (Stanislaw Gruszka) [604610]
- [mm] hugetlb: fix infinite loop in get_futex_key() when backed by huge pages (Stanislaw Gruszka) [604610]
- [kernel] flex_array: fix the panic when calling flex_array_alloc() without __GFP_ZERO (Stanislaw Gruszka) [604610]
- [netdrv] mac80211: remove bogus TX agg state assignment (Stanislaw Gruszka) [604610]
- [ata] libata: fix locking around blk_abort_request() (Stanislaw Gruszka) [604610]
- [netdrv] p54usb: Add usbid for Corega CG-WLUSB2GT (Stanislaw Gruszka) [604610]
- [usb] EHCI: defer reclamation of siTDs (Stanislaw Gruszka) [604610]
- [drm] nouveau: initialise display before enabling interrupts (Ben Skeggs) [596703]
- [drm] nv50: fix DP->DVI if output has been programmed for native DP previously (Ben Skeggs) [596703]
- [block] dm ioctl: return uevent flag after rename (Mike Snitzer) [609591]
- [block] dm ioctl: make __dev_status return void (Mike Snitzer) [609591]
- [block] dm ioctl: remove __dev_status from geometry and target message (Mike Snitzer) [609591]
- [infiniband] mlx4: enable IBoE feature (Doug Ledford) [529397]
- [dm] dm-replicator: Fix replicator_ctr() error path (Heinz Mauelshagen) [612743]
- [virt] vmware: disable NMI watchdog in guest (Don Zickus) [612321]
- [virt] KVM: Expose MCE control MSRs to userspace (Avi Kivity) [558416]

* Mon Jul 12 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-47.el6]
- [x86] eeepc-laptop: disable cpu speed control on EeePC 701 (Stanislaw Gruszka) [604608]
- [x86] gart: Disable GART explicitly before initialization (Stanislaw Gruszka) [604608]
- [netdrv] r8169: clean up my printk uglyness (Stanislaw Gruszka) [604608]
- [input] wacom: switch mode upon system resume (Stanislaw Gruszka) [604608]
- [fs] eCryptfs: Decrypt symlink target for stat size (Stanislaw Gruszka) [604608]
- [usb] cdc-acm: Update to new autopm API (Stanislaw Gruszka) [604608]
- [netdrv] e1000e: stop cleaning when we reach tx_ring->next_to_use (Stanislaw Gruszka) [604608]
- [kernel] sched: Fix a race between ttwu() and migrate_task() (Stanislaw Gruszka) [604608]
- [fs] ecryptfs: fix error code for missing xattrs in lower fs (Stanislaw Gruszka) [604608]
- [pci] fix nested spinlock hang in aer_inject (Stanislaw Gruszka) [604608]
- [fs] ecryptfs: fix use with tmpfs by removing d_drop from ecryptfs_destroy_inode (Stanislaw Gruszka) [604608]
- [scsi] add scsi target reset support to scsi ioctl (Stanislaw Gruszka) [604608]
- [pci] PCIe AER: prevent AER injection if hardware masks error reporting (Stanislaw Gruszka) [604608]
- [fs] quota: Fix possible dq_flags corruption (Stanislaw Gruszka) [604608]
- [fs] fix NFS4 handling of mountpoint stat (Stanislaw Gruszka) [604608]
- [agp] intel-agp: Switch to wbinvd_on_all_cpus (Stanislaw Gruszka) [604608]
- [drm] radeon/kms: add FireMV 2400 PCI ID (Stanislaw Gruszka) [604608]
- [x86] amd-iommu: Use helper function to destroy domain (Stanislaw Gruszka) [604608]
- [hwmon] sht15: Fix sht15_calc_temp interpolation function (Stanislaw Gruszka) [604608]
- [hwmon] sht15: Properly handle the case CONFIG_REGULATOR=n (Stanislaw Gruszka) [604608]
- [ata] libata: disable NCQ on Crucial C300 SSD (Stanislaw Gruszka) [604608]
- [x86] thinkpad-acpi: lock down video output state access (Stanislaw Gruszka) [604608]
- [x86] thinkpad-acpi: convert to seq_file (Stanislaw Gruszka) [604608]
- [sound] usb: Fix Oops after usb-midi disconnection (Stanislaw Gruszka) [604608]
- [x86] thinkpad-acpi: log initial state of rfkill switches (Stanislaw Gruszka) [604608]
- [x86] thinkpad-acpi: use input_set_capability (Stanislaw Gruszka) [604608]
- [x86] thinkpad-acpi: expose module parameters (Stanislaw Gruszka) [604608]
- [fs] ext3: Don't update the superblock in ext3_statfs() (Stanislaw Gruszka) [604608]
- [x86] thinkpad-acpi: log temperatures on termal alarm (Stanislaw Gruszka) [604608]
- [x86] thinkpad-acpi: adopt input device (Stanislaw Gruszka) [604608]
- [x86] thinkpad-acpi: issue backlight class events (Stanislaw Gruszka) [604608]
- [x86] thinkpad-acpi: silence bogus complain during rmmod (Stanislaw Gruszka) [604608]
- [x86] thinkpad-acpi: fix some version quirks (Stanislaw Gruszka) [604608]
- [kernel] resource: move kernel function inside __KERNEL__ (Stanislaw Gruszka) [604608]
- [fs] ext3: journal all modifications in ext3_xattr_set_handle (Stanislaw Gruszka) [604608]
- [video] backlight: mbp_nvidia_bl - add five more MacBook variants (Stanislaw Gruszka) [604608]
- [sound] mixart: range checking proc file (Stanislaw Gruszka) [604608]
- [hid] fix oops in gyration_event() (Stanislaw Gruszka) [604608]
- [ata] pata_ali: Fix regression with old devices (Stanislaw Gruszka) [604608]
- [hwmon] lis3: fix show rate for 8 bits chips (Stanislaw Gruszka) [604608]
- [cgroup] freezer: Fix buggy resume test for tasks frozen with cgroup freezer (Stanislaw Gruszka) [604608]
- [kernel] genirq: Force MSI irq handlers to run with interrupts disabled (Stanislaw Gruszka) [604608]
- [fs] fat: fix buffer overflow in vfat_create_shortname() (Stanislaw Gruszka) [604608]
- [netdrv] mlx4: add dynamic LRO disable support (Amerigo Wang) [584359]
- [netdrv] s2io: add dynamic LRO disable support (Amerigo Wang) [584359]
- [drm] nv50: rewrite display irq handler (Ben Skeggs) [598842]
- [drm] nv50: send evo "update" command after each disconnect (Ben Skeggs) [598842]
- [drm] nv50: when debugging on, log which crtc we connect an encoder to (Ben Skeggs) [598842]
- [drm] nv50: supply encoder disable() hook (Ben Skeggs) [598842]
- [drm] disable encoder rather than dpms off in drm_crtc_prepare_encoders() (Ben Skeggs) [598842]
- [drm] nv50: DCB quirk for Dell M6300 (Ben Skeggs) [598842]
- [fs] writeback: limit write_cache_pages integrity scanning to current EOF (Dave Chinner) [602490]
- [fs] xfs: remove nr_to_write writeback windup. (Dave Chinner) [602490]
- [fs] writeback: pay attention to wbc->nr_to_write in write_cache_pages (Eric Sandeen) [602490]

* Mon Jul 12 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-46.el6]
- [fs] ext4: stop issuing discards if not supported by device (Eric Sandeen) [608731]
- [block] dm: only initialize full request_queue for request-based device (Mike Snitzer) [595393]
- [block] dm: prevent table type changes after initial table load (Mike Snitzer) [595393]
- [dm] skip second flush if request unsupported (Mike Snitzer) [612014]
- [dm] only ignore -EOPNOTSUPP for empty barrier requests (Mike Snitzer) [612014]
- [dm] snapshot: implement a merge method for snapshot origin (Mike Snitzer) [612375]
- [dm] snapshot: test chunk size against both origin and snapshot sector size (Mike Snitzer) [612375]
- [dm] snapshot: open origin before exception store initialization (Mike Snitzer) [612375]
- [dm] snapshot: iterate both the origin and snapshot devices (Mike Snitzer) [612375]
- [block] dm: support discard if at least one underlying device supports it (Mike Snitzer) [612014]
- [block] dm: support discard for multiple devices (Mike Snitzer) [612014]
- [block] dm: clear the discard flag if the device loses discard capability (Mike Snitzer) [612014]
- [block] dm: check that target supports discard just before submitting request (Mike Snitzer) [612014]
- [scsi] convert discard to REQ_TYPE_FS instead of REQ_TYPE_BLOCK_PC (Mike Snitzer) [610054]
- [scsi] fix leak in scsi_setup_discard_cmnd error path (Mike Snitzer) [610054]
- [scsi] remove unused free discard page in sd_done (Mike Snitzer) [610054]
- [scsi] add sd_unprep_fn to free discard page (Mike Snitzer) [610054]
- [block] implement an unprep function corresponding directly to prep (Mike Snitzer) [610054]
- [block] don't allocate a payload for discard request (Mike Snitzer) [610054]
- [fs] ext4: move aio completion after unwritten extent conversion (Christoph Hellwig) [589985]
- [fs] xfs: move aio completion after unwritten extent conversion (Christoph Hellwig) [589985]
- [fs] direct-io: move aio_complete into ->end_io (Christoph Hellwig) [589985]
- [drm] radeon/kms/igp: fix possible divide by 0 in bandwidth code (Dave Airlie) [609755]
- [drm] nouveau: disable acceleration on NVA3/NVA5/NVA8 by default (Ben Skeggs) [591062]
- [drm] vt/fbcon: try harder to print output when panicing (Dave Airlie) [579002]
- [fs] GFS2: fix BUG in gfs2_adjust_quota (Abhijith Das) [603827]
- [fs] nfsd: nfsd_setattr needs to call commit_metadata (Christoph Hellwig) [593652]
- [net] netfilter: remove config option NF_CT_ACCT completely (Jiri Pirko) [578476]
- [net] Revert "[net] bonding: make bonding support netpoll" (Andy Gospodarek) [604672]
- [scsi] stex: fix inconsistent usage of max_lun (David Milburn) [593255]
- [kernel] sched: Kill migration thread in CPU_POST_DEAD event in migration_call, instead of CPU_DEAD (Steve Best) [604846]
- [tracing] ftrace: fix function_graph livelock under kvm (Jason Baron) [596653]
- [block] dm: mpath fix NULL pointer dereference when path parameters missing (Mike Snitzer) [607242]
- [dm] dm-replicator: mandatory API change for replicator_resume(), replicator_dev_resume() and reference count fix calling dm_table_get_md() (Heinz Mauelshagen) [594922]
- [x86] AMD IOMMU: change default to passthrough mode (Bhavna Sarathy) [607631]
- [x86] dell-laptop: Add another Dell laptop family to the DMI whitelist (Matthew Garrett) [609268]
- [netdrv] cnic: fix bnx2x panics with multiple interfaces enabled (Stanislaw Gruszka) [609184]
- [mm] fix khugepaged startup race (Andrea Arcangeli) [612217]
- [mm] add robustness to pmd_same checks (Andrea Arcangeli) [607650]
- [mm] Fix vmalloc slow down (Steven Whitehouse) [583026]

* Mon Jul 12 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-45.el6]
- [drm] i915: fix display setup bugs + hibernate (Dave Airlie) [608515 609763]
- [fs] NFSv4: Fix an embarassing typo in encode_attrs() (Steve Dickson) [560786]
- [fs] NFSv4: Ensure that /proc/self/mountinfo displays the minor version number (Steve Dickson) [560786]
- [fs] NFSv4.1: Ensure that we initialise the session when following a referral (Steve Dickson) [560786]
- [fs] SUNRPC: Fix a re-entrancy bug in xs_tcp_read_calldir() (Steve Dickson) [560786]
- [fs] nfs4: use mandatory attribute file type in nfs4_get_root (Steve Dickson) [560786]
- [x86] UV: uv_irq.c: Fix all sparse warnings (George Beshers) [573095]
- [x86] uv: Remove recursion in uv_heartbeat_enable() (George Beshers) [573095]
- [x86] pat: Update the page flags for memtype atomically instead of using memtype_lock (George Beshers) [573095]
- [x86] UV: Improve BAU performance and error recovery (George Beshers) [573095]
- [mm] ksm.c: remove an unneeded _notify in write_protect_page (George Beshers) [573095]
- [x86] UV: Delete unneeded boot messages (George Beshers) [573095]
- [x86] UV: Fix target_cpus() in x2apic_uv_x.c (George Beshers) [573095]
- [x86] UV: Clean up UV headers for MMR definitions (George Beshers) [573095]
- [x86] Enable NMI on all cpus on UV (George Beshers) [573095]
- [x86] uv: Add serial number parameter to uv_bios_get_sn_info() (George Beshers) [573095]
- [virt] xen: sync upstream xen_init_cpuid_mask (Andrew Jones) [609028]
- [virt] xen: disable gbpages on pv guests (Andrew Jones) [609028]
- [virt] KVM: Fix mov cr3 #GP at wrong instruction (Marcelo Tosatti) [611889]
- [virt] KVM: Fix mov cr4 #GP at wrong instruction (Marcelo Tosatti) [611889]
- [virt] KVM: Fix mov cr0 #GP at wrong instruction (Marcelo Tosatti) [611889]
- [virt] KVM: Add missing srcu_read_lock() for kvm_mmu_notifier_release() (Marcelo Tosatti) [601320]
- [virt] KVM: limit the number of pages per memory slot (Marcelo Tosatti) [601318]
- [virt] KVM: MMU: Remove user access when allowing kernel access to gpte.w=0 page (Marcelo Tosatti) [601316]
- [virt] KVM: x86: Add missing locking to arch specific vcpu ioctls (Marcelo Tosatti) [601313]
- [virt] KVM: MMU: remove rmap before clear spte (Marcelo Tosatti) [601311]
- [virt] KVM: MMU: Segregate shadow pages with different cr0.wp (Marcelo Tosatti) [601308]
- [virt] KVM: x86: Check LMA bit before set_efer (Marcelo Tosatti) [601307]
- [virt] KVM: Dont allow lmsw to clear cr0.pe (Marcelo Tosatti) [601305]
- [virt] KVM: VMX: blocked-by-sti must not defer NMI injections (Marcelo Tosatti) [601304]
- [virt] KVM: x86: Call vcpu_load and vcpu_put in cpuid_update (Marcelo Tosatti) [601303]
- [virt] KVM: x86: Inject #GP with the right rip on efer writes (Marcelo Tosatti) [601301]
- [virt] KVM: MMU: Dont read pdptrs with mmu spinlock held in mmu_alloc_roots (Marcelo Tosatti) [601300]
- [virt] KVM: x86: properly update ready_for_interrupt_injection (Marcelo Tosatti) [601298]
- [virt] KVM: VMX: enable VMXON check with SMX enabled (Marcelo Tosatti) [601297]
- [virt] KVM: VMX: free vpid when fail to create vcpu (Marcelo Tosatti) [601292]
- [virt] vhost: add unlikely annotations to error path (Michael S. Tsirkin) [602607]
- [virt] vhost: break out of polling loop on error (Michael S. Tsirkin) [602607]

* Wed Jul 07 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-44.el6]
- [mm] Prevent soft lockup - CPU#0 stuck for 61s! in kswapd0 (Larry Woodman) [596971]

* Tue Jul 06 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-43.el6]
- [x86] properly account for IRQ injected only into BSP (Gleb Natapov) [609082]

* Wed Jun 30 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-42.el6]
- [block] writeback: simplify the write back thread queue (Christoph Hellwig) [602595]

* Tue Jun 29 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-41.el6]
- [mm] Fix slabcache corruption (Larry Woodman) [602595]

* Tue Jun 29 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-40.el6]
- [infiniband] Add IBoE support (Doug Ledford) [571959]
- [scsi] hpsa: don't pretend the reset works (Tomas Henzl) [598681]
- [fs] revert "procfs: provide stack information for threads" and its fixup commits (George Beshers) [573095]
- [x86] mce: Fix MSR_IA32_MCI_CTL2 CMCI threshold setup (John Villalovos) [593558]
- [s390x] cio: use exception-save stsch (Hendrik Brueckner) [596333]
- [s390x] cio: add hook to reenable mss after hibernation (Hendrik Brueckner) [596333]
- [s390x] cio: allow enable_facility from outside init functions (Hendrik Brueckner) [596333]
- [x86] wmi: Free the allocated acpi objects through wmi_get_event_data (Stanislaw Gruszka) [606736]
- [mtd] UBI: fix volume creation input checking (Stanislaw Gruszka) [606736]
- [mm] avoid THP expose VM bugs (Andrea Arcangeli) [606131]
- [dm] discard support for the linear target (Mike Snitzer) [608280]
- [block] fix DISCARD_BARRIER requests (Mike Snitzer) [608280]
- [block] Don't count_vm_events for discard bio in submit_bio (Mike Snitzer) [608280]

* Tue Jun 29 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-39.el6]
- [x86] disable PentiumPro memory ordering errata workaround (Gleb Natapov) [605745 606054]
- [net] Bluetooth: Keep a copy of each HID device's report descriptor (Mauro Carvalho Chehab) [565583]
- [hid] make Wacom modesetting failures non-fatal (Mauro Carvalho Chehab) [565583]
- [hid] Implement Wacom quirk in the kernel (Mauro Carvalho Chehab) [565583]
- [hid] make raw reports possible for both feature and output reports (Mauro Carvalho Chehab) [565583]
- [kernel] resources: fix call to alignf() in allocate_resource() (Peter Bogdanovic) [587729]
- [kernel] resources: when allocate_resource() fails, leave resource untouched (Peter Bogdanovic) [587729]
- [pci] introduce pci_assign_unassigned_bridge_resources (Peter Bogdanovic) [587729]
- [pci] update bridge resources to get more big ranges in PCI assign unssigned (Peter Bogdanovic) [587729]
- [pci] add failed_list to pci_bus_assign_resources (Peter Bogdanovic) [587729]
- [pci] add pci_bridge_release_resources and pci_bus_release_bridge_resources (Peter Bogdanovic) [587729]
- [kernel] resource: add release_child_resources (Peter Bogdanovic) [587729]
- [pci] separate pci_setup_bridge to small functions (Peter Bogdanovic) [587729]
- [scsi] aacraid: Disable ASPM by default (Matthew Garrett) [599735]
- [pci] Don't enable aspm before drivers have had a chance to veto it (Matthew Garrett) [599735]
- [netdrv] ehea: Fix kernel deadlock in DLPAR-mem processing (Steve Best) [605736]
- [netdrv] ehea: fix delayed packet processing (Steve Best) [605738]
- [netdrv] ehea: fix possible DLPAR/mem deadlock (Steve Best) [600516]
- [netdrv] ehea: error handling improvement (Steve Best) [600516]
- [x86] Fall back to GART if initialization fails (Bhavna Sarathy) [598974]
- [x86] AMD IOMMU memory region fail with buggy BIOS (Bhavna Sarathy) [598974]
- [virt] Search the LAPIC's for one that will accept a PIC interrupt (Christopher Lalancette) [596223]
- [virt] KVM: x86: Kick VCPU outside PIC lock again (Christopher Lalancette) [596223]
- [virt] KVM: x86: In DM_LOWEST, only deliver interrupts to vcpus with enabled LAPIC's (Christopher Lalancette) [596223]
- [virt] KVM: x86: Allow any LAPIC to accept PIC interrupts (Christopher Lalancette) [596223]
- [virt] KVM: x86: Introduce a workqueue to deliver PIT timer interrupts (Christopher Lalancette) [596223]
- [scsi] ibmvfc: Reduce error recovery timeout (Steve Best) [605729]
- [scsi] ibmvfc: Fix command completion handling (Steve Best) [605729]
- [powerpc] Enable asymmetric SMT scheduling on POWER7 (Steve Best) [596304]
- [kernel] sched: Add asymmetric group packing option for sibling domain (Steve Best) [596304]
- [kernel] sched: Fix capacity calculations for SMT4 (Steve Best) [596304]
- [fs] Btrfs: update to latest upstream code (Josef Bacik) [593834]
- [fs] direct-io: do not merge logically non-contiguous requests (Josef Bacik) [593834]
- [fs] direct-io: add a hook for the fs to provide its own submit_bio function (Josef Bacik) [593834]
- [fs] allow short direct-io reads to be completed via buffered IO (Josef Bacik) [593834]
- [fs] GFS2: O_TRUNC not working on stuffed files across cluster (Robert S Peterson) [606428]
- [nfs] nfsd4: shut down callback queue outside state lock (Jeff Layton) [599522]
- [security] IMA: policy handling and general cleanups (Eric Paris) [584901]
- [security] IMA: fix object lifetime to support non ext* FS (Eric Paris) [584901]
- [netdrv] be2net: Include latest fixes from upstream (Ivan Vecera) [604729]
- [netdrv] be2net: Add PCI SR-IOV support (Ivan Vecera) [602451]
- [scsi] hpsa: do not allow hard reset of 640x-boards (Tomas Henzl) [598681]
- [scsi] hpsa: fix hard reset (Tomas Henzl) [598681]
- [scsi] hpsa: reset devices code (Tomas Henzl) [598681]
- [scsi] hpsa: find cfg addrs (Tomas Henzl) [598681]
- [scsi] hpsa: finding the memory BAR (Tomas Henzl) [598681]
- [scsi] hpsa: look up the board id (Tomas Henzl) [598681]
- [x86] uv: uv_global_gru_mmr_address() macro fix (George Beshers) [607696]
- [crypto] vmac: make it work on big-endian (Jarod Wilson) [605688]
- [net] ipvs: One-Packet Scheduler (Thomas Graf) [584336]
- [drm] i915: Disable Sandybridge support for 6.0 (Adam Jackson) [604838 605302]
- [netdrv] vxge: fix memory leak in vxge_alloc_msix() error path (Michal Schmidt) [580392]
- [netdrv] vxge: fix SINGLE/MULTI_FUNCTION definitions (Michal Schmidt) [580392]
- [netdrv] vxge: update to 2.0.8.20182-k (Michal Schmidt) [580392]
- [sound] fix PCM ring buffer issues (Jaroslav Kysela) [574844 590159 600311]
- [netdrv] e1000/e1000e: implement a simple interrupt moderation (Andy Gospodarek) [607283]
- [netdrv] e1000e: add PCI device id to enable support for 82567V-4 (Andy Gospodarek) [607264]
- [netdrv] e1000e: update driver version number (Andy Gospodarek) [582803]
- [netdrv] e1000e: enable support for EEE on 82579 (Andy Gospodarek) [582803]
- [netdrv] e1000e: initial support for 82579 LOMs (Andy Gospodarek) [582803]
- [netdrv] e1000e: move settting of flow control refresh timer to link setup code (Andy Gospodarek) [582803]
- [netdrv] e1000e: Fix/cleanup PHY reset code for ICHx/PCHx (Andy Gospodarek) [582803]
- [netdrv] e1000e: fix check for manageability on ICHx/PCH (Andy Gospodarek) [582803]
- [netdrv] e1000e: separate out PHY statistics register updates (Andy Gospodarek) [582803]
- [netdrv] e1000e: more cleanup e1000_sw_lcd_config_ich8lan() (Andy Gospodarek) [582803]
- [netdrv] e1000e: cleanup e1000_sw_lcd_config_ich8lan() (Andy Gospodarek) [582803]
- [netdrv] e1000e: cleanup ethtool loopback setup code (Andy Gospodarek) [582803]
- [netdrv] e1000e: reset MAC-PHY interconnect on 82577/82578 (Andy Gospodarek) [582803]
- [netdrv] e1000e: Incorrect function pointer set for force_speed_duplex on 82577 (Andy Gospodarek) [598570]
- [netdrv] e1000e: Reset 82577/82578 PHY before first PHY register read (Andy Gospodarek) [598570]
- [fs] GFS2: Fix kernel NULL pointer dereference by dlm_astd (Robert S Peterson) [604244]
- [fs] GFS2: recovery stuck on transaction lock (Robert S Peterson) [590878]
- [netdrv] tg3: Include support for 5719 device (John Feeney) [595511]
- [mm] Do not attempt to allocate memory below mmap_min_addr (Eric Paris) [540333]
- [scsi] qla2xxx: Updated driver version to 8.03.01.05.06.0-k8 (Chad Dupuis) [595477]
- [scsi] qla2xxx: Add portid to async-request messages (Chad Dupuis) [595477]
- [scsi] qla2xxx: Propogate transport disrupted status for cable pull conditions for faster failover (Chad Dupuis) [595477]
- [scsi] qla2xxx: Do not restrict flash operations to specific regions for 4G adapters (Chad Dupuis) [595477]
- [scsi] qla2xxx: For ISP 23xx, select user specified login timeout value if greater than minuimum value(4 secs) (Chad Dupuis) [595477]
- [scsi] qla2xxx: Removed redundant check for ISP 84xx (Chad Dupuis) [595477]
- [scsi] qla2xxx: Do not enable VP in non fabric topology (Chad Dupuis) [595477]
- [scsi] qla2xxx: Make the FC port capability mutual exclusive (Chad Dupuis) [595477]
- [scsi] qla2xxx: Limit rport-flaps during link-disruptions (Chad Dupuis) [595477]
- [scsi] qla2xxx: Correct async-srb issues (Chad Dupuis) [595477]
- [scsi] qla2xxx: Correct use-after-free oops seen during EH-abort (Chad Dupuis) [595477]
- [scsi] qla2xxx: Fix cpu-affinity usage for non-capable ISPs (Chad Dupuis) [595477]
- [scsi] qla2xxx: Limit mailbox command contention for ADISC requests (Chad Dupuis) [595477]
- [scsi] qla2xxx: Further generalization of SRB CTX infrastructure (Chad Dupuis) [595477]
- [scsi] qla2xxx: ensure flash operation and host reset via sg_reset are mutually exclusive (Chad Dupuis) [595477]
- [scsi] qla2xxx: Prevent sending mbx commands from sysfs during isp reset (Chad Dupuis) [595477]
- [scsi] qla2xxx: Cleanup FCP-command-status processing debug statements (Chad Dupuis) [595477]
- [scsi] qla2xxx: Clear error status after uncorrectable non-fatal errors (Chad Dupuis) [595477]
- [scsi] qla2xxx: Add char device to incease driver use count (Chad Dupuis) [595477]
- [scsi] qla2xxx: Display proper link state for disconnected ports (Chad Dupuis) [595477]
- [scsi] qla2xxx: Check for ISP84xx before processing to get 84xx firmware version (Chad Dupuis) [595477]

* Fri Jun 25 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-38.el6]
- [ata] ahci: Fix failure to detect devices (Matthew Garrett) [608146]
- [ata] ahci: Fix device detection when stopping DMA engines (Matthew Garrett) [601195]
- [mm] Disable transparent hugepages when running under Xen (Andrea Arcangeli) [605566]
- [netdrv] tg3: Fix TX BD corruption on 5755+ devices (John Feeney) [603936]
- [netdrv] tg3: Fix memory leak on 5717/57765/5719 devices (John Feeney) [603933]
- [netdrv] bnx2: update firmware to 09-5.0.0.j15 to improve performance (John Feeney) [593797]
- [netdrv] iwlwifi: cancel scan watchdog in iwl_bg_abort_scan (John Linville) [604266]
- [netdrv] add bnx2_del_napi() to stop rmmod hangs (John Feeney) [599630]
- [virt] virtio: net: Remove net-specific advertising of PUBLISH_USED feature (Amit Shah) [605591]
- [virt] KVM: Increase NR_IOBUS_DEVS limit to 200 (Michael S. Tsirkin) [602262]
- [virt] account only for IRQ injected into BSP (Gleb Natapov) [601564]
- [virt] KVM: read apic->irr with ioapic lock held (Marcelo Tosatti) [579970]
- [x86] ACPI: Disable ASPM if the platform won't provide _OSC control for PCIe (Matthew Garrett) [584466]
- [x86] Move notify_cpu_starting() callback to a later stage (Prarit Bhargava) [600296]
- [x86] cpuidle: Fix incorrect optimization (John Villalovos) [593549]
- [block] cfq: Don't allow queue merges for queues that have no process references (Jeff Moyer) [605264]
- [infiniband] ehca: bitmask handling for lock_hcalls (Steve Best) [605739]
- [tpm] Fix tpm_readpubek_params_out struct (Peter Bogdanovic) [597235]
- [usb] Fix a hang of khubd if UHCI is removed (Pete Zaitcev) [579093]
- [oprofile] fix oprofile samples dropping under load on larger systems (John Villalovos) [561557]
- [kernel] check SEND_SIG_FORCED on TP_STORE_SIGINFO() (Oleg Nesterov) [591780]
- [kernel] pids: increase pid_max based on num_possible_cpus (Oleg Nesterov) [593164]
- [kernel] sys_personality: change sys_personality() to accept "unsigned int" instead of u_long (Oleg Nesterov) [593265]
- [kernel] fix cgroup's cpu controller to provide fair CPU usage to each group in some conditions (Larry Woodman) [544197]
- [gpu] vgaarb: fix incorrect dereference of userspace pointer (Danny Feng) [564247]
- [kernel] sched: avoid cache misses on large machines due to sibling preference (Jerome Marchand) [592302]
- [scsi] ipr: move setting of the allow_restart flag for vsets (Steve Best) [603090]
- [scsi] ibmvscsi: fix DMA API misuse (Steve Best) [595417]
- [netdrv] l2tp: Fix oops in pppol2tp_xmit (Danny Feng) [607055]
- [net] sysfs: ethtool_ops can be NULL (Danny Feng) [603662]
- [net] udp: Fix bogus UFO packet generation (Herbert Xu) [602878]
- [net] vlan: fix vlan_skb_recv() (Michael S. Tsirkin) [598920]
- [net] bonding: Fix fcoe mpio over inactive slave in a bond (Neil Horman) [603239]
- [net] bridge: Fix OOM crash in deliver_clone (Herbert Xu) [604494]
- [s390x] kernel: fix kernel panic caused by using kprobes (Hendrik Brueckner) [596876]
- [s390x] ccwgroup: add locking around drvdata access (Hendrik Brueckner) [598563]
- [s390x] cmm: fix module unload handling (Hendrik Brueckner) [598554]
- [powerpc] Rework VDSO gettimeofday to prevent time going backwards (Steve Best) [591495]
- [powerpc] Move kdump default base address to 64MB on 64bit (Steve Best) [603779]
- [fs] gfs2: Better error reporting when mounting a gfs fs without enough journals (Abhijith Das) [600408]
- [tty] Revert "[tty] fix race in tty_fasync" (Stanislaw Gruszka) [606747]
- [kdump] kexec: fix OOPS in crash_kernel_shrink (Steve Best) [592336]
- [fs] btrfs: prevent users from setting ACLs on files they do not own (Danny Feng) [603594] {CVE-2010-2071}
- [fs] cifs: remove bogus first_time check in NTLMv2 session setup code (Jeff Layton) [604785]
- [fs] cifs: don't attempt busy-file rename unless it's in same directory (Jeff Layton) [603707]
- [fs] ext4: Fix compat EXT4_IOC_ADD_GROUP (Eric Sandeen) [602428]
- [fs] ext4: Prevent creation of files larger than RLIMIT_FSIZE using fallocate (Eric Sandeen) [602427]
- [fs] ext4: Use our own write_cache_pages() (Eric Sandeen) [602384]
- [fs] xfs: Make fiemap work in query mode (Eric Sandeen) [602061]
- [fs] ext4: restart ext4_ext_remove_space() after transaction restart (Josef Bacik) [589645]
- [fs] ext4: Make sure the MOVE_EXT ioctl can't overwrite append-only files (Eric Sandeen) [601009] {CVE-2010-2066}
- [fs] btrfs: check for read permission on src file in the clone ioctl (Danny Feng) [593227] {CVE-2010-1636}
- [drm] radeon: fixes for radeon driver from upstream (Dave Airlie) [589098]
- [drm] radeon port 2.6.35 HDMI audio to RHEL6 (Jerome Glisse) [604435]
- [drm] nv50: fix iommu errors caused by device reading from address 0 (Ben Skeggs) [602498]
- [ata] libata: don't flush dcache on slab pages (Stanislaw Gruszka) [606719]
- [fs] cifs: don't call cifs_new_fileinfo unless cifs_open succeeds (Jeff Layton) [593422]
- [fs] cifs: don't ignore cifs_posix_open_inode_helper return value (Jeff Layton) [593422]
- [fs] cifs: clean up arguments to cifs_open_inode_helper (Jeff Layton) [593422]
- [fs] cifs: pass instantiated filp back after open call (Jeff Layton) [593422]
- [fs] cifs: move cifs_new_fileinfo call out of cifs_posix_open (Jeff Layton) [593422]
- [fs] cifs: implement drop_inode superblock op (Jeff Layton) [593422]
- [fs] cifs: checkpatch cleanup (Jeff Layton) [593422]
- [fs] nfsd: ensure sockets are closed on error (Jeff Layton) [603735]
- [fs] Revert "sunrpc: move the close processing after do recvfrom method" (Jeff Layton) [603735]
- [fs] Revert "sunrpc: fix peername failed on closed listener" (Jeff Layton) [603735]
- [virt] kvm: Prevent internal slots from being COWed (Glauber Costa) [601192]
- [virt] kvm: Keep slot ID in memory slot structure (Glauber Costa) [601192]
- [fs] writeback: split writeback_inodes_wb (Christoph Hellwig) [601202]
- [fs] writeback: remove writeback_inodes_wbc (Christoph Hellwig) [601202]
- [fs] writeback: fix pin_sb_for_writeback (Christoph Hellwig) [601202]
- [fs] writeback: add missing requeue_io in writeback_inodes_wb (Christoph Hellwig) [601202]
- [fs] writeback: simplify and split bdi_start_writeback (Christoph Hellwig) [601202]
- [fs] writeback: simplify wakeup_flusher_threads (Christoph Hellwig) [601202]
- [fs] writeback: fix writeback_inodes_wb from writeback_inodes_sb (Christoph Hellwig) [601202]
- [fs] writeback: enforce s_umount locking in writeback_inodes_sb (Christoph Hellwig) [601202]
- [fs] writeback: queue work on stack in writeback_inodes_sb (Christoph Hellwig) [601202]
- [fs] writeback: fix writeback completion notifications (Christoph Hellwig) [601202]
- [fs] vfs: improve writeback_inodes_wb() (Christoph Hellwig) [601202]
- [fs] writeback: remove unused nonblocking and congestion checks (Christoph Hellwig) [601202]
- [fs] writeback: remove the always false bdi_cap_writeback_dirty() test (Christoph Hellwig) [601202]
- [misc] hpilo: fix pointer warning in ilo_ccb_setup (Prarit Bhargava) [603733]
- [netdrv] libertas_tf: Fix warning in lbtf_rx for stats struct (Prarit Bhargava) [603733]
- [scsi] Fix userspace warning in /usr/include/scsi/scsi.h (Prarit Bhargava) [603733]
- [pci] Fix section mismatch warning in pcibios_scan_specific_bus() (Prarit Bhargava) [603733]
- [fs] Fix warning in fs/ecryptfs/messaging.c: ecryptfs_process_response() (Prarit Bhargava) [603733]
- [fs] Fix warning in fs/btrfs/ordered-data.c: btrfs_dec_test_ordered_pending() (Prarit Bhargava) [603733]
- [netdrv] Fix warnings in drivers/net/bnx2.c (Prarit Bhargava) [603733]
- [doc] Fix warning in Documentation/spi/spidev_fdx.c: do_msg() (Prarit Bhargava) [603733]
- [kernel] Fix stack warning in lib/decompress_bunzip2.c: get_next_block() (Prarit Bhargava) [603733]
- [netdrv] Fix warning in drivers/net/vxge/vxge-main.c: vxge_probe() (Prarit Bhargava) [603733]
- [v4l] Fix warnings in drivers/media/dvb/frontends (Prarit Bhargava) [603733]
- [trace] Fix warning in include/trace/events/kmem.h: mm_kswapd_ran() (Prarit Bhargava) [603733]
- [scsi] Fix warning in drivers/scsi/megaraid/megaraid_sas.c: process_fw_state_change_wq() (Prarit Bhargava) [603733]
- [pcmcia] Fix warnings in drivers/pcmcia/socket_sysfs.c (Prarit Bhargava) [603733]
- [netdrv] Fix warning in drivers/net/wireless/wl3501_cs.c: wl3501_esbq_exec() (Prarit Bhargava) [603733]
- [drm] Workaround broken check_headers.pl (Prarit Bhargava) [603733]
- [isdn] Fix warning in drivers/isdn/hardware/mISDN/hfcpci.c: hfcpci_softirq() (Prarit Bhargava) [603733]
- [virt] Fix warning in drivers/vhost/vhost.c: vhost_signal() (Prarit Bhargava) [603733]
- [md] Fix warning in drivers/md/dm-repl.c: _replicator_slink_message() (Prarit Bhargava) [603733]
- [virt] Fix warning in arch/x86/kvm/svm.c: svm_handle_mce() (Prarit Bhargava) [603733]
- [net] Fix stack warning in net/mac80211/debugfs_sta.c: sta_agg_status_read() (Prarit Bhargava) [603733]
- [kernel] Fix warnings in scripts/mod/mod-extract.c (Prarit Bhargava) [603733]
- [mm] Fix warning in mm/mprotect.c: mprotect_fixup() (Prarit Bhargava) [603733]
- [mm] Fix warning in mm/mmap.c: __split_vma() (Prarit Bhargava) [603733]
- [mca] Fix warning in include/linux/mca-legacy.h (Prarit Bhargava) [603733]
- [mm] Fix warning in include/linux/khugepaged.h (Andrea Arcangeli) [603733]
- [virt] Fix warnings in drivers/xen/events.c() (Prarit Bhargava) [603733]
- [x86] Fix warning in drivers/platform/x86/thinkpad_acpi.c (Prarit Bhargava) [603733]
- [netdrv] Fix warnings in drivers/net/wireless/b43/phy_lp.c (Prarit Bhargava) [603733]
- [block] Fix warning in drivers/block/cciss.c: fail_all_cmds() (Prarit Bhargava) [603733]
- [isdn] Fix warnings in drivers/isdn/hardware/mISDN/w6692.c (Prarit Bhargava) [603733]
- [kernel] Fix compiler warning in sched.c (Larry Woodman) [544197]
- [fs] fscache/object-list.c: fix warning on 32-bit (Prarit Bhargava) [603733]
- [sysfs] Fix warning in sysfs_open_file (Prarit Bhargava) [603733]
- [kdump] Fix warning in kexec_crash_size_show (Prarit Bhargava) [603733]
- [netdrv] libertas: fix uninitialized variable warning (Prarit Bhargava) [603733]
- [drm] Fixes linux-next & linux-2.6 checkstack warnings (Prarit Bhargava) [603733]
- [x86] acpi_pad: squish warning (Prarit Bhargava) [603733]
- [netdrv] iwlwifi: dynamically allocate buffer for sram debugfs file (Prarit Bhargava) [603733]
- [isdn] Fix warnings in eicon driver (Prarit Bhargava) [603733]
- [net] bridge: Make first arg to deliver_clone const (Prarit Bhargava) [603733]
- [kernel] linux/elfcore.h: hide kernel functions (Prarit Bhargava) [603733]
- [fs] quota: suppress warning: "quotatypes" defined but not used (Prarit Bhargava) [603733]
- [fs] fuse: fix large stack use (Prarit Bhargava) [603733]
- [uwb] wlp: refactor wlp_get_<attribute>() macros (Prarit Bhargava) [603733]
- [usb] Remove large struct from the stack in USB storage isd200 driver (Prarit Bhargava) [603733]
- [usb] isp1362: better 64bit printf warning fixes (Prarit Bhargava) [603733]
- [pci] PCI: kill off pci_register_set_vga_state() symbol export (Prarit Bhargava) [603733]
- [x86] intel-iommu: Fix section mismatch dmar_ir_support() uses dmar_tbl (Prarit Bhargava) [603733]
- [v4l] dvb-bt8xx: fix compile warning (Prarit Bhargava) [603733]
- [tty] tty_buffer: Fix distinct type warning (Prarit Bhargava) [603733]
- [virt] virtio: fix section mismatch warnings (Prarit Bhargava) [603733]
- [ata] Fix warning in libata-eh.c (Prarit Bhargava) [603733]
- [crypto] testmgr: Fix warning (Prarit Bhargava) [603733]
- [x86] Use __builtin_memset and __builtin_memcpy for memset/memcpy (Prarit Bhargava) [603733]
- [x86] apic: Fix prototype in hw_irq.h (Prarit Bhargava) [603733]
- [x86] nmi_watchdog: relax the nmi checks during bootup (Don Zickus) [596760]
- [x86] nmi_watchdog: disable correct cpu if it fails check (Don Zickus) [596760]
- [netdrv] iwlwifi: update supported PCI_ID list for 5xx0 series (John Linville) [599148]
- [netdrv] iwlwifi: recalculate average tpt if not current (John Linville) [595845]
- [netdrv] iwl3945: enable stuck queue detection on 3945 (John Linville) [595847]
- [netdrv] iwlwifi: fix internal scan race (John Linville) [595846]
- [netdrv] iwlwifi: fix scan races (John Linville) [595846]
- [virt] virtio: fix balloon without VIRTIO_BALLOON_F_STATS_VQ (Amit Shah) [601690]
- [virt] virtio: Fix scheduling while atomic in virtio_balloon stats (Amit Shah) [601690]
- [virt] virtio: Add memory statistics reporting to the balloon driver (Amit Shah) [601690]
- [block] make blk_init_free_list and elevator_init idempotent (Mike Snitzer) [594584]
- [block] avoid unconditionally freeing previously allocated request_queue (Mike Snitzer) [594584]
- [virt] vhost: fix the memory leak which will happen when memory_access_ok fails (Michael S. Tsirkin) [599299]
- [virt] vhost-net: fix to check the return value of copy_to/from_user() correctly (Michael S. Tsirkin) [599299]
- [virt] vhost: fix to check the return value of copy_to/from_user() correctly (Michael S. Tsirkin) [599299]
- [virt] vhost: Fix host panic if ioctl called with wrong index (Michael S. Tsirkin) [599299]
- [block] writeback: fixups for !dirty_writeback_centisecs (Mike Snitzer) [594570]
- [fs] writeback: disable periodic old data writeback for !dirty_writeback_centisecs (Mike Snitzer) [594570]
- [modsign] Include the GNU build ID note in the digest (David Howells) [581965]
- [modsign] Fix a number of module signing bugs (David Howells) [581965]
- [modsign] KEYS: Return more accurate error codes (David Howells) [591891]
- [netdrv] ixgbe: fix automatic LRO/RSC settings for low latency (Andy Gospodarek) [595555]
- [scsi] sync fcoe with upstream (Mike Christie) [603263]
- [trace] conflicting tracepoint power.h headers (Mark Wielaard) [599175]
- [netdrv] ixgbe: fix panic when shutting down system with WoL enabled (Andy Gospodarek) [601066]
- [netdrv] ixgbe: ixgbe_down needs to stop dev_watchdog (Andy Gospodarek) [604807]
- [scsi] sync fcoe (Mike Christie) [595558]
- [kernel] CRED: Fix a race in creds_are_invalid() in credentials debugging (James Leddy) [578268]
- [kernel] Remove timeout logic in mutex_spin_on_owner() to match upstream (Steve Best) [602805]

* Sun Jun 20 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-37.el6]
- [virt] Disable transparent hugepages when running under Xen (Dor Laor) [605566]
- [pci] fix compilation when CONFIG_PCI_MSI=n (Vivek Goyal) [589397]
- [block] virtio_blk: support barriers without FLUSH feature (Christoph Hellwig) [602595]
- [mm] make compound_lock irqsafe in put_page (Andrea Arcangeli) [605354]
- [mm] remove compound_lock from futex (Andrea Arcangeli) [605354]
- [mm] memcontrol compound_lock irqsafe (Andrea Arcangeli) [605354]
- [mm] add compound_lock_irqsave/irqrestore (Andrea Arcangeli) [605354]

* Wed Jun 16 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-36.el6]
- [virt] virtio-pci: Disable MSI at startup (Vivek Goyal) [589397]
- [mm] Reenable transparent hugepages (Aristeu Rozanski) [602436]

* Tue Jun 15 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-35.el6]
- [mm] Revert "[redhat] Enable transparent hugepages by default" (Aristeu Rozanski) [602436]

* Tue Jun 15 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-34.el6]
- [net] Revert "[net] bridge: make bridge support netpoll" (Herbert Xu) [602927]
- [virt] always invalidate and flush on spte page size change (Andrea Arcangeli) [578134]
- [mm] root anon vma bugchecks (Andrea Arcangeli) [578134]
- [mm] resurrect the check in page_address_in_vma (Andrea Arcangeli) [578134]
- [mm] root anon vma use root (Andrea Arcangeli) [578134]
- [mm] avoid ksm hang (Andrea Arcangeli) [578134]
- [mm] always add new vmas at the end (Andrea Arcangeli) [578134]
- [mm] remove unnecessary lock from __vma_link (Andrea Arcangeli) [578134]
- [mm] optimize hugepage tracking for memcgroup & handle splitting (Rik van Riel) [597108]
- [mm] properly move a transparent hugepage between cgroups (Rik van Riel) [597081]
- [mm] scale statistics if the page is a transparent hugepage (Rik van Riel) [597077]
- [mm] enhance mem_cgroup_charge_statistics with a page_size argument (Rik van Riel) [597058]
- [virt] add option to disable spinlock patching on hypervisor (Gleb Natapov) [599068]
- [virt] xen: don't touch xsave in cr4 (Andrew Jones) [599069]
- [drm] Update core to current drm-linus (Adam Jackson) [589547 589792 597022]
- [mm] fix refcount bug in anon_vma code (Rik van Riel) [602739]

* Thu Jun 03 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-33.el6]
- [netdrv] vlan: allow null VLAN ID to be used (Andy Gospodarek) [595555]
- [netdrv] ixgbe: Add boolean parameter to ixgbe_set_vmolr (Andy Gospodarek) [595555]
- [netdrv] ixgbe: fix bug when EITR=0 causing no writebacks (Andy Gospodarek) [595555]
- [netdrv] ixgbe: enable extremely low latency (Andy Gospodarek) [595555]
- [netdrv] ixgbe: added compat bits (Andy Gospodarek) [595555]
- [netdrv] ixgbe: dcb, do not tag tc_prio_control frames (Andy Gospodarek) [595555]
- [netdrv] ixgbe: fix ixgbe_tx_is_paused logic (Andy Gospodarek) [595555]
- [netdrv] ixgbe: always enable vlan strip/insert when DCB is enabled (Andy Gospodarek) [595555]
- [netdrv] ixgbe: remove some redundant code in setting FCoE FIP filter (Andy Gospodarek) [595555]
- [netdrv] ixgbe: fix wrong offset to fc_frame_header in ixgbe_fcoe_ddp (Andy Gospodarek) [595555]
- [netdrv] ixgbe: fix header len when unsplit packet overflows to data buffer (Andy Gospodarek) [595555]
- [netdrv] ixgbe: fix setting of promisc mode when using mac-vlans (Andy Gospodarek) [595555]
- [netdrv] ixgbe: Add support for VF MAC and VLAN configuration (Andy Gospodarek) [595555]
- [netdrv] ixgbe: fix bug with vlan strip in promsic mode (Andy Gospodarek) [595555]
- [virt] use unfair spinlock when running on hypervisor (Gleb Natapov) [599068]

* Wed Jun 02 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-32.el6]
- [kernel] sched: update normalized values on user updates via proc (Hendrik Brueckner) [590748]
- [kernel] sched: Make tunable scaling style configurable (Hendrik Brueckner) [590748]
- [s390x] nohz: Introduce arch_needs_cpu (Hendrik Brueckner) [590009]
- [ppc64] Use form 1 affinity to setup node distance (Steve Best) [594502]
- [ppc64] numa: Use ibm, architecture-vec-5 to detect form 1 affinity (Steve Best) [594502]
- [ppc64] Set a smaller value for RECLAIM_DISTANCE to enable zone reclaim (Steve Best) [594502]
- [block] Add padding to writeback_control (Mike Snitzer) [594570]
- [fs] cifs: fix page refcount leak (Jeff Layton) [595827]
- [scsi] megaraid_sas - Add three times Online controller reset (Tomas Henzl) [594821]
- [scsi] megaraid: update driver version to 4.28 (Tomas Henzl) [577010]
- [netdrv] tg3: Provide more support for 57765 with v3.108 (John Feeney) [581691]
- [scsi] skip sense logging for some ATA PASS-THROUGH cdbs (Jeff Moyer) [596997]
- [block] allow initialization of previously allocated request_queue (Mike Snitzer) [594584]
- [usb] Fix oops on switching USB controllers (Pete Zaitcev) [578979]
- [drm] nouveau: important fixes to vbios parser (Ben Skeggs) [596604]
- [virt] virtio: console: Fix crash when port is unplugged and blocked for write (Amit Shah) [596635]
- [virt] virtio: console: Fix crash when hot-unplugging a port and read is blocked (Amit Shah) [596635]
- [kernel] signals: check_kill_permission(): don't check creds if same_thread_group() (Oleg Nesterov) [595499]
- [drm] fix issue with wake up like upstream commit (Dave Airlie) [577959]
- [x86] Fix AMD IOMMU suspend/resume (Matthew Garrett) [593787]
- [mm] do_generic_file_read: clear page errors when issuing a fresh read of the page (Rik van Riel) [596334]
- [x86] Fix loud HPET warning on Intel Platforms (Prarit Bhargava) [592036]
- [x86] Intel Cougar Point PCH support for SATA, USB, HD Audio, I2C(SMBUS), and iTCO Watchdog (John Villalovos) [560077]
- [x86] dell-laptop: Update to match mainline (Matthew Garrett) [586495]
- [kernel] proc: backport afinity_hint code (Neil Horman) [591509]
- [scsi] bfa: powerpc compilation warning and endian fix (Rob Evers) [583154]
- [scsi] bfa: code review fixes (Rob Evers) [583154]
- [s390x] dasd: fix race between tasklet and dasd_sleep_on (Hendrik Brueckner) [591963]
- [s390x] vdso: add missing vdso_install target (Hendrik Brueckner) [587368]
- [mm] mempolicy: fix get_mempolicy() for relative and static nodes (Steve Best) [592327]
- [net] reserve ports for applications using fixed port numbers (Amerigo Wang) [580970]
- [kernel] sysctl: add proc_do_large_bitmap (Amerigo Wang) [580970]
- [kernel] sysctl: refactor integer handling proc code (Amerigo Wang) [580970]
- [virt] VMware Balloon: clamp number of collected non-balloonable pages (Amit Shah) [582826]
- [virt] x86, hypervisor: add missing <linux/module.h> (Amit Shah) [582826]
- [nfs] nfsd4: bug in read_buf (Steve Dickson) [597215]
- [nfs] svcrdma: RDMA support not yet compatible with RPC6 (Steve Dickson) [597215]
- [nfs] Revert "nfsd4: distinguish expired from stale stateids" (Steve Dickson) [597215]
- [nfs] nfsd: safer initialization order in find_file() (Steve Dickson) [597215]
- [nfs] nfs4: minor callback code simplification, comment (Steve Dickson) [597215]
- [nfs] NFSD: don't report compiled-out versions as present (Steve Dickson) [597215]
- [nfs] nfsd4: implement reclaim_complete (Steve Dickson) [597215]
- [nfs] nfsd4: nfsd4_destroy_session must set callback client under the state lock (Steve Dickson) [597215]
- [nfs] nfsd4: keep a reference count on client while in use (Steve Dickson) [597215]
- [nfs] nfsd4: mark_client_expired (Steve Dickson) [597215]
- [nfs] nfsd4: introduce nfs4_client.cl_refcount (Steve Dickson) [597215]
- [nfs] nfsd4: refactor expire_client (Steve Dickson) [597215]
- [nfs] nfsd4: extend the client_lock to cover cl_lru (Steve Dickson) [597215]
- [nfs] nfsd4: use list_move in move_to_confirmed (Steve Dickson) [597215]
- [nfs] nfsd4: fold release_session into expire_client (Steve Dickson) [597215]
- [nfs] nfsd4: rename sessionid_lock to client_lock (Steve Dickson) [597215]
- [nfs] nfsd4: fix bare destroy_session null dereference (Steve Dickson) [597215]
- [nfs] nfsd4: use local variable in nfs4svc_encode_compoundres (Steve Dickson) [597215]
- [nfs] nfsd: further comment typos (Steve Dickson) [597215]
- [nfs] sunrpc: centralise most calls to svc_xprt_received (Steve Dickson) [597215]
- [nfs] nfsd4: fix unlikely race in session replay case (Steve Dickson) [597215]
- [nfs] nfsd4: fix filehandle comment (Steve Dickson) [597215]
- [nfs] nfsd: potential ERR_PTR dereference on exp_export() error paths (Steve Dickson) [597215]
- [nfs] nfsd4: complete enforcement of 4.1 op ordering (Steve Dickson) [597215]
- [nfs] nfsd4: allow 4.0 clients to change callback path (Steve Dickson) [597215]
- [nfs] nfsd4: rearrange cb data structures (Steve Dickson) [597215]
- [nfs] NFSD: NFSv4 callback client should use RPC_TASK_SOFTCONN (Steve Dickson) [597215]
- [nfs] nfsd4: cl_count is unused (Steve Dickson) [597215]
- [nfs] nfsd4: don't sleep in lease-break callback (Steve Dickson) [597215]
- [nfs] nfsd4: indentation cleanup (Steve Dickson) [597215]
- [nfs] nfsd4: consistent session flag setting (Steve Dickson) [597215]
- [nfs] nfsd4: remove probe task's reference on client (Steve Dickson) [597215]
- [nfs] nfsd4: remove dprintk (Steve Dickson) [597215]
- [nfs] nfsd4: shutdown callbacks on expiry (Steve Dickson) [597215]
- [nfs] nfsd4: preallocate nfs4_rpc_args (Steve Dickson) [597215]
- [nfs] svcrpc: don't hold sv_lock over svc_xprt_put() (Steve Dickson) [597215]
- [nfs] nfsd: don't break lease while servicing a COMMIT (Steve Dickson) [597215]
- [nfs] nfsd: factor out hash functions for export caches (Steve Dickson) [597215]
- [nfs] sunrpc: never return expired entries in sunrpc_cache_lookup (Steve Dickson) [597215]
- [nfs] sunrpc/cache: factor out cache_is_expired (Steve Dickson) [597215]
- [nfs] sunrpc: don't keep expired entries in the auth caches (Steve Dickson) [597215]
- [nfs] nfsd4: document lease/grace-period limits (Steve Dickson) [597215]
- [nfs] nfsd4: allow setting grace period time (Steve Dickson) [597215]
- [nfs] nfsd4: reshuffle lease-setting code to allow reuse (Steve Dickson) [597215]
- [nfs] nfsd4: remove unnecessary lease-setting function (Steve Dickson) [597215]
- [nfs] nfsd4: simplify lease/grace interaction (Steve Dickson) [597215]
- [nfs] nfsd4: simplify references to nfsd4 lease time (Steve Dickson) [597215]
- [nfs] Fix another nfs_wb_page() deadlock (Steve Dickson) [595478]
- [nfs] Ensure that we mark the inode as dirty if we exit early from commit (Steve Dickson) [595478]
- [nfs] Fix a lock imbalance typo in nfs_access_cache_shrinker (Steve Dickson) [595478]
- [nfs] sunrpc: fix leak on error on socket xprt setup (Steve Dickson) [595478]
- [pci] Add padding to PCI structs for future enhancements (Prarit Bhargava) [590286]

* Wed May 26 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-31.el6]
- [mm] fix vma_adjust lock inversion (Andrea Arcangeli) [595808]
- [mm] eliminate compiler warning introduced by my "kernel pagefault tracepoint for x86 & x86_64 patch" (Larry Woodman) [526032]
- [netdrv] tg3: Fix INTx fallback when MSI fails (Steve Best) [594456]
- [virt] correctly trace irq injection on SVM (Gleb Natapov) [594020]
- [virt] KVM: remove CAP_SYS_RAWIO requirement from kvm_vm_ioctl_assign_irq (Alex Williamson) [594912]
- [virt] KVM: Fix wallclock version writing race (Glauber Costa) [592033]
- [x86] Fix double enable_IR_x2apic call on SMP kernel on !SMP boards (Luming Yu) [585122]
- [block] Adjust elv_iosched_show to return "none" for bio-based DM (Mike Snitzer) [595393]
- [dm] mpath: Add a feature flag attribute to the multipath structure (Mike Snitzer) [594503]
- [kernel] fix compat_sys_sched_getaffinity() (Oleg Nesterov) [582407]
- [usb] usbcore: Fix issue with disabled USB3 protocol ports (Bhavna Sarathy) [591916]
- [kernel] python: change scripts to use system python instead of env (Don Zickus) [575965]
- [scsi] mpt2sas: update to 05.100.00.02 (Tomas Henzl) [591971]
- [virt] Fix FV Xen guest when xen_pv_hvm not enabled (Don Dutile) [523134]
- [net] enhance network cgroup classifier to work in softirq context (Neil Horman) [595351]
- [net] gro: Fix bogus gso_size on the first fraglist entry (Herbert Xu) [594561]
- [nfs] sunrpc trace points (Steve Dickson) [567741]
- [nfs] don't try to decode GETATTR if DELEGRETURN returned error (Jeff Layton) [584391]
- [nfs] d_revalidate() is too trigger-happy with d_drop() (Jeff Layton) [587225]
- [ppc64] Fix zero length strncmp() on powerpc (Steve Best) [593129]
- [ppc64] pseries: Fix xics interrupt affinity (Steve Best) [592438]
- [ppc] Improve 64bit copy_tofrom_user (Steve Best) [591344]
- [fs] GFS2: Fix permissions checking for setflags ioctl() (Steven Whitehouse) [595395] {CVE-2010-1641}
- [gfs] GFS2: Add two useful messages (Steven Whitehouse) [589510]
- [serial] fix serial console hang after entering username (John Villalovos) [590851]
- [kdump] kexec can't load capturing kernel on some big RAM systems (Vitaly Mayatskikh) [580843]
- [fs] cleanup generic block based fiemap (Josef Bacik) [578560]
- [fs] vfs: add NOFOLLOW/UNUSED to umount flags (Josef Bacik) [562078]
- [fs] dlm: fix ast ordering for user locks (David Teigland) [592418]
- [fs] cifs: fix noserverino handling when unix extensions are enabled (Jeff Layton) [591483]
- [fs] cifs: don't update uniqueid in cifs_fattr_to_inode (Jeff Layton) [591483]
- [fs] cifs: always revalidate hardlinked inodes when using noserverino (Jeff Layton) [591483]
- [fs] cifs: Fix losing locks during fork() (Jeff Layton) [591483]
- [fs] cifs: propagate cifs_new_fileinfo() error back to the caller (Jeff Layton) [591483]
- [fs] cifs: add comments explaining cifs_new_fileinfo behavior (Jeff Layton) [591483]
- [fs] cifs: Allow null nd (as nfs server uses) on create (Jeff Layton) [591483]
- [fs] cifs: remove unused parameter from cifs_posix_open_inode_helper() (Jeff Layton) [591483]
- [fs] cifs: drop quota operation stubs (Jeff Layton) [591483]
- [fs] cifs: Remove unused cifs_oplock_cachep (Jeff Layton) [591483]
- [fs] cifs: Cleanup various minor breakage in previous cFYI cleanup (Jeff Layton) [591483]
- [fs] cifs: Neaten cERROR and cFYI macros, reduce text space (Jeff Layton) [591483]
- [fs] cifs: trivial white space (Jeff Layton) [591483]
- [fs] cifs: use add_to_page_cache_lru (Jeff Layton) [591483]
- [fs] cifs: not overwriting file_lock structure after GET_LK (Jeff Layton) [591483]
- [fs] cifs: Fix a kernel BUG with remote OS/2 server (Jeff Layton) [591483]
- [fs] cifs: initialize nbytes at the beginning of CIFSSMBWrite() (Jeff Layton) [591483]
- [fs] cifs: back out patches that didn't make it upstream (Jeff Layton) [591483]
- [fs] cifs: guard against hardlinking directories (Jeff Layton) [591229]
- [pci] check caps from sysfs file open to read device dependent config space (Don Dutile) [559709]
- [fs] sysfs: add struct file* to bin_attr callbacks (Don Dutile) [559709]
- [ata] pata_via: fixup detection issues (David Milburn) [591074]
- [security] keys: call_sbin_request_key() must write lock keyrings before modifying them (David Howells) [591891]
- [security] keys: Use RCU dereference wrappers in keyring key type code (David Howells) [591891]
- [security] keys: find_keyring_by_name() can gain access to a freed keyring (David Howells) [585101 591891] {CVE-2010-1437}
- [security] keys: Fix RCU handling in key_gc_keyring() (David Howells) [591891]
- [security] keys: the request_key() syscall should link an existing key to the dest keyring (David Howells) [591891]
- [security] keys: don't need to use RCU in keyring_read() as semaphore is held (David Howells) [591891]
- [security] keys: fix an RCU warning (David Howells) [591891]
- [security] keys: PTR_ERR return of wrong pointer in keyctl_get_security() (David Howells) [591891]
- [fs] CacheFiles: Fix error handling in cachefiles_determine_cache_security() (David Howells) [591894]
- [fs] CacheFiles: Fix occasional EIO on call to vfs_unlink() (David Howells) [591894]
- [fs] fs-cache: order the debugfs stats correctly (David Howells) [591894]
- [fs] SLOW_WORK: CONFIG_SLOW_WORK_PROC should be CONFIG_SLOW_WORK_DEBUG (David Howells) [591894]
- [fs] fscache: add missing unlock (David Howells) [591894]
- [fs] FS-Cache: Remove the EXPERIMENTAL flag (David Howells) [591894]
- [fs] CacheFiles: Fix a race in cachefiles_delete_object() vs rename (David Howells) [591894]
- [fs] switch cachefiles to kern_path() (David Howells) [591894]
- [fs] FS-Cache: Avoid maybe-used-uninitialised warning on variable (David Howells) [591894]
- [net] bonding: make bonding support netpoll (Amerigo Wang) [587751]
- [net] bridge: make bridge support netpoll (Amerigo Wang) [587751]
- [net] netpoll: add generic support for bridge and bonding devices (Amerigo Wang) [587751]
- [ppc64] Use lwarx/ldarx hint in bit locks (Steve Best) [594515]
- [ppc64] 85xx: Make sure lwarx hint isn't set on ppc32 (Steve Best) [594515]
- [ppc64] Use lwarx hint in spinlocks (Steve Best) [594515]
- [fs] tmpfs: Insert tmpfs cache pages to inactive list at first (Rik van Riel) [595210]
- [mm] vmscan: detect mapped file pages used only once (Rik van Riel) [595210]
- [mm] vmscan: drop page_mapping_inuse() (Rik van Riel) [595210]
- [mm] vmscan: factor out page reference checks (Rik van Riel) [595210]
- [nfs] SUNRPC: Don't spam gssd with upcall requests when the kerberos key expired (Steve Dickson) [595478]
- [nfs] SUNRPC: Reorder the struct rpc_task fields (Steve Dickson) [595478]
- [nfs] SUNRPC: Remove the 'tk_magic' debugging field (Steve Dickson) [595478]
- [nfs] SUNRPC: Move the task->tk_bytes_sent and tk_rtt to struct rpc_rqst (Steve Dickson) [595478]
- [nfs] Don't call iput() in nfs_access_cache_shrinker (Steve Dickson) [595478]
- [nfs] Clean up nfs_access_zap_cache() (Steve Dickson) [595478]
- [nfs] Don't run nfs_access_cache_shrinker() when the mask is GFP_NOFS (Steve Dickson) [595478]
- [nfs] SUNRPC: Ensure rpcauth_prune_expired() respects the nr_to_scan parameter (Steve Dickson) [595478]
- [nfs] SUNRPC: Ensure memory shrinker doesn't waste time in rpcauth_prune_expired() (Steve Dickson) [595478]
- [nfs] SUNRPC: Dont run rpcauth_cache_shrinker() when gfp_mask is GFP_NOFS (Steve Dickson) [595478]
- [nfs] Read requests can use GFP_KERNEL (Steve Dickson) [595478]
- [nfs] Clean up nfs_create_request() (Steve Dickson) [595478]
- [nfs] Don't use GFP_KERNEL in rpcsec_gss downcalls (Steve Dickson) [595478]
- [nfs] NFSv4: Don't use GFP_KERNEL allocations in state recovery (Steve Dickson) [595478]
- [nfs] SUNRPC: Fix xs_setup_bc_tcp() (Steve Dickson) [595478]
- [nfs] SUNRPC: Replace jiffies-based metrics with ktime-based metrics (Steve Dickson) [595478]
- [kernel] ktime: introduce ktime_to_ms() (Steve Dickson) [595478]
- [nfs] SUNRPC: RPC metrics and RTT estimator should use same RTT value (Steve Dickson) [595478]
- [nfs] Calldata for nfs4_renew_done() (Steve Dickson) [595478]
- [nfs] nfs4: renewd renew operations should take/put a client reference (Steve Dickson) [595478]
- [nfs] Squelch compiler warning in nfs_add_server_stats() (Steve Dickson) [595478]
- [nfs] Clean up fscache_uniq mount option (Steve Dickson) [595478]
- [nfs] Squelch compiler warning (Steve Dickson) [595478]
- [nfs] SUNRPC: Trivial cleanups in include/linux/sunrpc/xdr.h (Steve Dickson) [595478]
- [nfs] NFSv4: Clean up the NFSv4 setclientid operation (Steve Dickson) [595478]
- [nfs] NFSv4: Allow attribute caching with 'noac' mounts if client holds a delegation (Steve Dickson) [595478]
- [nfs] SUNRPC: Fail over more quickly on connect errors (Steve Dickson) [595478]
- [nfs] SUNRPC: Move the test for XPRT_CONNECTING into xprt_connect() (Steve Dickson) [595478]
- [nfs] SUNRPC: Cleanup - make rpc_new_task() call rpc_release_calldata on failure (Steve Dickson) [595478]
- [nfs] SUNRPC: Clean up xprt_release() (Steve Dickson) [595478]
- [nfs] NFSv4: Fix up the documentation for nfs_do_refmount (Steve Dickson) [595478]
- [nfs] Replace nfsroot on-stack filehandle (Steve Dickson) [595478]
- [nfs] Cleanup file handle allocations in fs/nfs/super.c (Steve Dickson) [595478]
- [nfs] Prevent the mount code from looping forever on broken exports (Steve Dickson) [595478]
- [nfs] Reduce stack footprint of nfs3_proc_getacl() and nfs3_proc_setacl() (Steve Dickson) [595478]
- [nfs] Reduce stack footprint of nfs_statfs() (Steve Dickson) [595478]
- [nfs] Reduce stack footprint of nfs_setattr() (Steve Dickson) [595478]
- [nfs] Reduce stack footprint of nfs4_proc_create() (Steve Dickson) [595478]
- [nfs] Reduce the stack footprint of nfs_proc_symlink() (Steve Dickson) [595478]
- [nfs] Reduce the stack footprint of nfs_proc_create (Steve Dickson) [595478]
- [nfs] Reduce the stack footprint of nfs_rmdir (Steve Dickson) [595478]
- [nfs] Reduce stack footprint of nfs_proc_remove() (Steve Dickson) [595478]
- [nfs] Reduce stack footprint of nfs3_proc_readlink() (Steve Dickson) [595478]
- [nfs] Reduce the stack footprint of nfs_link() (Steve Dickson) [595478]
- [nfs] Reduce stack footprint of nfs_readdir() (Steve Dickson) [595478]
- [nfs] Reduce stack footprint of nfs3_proc_rename() and nfs4_proc_rename() (Steve Dickson) [595478]
- [nfs] Reduce stack footprint of nfs_revalidate_inode() (Steve Dickson) [595478]
- [nfs] NFSv4: Reduce stack footprint of nfs4_proc_access() and nfs3_proc_access() (Steve Dickson) [595478]
- [nfs] NFSv4: Reduce the stack footprint of nfs4_remote_referral_get_sb (Steve Dickson) [595478]
- [nfs] NFSv4: Reduce stack footprint of nfs4_get_root() (Steve Dickson) [595478]
- [nfs] Reduce the stack footprint of nfs_follow_remote_path() (Steve Dickson) [595478]
- [nfs] Reduce the stack footprint of nfs_lookup (Steve Dickson) [595478]
- [nfs] NFSv4: Reduce the stack footprint of try_location() (Steve Dickson) [595478]
- [nfs] Reduce the stack footprint of nfs_create_server (Steve Dickson) [595478]
- [nfs] Reduce the stack footprint of nfs_follow_mountpoint() (Steve Dickson) [595478]
- [nfs] NFSv4: Eliminate nfs4_path_walk() (Steve Dickson) [595478]
- [nfs] Add helper functions for allocating filehandles and fattr structs (Steve Dickson) [595478]
- [nfs] NFSv4: Fix the locking in nfs_inode_reclaim_delegation() (Steve Dickson) [595478]
- [nfs] fix memory leak in nfs_get_sb with CONFIG_NFS_V4 (Steve Dickson) [595478]
- [nfs] fix some issues in nfs41_proc_reclaim_complete() (Steve Dickson) [595478]
- [nfs] Ensure that nfs_wb_page() waits for Pg_writeback to clear (Steve Dickson) [595478]
- [nfs] Fix an unstable write data integrity race (Steve Dickson) [595478]
- [nfs] testing for null instead of ERR_PTR() (Steve Dickson) [595478]
- [nfs] NFSv4: Don't attempt an atomic open if the file is a mountpoint (Steve Dickson) [595478]
- [nfs] SUNRPC: Fix a bug in rpcauth_prune_expired (Steve Dickson) [595478]
- [nfs] NFSv4: fix delegated locking (Steve Dickson) [595478]
- [nfs] Ensure that the WRITE and COMMIT RPC calls are always uninterruptible (Steve Dickson) [595478]
- [nfs] Fix a race with the new commit code (Steve Dickson) [595478]
- [nfs] Fix the mode calculation in nfs_find_open_context (Steve Dickson) [595478]
- [nfs] NFSv4: Fall back to ordinary lookup if nfs4_atomic_open() returns EISDIR (Steve Dickson) [595478]
- [nfs] SUNRPC: Fix the return value of rpc_run_bc_task() (Steve Dickson) [595478]
- [nfs] SUNRPC: Fix a use after free bug with the NFSv4.1 backchannel (Steve Dickson) [595478]
- [nfs] ensure bdi_unregister is called on mount failure (Steve Dickson) [595478]
- [nfs] fix unlikely memory leak (Steve Dickson) [595478]
- [nfs] nfs41: renewd sequence operations should take/put client reference (Steve Dickson) [595478]
- [nfs] prevent backlogging of renewd requests (Steve Dickson) [595478]
- [nfs] rpc client can not deal with ENOSOCK, so translate it into ENOCONN (Steve Dickson) [595478]

* Tue May 25 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-30.el6]
- [perf] sync tools/perf to 2.6.34 (Jason Baron) [578987]
- [drm] i915: Update to 2.6.34-rc7 (Adam Jackson) [592003]
- [perf] userspace and core update fix (Jason Baron) [567828 578987]
- [perf] rhel6 perf fixups (Jason Baron) [567828 578987]
- [perf] backport latest core perf support (Jason Baron) [567828 578987]
- [perf] pull back 'perf' userspace (Jason Baron) [567828 578987]
- [drm] radeon/kms: report lvds status as unknown with closed lid (Jerome Glisse) [585111 591628]
- [drm] fbdev: fix cloning on fbcon (Dave Airlie) [512023]
- [drm] fbcon disconnected + hotplug operation (Jerome Glisse) [580789]
- [kernel] slow-work: use get_ref wrapper instead of directly calling get_ref (Dave Airlie) [580789]
- [drm] radeon/kms: add special workaround for triple head servers (Dave Airlie) [512023]
- [infiniband] RDMA: Use rlimit helpers (Doug Ledford) [500229]
- [infiniband] ipoib: returned back addrlen check for mc addresses (Doug Ledford) [500229]
- [infiniband] RDMA/amso1100: Fix error paths in post_send and post_recv (Doug Ledford) [500229]
- [infiniband] IB/srp: Clean up error path in srp_create_target_ib() (Doug Ledford) [500229]
- [infiniband] IB/srp: Split send and recieve CQs to reduce number of interrupts (Doug Ledford) [500229]
- [infiniband] rdma: potential ERR_PTR dereference (Doug Ledford) [500229]
- [infiniband] RDMA/cm: Set num_paths when manually assigning path records (Doug Ledford) [500229]
- [infiniband] IB/cm: Fix device_create() return value check (Doug Ledford) [500229]
- [infiniband] IB/ucm: Clean whitespace errors (Doug Ledford) [500229]
- [infiniband] IB/ucm: Increase maximum devices supported (Doug Ledford) [500229]
- [infiniband] IB/ucm: Use stack variable 'base' in ib_ucm_add_one (Doug Ledford) [500229]
- [infiniband] IB/ucm: Use stack variable 'devnum' in ib_ucm_add_one (Doug Ledford) [500229]
- [infiniband] RDMA/cm: Remove unused definition of RDMA_PS_SCTP (Doug Ledford) [500229]
- [infiniband] RDMA/cm: Revert association of an RDMA device when binding to loopback (Doug Ledford) [500229]
- [infiniband] IB/addr: Correct CONFIG_IPv6 to CONFIG_IPV6 (Doug Ledford) [500229]
- [infiniband] IB/addr: Fix IPv6 routing lookup (Doug Ledford) [500229]
- [infiniband] IB/addr: Simplify resolving IPv4 addresses (Doug Ledford) [500229]
- [infiniband] RDMA/cm: fix loopback address support (Doug Ledford) [500229]
- [infiniband] IB/addr: Store net_device type instead of translating to RDMA transport (Doug Ledford) [500229]
- [infiniband] IB/addr: Verify source and destination address families match (Doug Ledford) [500229]
- [infiniband] RDMA/cma: Replace net_device pointer with index (Doug Ledford) [500229]
- [infiniband] RDMA/cma: Fix AF_INET6 support in multicast joining (Doug Ledford) [500229]
- [infiniband] RDMA/cma: Correct detection of SA Created MGID (Doug Ledford) [500229]
- [infiniband] RDMA/addr: Use appropriate locking with for_each_netdev() (Doug Ledford) [500229]
- [infiniband] RDMA/ucma: Add option to manually set IB path (Doug Ledford) [500229]
- [infiniband] IB/mad: Ignore iWARP devices on device removal (Doug Ledford) [500229]
- [infiniband] IB/umad: Clean whitespace (Doug Ledford) [500229]
- [infiniband] IB/umad: Increase maximum devices supported (Doug Ledford) [500229]
- [infiniband] IB/umad: Use stack variable 'base' in ib_umad_init_port (Doug Ledford) [500229]
- [infiniband] IB/umad: Use stack variable 'devnum' in ib_umad_init_port (Doug Ledford) [500229]
- [infiniband] IB/umad: Remove port_table[] (Doug Ledford) [500229]
- [infiniband] IB/umad: Convert *cdev to cdev in struct ib_umad_port (Doug Ledford) [500229]
- [infiniband] IB/uverbs: Use anon_inodes instead of private infinibandeventfs (Doug Ledford) [500229]
- [infiniband] IB/core: Fix and clean up ib_ud_header_init() (Doug Ledford) [500229]
- [infiniband] IB/core: Pack struct ib_device a little tighter (Doug Ledford) [500229]
- [infiniband] IB/uverbs: Whitespace cleanup (Doug Ledford) [500229]
- [infiniband] IB/uverbs: Pack struct ib_uverbs_event_file tighter (Doug Ledford) [500229]
- [infiniband] IB/uverbs: Increase maximum devices supported (Doug Ledford) [500229]
- [infiniband] IB/uverbs: use stack variable 'base' in ib_uverbs_add_one (Doug Ledford) [500229]
- [infiniband] IB/uverbs: Use stack variable 'devnum' in ib_uverbs_add_one (Doug Ledford) [500229]
- [infiniband] IB/uverbs: Remove dev_table (Doug Ledford) [500229]
- [infiniband] IB/uverbs: Convert *cdev to cdev in struct ib_uverbs_device (Doug Ledford) [500229]
- [infiniband] IB/uverbs: Fix return of PTR_ERR() of wrong pointer in ib_uverbs_get_context() (Doug Ledford) [500229]
- [infiniband] IB: Clarify the documentation of ib_post_send() (Doug Ledford) [500229]
- [infiniband] IB/ehca: Allow access for ib_query_qp() (Doug Ledford) [500229]
- [infiniband] IB/ehca: Do not turn off irqs in tasklet context (Doug Ledford) [500229]
- [infiniband] IB/ehca: Fix error paths in post_send and post_recv (Doug Ledford) [500229]
- [infiniband] IB/ehca: Rework destroy_eq() (Doug Ledford) [500229]
- [infiniband] IPoIB: Include return code in trace message for ib_post_send() failures (Doug Ledford) [500229]
- [infiniband] IPoIB: Fix TX queue lockup with mixed UD/CM traffic (Doug Ledford) [500229]
- [infiniband] IPoIB: Remove TX moderation settings from ethtool support (Doug Ledford) [500229]
- [infiniband] IB/ipath: Use bitmap_weight() (Doug Ledford) [500229]
- [infiniband] Remove BKL from ipath_open() (Doug Ledford) [500229]
- [rds] remove uses of NIPQUAD, use pI4 (Doug Ledford) [500229]
- [rds] RDS/IB+IW: Move recv processing to a tasklet (Doug Ledford) [500229]
- [rds] Do not send congestion updates to loopback connections (Doug Ledford) [500229]
- [rds] Fix panic on unload (Doug Ledford) [500229]
- [rds] Fix potential race around rds_i[bw]_allocation (Doug Ledford) [500229]
- [rds] Add GET_MR_FOR_DEST sockopt (Doug Ledford) [500229]
- [infiniband] IB/mlx4: Check correct variable for allocation failure (Doug Ledford) [500229]
- [infiniband] mlx4: replace the dma_sync_single_range_for_cpu/device API (Doug Ledford) [500229]
- [infiniband] IB/mlx4: Simplify retrieval of ib_device (Doug Ledford) [500229]
- [infiniband] mlx4_core: Fix cleanup in __mlx4_init_one() error path (Doug Ledford) [500229]
- [infiniband] IB/mlx4: Fix queue overflow check in post_recv (Doug Ledford) [500229]
- [infiniband] IB/mlx4: Initialize SRQ scatter entries when creating an SRQ (Doug Ledford) [500229]
- [infiniband] mlx4: use bitmap_find_next_zero_area (Doug Ledford) [500229]
- [infiniband] mlx4_core: return a negative error value (Doug Ledford) [500229]
- [infiniband] mlx4_core: Fix parsing of reserved EQ cap (Doug Ledford) [500229]
- [infiniband] IB/mlx4: Remove limitation on LSO header size (Doug Ledford) [500229]
- [infiniband] IB/mlx4: Remove unneeded code (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Correct cap.max_inline_data assignment in nes_query_qp() (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Fix CX4 link problem in back-to-back configuration (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Clear stall bit before destroying NIC QP (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Set assume_aligned_header bit (Doug Ledford) [500229]
- [infiniband] convert to use netdev_for_each_mc_addr (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Add support for KR device id 0x0110 (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Change WQ overflow return code (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Multiple disconnects cause crash during AE handling (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Fix crash when listener destroyed during loopback setup (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Use atomic counters for CM listener create and destroy (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Fix stale ARP issue (Doug Ledford) [500229]
- [infiniband] RDMA/nes: FIN during MPA startup causes timeout (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Free kmap() resources (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Check for zero STag (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Fix Xansation test crash on cm_node ref_count (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Abnormal listener exit causes loopback node crash (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Fix crash in nes_accept() (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Resource not freed for REJECTed connections (Doug Ledford) [500229]
- [infiniband] RDMA/nes: MPA request/response error checking (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Fix query of ORD values (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Fix MAX_CM_BUFFER define (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Pass correct size to ioremap_nocache() (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Update copyright and branding string (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Add max_cqe check to nes_create_cq() (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Clean up struct nes_qp (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Implement IB_SIGNAL_ALL_WR as an iWARP extension (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Add additional SFP+ PHY uC status check and PHY reset (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Correct fast memory registration implementation (Doug Ledford) [500229]
- [infiniband] RDMA/nes: Add support for IB_WR_*INV (Doug Ledford) [500229]
- [infiniband] RDMA/nes: In nes_post_recv() always set bad_wr on error (Doug Ledford) [500229]
- [infiniband] RDMA/nes: In nes_post_send() always set bad_wr on error (Doug Ledford) [500229]
- [netdrv] cxgb3: fix linkup issue (Doug Ledford) [500229]
- [netdrv] RDMA/cxgb3: Wait at least one schedule cycle during device removal (Doug Ledford) [500229]
- [netdrv] cxgb3: fix hot plug removal crash (Doug Ledford) [500229]
- [netdrv] RDMA/cxgb3: Mark RDMA device with CXIO_ERROR_FATAL when removing (Doug Ledford) [500229]
- [netdrv] RDMA/cxgb3: Don't allocate the SW queue for user mode CQs (Doug Ledford) [500229]
- [netdrv] RDMA/cxgb3: Increase the max CQ depth (Doug Ledford) [500229]
- [netdrv] RDMA/cxgb3: Doorbell overflow avoidance and recovery (Doug Ledford) [500229]
- [netdrv] cxgb3: convert to use netdev_for_each_addr (Doug Ledford) [500229]
- [netdrv] cxgb3: fix link flap (Doug Ledford) [500229]
- [netdrv] cxgb3: FIx VLAN over Jumbo frames (Doug Ledford) [500229]
- [netdrv] RDMA/cxgb3: Remove BUG_ON() on CQ rearm failure (Doug Ledford) [500229]
- [netdrv] cxgb3: fix GRO checksum check (Doug Ledford) [500229]
- [netdrv] cxgb3: add memory barriers (Doug Ledford) [500229]
- [netdrv] iwch_cm.c: use pM to show MAC address (Doug Ledford) [500229]
- [netdrv] cxgb3: Use kzalloc for allocating only one thing (Doug Ledford) [500229]
- [netdrv] RDMA/cxgb3: Fix error paths in post_send and post_recv (Doug Ledford) [500229]
- [netdrv] cxgb3: declare MODULE_FIRMWARE (Doug Ledford) [500229]
- [netdrv] cxgb3: Set the rxq (Doug Ledford) [500229]
- [netdrv] cxgb3: No need to wake queue in xmit handler (Doug Ledford) [500229]
- [netdrv] cxgb3: Added private MAC address and provisioning packet handler for iSCSI (Doug Ledford) [500229]
- [net] Hook up cxgb4 to Kconfig and Makefile (Doug Ledford) [500229]
- [netdrv] cxgb4: Add remaining driver headers and L2T management (Doug Ledford) [500229]
- [netdrv] cxgb4: Add main driver file and driver Makefile (Doug Ledford) [500229]
- [netdrv] cxgb4: Add HW and FW support code (Doug Ledford) [500229]
- [netdrv] cxgb4: Add packet queues and packet DMA code (Doug Ledford) [500229]
- [netdrv] cxgb4: Add register, message, and FW definitions (Doug Ledford) [500229]
- [net] use helpers to access mc list (Doug Ledford) [500229]
- [net] use helpers to access uc list (Doug Ledford) [500229]
- [kernel] strstrip incorrectly marked __must_check (Doug Ledford) [500229]
- [pci] introduce pci_pcie_cap() (Doug Ledford) [500229]
- [pci] cache PCIe capability offset (Doug Ledford) [500229]
- [kernel] bitmap: introduce bitmap_set, bitmap_clear, bitmap_find_next_zero_area (Doug Ledford) [500229]
- [md] Remove unnecessary casts of void * (Doug Ledford) [583050 586296 586299 588371]
- [md] expose max value of behind writes counter (Doug Ledford) [583050 586296 586299 588371]
- [md] remove some dead fields from mddev_s (Doug Ledford) [583050 586296 586299 588371]
- [md] allow integers to be passed to md/level (Doug Ledford) [583050 586296 586299 588371]
- [md] notify mdstat waiters of level change (Doug Ledford) [583050 586296 586299 588371]
- [md] don't unregister the thread in mddev_suspend (Doug Ledford) [583050 586296 586299 588371]
- [md] factor out init code for an mddev (Doug Ledford) [583050 586296 586299 588371]
- [md] pass mddev to make_request functions rather than request_queue (Doug Ledford) [583050 586296 586299 588371]
- [md] call md_stop_writes from md_stop (Doug Ledford) [583050 586296 586299 588371]
- [md] split md_set_readonly out of do_md_stop (Doug Ledford) [583050 586296 586299 588371]
- [md] factor md_stop_writes out of do_md_stop (Doug Ledford) [583050 586296 586299 588371]
- [md] start to refactor do_md_stop (Doug Ledford) [583050 586296 586299 588371]
- [md] factor do_md_run to separate accesses to ->gendisk (Doug Ledford) [583050 586296 586299 588371]
- [md] remove ->changed and related code (Doug Ledford) [583050 586296 586299 588371]
- [md] don't reference gendisk in getgeo (Doug Ledford) [583050 586296 586299 588371]
- [md] move io accounting out of personalities into md_make_request (Doug Ledford) [583050 586296 586299 588371]
- [md] notify level changes through sysfs (Doug Ledford) [583050 586296 586299 588371]
- [md] Relax checks on ->max_disks when external metadata handling is used (Doug Ledford) [583050 586296 586299 588371]
- [md] Correctly handle device removal via sysfs (Doug Ledford) [583050 586296 586299 588371]
- [md] Add support for Raid5->Raid0 and Raid10->Raid0 takeover (Doug Ledford) [583050 586296 586299 588371]
- [md] Add support for Raid0->Raid5 takeover (Doug Ledford) [583050 586296 586299 588371]
- [md] discard StateChanged device flag (Doug Ledford) [583050 586296 586299 588371]
- [md] manage redundancy group in sysfs when changing level (Doug Ledford) [583050 586296 586299 588371]
- [md] remove unneeded sysfs files more promptly (Doug Ledford) [583050 586296 586299 588371]
- [md] set mddev readonly flag on blkdev BLKROSET ioctl (Doug Ledford) [583050 586296 586299 588371]
- [md] don't insist on valid event count for spare devices (Doug Ledford) [583050 586296 586299 588371]
- [md] simplify updating of event count to sometimes avoid updating spares (Doug Ledford) [583050 586296 586299 588371]
- [md] restore ability of spare drives to spin down (Doug Ledford) [583050 586296 586299 588371]
- [md] raid6: Fix raid-6 read-error correction in degraded state (Doug Ledford) [583050 586296 586299 588371]
- [md] raid5: allow for more than 2^31 chunks (Doug Ledford) [583050 586296 586299 588371]
- [md] deal with merge_bvec_fn in component devices better (Doug Ledford) [583050 586296 586299 588371]
- [md] fix some lockdep issues between md and sysfs (Doug Ledford) [583050 586296 586299 588371]
- [md] fix 'degraded' calculation when starting a reshape (Doug Ledford) [583050 586296 586299 588371]
- [md] allow a resync that is waiting for other resync to complete, to be aborted (Doug Ledford) [583050 586296 586299 588371]
- [md] remove unnecessary code from do_md_run (Doug Ledford) [583050 586296 586299 588371]
- [md] make recovery started by do_md_run() visible via sync_action (Doug Ledford) [583050 586296 586299 588371]
- [md] use pU to print UUIDs (Doug Ledford) [583050 586296 586299 588371]
- [md] add 'recovery_start' per-device sysfs attribute (Doug Ledford) [583050 586296 586299 588371]
- [md] rcu_read_lock() walk of mddev->disks in md_do_sync() (Doug Ledford) [583050 586296 586299 588371]
- [md] integrate spares into array at earliest opportunity (Doug Ledford) [583050 586296 586299 588371]
- [md] move compat_ioctl handling into md.c (Doug Ledford) [583050 586296 586299 588371]
- [md] add MODULE_DESCRIPTION for all md related modules (Doug Ledford) [583050 586296 586299 588371]
- [md] raid: improve MD/raid10 handling of correctable read errors (Doug Ledford) [583050 586296 586299 588371]
- [md] raid10: print more useful messages on device failure (Doug Ledford) [583050 586296 586299 588371]
- [md] bitmap: update dirty flag when bitmap bits are explicitly set (Doug Ledford) [583050 586296 586299 588371]
- [md] Support write-intent bitmaps with externally managed metadata (Doug Ledford) [583050 586296 586299 588371]
- [md] bitmap: move setting of daemon_lastrun out of bitmap_read_sb (Doug Ledford) [583050 586296 586299 588371]
- [md] support updating bitmap parameters via sysfs (Doug Ledford) [583050 586296 586299 588371]
- [md] factor out parsing of fixed-point numbers (Doug Ledford) [583050 586296 586299 588371]
- [md] support bitmap offset appropriate for external-metadata arrays (Doug Ledford) [583050 586296 586299 588371]
- [md] remove needless setting of thread->timeout in raid10_quiesce (Doug Ledford) [583050 586296 586299 588371]
- [md] change daemon_sleep to be in 'jiffies' rather than 'seconds' (Doug Ledford) [583050 586296 586299 588371]
- [md] move offset, daemon_sleep and chunksize out of bitmap structure (Doug Ledford) [583050 586296 586299 588371]
- [md] collect bitmap-specific fields into one structure (Doug Ledford) [583050 586296 586299 588371]
- [md] add honouring of suspend_{lo,hi} to raid1 (Doug Ledford) [583050 586296 586299 588371]
- [md] raid5: don't complete make_request on barrier until writes are scheduled (Doug Ledford) [583050 586296 586299 588371]
- [md] support barrier requests on all personalities (Doug Ledford) [583050 586296 586299 588371]
- [md] don't reset curr_resync_completed after an interrupted resync (Doug Ledford) [583050 586296 586299 588371]
- [md] adjust resync_min usefully when resync aborts (Doug Ledford) [583050 586296 586299 588371]

* Mon May 24 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-29.el6]
- [mm] fix mm_take_all_locks regression in 3-7/49 (Andrea Arcangeli) [556572]
- [mm] avoid __cpuset_node_allowed_softwall to run when allocation is atomic (Andrea Arcangeli) [556572 591283]
- [mm] fix race between do_huge_pmd_anonymous_page and pte_alloc_map (Andrea Arcangeli) [556572]
- [mm] add missing update for root-anon-vma drop_anon_vma in memory compactation (Andrea Arcangeli) [556572]
- [mm] exec vs split_huge_page (Andrea Arcangeli) [556572]
- [mm] include anon hugepages into the anon stats (Andrea Arcangeli) [556572]
- [mm] split_huge_page anon_vma ordering dependency (Andrea Arcangeli) [556572]
- [mm] align page_add_new_anon_rmap (Andrea Arcangeli) [556572]
- [mm] do_pages_move cannot handle hugepages (Andrea Arcangeli) [556572]
- [mm] padding to decrease risk of kabi breakage (Andrea Arcangeli) [556572]
- [mm] transhuge isolate_migratepages() (Andrea Arcangeli) [556572]
- [mm] select CONFIG_COMPACTION if TRANSPARENT_HUGEPAGE enabled (Andrea Arcangeli) [556572]
- [mm] compaction: Do not schedule work on other CPUs for compaction (Andrea Arcangeli) [556572]
- [mm] Defer compaction using an exponential backoff when compaction fails (Andrea Arcangeli) [556572]
- [mm] Add a tunable that decides when memory should be compacted and when it should be reclaimed (Andrea Arcangeli) [556572]
- [mm] Direct compact when a high-order allocation fails (Andrea Arcangeli) [556572]
- [mm] Add /sys trigger for per-node memory compaction (Andrea Arcangeli) [556572]
- [mm] Add /proc trigger for memory compaction (Andrea Arcangeli) [556572]
- [mm] Memory compaction core (Andrea Arcangeli) [556572]
- [mm] Move definition for LRU isolation modes to a header (Andrea Arcangeli) [556572]
- [mm] Export fragmentation index via /proc/extfrag_index (Andrea Arcangeli) [556572]
- [mm] Export unusable free space index via /proc/unusable_index (Andrea Arcangeli) [556572]
- [mm] Allow CONFIG_MIGRATION to be set without CONFIG_NUMA or memory hot-remove (Andrea Arcangeli) [556572]
- [mm] Allow the migration of PageSwapCache pages (Andrea Arcangeli) [556572]
- [mm] Do not try to migrate unmapped anonymous pages (Andrea Arcangeli) [556572]
- [mm] Share the anon_vma ref counts between KSM and page migration (Andrea Arcangeli) [556572]
- [mm] Take a reference to the anon_vma before migrating (Andrea Arcangeli) [556572]
- [mm] add numa awareness to hugepage allocations (Andrea Arcangeli) [556572]
- [mm] enable direct defrag (Andrea Arcangeli) [556572]
- [mm] ksm: check for ERR_PTR from follow_page() (Andrea Arcangeli) [556572]
- [mm] err.h: add helper function to simplify pointer error checking (Andrea Arcangeli) [556572]
- [mm] don't leave orhpaned swap cache after ksm merging (Andrea Arcangeli) [556572]
- [mm] adapt to anon-vma root locking (Andrea Arcangeli) [556572]
- [mm] set default to never (Andrea Arcangeli) [556572]
- [mm] transparent hugepage bootparam (Andrea Arcangeli) [556572]
- [mm] remove lumpy reclaim (Andrea Arcangeli) [556572 583003]
- [mm] memcg fix prepare migration (Andrea Arcangeli) [556572]
- [mm] avoid false positive warning in mmio (Andrea Arcangeli) [556572]
- [virt] fix kvm swapping memory corruption (Andrea Arcangeli) [556572 583861]
- [mm] remove khugepaged/enabled (Andrea Arcangeli) [556572]
- [mm] use only khugepaged_wait (Andrea Arcangeli) [556572]
- [mm] khugepaged user stack (Andrea Arcangeli) [556572]
- [mm] define hugetlb_page (Andrea Arcangeli) [556572]
- [mm] migration: avoid race between shift_arg_pages() and rmap_walk() during migration by not migrating temporary stacks (Andrea Arcangeli) [556572]
- [mm] extend KSM refcounts to the anon_vma root (Andrea Arcangeli) [556572]
- [mm] always lock the root (oldest) anon_vma (Andrea Arcangeli) [556572]
- [mm] track the root (oldest) anon_vma (Andrea Arcangeli) [556572]
- [mm] change direct call of spin_lock(anon_vma->lock) to inline function (Andrea Arcangeli) [556572]
- [mm] rename anon_vma_lock to vma_lock_anon_vma (Andrea Arcangeli) [556572]
- [mm] rmap: remove anon_vma check in page_address_in_vma() (Andrea Arcangeli) [556572]
- [mm] mmap: check ->vm_ops before dereferencing (Andrea Arcangeli) [556572]
- [fs] xfs_export_operations.commit_metadata (Christoph Hellwig) [585442]
- [fs] xfs: fix inode pincount check in fsync (Christoph Hellwig) [585442]
- [fs] xfs: miscellaneous fixes from 2.6.34 (Dave Chinner) [585442]
- [fs] xfs: reserved block pool and ENOSPC fixes from 2.6.34 (Dave Chinner) [542712 585442]
- [fs] xfs: delayed write metadata from 2.6.34 (Dave Chinner) [585442]
- [lib] introduce list_sort (Dave Chinner) [585442]
- [fs] xfs: log fixes from 2.6.34 (Dave Chinner) [585442]
- [fs] xfs: quota changes from 2.6.34 (Dave Chinner) [585442]
- [fs] xfs: buffer API cleanups from 2.6.34 (Dave Chinner) [585442]
- [fs] xfs: AG indexing fixes from 2.6.34 (Dave Chinner) [585442]
- [fs] xfs: idle kernel thread fixes from 2.6.34 (Dave Chinner) [585442]
- [fs] online defrag fixes from 2.6.34 (Dave Chinner) [585442]
- [fs] jbd2: delay discarding buffers in journal_unmap_buffer (Eric Sandeen) [593082]
- [fs] ext4: Use slab allocator for sub-page sized allocations (Eric Sandeen) [593082]
- [fs] jbd2: don't use __GFP_NOFAIL in journal_init_common() (Eric Sandeen) [593082]
- [fs] jbd: jbd-debug and jbd2-debug should be writable (Eric Sandeen) [593082]
- [fs] ext4: Fixed inode allocator to correctly track a flex_bg's used_dirs (Eric Sandeen) [593082]
- [fs] ext4: Fix estimate of # of blocks needed to write indirect-mapped files (Eric Sandeen) [593082]
- [fs] ext4: fix up rb_root initializations to use RB_ROOT (Eric Sandeen) [593082]
- [fs] ext4: Release page references acquired in ext4_da_block_invalidatepages (Eric Sandeen) [593082]
- [fs] ext4: make "offset" consistent in ext4_check_dir_entry() (Eric Sandeen) [593082]
- [fs] ext4: Convert BUG_ON checks to use ext4_error() instead (Eric Sandeen) [593082]
- [fs] ext4: Handle non empty on-disk orphan link (Eric Sandeen) [593082]
- [fs] ext4: explicitly remove inode from orphan list after failed direct io (Eric Sandeen) [593082]
- [fs] ext4: Fix fencepost error in chosing choosing group vs file preallocation (Eric Sandeen) [593082]
- [fs] ext4: Fix BUG_ON at fs/buffer.c:652 in no journal mode (Eric Sandeen) [593082]
- [fs] ext4: correctly calculate number of blocks for fiemap (Eric Sandeen) [593082]
- [fs] ext4: add missing error checking to ext4_expand_extra_isize_ea() (Eric Sandeen) [593082]
- [fs] ext4: move __func__ into a macro for ext4_warning, ext4_error (Eric Sandeen) [593082]
- [fs] ext4: Use bitops to read/modify EXT4_I(inode)->i_state (Eric Sandeen) [593082]
- [fs] ext4: Drop EXT4_GET_BLOCKS_UPDATE_RESERVE_SPACE flag (Eric Sandeen) [593082]
- [fs] ext4: return correct wbc.nr_to_write in ext4_da_writepages (Eric Sandeen) [593082]
- [fs] ext4: replace BUG() with return -EIO in ext4_ext_get_blocks (Eric Sandeen) [593082]
- [virt] KVM SVM Implement workaround for Erratum 383 (Bhavna Sarathy) [592311]
- [virt] KVM SVM Handle MCEs early in the vmexit process (Bhavna Sarathy) [592311]
- [usb] serial: ftdi: add CONTEC vendor and product id (Stanislaw Gruszka) [584757]
- [usb] fix usbfs regression (Stanislaw Gruszka) [584757]
- [usb] add new ftdi_sio device ids (Stanislaw Gruszka) [580067]
- [usb] ftdi_sio: add device IDs (several ELV, one Mindstorms NXT) (Stanislaw Gruszka) [580067]
- [usb] ftdi_sio: new device id for papouch AD4USB (Stanislaw Gruszka) [580067]
- [v4l] gspca_mr973010a: Fix cif type 1 cameras not streaming on UHCI controllers (Stanislaw Gruszka) [580067]
- [v4l] DVB: Add support for Asus Europa Hybrid DVB-T card (Stanislaw Gruszka) [580063]
- [usb] mos7840: add device IDs for B&B electronics devices (Stanislaw Gruszka) [580063]
- [ppc64] fsl: Add PCI device ids for new QoirQ chips (Stanislaw Gruszka) [580063]
- [fs] vfs: Fix vmtruncate() regression (Stanislaw Gruszka) [579693]
- [kernel] sched: Fix task priority bug (Stanislaw Gruszka) [579693]
- [serial] 8250_pnp: add a new Fujitsu Wacom Tablet PC device (Stanislaw Gruszka) [579693]
- [i2c] pca: Don't use *_interruptible (Stanislaw Gruszka) [579693]
- [i2c] Do not use device name after device_unregister (Stanislaw Gruszka) [579693]
- [kernel] sched: Fix cpu_clock() in NMIs, on !CONFIG_HAVE_UNSTABLE_SCHED_CLOCK (Stanislaw Gruszka) [579693]
- [hid] add device IDs for new model of Apple Wireless Keyboard (Stanislaw Gruszka) [579693]
- [v4l] gspca: sn9c20x: Fix test of unsigned (Stanislaw Gruszka) [579693]
- [x86] SGI UV: Fix mapping of MMIO registers (Stanislaw Gruszka) [579693]
- [perf] timechart: Use tid not pid for COMM change (Stanislaw Gruszka) [580062]
- [usb] fix usbstorage for 2770:915d delivers no FAT (Stanislaw Gruszka) [580062]
- [x86] PCI/PAT: return EINVAL for pci mmap WC request for !pat_enabled (Stanislaw Gruszka) [580062]
- [acpi] EC: Add wait for irq storm (Stanislaw Gruszka) [580062]
- [acpi] EC: Accelerate query execution (Stanislaw Gruszka) [580062]
- [usb] add speed values for USB 3.0 and wireless controllers (Stanislaw Gruszka) [580062]
- [usb] add missing delay during remote wakeup (Stanislaw Gruszka) [580062]
- [usb] EHCI & UHCI: fix race between root-hub suspend and port resume (Stanislaw Gruszka) [580062]
- [usb] EHCI: fix handling of unusual interrupt intervals (Stanislaw Gruszka) [580062]
- [usb] Don't use GFP_KERNEL while we cannot reset a storage device (Stanislaw Gruszka) [580062]
- [usb] serial: fix memory leak in generic driver (Stanislaw Gruszka) [580062]
- [char] nozomi: quick fix for the close/close bug (Stanislaw Gruszka) [580062]
- [tty] fix race in tty_fasync (Stanislaw Gruszka) [580062]
- [netdrv] netiucv: displayed TX bytes value much too high (Stanislaw Gruszka) [580063]
- [block] md: fix small irregularity with start_ro module parameter (Stanislaw Gruszka) [580063]
- [input] i8042: add Dritek quirk for Acer Aspire 5610 (Stanislaw Gruszka) [580063]
- [hid] fixup quirk for NCR devices (Stanislaw Gruszka) [580063]
- [dmi] allow omitting ident strings in DMI tables (Stanislaw Gruszka) [580063]
- [scsi] scsi_dh: create sysfs file, dh_state for all SCSI disk devices (Stanislaw Gruszka) [580063]
- [nfs] Revert default r/wsize behavior (Stanislaw Gruszka) [580063]
- [usb] SIS USB2VGA DRIVER: support KAIREN's USB VGA adaptor USB20SVGA-MB-PLUS (Stanislaw Gruszka) [580067]
- [input] alps: add support for the touchpad on Toshiba Tecra A11-11L (Stanislaw Gruszka) [584757]
- [fs] gfs2: stuck in inode wait, no glocks stuck (Robert S Peterson) [583737]
- [netdrv] cnic: update to to 2.1.1 (Stanislaw Gruszka) [590019]
- [netdrv] bnx2x: fix system hung after netdev watchdog (Stanislaw Gruszka) [581907]
- [netdrv] bnx2: Fix most severe bugs in bnx2 2.0.8+ (John Feeney) [590879]
- [netdrv] Update bnx2 driver to 2.0.8 and fw to mips-06-5.0.0.j6 et al (John Feeney) [464728]
- [virt] VMware Balloon driver (Amit Shah) [582826]
- [x86] With Sandybridge graphics, kernel reboots unless 'agp=off' used on command line (John Villalovos) [591294]
- [kernel] unify string representation of NULL in vsprintf.c (Dave Anderson) [589613]
- [kernel] coredump: fix the page leak in dump_seek() (Oleg Nesterov) [580126]
- [edac] EDAC support for Nehalem Memory Controllers (Mauro Carvalho Chehab) [584507]
- [iscsi] Include support for next gen Dell iSCSI PowerVault controller MD36xxi into RDAC scsi device handler's device list (Shyam Iyer) [593814]
- [scsi] lpfc Update from 8.3.5.9 to 8.3.5.13 FC/FCoE (Rob Evers) [591648]
- [infiniband] iser: fix failover slowdown (Mike Christie) [589174]
- [net] TCP: avoid to send keepalive probes if receiving data (Flavio Leitner) [593052]
- [nfs] commit_metadata export operation replacing nfsd_sync_dir (Christoph Hellwig) [593652]
- [ppc64] numa: Add form 1 NUMA affinity (Steve Best) [593466]
- [ppc64] eeh: Fix a bug when pci structure is null (Steve Best) [593854]
- [ppc64] perf_event: Fix oops due to perf_event_do_pending call (Steve Best) [593464]
- [ppc] pseries: Quieten cede latency printk (Steve Best) [591739]
- [fs] GFS2: Don't "get" xattrs for ACLs when ACLs are turned off (Steven Whitehouse) [546294]
- [kexec] fix OOPS in crash_kernel_shrink (Steve Best) [592336]
- [fs] ext4: don't use quota reservation for speculative metadata blocks (Eric Sandeen) [587095]
- [fs] quota: add the option to not fail with EDQUOT in block allocation (Eric Sandeen) [587095]
- [fs] quota: use flags interface for dquot alloc/free space (Eric Sandeen) [587095]
- [fs] ext4: Fix quota accounting error with fallocate (Eric Sandeen) [587095]
- [fs] ext4: Ensure zeroout blocks have no dirty metadata (Eric Sandeen) [587095]
- [virt] vhost-net: utilize PUBLISH_USED_IDX feature (Michael S. Tsirkin) [593158]
- [virt] virtio: put last seen used index into ring itself (Michael S. Tsirkin) [593158]
- [virt] vhost: fix barrier pairing (Michael S. Tsirkin) [593158]
- [virt] virtio: use smp_XX barriers on SMP (Michael S. Tsirkin) [593158]
- [virt] virtio_ring: remove a level of indirection (Michael S. Tsirkin) [593158]
- [virt] trans_virtio: use virtqueue_xxx wrappers (Michael S. Tsirkin) [593158]
- [virt] virtio-rng: use virtqueue_xxx wrappers (Michael S. Tsirkin) [593158]
- [virt] virtio_net: use virtqueue_xxx wrappers (Michael S. Tsirkin) [593158]
- [virt] virtio_blk: use virtqueue_xxx wrappers (Michael S. Tsirkin) [593158]
- [virt] virtio_console: use virtqueue_xxx wrappers (Michael S. Tsirkin) [593158]
- [virt] virtio_balloon: use virtqueue_xxx wrappers (Michael S. Tsirkin) [593158]
- [virt] virtio: add virtqueue_ vq_ops wrappers (Michael S. Tsirkin) [593158]
- [virt] vhost-net: fix vq_memory_access_ok error checking (Michael S. Tsirkin) [593158]
- [virt] vhost: fix error handling in vring ioctls (Michael S. Tsirkin) [593158]
- [virt] vhost: fix interrupt mitigation with raw sockets (Michael S. Tsirkin) [593158]
- [virt] vhost: fix error path in vhost_net_set_backend (Michael S. Tsirkin) [593158]
- [netdrv] iwlwifi: iwl_good_ack_health() only apply to AGN device (John Linville) [573029]
- [netdrv] iwlwifi: code cleanup for connectivity recovery (John Linville) [573029]
- [netdrv] iwlwifi: Recover TX flow failure (John Linville) [573029]
- [netdrv] iwlwifi: move plcp check to separated function (John Linville) [573029]
- [netdrv] iwlwifi: Recover TX flow stall due to stuck queue (John Linville) [573029]
- [netdrv] iwlwifi: add internal short scan support for 3945 (John Linville) [573029]
- [netdrv] iwlwifi: separated time check for different type of force reset (John Linville) [573029]
- [netdrv] iwlwifi: Adjusting PLCP error threshold for 1000 NIC (John Linville) [573029]
- [netdrv] iwlwifi: multiple force reset mode (John Linville) [573029]
- [netdrv] iwlwifi: Tune radio to prevent unexpected behavior (John Linville) [573029]
- [netdrv] iwlwifi: Logic to control how frequent radio should be reset if needed (John Linville) [573029]
- [netdrv] iwlwifi: add function to reset/tune radio if needed (John Linville) [573029]
- [netdrv] iwlwifi: clear all the stop_queue flag after load firmware (John Linville) [573029]
- [netdrv] iwlwifi: check for aggregation frame and queue (John Linville) [573029]
- [ppc64] kdump: Fix race in kdump shutdown (Steve Best) [559709]
- [ppc64] kexec: Fix race in kexec shutdown (Steve Best) [593853]
- [net] Add ndo_{set|get}_vf_port support for enic dynamic vnics (Chris Wright) [581087]
- [net] Add netlink support for virtual port management (was iovnl) (Chris Wright) [581087]
- [net] core: add IFLA_STATS64 support (Chris Wright) [581087]
- [netdrv] igb: support for VF configuration tools (Chris Wright) [581087]
- [net] rtnetlink: Add SR-IOV VF configuration methods (Chris Wright) [581087]
- [pci] Add SR-IOV convenience functions and macros (Chris Wright) [581087]
- [scsi] sync iscsi layer (Mike Christie) [564148 570682]

* Thu May 20 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-28.el6]
- [mm] New round-robin rotor for SLAB allocations (Larry Woodman) [593154]
- [netdrv] ixgbe: FCoE fixes (Andy Gospodarek) [593474]
- [net] vlan: updates vlan real_num_tx_queues (Andy Gospodarek) [593474]
- [net] vlan: adds vlan_dev_select_queue (Andy Gospodarek) [593474]
- [net] vlan: Precise RX stats accounting (Andy Gospodarek) [593474]
- [net] add dev_txq_stats_fold() helper (Andy Gospodarek) [593474]
- [net] vlan: Add support to netdev_ops.ndo_fcoe_get_wwn for VLAN device (Andy Gospodarek) [593474]
- [netdrv] ixgbe: fixes for link problems, possible DMA errors, and VF/SR-IOV changes (Andy Gospodarek) [575188]
- [sound] ALSA HDA driver update 2010-05-11 (Jaroslav Kysela) [591083]
- [mm] show per-process swap usage via procfs (Larry Woodman) [546533]
- [netdrv] cxgb3 won't recover from EEH event twice (Steve Best) [591738]
- [virt] x86, cpu: Print AMD virtualization features in /proc/cpuinfo (Gleb Natapov) [592688]
- [x86] Intel ICH9 workaround for HPET timer issue on IbexPeak Platform (Luming Yu) [502629]
- [pci] Update pci_dev and pci_bus structs before kabi freeze (Prarit Bhargava) [593322]
- [pci] Output FW warning in pci_read/write_vpd (Prarit Bhargava) [586979]
- [infiniband] ehca: Require in_wc in process_mad() (Steve Best) [593095]
- [security] mmap_min_addr check CAP_SYS_RAWIO only for write (Eric Paris) [592417]
- [scsi] aacraid: Eliminate use after free (Tomas Henzl) [592926]
- [scsi] lpfc Update from 8.3.5.7 to 8.3.5.9 FC/FCoE (Rob Evers) [580677]
- [char] Eliminate use after free (Amit Shah) [593189]
- [ipmi] fix unlock balance (Tomas Henzl) [592925]
- [ppc64] only call start-cpu when a CPU is stopped (Steve Best) [592440]
- [ppc64] make query_cpu_stopped callable outside hotplug cpu (Steve Best) [592440]
- [kernel] cpufreq: make the iowait-is-busy-time a sysfs tunable (Rik van Riel) [585330]
- [kernel] ondemand: Solve the big performance issue with ondemand during disk IO (Rik van Riel) [585330]
- [kernel] sched: introduce get_cpu_iowait_time_us() (Rik van Riel) [585330]
- [kernel] sched: eliminate the ts->idle_lastupdate field (Rik van Riel) [585330]
- [kernel] sched: fold updating of the last update time into update_ts_time_stats() (Rik van Riel) [585330]
- [kernel] sched: update the idle statistics in get_cpu_idle_time_us (Rik van Riel) [585330]
- [kernel] sched: introduce a function to update the idle statistics (Rik van Riel) [585330]
- [kernel] sched: add a comment to get_cpu_idle_time_us (Rik van Riel) [585330]
- [kernel] nohz: Reuse ktime in sub-functions of tick_check_idle (Rik van Riel) [585330]
- [virt] Xen PV-on-HVM: Disable xen-blkfront for IDE & SCSI devices (Don Dutile) [523134]
- [virt] xen: PV-on-HVM: Disable xen-blkfront for PV-on-HVM for now (Don Dutile) [523134]
- [virt] xen: PV-on-HVM: Prevent pv drivers from crashing a FV guest if pv-on-hvm not configured (Don Dutile) [523134]
- [virt] xen: PV-on-HVM: Add kernel command line enablement control (Don Dutile) [523134]
- [virt] xen: backport PV-on-HVM (Don Dutile) [523134]
- [ppc] pseries: Pass more accurate number of supported cores to firmware (Steve Best) [591341]
- [ppc] Add static fields to ibm, client-architecture call (Steve Best) [591341]
- [kernel] mutex: Fix optimistic spinning vs. BKL (Steve Best) [591735]
- [kernel] mutex: Don't spin when the owner CPU is offline or other weird cases (Steve Best) [591735]
- [kernel] sched: Don't use possibly stale sched_class (Stanislaw Gruszka) [580067]
- [usb] unusual_devs: Add support for multiple Option 3G sticks (Stanislaw Gruszka) [580067]
- [usb] cp210x: Add 81E8 Zephyr Bioharness (Stanislaw Gruszka) [580067]
- [usb] serial: ftdi: add CONTEC vendor and product id (Stanislaw Gruszka) [580067]
- [usb] ftdi_sio: sort PID/VID entries in new ftdi_sio_ids.h header (Stanislaw Gruszka) [580067]
- [usb] ftdi_sio: isolate all device IDs to new ftdi_sio_ids.h header (Stanislaw Gruszka) [580067]
- [usb] Move hcd free_dev call into usb_disconnect to fix oops (Stanislaw Gruszka) [580067]
- [usb] remove debugging message for uevent constructions (Stanislaw Gruszka) [580067]
- [usb] fix crash in uhci_scan_schedule (Stanislaw Gruszka) [580067]
- [usb] fix the idProduct value for USB-3.0 root hubs (Stanislaw Gruszka) [580067]
- [usb] xhci: Fix finding extended capabilities registers (Stanislaw Gruszka) [580067]
- [x86] Fix SCI on IOAPIC != 0 (Stanislaw Gruszka) [580067]
- [x86] Avoid race condition in pci_enable_msix() (Stanislaw Gruszka) [580067]
- [x86] thinkpad-acpi: make driver events work in NVRAM poll mode (Stanislaw Gruszka) [580067]
- [x86] thinkpad-acpi: document HKEY event 3006 (Stanislaw Gruszka) [580067]
- [x86] thinkpad-acpi: R52 brightness_mode has been confirmed (Stanislaw Gruszka) [580067]
- [x86] thinkpad-acpi: fix poll thread auto-start (Stanislaw Gruszka) [580067]
- [net] scm: Only support SCM_RIGHTS on unix domain sockets. (Stanislaw Gruszka) [580067]
- [usb] serial: sierra driver indat_callback fix (Stanislaw Gruszka) [580067]
- [tty] Fix the ldisc hangup race (Stanislaw Gruszka) [580067]
- [kernel] devtmpfs: reset inode permissions before unlinking (Stanislaw Gruszka) [580067]
- [kernel] driver-core: fix race condition in get_device_parent() (Stanislaw Gruszka) [580067]
- [pm] hibernate: Fix preallocating of memory (Stanislaw Gruszka) [580067]
- [tpm] tpm_tis: TPM_STS_DATA_EXPECT workaround (Stanislaw Gruszka) [580067]
- [fs] Switch proc/self to nd_set_link() (Stanislaw Gruszka) [580067]
- [hid] usbhid: introduce timeout for stuck ctrl/out URBs (Stanislaw Gruszka) [580067]
- [hid] add multi-input quirk for NextWindow Touchscreen (Stanislaw Gruszka) [580067]
- [hid] remove TENX iBuddy from blacklist (Stanislaw Gruszka) [580067]
- [fs] vfs: take f_lock on modifying f_mode after open time (Stanislaw Gruszka) [580067]
- [acpi] thinkpad-acpi: wrong thermal attribute_group removed in thermal_exit() (Stanislaw Gruszka) [580067]
- [acpi] fix "acpi=ht" boot option (Stanislaw Gruszka) [580067]
- [acpi] remove Asus P2B-DS from acpi=ht blacklist (Stanislaw Gruszka) [580067]
- [pci] hotplug: check ioremap() return value in ibmphp_ebda.c (Stanislaw Gruszka) [580067]
- [pci] hotplug: ibmphp: read the length of ebda and map entire ebda region (Stanislaw Gruszka) [580067]
- [x86] msr/cpuid: Pass the number of minors when unregistering MSR and CPUID drivers (Stanislaw Gruszka) [580063]
- [fs] fnctl: f_modown should call write_lock_irqsave/restore (Stanislaw Gruszka) [580063]
- [sound] ASoC: fix a memory-leak in wm8903 (Stanislaw Gruszka) [580063]
- [mtd] UBI: initialise update marker (Stanislaw Gruszka) [580063]
- [mtd] UBI: fix memory leak in update path (Stanislaw Gruszka) [580063]
- [ipc] ns: fix memory leak (idr) (Stanislaw Gruszka) [580063]
- [input] i8042: remove identification strings from DMI tables (Stanislaw Gruszka) [580063]
- [netdrv] starfire: clean up properly if firmware loading fails (Stanislaw Gruszka) [580064]
- [kernel] random: drop weird m_time/a_time manipulation (Stanislaw Gruszka) [580064]
- [kernel] random: Remove unused inode variable (Stanislaw Gruszka) [580064]
- [mm] purge fragmented percpu vmap blocks (Stanislaw Gruszka) [580064]
- [mm] percpu-vmap fix RCU list walking (Stanislaw Gruszka) [580064]
- [x86] Add quirk for Intel DG45FC board to avoid low memory corruption (Stanislaw Gruszka) [580064]
- [regulator] Specify REGULATOR_CHANGE_STATUS for WM835x LED constraints (Stanislaw Gruszka) [580064]
- [x86] Add Dell OptiPlex 760 reboot quirk (Stanislaw Gruszka) [580064]
- [mm] fix migratetype bug which slowed swapping (Stanislaw Gruszka) [580064]
- [input] winbond-cir: remove dmesg spam (Stanislaw Gruszka) [580064]
- [acpi] Advertise to BIOS in _OSC: _OST on _PPC changes (Stanislaw Gruszka) [580064]
- [infiniband] Fix failure exit in ipathfs (Stanislaw Gruszka) [580064]
- [acpi] fix OSC regression that caused aer and pciehp not to load (Stanislaw Gruszka) [580064]
- [acpi] Add platform-wide _OSC support (Stanislaw Gruszka) [580064]
- [acpi] Add a generic API for _OSC (Stanislaw Gruszka) [580064]
- [s390x] fix single stepped svcs with TRACE_IRQFLAGS=y (Stanislaw Gruszka) [580064]
- [fs] sysfs: sysfs_sd_setattr set iattrs unconditionally (Stanislaw Gruszka) [580065]
- [acpi] fix High cpu temperature with 2.6.32 (Stanislaw Gruszka) [580065]
- [usb] usbfs: properly clean up the as structure on error paths (Stanislaw Gruszka) [580065]
- [kernel] class: Free the class private data in class_release (Stanislaw Gruszka) [580065]
- [serial] 8250: add serial transmitter fully empty test (Stanislaw Gruszka) [580065]
- [rtc] rtc-fm3130: add missing braces (Stanislaw Gruszka) [580065]
- [ata] Call flush_dcache_page after PIO data transfers in libata-sff.c (Stanislaw Gruszka) [580065]
- [net] dst: call cond_resched() in dst_gc_task() (Stanislaw Gruszka) [580065]
- [crypto] padlock-sha: Add import/export support (Stanislaw Gruszka) [580065]
- [x86] dell-wmi, hp-wmi: check wmi_get_event_data() return value (Stanislaw Gruszka) [580065]
- [tpm] tpm_infineon: fix suspend/resume handler for pnp_driver (Stanislaw Gruszka) [580065]
- [usb] ftdi_sio: add USB device ID's for B&B Electronics line (Stanislaw Gruszka) [580063]
- [fs] anon_inode: set S_IFREG on the anon_inode (Eric Paris) [591813]

* Tue May 18 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-27.el6]
- [ppc] pseries: Flush lazy kernel mappings after unplug operations (Steve Best) [591340]
- [fs] ext3: enable barriers by default (Eric Sandeen) [586062]
- [tracing] regset xstate extensions + generic PTRACE_{GET,SET}REGSET support (Oleg Nesterov) [587724]
- [scsi] hpsa: update to 2.0.2 (Tomas Henzl) [587418]
- [mm] Print more information about the task being OOM killed (Larry Woodman) [546533]
- [netdrv] igb/igbvf: use netdev_alloc_skb_ip_align() (Stefan Assmann) [589497]
- [acpi] Fix regression where _PPC is not read at boot even when ignore_ppc=0 (Matthew Garrett) [571893]
- [x86] i386: Do a global tlb flush on S4 resume (Matthew Garrett) [572818]
- [pci] Add ABI for PCI runtime power management (Matthew Garrett) [589781]
- [block] Fix regression in O_DIRECT|O_SYNC writes to block devices (Jeff Moyer) [582628]
- [kernel] add skip_spaces() implementation (Jaroslav Kysela) [591078]
- [kernel] sched: cpuacct: Use bigger percpu counter batch values for stats counters (Steve Best) [591343]
- [kernel] idr: fix a critical misallocation bug (Eric Paris) [582109]
- [net] tcp: Fix OOB POLLIN avoidance (Oleg Nesterov) [584786]
- [s390x] qeth: synchronize configuration interface (Hendrik Brueckner) [586962]
- [fs] inotify: race use after free/double free in inotify inode marks (Eric Paris) [582109]
- [fs] ext4: Add flag to files with blocks intentionally past EOF (Eric Sandeen) [578562]
- [drm] backport patches up to 2.6.34-rc7 (Adam Jackson) [589792]
- [kernel] elf coredump: add extended numbering support (Amerigo Wang) [578659]
- [kernel] binfmt_elf_fdpic: Fix build breakage introduced by coredump changes. (Amerigo Wang) [578659]
- [kernel] elf coredump: make offset calculation process and writing process explicit (Amerigo Wang) [578659]
- [kernel] elf coredump: replace ELF_CORE_EXTRA_* macros by functions (Amerigo Wang) [578659]
- [kernel] coredump: move dump_write() and dump_seek() into a header file (Amerigo Wang) [578659]
- [kernel] coredump: unify dump_seek() implementations for each binfmt_*.c (Amerigo Wang) [578659]
- [mm] introduce coredump parameter structure (Amerigo Wang) [578659]
- [powerpc] Reduce printk from pseries_mach_cpu_die() (Steve Best) [590754]
- [powerpc] Move checks in pseries_mach_cpu_die() (Steve Best) [590754]
- [powerpc] Reset kernel stack on cpu online from cede state (Steve Best) [590754]
- [virt] don't compute pvclock adjustments if we trust the tsc (Glauber Costa) [569603]
- [virt] Try using new kvm clock msrs (Glauber Costa) [569603]
- [virt] Add a global synchronization point for pvclock (Glauber Costa) [569603]
- [virt] Enable pvclock flags in vcpu_time_info structure (Glauber Costa) [569603]
- [virt] Tell the guest we'll warn it about tsc stability (Glauber Costa) [592296]
- [virt] export paravirtual cpuid flags in KVM_GET_SUPPORTED_CPUID (Glauber Costa) [592296]
- [virt] add new KVMCLOCK cpuid feature (Glauber Costa) [592296]
- [virt] change msr numbers for kvmclock (Glauber Costa) [592296]
- [scsi] enclosure: fix oops while iterating enclosure_status array (Stanislaw Gruszka) [580062]
- [usb] fix bitmask merge error (Stanislaw Gruszka) [580062]
- [acpi] enable C2 and Turbo-mode on Nehalem notebooks on A/C (Stanislaw Gruszka) [580063]
- [input] i8042: add Gigabyte M1022M to the noloop list (Stanislaw Gruszka) [580063]
- [kernel] nohz: Prevent clocksource wrapping during idle (Stanislaw Gruszka) [580063]
- [kernel] sched: Fix missing sched tunable recalculation on cpu add/remove (Stanislaw Gruszka) [580063]
- [netdrv] atl1c: use common_task instead of reset_task and link_chg_task (Stanislaw Gruszka) [580063]
- [netdrv] atl1e: disable NETIF_F_TSO6 for hardware limit (Stanislaw Gruszka) [580063]
- [kernel] driver-core: fix devtmpfs crash on s390 (Stanislaw Gruszka) [580063]
- [kernel] devtmpfs: set root directory mode to 0755 (Stanislaw Gruszka) [580063]
- [input] ALPS: add interleaved protocol support for Dell E6x00 series (Stanislaw Gruszka) [580063]
- [mm] flush dcache before writing into page to avoid alias (Stanislaw Gruszka) [580064]
- [block] pktcdvd: removing device does not remove its sysfs dir (Stanislaw Gruszka) [580064]
- [mm] add new 'read_cache_page_gfp()' helper function (Stanislaw Gruszka) [580064]
- [acpi] Add NULL pointer check in acpi_bus_start (Stanislaw Gruszka) [580065]
- [usb] usbfs: only copy the actual data received (Stanislaw Gruszka) [580065]
- [net] netfilter: xtables: compat out of scope fix (Stanislaw Gruszka) [580065]
- [net] pktgen: Fix freezing problem (Stanislaw Gruszka) [580065]

* Thu May 13 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-26.el6]
- [scsi] Sync fcoe to upsteam (Mike Christie) [590781]
- [netdrv] bnx2x: fix memory barrier (Stanislaw Gruszka) [580477]
- [x86] kprobes: fix removed int3 checking order (Dave Anderson) [585400]
- [net] fix oops at bootime in sysctl code (Stanislaw Gruszka) [580064]
- [net] af_packet: Don't use skb after dev_queue_xmit() (Stanislaw Gruszka) [580064]
- [net] restore ip source validation (Stanislaw Gruszka) [580064]
- [net] tcp: update the netstamp_needed counter when cloning sockets (Stanislaw Gruszka) [580064]
- [net] icmp: send fragment reassembly timeout w/ conntrack enabled (Neil Horman) [563175]
- [fs] GFS2: stuck in inode wait, no glocks stuck (Robert S Peterson) [583737]
- [mm] compcache: Backport compcache: ramzswap documentation (Jerome Marchand) [578641]
- [mm] compcache: xvmalloc memory allocator (Jerome Marchand) [578641]
- [mm] compcache: virtual block device driver (ramzswap) (Jerome Marchand) [578641]
- [mm] readahead: fix NULL filp dereference (Josef Bacik) [591055]
- [netdrv] tg3: 57780 and 5785 devices refuse to attach (Andy Gospodarek) [564117]
- [x86] Fetch valid frequencies for powernow_k8.o from ACPI _PST table (Bhavna Sarathy) [464630]
- [s390x] ptrace: fix return value of do_syscall_trace_enter() (Hendrik Brueckner) [588216]
- [fs] gfs2: fix oops while copying from ext3 to gfs2 (Abhijith Das) [586009] {CVE-2010-1436}
- [virt] virtio: console: Accept console size along with resize control message (Amit Shah) [589307]
- [virt] virtio: console: Store each console's size in the console structure (Amit Shah) [589307]
- [virt] virtio: console: Resize console port 0 on config intr only if multiport is off (Amit Shah) [589307]
- [sound] ac97: Add IBM ThinkPad R40e to Headphone/Line Jack Sense blacklist (Stanislaw Gruszka) [584757]
- [sound] ac97: Add Toshiba P500 to ac97 jack sense blacklist (Stanislaw Gruszka) [584757]
- [x86] amd: Restrict usage of c1e_idle() (Stanislaw Gruszka) [584757]
- [x86] Fix placement of FIX_OHCI1394_BASE (Stanislaw Gruszka) [584757]
- [net] netfilter: xt_recent: fix regression in rules using a zero hit_count (Stanislaw Gruszka) [584757]
- [kernel] softlockup: Stop spurious softlockup messages due to overflow (Stanislaw Gruszka) [584757]
- [kernel] cpuset: fix the problem that cpuset_mem_spread_node() returns an offline node (Stanislaw Gruszka) [584757]
- [pci] cleanup error return for pcix get and set mmrbc functions (Stanislaw Gruszka) [584757]
- [pci] fix access of PCI_X_CMD by pcix get and set mmrbc functions (Stanislaw Gruszka) [584757]
- [pci] fix return value from pcix_get_max_mmrbc() (Stanislaw Gruszka) [584757]
- [net] if_tunnel.h: add missing ams/byteorder.h include (Stanislaw Gruszka) [584757]
- [netdrv] jme: Protect vlgrp structure by pause RX actions (Stanislaw Gruszka) [584757]
- [netdrv] jme: Fix VLAN memory leak (Stanislaw Gruszka) [584757]
- [usb] option: add support for a new CMOTECH device to usb/serial/option (Stanislaw Gruszka) [584757]
- [usb] option: move hardcoded PID to a macro in usb/serial/option (Stanislaw Gruszka) [584757]
- [usb] option: fix incorrect manufacturer name in usb/serial/option: MAXON->CMOTECH (Stanislaw Gruszka) [584757]
- [usb] xHCI: re-initialize cmd_completion (Stanislaw Gruszka) [584757]
- [usb] EHCI: adjust ehci_iso_stream for changes in ehci_qh (Stanislaw Gruszka) [584757]
- [usb] EHCI: fix ITD list order (Stanislaw Gruszka) [584757]
- [tty] Take a 256 byte padding into account when buffering below sub-page units (Stanislaw Gruszka) [584757]
- [tty] Keep the default buffering to sub-page units (Stanislaw Gruszka) [584757]
- [mm] tmpfs: cleanup mpol_parse_str() (Stanislaw Gruszka) [584757]
- [perf] Make the install relative to DESTDIR if specified (Stanislaw Gruszka) [584757]
- [perf] perf_event: Fix oops triggered by cpu offline/online (Stanislaw Gruszka) [584757]
- [isdn] gigaset: prune use of tty_buffer_request_room (Stanislaw Gruszka) [584757]
- [isdn] gigaset: correct clearing of at_state strings on RING (Stanislaw Gruszka) [584757]
- [sound] hda: Disable MSI for Nvidia controller (Stanislaw Gruszka) [584757]
- [sound] hda: Fix 0 dB offset for HP laptops using CX20551 (Stanislaw Gruszka) [584757]
- [sound] hda: Fix secondary ADC of ALC260 basic model (Stanislaw Gruszka) [584757]
- [virt] virtio: fix out of range array access (Stanislaw Gruszka) [584757]
- [ipc] mqueue: fix mq_open() file descriptor leak on user-space processes (Stanislaw Gruszka) [584757]
- [security] sysctl: require CAP_SYS_RAWIO to set mmap_min_addr (Stanislaw Gruszka) [584757]
- [kernel] sched: Mark boot-cpu active before smp_init() (Stanislaw Gruszka) [584757]
- [pci] add support for 82576NS serdes to existing SR-IOV quirk (Stanislaw Gruszka) [584757]
- [v4l] DVB: em28xx-dvb: fix memleak in dvb_fini() (Stanislaw Gruszka) [584757]
- [pci] unconditionally clear AER uncorr status register during cleanup (Stanislaw Gruszka) [584757]
- [tracing] Do not record user stack trace from NMI context (Stanislaw Gruszka) [584757]
- [tracing] Disable buffer switching when starting or stopping trace (Stanislaw Gruszka) [584757]
- [tracing] Use same local variable when resetting the ring buffer (Stanislaw Gruszka) [584757]
- [tracing] function-graph: Init curr_ret_stack with ret_stack (Stanislaw Gruszka) [584757]
- [tracing] ring-buffer: Move disabled check into preempt disable section (Stanislaw Gruszka) [584757]
- [input] i8042: add ALDI/MEDION netbook E1222 to qurik reset table (Stanislaw Gruszka) [584757]
- [net] netfilter: xt_recent: fix false match (Stanislaw Gruszka) [580067]
- [net] netfilter: xt_recent: fix buffer overflow (Stanislaw Gruszka) [580067]
- [tracing] oprofile/x86: fix msr access to reserved counters (Stanislaw Gruszka) [580067]
- [tracing] oprofile/x86: use kzalloc() instead of kmalloc() (Stanislaw Gruszka) [580067]
- [tracing] oprofile/x86: remove node check in AMD IBS initialization (Stanislaw Gruszka) [580067]
- [tracing] oprofile: remove tracing build dependency (Stanislaw Gruszka) [580067]
- [x86] oprofile: fix perfctr nmi reservation for mulitplexing (Stanislaw Gruszka) [580067]
- [netdrv] via-rhine: Fix scheduling while atomic bugs (Stanislaw Gruszka) [580067]
- [net] ipv6: conntrack: Add member of user to nf_ct_frag6_queue structure (Stanislaw Gruszka) [580067]
- [net] Remove bogus IGMPv3 report handling (Stanislaw Gruszka) [580067]
- [net] sysfs: Use rtnl_trylock in wireless sysfs methods (Stanislaw Gruszka) [580067]
- [net] Fix sysctl restarts (Stanislaw Gruszka) [580067]
- [mm] slab: initialize unused alien cache entry as NULL at alloc_alien_cache() (Stanislaw Gruszka) [580067]
- [v4l] DVB: cxusb: Select all required frontend and tuner modules (Stanislaw Gruszka) [580067]
- [v4l] dvb: l64781.ko broken with gcc 4.5 (Stanislaw Gruszka) [580067]
- [v4l] DVB: uvcvideo: Fix controls blacklisting (Stanislaw Gruszka) [580063]
- [net] netfilter: nf_conntrack: fix hash resizing with namespaces (Stanislaw Gruszka) [580065]
- [net] netfilter: nf_conntrack: restrict runtime expect hashsize modifications (Stanislaw Gruszka) [580065]
- [net] netfilter: xtables: fix conntrack match v1 ipt-save output (Stanislaw Gruszka) [580063]
- [v4l] DVGB: DocBook/media: create links for included sources (Stanislaw Gruszka) [580063]
- [v4l] DVB: DocBook/media: copy images after building HTML (Stanislaw Gruszka) [580063]
- [v4l] DVB: dvb-core: fix initialization of feeds list in demux filter (Stanislaw Gruszka) [580065]
- [dma] ioat: fix infinite timeout checking in ioat2_quiesce (Stanislaw Gruszka) [580065]
- [v4l] DVB: smsusb: add autodetection support for five additional Hauppauge USB IDs (Stanislaw Gruszka) [580063]
- [x86] cpufreq: Fix use after free of struct powernow_k8_data (Stanislaw Gruszka) [580065]
- [regulator] Fix display of null constraints for regulators (Stanislaw Gruszka) [580065]

* Mon May 10 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-25.el6]
- [fs] exec: Fix 'flush_old_exec()/setup_new_exec()' split (Jiri Olsa) [586024] {CVE-2010-0307}
- [powerpc] TIF_ABI_PENDING bit removal (Jiri Olsa) [586024] {CVE-2010-0307}
- [x86] set_personality_ia32() misses force_personality32 (Jiri Olsa) [586024] {CVE-2010-0307}
- [x86] get rid of the TIF_ABI_PENDING bit (Jiri Olsa) [586024] {CVE-2010-0307}
- [kernel] split 'flush_old_exec' into two functions (Jiri Olsa) [586024] {CVE-2010-0307}
- [net] sctp: fix skb_over_panic from processing too many unknown params (Neil Horman) [584659] {CVE-2010-1173}
- [virt] kvm: fix vmx null pointer dereference (Eduardo Habkost) [570534] {CVE-2010-0435}
- [fs] gfs2: fix quota state reporting (Christoph Hellwig) [589945]
- [fs] gfs2: fix quota file size not a multiple of struct gfs2_quota (Abhijith Das) [589813]
- [x86] Use physical mode for IBM Summit platforms (John Villalovos) [558397]
- [mm] page allocator: update NR_FREE_PAGES only when necessary (Stanislaw Gruszka) [579693]
- [mm] memcg: ensure list is empty at rmdir (Stanislaw Gruszka) [579693]
- [video] revert "drivers/video/s3c-fb.c: fix clock setting for Samsung SoC Framebuffer" (Stanislaw Gruszka) [579693]
- [v4l] DVB: gspca - sunplus: Fix bridge exchanges (Stanislaw Gruszka) [580062]
- [hwmon] fschmd: Fix a memleak on multiple opens of /dev/watchdog (Stanislaw Gruszka) [580063]
- [sound] hda: Fix HP T5735 automute (Stanislaw Gruszka) [580063]
- [sound] hda: Fix quirk for Maxdata obook4-1 (Stanislaw Gruszka) [580063]
- [sound] ice1724: Patch for suspend/resume for ESI Juli@ (Stanislaw Gruszka) [580063]
- [sound] usb-audio: Avoid Oops after disconnect (Stanislaw Gruszka) [580065]
- [sound] ctxfi: fix PTP address initialization (Stanislaw Gruszka) [580065]
- [hwmon] lm78: Request I/O ports individually for probing (Stanislaw Gruszka) [580065]
- [hwmon] w83781d: Request I/O ports individually for probing (Stanislaw Gruszka) [580065]
- [hwmon] tmp421: Fix temperature conversions (Stanislaw Gruszka) [580067]
- [sound] via82xx: add quirk for D1289 motherboard (Stanislaw Gruszka) [580067]
- [hwmon] tmp421: Restore missing inputs (Stanislaw Gruszka) [580067]
- [sound] USB MIDI support for Access Music VirusTI (Stanislaw Gruszka) [580067]
- [sound] hda-intel: Add position_fix quirk for ASUS M2V-MX SE (Stanislaw Gruszka) [580067]
- [sound] pcm core: fix fifo_size channels interval check (Stanislaw Gruszka) [580067]
- [sound] hda: Use 3stack quirk for Toshiba Satellite L40-10Q (Stanislaw Gruszka) [580067]
- [bluetooth] Fix potential bad memory access with sysfs files (Stanislaw Gruszka) [584757]
- [hwmon] coretemp: Add missing newline to dev_warn() message (Stanislaw Gruszka) [584757]
- [bluetooth] Fix kernel crash on L2CAP stress tests (Stanislaw Gruszka) [584757]
- [input] wacom: ensure the device is initialized properly upon resume (Stanislaw Gruszka) [584757]
- [sound] hda: Fix input source elements of secondary ADCs on Realtek (Stanislaw Gruszka) [584757]
- [x86] nmi watchdog: use generic interrupt source to determine deadlocks (Don Zickus) [574570]
- [dm] eliminate some holes in data structures (Mike Snitzer) [586089]
- [dm] ioctl: introduce flag indicating uevent was generated (Mike Snitzer) [586089]
- [dm] free dm_io before bio_endio not after (Mike Snitzer) [586089]
- [dm] table: remove unused dm_get_device range parameters (Mike Snitzer) [586089]
- [dm] ioctl: only issue uevent on resume if state changed (Mike Snitzer) [586089]
- [dm] raid1: always return error if all legs fail (Mike Snitzer) [586089]
- [dm] mpath: refactor pg_init (Mike Snitzer) [586089]
- [dm] mpath: wait for pg_init completion when suspending (Mike Snitzer) [586089]
- [dm] mpath: hold io until all pg_inits completed (Mike Snitzer) [586089]
- [dm] mpath: avoid storing private suspended state (Mike Snitzer) [586089]
- [dm] document when snapshot has finished merging (Mike Snitzer) [586089]
- [dm] table: remove dm_get from dm_table_get_md (Mike Snitzer) [586089]
- [dm] mpath: skip activate_path for failed paths (Mike Snitzer) [586089]
- [dm] mpath: pass struct pgpath to pg init done (Mike Snitzer) [586089]
- [netdrv] mac80211: fix deferred hardware scan requests (John Linville) [561762]
- [x86] asus-laptop: add Lenovo SL hotkey support (Stanislaw Gruszka) [579693]
- [input] pmouse: move Sentelic probe down the list (Stanislaw Gruszka) [579693]
- [pci] cardbus: Add a fixup hook and fix powerpc (Stanislaw Gruszka) [579693]
- [mfd] Correct WM835x ISINK ramp time defines (Stanislaw Gruszka) [579693]
- [mfd] WM835x GPIO direction register is not locked (Stanislaw Gruszka) [579693]
- [edac] i5000_edac critical fix panic out of bounds (Stanislaw Gruszka) [579693]
- [i2c] i2c-tiny-usb: Fix on big-endian systems (Stanislaw Gruszka) [580065]
- [x86] thinkpad-acpi: fix bluetooth/wwan resume (Stanislaw Gruszka) [580067]
- [v4l] DVB: bttv: Move I2C IR initialization (Stanislaw Gruszka) [580067]
- [bluetooth] Fix sleeping function in RFCOMM within invalid context (Stanislaw Gruszka) [584757]
- [i2c] i2c-i801: Don't use the block buffer for I2C block writes (Stanislaw Gruszka) [584757]
- [s390x] vdso: use ntp adjusted clock multiplier (Hendrik Brueckner) [575728]
- [s390x] timekeeping: Fix clock_gettime vsyscall time warp (Hendrik Brueckner) [575728]
- [s390x] timekeeping: Fix accumulation bug triggered by long delay (Hendrik Brueckner) [575728]
- [netdrv] igb: fix warning in drivers/net/igb/igb_main.c (Stefan Assmann) [589272]
- [x86] Re-get cfg_new in case reuse/move irq_desc (Stanislaw Gruszka) [580065 583555]
- [hwmon] adt7462: fix wrong ADT7462_VOLT_COUNT (Stanislaw Gruszka) [580065]
- [fs] exec.c: fix initial stack reservation (Stanislaw Gruszka) [580067]
- [fs] exec.c: restrict initial stack space expansion to rlimit (Stanislaw Gruszka) [580065]
- [kernel] resource: add helpers for fetching rlimits (Stanislaw Gruszka) [580065]
- [tracing] ext4: Convert some events to DEFINE_EVENT (Mike Snitzer) [588108]
- [tracing] Convert some jbd2 events to DEFINE_EVENT (Mike Snitzer) [588108]
- [tracing] Convert some block events to DEFINE_EVENT (Mike Snitzer) [588108]
- [tracing] Convert some power events to DEFINE_EVENT (Mike Snitzer) [588108]
- [tracing] Convert some workqueue events to DEFINE_EVENT (Mike Snitzer) [588108]
- [tracing] Convert softirq events to DEFINE_EVENT (Mike Snitzer) [588108]
- [tracing] Convert some kmem events to DEFINE_EVENT (Mike Snitzer) [588108]
- [tracing] Convert module refcnt events to DEFINE_EVENT (Mike Snitzer) [588108]
- [tracing] xfs: use DECLARE_EVENT_CLASS (Mike Snitzer) [588108]
- [tracing] Harmonize event field names and print output names (Mike Snitzer) [588108]
- [tracing] Add DEFINE_EVENT(), DEFINE_SINGLE_EVENT() support to docbook (Mike Snitzer) [588108]
- [block] blk-cgroup: config options re-arrangement (Vivek Goyal) [586182]
- [block] blkio: Fix another BUG_ON() crash due to cfqq movement across groups (Vivek Goyal) [586182]
- [block] blkio: Fix blkio crash during rq stat update (Vivek Goyal) [586182]
- [block] blkio: Initialize blkg->stats_lock for the root cfqg too (Vivek Goyal) [586182]
- [block] blkio: Fix compile errors (Vivek Goyal) [586182]
- [block] Update to io-controller stats (Vivek Goyal) [586182]
- [block] io-controller: Add a new interface "weight_device" for IO-Controller (Vivek Goyal) [586182]
- [block] cfq-iosched: Fix the incorrect timeslice accounting with forced_dispatch (Vivek Goyal) [586182]
- [block] blkio: Add more debug-only per-cgroup stats (Vivek Goyal) [586182]
- [block] blkio: Add io_queued and avg_queue_size stats (Vivek Goyal) [586182]
- [block] blkio: Add io_merged stat (Vivek Goyal) [586182]
- [block] blkio: Changes to IO controller additional stats patches (Vivek Goyal) [586182]
- [block] expose the statistics in blkio.time and blkio.sectors for the root cgroup (Vivek Goyal) [586182]
- [block] blkio: Increment the blkio cgroup stats for real now (Vivek Goyal) [586182]
- [block] blkio: Add io controller stats like (Vivek Goyal) [586182]
- [block] blkio: Remove per-cfqq nr_sectors as we'll be passing (Vivek Goyal) [586182]
- [block] cfq-iosched: Add additional blktrace log messages in CFQ for easier debugging (Vivek Goyal) [586182]
- [block] cfq-iosched: requests "in flight" vs "in driver" clarification (Vivek Goyal) [586182]
- [ppc] cxgb3: Wait longer for control packets on initialization (Steve Best) [588848]
- [virt] KVM: convert ioapic lock to spinlock (Marcelo Tosatti) [588811]
- [virt] KVM: fix the handling of dirty bitmaps to avoid overflows (Marcelo Tosatti) [588811]
- [virt] KVM: MMU: fix kvm_mmu_zap_page() and its calling path (Marcelo Tosatti) [588811]
- [virt] KVM: VMX: Save/restore rflags.vm correctly in real mode (Marcelo Tosatti) [588811]
- [virt] KVM: Dont spam kernel log when injecting exceptions due to bad cr writes (Marcelo Tosatti) [588811]
- [virt] KVM: SVM: Fix memory leaks that happen when svm_create_vcpu() fails (Marcelo Tosatti) [588811]
- [virt] KVM: VMX: Update instruction length on intercepted BP (Marcelo Tosatti) [588811]
- [drm] nouveau: initial eDP support + additional fixes (Ben Skeggs) [588581]
- [s390x] zcore: Fix reipl device detection (Hendrik Brueckner) [587025]
- [connector] Delete buggy notification code (Stanislaw Gruszka) [580064 586025] {CVE-2010-0410}
- [netdrv] ath9k: fix beacon slot/buffer leak (Stanislaw Gruszka) [580064]
- [fusion] mptsas: Fix issue with chain pools allocation on katmai (Stanislaw Gruszka) [580064]
- [sunrpc] Fix a potential memory leak in auth_gss (Stanislaw Gruszka) [584757]
- [tracing] scsi: Enhance SCSI command tracing (Mike Snitzer) [588108]
- [tracing] scsi: Add missing verify command definitions (Mike Snitzer) [588108]
- [tracing] scsi: ftrace based SCSI command tracing (Mike Snitzer) [588108]
- [tracing] add __print_hex() (Mike Snitzer) [588108]
- [tracing] Add notrace to TRACE_EVENT implementation functions (Mike Snitzer) [588108]
- [tracing] Move a printk out of ftrace_raw_reg_event_foo() (Mike Snitzer) [588108]
- [tracing] Rename TRACE_EVENT_TEMPLATE() to DECLARE_EVENT_CLASS() (Mike Snitzer) [588108]
- [tracing] Convert some sched trace events to DEFINE_EVENT and _PRINT (Mike Snitzer) [588108]
- [tracing] Create new DEFINE_EVENT_PRINT (Mike Snitzer) [588108]
- [tracing] Create new TRACE_EVENT_TEMPLATE (Mike Snitzer) [588108]
- [tracing] additional interface changes and fixes (Mike Snitzer) [588108]
- [tracing] Ftrace dynamic ftrace_event_call support (Mike Snitzer) [588108]
- [fs] quota: fix WARN_ON when quota reservations get out of sync (Eric Sandeen) [581951]
- [scsi] fcoe: sync with upstream (Mike Christie) [577049 578328]

* Mon May 03 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-24.el6]
- [fs] ecryptfs: disallow ecryptfs as underlying filesystem (Eric Sandeen) [585185]
- [mm] Fix Section Mismatch warning in put_page_bootmem() (Prarit Bhargava) [587040]
- [mm] transparent hugepage support update (Andrea Arcangeli) [556572]
- [netdrv] ath9k: revert fb6635f6c114313f246cc34abc0b677264a765ed (Aristeu Rozanski) [584757]
- [virt] KVM: take srcu lock before call to complete_pio() (Gleb Natapov) [585887]
- [virt] virtio: Fix GFP flags passed from the virtio balloon driver (Amit Shah) [584680]
- [x86] Check chip_data value in irq_force_complete_move() (Prarit Bhargava) [564398]
- [x86] nmi_watchdog: use __cpuinit for 32-bit nmi_watchdog_default (Prarit Bhargava) [586967]
- [acpi] Fall back to manually changing SCI_EN (Matthew Garrett) [587008]
- [pci] Ensure that devices are resumed properly (Matthew Garrett) [586780]
- [serial] usb-serial: Rework and update qcserial (Matthew Garrett) [587009]
- [scsi] scsi_lib: Fix bug in completion of bidi commands (Stanislaw Gruszka) [580064]
- [net] phonet: add check for null pernet mem pointer in notifier (Jiri Pirko) [573122]
- [nfs] Ensure that writeback_single_inode() calls write_inode() when syncing (Jeff Layton) [584382]
- [serial] 8250_pnp: use wildcard for serial Wacom tablets (Stanislaw Gruszka) [580062]
- [fs] ext4: check s_log_groups_per_flex in online resize code (Eric Sandeen) [519461]
- [x86] Fix sched_clock_cpu for systems with unsynchronized TSC (Prarit Bhargava) [568344]
- [x86] Reenable TSC sync check at boot, even with NONSTOP_TSC (Prarit Bhargava) [568344]
- [mm] slab: add memory hotplug support (Prarit Bhargava) [562880]
- [x86] Set hotpluggable nodes in nodes_possible_map (Prarit Bhargava) [568344]
- [x86] acpi: Auto Online Hot-Added Memory (Prarit Bhargava) [568344]
- [mm] memory hotplug: fix a bug on /dev/mem for 64-bit kernels (Prarit Bhargava) [568344]
- [mm] update all PGDs for direct mapping changes on 64 bit (Prarit Bhargava) [568344]
- [x86] acpi: Map hotadded cpu to correct node (Prarit Bhargava) [568344]
- [ipmi] Change timeout and event poll to one second (Matthew Garrett) [584106]
- [ipmi] Attempt to register multiple SIs of the same type (Matthew Garrett) [584106]
- [ipmi] Reduce polling (Matthew Garrett) [584106]
- [ipmi] Reduce polling when interrupts are available (Matthew Garrett) [584106]
- [ipmi] Change device discovery order (Matthew Garrett) [584106]
- [ipmi] Only register one si per bmc (Matthew Garrett) [584106]
- [ipmi] Split device discovery and registration (Matthew Garrett) [584106]
- [ipmi] Change addr_source to an enum rather than strings (Matthew Garrett) [584106]
- [drm] radeon: rs780/rs880: MSI quirk fixes (Dave Airlie) [586168]
- [drm] radeon/kms: MC + watermark fixes + reset (Dave Airlie) [586168]
- [drm] radeon/kms/evergreen: add evergreen stage 2 - HPD irq (Dave Airlie) [580757]
- [drm] radeon: fixup radeon_asic struct c/h files (Dave Airlie) [586168]
- [drm] radeon/kms: misc + tv dac fixes (Dave Airlie) [586168]
- [drm] radeon/kms: squash upstream HDMI audio commits (Dave Airlie) [586168]
- [drm] kms/radeon: Integrated graphics fixes (Dave Airlie) [586168]
- [drm] radeon/kms: spread spectrum + pll fixes (Dave Airlie) [586168]
- [drm] radeon: add initial evergreen support + fixes (Dave Airlie) [580757]
- [kernel] tty: tty->pgrp races (Jiri Olsa) [586022]
- [netdrv] kernel: fix the r8169 frame length check error (Jiri Olsa) [586017] {CVE-2009-4537}

* Tue Apr 27 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-23.el6]
- [doc] add the documentation for mpol=local (Stanislaw Gruszka) [584757]
- [fs] tmpfs: handle MPOL_LOCAL mount option properly (Stanislaw Gruszka) [584757]
- [fs] tmpfs: mpol=bind:0 don't cause mount error (Stanislaw Gruszka) [584757]
- [netdrv] tun: orphan an skb on tx (Michael S. Tsirkin) [584428]
- [s390x] vmalloc: IPL failure with enabled memory cgroups (Hendrik Brueckner) [580918]
- [netdrv] b43: fall back gracefully to PIO mode after fatal DMA errors (John Linville) [583069]
- [netdrv] b43: Allow PIO mode to be selected at module load (John Linville) [583069]
- [netdrv] b43: Remove reset after fatal DMA error (John Linville) [583069]
- [netdrv] b43: Optimize PIO scratchbuffer usage (John Linville) [583069]
- [fs] vfs: get_sb_single() - do not pass options twice (Stanislaw Gruszka) [580063]
- [fs] tmpfs: fix oops on mounts with mpol=default (Stanislaw Gruszka) [584757]
- [kernel] cred.c: use kmem_cache_free (Stanislaw Gruszka) [580064]
- [fs] partition/msdos: fix unusable extended partition for > 512B sector (Stanislaw Gruszka) [584757]
- [fs] partitions/msdos: add support for large disks (Stanislaw Gruszka) [584757]
- [fs] eCryptfs: Add getattr function (Stanislaw Gruszka) [580065]
- [fs] ecryptfs: initialize private persistent file before dereferencing pointer (Stanislaw Gruszka) [580062]
- [fs] ecryptfs: use after free (Stanislaw Gruszka) [580062]
- [ppc] Track backing pages used allocated by vmemmap_populate() (Steve Best) [547854]
- [netdrv] be2net: recent bug fixes from upstream (Ivan Vecera) [583766]
- [sunrpc] handle allocation errors from __rpc_lookup_create() (Stanislaw Gruszka) [584757]
- [nfs] Prevent another deadlock in nfs_release_page() (Stanislaw Gruszka) [584757]
- [nfs] NFSv4: Don't ignore the NFS_INO_REVAL_FORCED flag in nfs_revalidate_inode() (Stanislaw Gruszka) [584757]
- [nfs] Fix an allocation-under-spinlock bug (Stanislaw Gruszka) [580067]
- [sunrpc] Handle EINVAL error returns from the TCP connect operation (Stanislaw Gruszka) [580067]
- [sunrpc] remove unnecessary svc_xprt_put (Stanislaw Gruszka) [580067]
- [x86] Add iMac9,1 to pci_reboot_dmi_table (Stanislaw Gruszka) [580067]
- [rtc] rtc-core: fix memory leak (Stanislaw Gruszka) [580067]
- [mm] readahead: introduce FMODE_RANDOM for POSIX_FADV_RANDOM (Stanislaw Gruszka) [580067]
- [fs] fix LOOKUP_FOLLOW on automount "symlinks" (Stanislaw Gruszka) [580067]
- [nfs] Too many GETATTR and ACCESS calls after direct I/O (Stanislaw Gruszka) [580065]
- [virt] kvmclock: count total_sleep_time when updating guest clock (Stanislaw Gruszka) [580065]
- [kernel] Export the symbol of getboottime and mmonotonic_to_bootbased (Stanislaw Gruszka) [580065]
- [nfs] NFS: Fix the mapping of the NFSERR_SERVERFAULT error (Stanislaw Gruszka) [580065]
- [nfs] NFS: Fix a umount race (Stanislaw Gruszka) [580065]
- [x86] amd-iommu: Fix possible integer overflow (Stanislaw Gruszka) [580064]
- [ata] libata: retry FS IOs even if it has failed with AC_ERR_INVALID (Stanislaw Gruszka) [580064]
- [firewire] firewire: ohci: fix crashes with TSB43AB23 on 64bit systems (Stanislaw Gruszka) [580064]
- [ata] pata_hpt3x2n: always stretch UltraDMA timing (Stanislaw Gruszka) [580067]
- [cgroup] memcg: fix oom killing a child process in an other cgroup (Stanislaw Gruszka) [580067]
- [ata] libata: retry link resume if necessary (Stanislaw Gruszka) [580064]
- [firewire] core: add_descriptor size check (Stanislaw Gruszka) [580064]
- [netdrv] iwlwifi: fix scan race (Stanislaw Gruszka) [584759]
- [netdrv] iwlwifi: clear all tx queues when firmware ready (Stanislaw Gruszka) [584759]
- [netdrv] iwlwifi: need check for valid qos packet before free (Stanislaw Gruszka) [584759]
- [netdrv] mac80211: tear down all agg queues when restart/reconfig hw (Stanislaw Gruszka) [584759]
- [netdrv] mac80211: move netdev queue enabling to correct spot (Stanislaw Gruszka) [584759]
- [netdrv] setup correct int pipe type in ar9170_usb_exec_cmd (Stanislaw Gruszka) [584759]
- [netdrv] iwlwifi: range checking issue (Stanislaw Gruszka) [584759]
- [netdrv] iwlwifi: fix nfreed-- (Stanislaw Gruszka) [584759]
- [netdrv] iwlwifi: counting number of tfds can be free for 4965 (Stanislaw Gruszka) [584759]
- [netdrv] b43: Workaround circular locking in hw-tkip key update callback (Stanislaw Gruszka) [584757]
- [ata] ahci: use BIOS date in broken_suspend list (Stanislaw Gruszka) [584757]
- [netdrv] mac80211: Reset dynamic ps timer in Rx path (Stanislaw Gruszka) [584757]
- [netdrv] ath9k: Enable IEEE80211_HW_REPORTS_TX_ACK_STATUS flag for ath9k (Stanislaw Gruszka) [584757]
- [netdrv] mac80211: Retry null data frame for power save (Stanislaw Gruszka) [584757]
- [netdrv] ath9k: Enable TIM timer interrupt only when needed. (Stanislaw Gruszka) [584757]
- [netdrv] ath9k: fix BUG_ON triggered by PAE frames (Stanislaw Gruszka) [584757]
- [netdrv] iwlwifi: Silence tfds_in_queue message (Stanislaw Gruszka) [584757]
- [netdrv] iwlwifi: use dma_alloc_coherent (Stanislaw Gruszka) [584757]
- [netdrv] wl1251: fix potential crash (Stanislaw Gruszka) [584757]
- [block] readahead: add blk_run_backing_dev (Stanislaw Gruszka) [584757]
- [netdrv] ath9k: fix lockdep warning when unloading module (Stanislaw Gruszka) [584757]
- [scsi] mvsas: add support for Adaptec ASC-1045/1405 SAS/SATA HBA (Stanislaw Gruszka) [584757]
- [netdrv] ath5k: fix setup for CAB queue (Stanislaw Gruszka) [584757]
- [netdrv] ath5k: dont use external sleep clock in AP mode (Stanislaw Gruszka) [584757]
- [netdrv] tg3: Fix tg3_poll_controller() passing wrong pointer to tg3_interrupt() (Stanislaw Gruszka) [584757]
- [netdrv] b43/b43legacy: Wake queues in wireless_core_start (Stanislaw Gruszka) [580067]
- [netdrv] ath5k: use correct packet type when transmitting (Stanislaw Gruszka) [580067]
- [netdrv] ath9k: disable RIFS search for AR91xx based chips (Stanislaw Gruszka) [580067]
- [netdrv] ath9k: fix rate control fallback rate selection (Stanislaw Gruszka) [580067]
- [netdrv] ath9k: fix beacon timer restart after a card reset (Stanislaw Gruszka) [580067]
- [netdrv] p54usb: Add the USB ID for Belkin (Accton) FD7050E ver 1010ec (Stanislaw Gruszka) [580067]
- [netdrv] rndis_wlan: disable stall workaround (Stanislaw Gruszka) [580067]
- [netdrv] rndis_wlan: fix buffer overflow in rndis_query_oid (Stanislaw Gruszka) [580067]
- [netdrv] rndis_wlan: handle NL80211_AUTHTYPE_AUTOMATIC (Stanislaw Gruszka) [580067]
- [netdrv] sky2: fix transmit DMA map leakage (Stanislaw Gruszka) [580067]
- [netdrv] airo: fix setting zero length WEP key (Stanislaw Gruszka) [580067]
- [netdrv] mac80211: quit addba_resp_timer if Tx BA session is torn down (Stanislaw Gruszka) [580067]
- [netdrv] iwlwifi: sanity check before counting number of tfds can be free (Stanislaw Gruszka) [580067]
- [netdrv] iwlwifi: set HT flags after channel in rxon (Stanislaw Gruszka) [580067]
- [netdrv] iwlwifi: error checking for number of tfds in queue (Stanislaw Gruszka) [580067]
- [netdrv] iwlwifi: Fix to set correct ht configuration (Stanislaw Gruszka) [580065]
- [netdrv] mac80211: Fix probe request filtering in IBSS mode (Stanislaw Gruszka) [580065]
- [netdrv] ath9k: Fix sequence numbers for PAE frames (Stanislaw Gruszka) [580065]
- [netdrv] b43: Fix throughput regression (Stanislaw Gruszka) [580065]
- [netdrv] rtl8187: Add new device ID (Stanislaw Gruszka) [580065]
- [ata] ahci: add Acer G725 to broken suspend list (Stanislaw Gruszka) [580065]
- [scsi] mptfusion: mptscsih_abort return value should be SUCCESS instead of value 0 (Stanislaw Gruszka) [580065]
- [nfs] Fix an Oops when truncating a file (Stanislaw Gruszka) [580065]
- [block] cciss: Make cciss_seq_show handle holes in the h->drv[] array (Stanislaw Gruszka) [580065]
- [netdrv] ath9k: fix eeprom INI values override for 2GHz-only cards (Stanislaw Gruszka) [580064]
- [netdrv] mac80211: fix NULL pointer dereference when ftrace is enabled (Stanislaw Gruszka) [580064]
- [block] fix bugs in bio-integrity mempool usage (Stanislaw Gruszka) [580064]
- [netdrv] sky2: Fix oops in sky2_xmit_frame() after TX timeout (Stanislaw Gruszka) [580064]
- [netdrv] iwlwifi: set default aggregation frame count limit to 31 (Stanislaw Gruszka) [580064]
- [netdrv] e1000/e1000e: don't use small hardware rx buffers (Stanislaw Gruszka) [580064]
- [netdrv] e1000: enhance frame fragment detection (Stanislaw Gruszka) [580064]
- [mm] rmap: anon_vma_prepare() can leak anon_vma_chain (Rik van Riel) [579936]
- [mm] rmap: add exclusively owned pages to the newest anon_vma (Rik van Riel) [579936]
- [mm] anonvma: when setting up page->mapping, we need to pick the _oldest_ anonvma (Rik van Riel) [579936]
- [mm] anon_vma: clone the anon_vma chain in the right order (Rik van Riel) [579936]
- [mm] vma_adjust: fix the copying of anon_vma chains (Rik van Riel) [579936]
- [mm] Simplify and comment on anon_vma re-use for anon_vma_prepare() (Rik van Riel) [579936]
- [mm] rmap: fix anon_vma_fork() memory leak (Rik van Riel) [579936]
- [s390x] nss: add missing .previous statement to asm function (Hendrik Brueckner) [581521]
- [ata] pata_mavell: correct check of AHCI config option (David Milburn) [584483]
- [fs] ext4: Issue the discard operation before releasing the blocks (Eric Sandeen) [575884]
- [scsi] 3w_sas: new driver (Tomas Henzl) [572781]
- [kernel] hrtimer: Tune hrtimer_interrupt hang logic (Marcelo Tosatti) [576355]

* Tue Apr 20 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-22.el6]
- [netdrv] b43: ssb: do not read SPROM if it does not exist (John Linville) [574895]
- [netdrv] igb: add support for Intel I350 Gigabit Network Connection (Stefan Assmann) [580727]
- [kernel] exec: refactor how usermodehelpers work and modify core_pipe recursion check (Neil Horman) [557387]
- [kernel] re-export page_is_ram() for crash module (Prarit Bhargava) [583032]
- [x86] amd_iommu: allow iommu to complete dma transactions during transition to kdump kernel (Neil Horman) [577788]
- [nfs] rsize and wsize settings ignored on v4 mounts (Steve Dickson) [582697]
- [net] igmp: fix ip_mc_sf_allow race (Flavio Leitner) [578932]
- [net] Remove skb_dma_map/unmap calls from drivers (Thomas Graf) [576690]
- [scsi] mpt2sas: IOs needs to be pause until handles are refreshed for all device after recovery (Tomas Henzl) [577909]
- [scsi] mpt2sas: Reworked scmd->result priority for _scsih_qcmd (Tomas Henzl) [577909]
- [x86] Suppress stack overrun message for init_task (Prarit Bhargava) [582625]
- [sunrpc] gss_krb5: Advertise rc4-hmac enctype support in the rpcsec_gss/krb5 upcall (Steve Dickson) [498317]
- [sunrpc] gss_krb5: Add support for rc4-hmac encryption (Steve Dickson) [498317]
- [sunrpc] gss_krb5: Use confounder length in wrap code (Steve Dickson) [498317]
- [sunrpc] gssd_krb5: More arcfour-hmac support (Steve Dickson) [498317]
- [sunrpc] gss_krb5: Save the raw session key in the context (Steve Dickson) [498317]
- [sunrpc] gssd_krb5: arcfour-hmac support (Steve Dickson) [498317]
- [sunrpc] gss_krb5: Advertise AES enctype support in the rpcsec_gss/krb5 upcall (Steve Dickson) [498317]
- [sunrpc] gss_krb5: add remaining pieces to enable AES encryption support (Steve Dickson) [498317]
- [sunrpc] gss_krb5: add support for new token formats in rfc4121 (Steve Dickson) [498317]
- [sunrpc] xdr: Add an export for the helper function write_bytes_to_xdr_buf() (Steve Dickson) [498317]
- [sunrpc] gss_krb5: Advertise triple-des enctype support in the rpcsec_gss/krb5 upcall (Steve Dickson) [498317]
- [sunrpc] gss_krb5: add support for triple-des encryption (Steve Dickson) [498317]
- [sunrpc] gss_krb5: Add upcall info indicating supported kerberos enctypes (Steve Dickson) [498317]
- [sunrpc] gss_krb5: handle new context format from gssd (Steve Dickson) [498317]
- [sunrpc] gss_krb5: import functionality to derive keys into the kernel (Steve Dickson) [498317]
- [sunrpc] gss_krb5: add ability to have a keyed checksum (hmac) (Steve Dickson) [498317]
- [sunrpc] gss_krb5: introduce encryption type framework (Steve Dickson) [498317]
- [sunrpc] gss_krb5: prepare for new context format (Steve Dickson) [498317]
- [sunrpc] gss_krb5: split up functions in preparation of adding new enctypes (Steve Dickson) [498317]
- [sunrpc] gss_krb5: Don't expect blocksize to always be 8 when calculating padding (Steve Dickson) [498317]
- [sunrpc] gss_krb5: Added and improved code comments (Steve Dickson) [498317]
- [sunrpc] gss_krb5: Introduce encryption type framework (Steve Dickson) [498317]
- [mm] Fix vfree race resulting in kernel bug (Steven Whitehouse) [582522]
- [ata] libata: fix accesses at LBA28 boundary (David Milburn) [582432]
- [netdrv] b43: Rewrite DMA Tx status handling sanity checks (John Linville) [574533]
- [char] tty: release_one_tty() forgets to put pids (Oleg Nesterov) [582077] {CVE-2010-1162}
- [mm] oom: fix the unsafe usage of badness() in proc_oom_score() (Oleg Nesterov) [582069]
- [netdrv] bonding: fix broken multicast with round-robin mode (Andy Gospodarek) [581644]
- [x86] Remove sysfs_attr_init, sysfs_bin_attr_init changes introduced in last MCE patch (Prarit Bhargava) [581659]
- [kernel] sched_getaffinity: allow less than NR_CPUS length (Oleg Nesterov) [578970]
- [scsi] bfa sync w/ upstream (Rob Evers) [576716]
- [gfs] GFS2: Fix ordering of ordered buffers (Steven Whitehouse) [581011]
- [gfs] GFS2: Don't withdraw on partial rindex entries (Robert S Peterson) [581009]
- [gfs] GFS2: livelock while reclaiming unlinked dinodes (Robert S Peterson) [570182]
- [scsi] mpt2sas: Do not reset handle before calling _scsih_remove_device in RESCAN task after HBA RESET (Tomas Henzl) [572646]
- [scsi] mpt2sas: Device removal algorithm in interrupt ctx (Tomas Henzl) [572646]
- [scsi] mpt2sas: fix the incorrect scsi_dma_map error checking (Tomas Henzl) [572646]
- [scsi] Upgrading version to 04.100.01.02 (Tomas Henzl) [572646]
- [scsi] mpt2sas: modified _scsih_sas_device_find_by_handle/sas_address (Tomas Henzl) [572646]
- [scsi] mpt2sas: RESCAN Barrier work is added in case of HBA reset (Tomas Henzl) [572646]
- [scsi] update the version to 04.100.01.00 (Tomas Henzl) [572646]
- [scsi] scsi_transport_sas: add support for transport layer retries (TLR) (Tomas Henzl) [572646]
- [scsi] mpt2sas: Added raid transport support (Tomas Henzl) [572646]
- [scsi] eliminate potential kmalloc failure in scsi_get_vpd_page() (Tomas Henzl) [572646]
- [ata] libata: fix ata_id_logical_per_physical_sectors (David Milburn) [582021]
- [netdrv] iwlwifi: Fix throughput stall issue in HT mode for 5000 (Stanislaw Gruszka) [580063]
- [infiniband] IPoIB: Clear ipoib_neigh.dgid in ipoib_neigh_alloc() (Stanislaw Gruszka) [580063]
- [net] cfg80211: fix channel setting for wext (Stanislaw Gruszka) [580063]
- [net] mac80211: check that ieee80211_set_power_mgmt only handles STA interfaces (Stanislaw Gruszka) [580063]
- [ata] ata_piix: fix MWDMA handling on PIIX3 (Stanislaw Gruszka) [580063]
- [ata] ahci: disable SNotification capability for ich8 (Stanislaw Gruszka) [580063]
- [netdrv] ar9170: Add support for D-Link DWA 160 A2 (Stanislaw Gruszka) [580063]
- [netdrv] sfc: Fix DMA mapping cleanup in case of an error in TSO (Stanislaw Gruszka) [580063]
- [fs] ext4: don't call write_inode under the journal (Josef Bacik) [576202]
- [fs] ext4: Calculate metadata requirements more accurately (Josef Bacik) [576202]
- [fs] ext4: Patch up how we claim metadata blocks for quota purposes (Josef Bacik) [576202]
- [fs] ext4: fix potential quota deadlock (Josef Bacik) [576202]
- [virt] virtio: console: Add support for nonblocking write()s (Amit Shah) [576241]
- [virt] virtio: console: Rename wait_is_over() to will_read_block() (Amit Shah) [576241]
- [virt] virtio: console: Don't always create a port 0 if using multiport (Amit Shah) [576241]
- [virt] virtio: console: Use a control message to add ports (Amit Shah) [576241]
- [virt] virtio: console: Move code around for future patches (Amit Shah) [576241]
- [virt] virtio: console: Remove config work handler (Amit Shah) [576241]
- [virt] virtio: console: Don't call hvc_remove() on unplugging console ports (Amit Shah) [576241]
- [virt] virtio: console: Return -EPIPE to hvc_console if we lost the connection (Amit Shah) [576241]
- [virt] virtio: console: Let host know of port or device add failures (Amit Shah) [576241]
- [virt] virtio: console: Add a __send_control_msg() that can send messages without a valid port (Amit Shah) [576241]
- [virt] hvc_console: Fix race between hvc_close and hvc_remove (Amit Shah) [577222]
- [virt] virtio: console makes incorrect assumption about virtio API (Amit Shah) [576241]
- [virt] MAINTAINERS: Put the virtio-console entry in correct alphabetical order (Amit Shah) [576241]
- [virt] virtio: console: Fix early_put_chars usage (Amit Shah) [576241]
- [virt] virtio: console: Check if port is valid in resize_console (Amit Shah) [576241]
- [virt] virtio: console: Generate a kobject CHANGE event on adding 'name' attribute (Amit Shah) [576241]
- [virt] virtio: console: Use better variable names for fill_queue operation (Amit Shah) [576241]
- [virt] virtio: console: Fix type of 'len' as unsigned int (Amit Shah) [576241]
- [vfs] rename block_fsync() to blkdev_fsync() (Jeff Moyer) [579781]
- [char] raw: add an fsync method (Jeff Moyer) [579781]
- [x86] Don't use logical-flat mode when more than 8 CPUs are possible (John Villalovos) [563798]
- [net] Backport the new socket API recvmmsg, receive multiple messages (Arnaldo Carvalho de Melo) [579850]
- [kernel] coredump: fix the page leak in dump_seek() (Oleg Nesterov) [580126]
- [s390x] callhome: fix broken proc interface and activate comp ID (Hendrik Brueckner) [579482]

* Mon Apr 12 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-21.el6]
- [x86] Update x86 MCE code (Prarit Bhargava) [580587]
- [scsi] 3w-xxxx: Force 60 second timeout default (Tomas Henzl) [572778]
- [netdrv] enic: update to upstream version 1.3.1.1 (Andy Gospodarek) [575950]
- [netdrv] igb: Add support for 82576 ET2 Quad Port Server Adapter (Stefan Assmann) [577421]
- [kernel] resource: Fix generic page_is_ram() for partial RAM pages (Prarit Bhargava) [578834]
- [x86] Use the generic page_is_ram() (Prarit Bhargava) [578834]
- [x86] Remove BIOS data range from e820 (Prarit Bhargava) [578834]
- [kernel] Move page_is_ram() declaration to mm.h (Prarit Bhargava) [578834]
- [kernel] Generic page_is_ram: use __weak (Prarit Bhargava) [578834]
- [kernel] resources: introduce generic page_is_ram() (Prarit Bhargava) [578834]
- [fs] GFS2: Clean up copying from stuffed files (Steven Whitehouse) [580857]
- [netdrv] igb: restrict WoL for 82576 ET2 Quad Port Server Adapter (Stefan Assmann) [578804]
- [drm] radeon/kms: move radeon KMS on/off switch out of staging (Dave Airlie) [580766]
- [netdrv] p54: fix deadlocks under tx load (Michal Schmidt) [580557]
- [gfs2] GFS2: Mandatory locking fix (Steven Whitehouse) [571606] {CVE-2010-0727}
- [x86] AMD: Fix NULL pointer dereference on 32-bit (Bhavna Sarathy) [571474]
- [x86] Add wbinvd SMP helper routines (Bhavna Sarathy) [571474]
- [x86] L3 cache: Remove NUMA dependency (Bhavna Sarathy) [571474]
- [x86] Calculate L3 indices (Bhavna Sarathy) [571474]
- [x86] Add cache index disable sys attributes (Bhavna Sarathy) [571474]
- [x86] Fix disabling of L3 cache indices (Bhavna Sarathy) [571474]
- [fs] NFS: Avoid a deadlock in nfs_release_page (Jeff Layton) [525963]
- [fs] NFS: Remove requirement for inode->i_mutex from nfs_invalidate_mapping (Jeff Layton) [525963]
- [fs] NFS: Clean up nfs_sync_mapping (Jeff Layton) [525963]
- [fs] NFS: Simplify nfs_wb_page() (Jeff Layton) [525963]
- [fs] NFS: Replace __nfs_write_mapping with sync_inode() (Jeff Layton) [525963]
- [fs] NFS: Simplify nfs_wb_page_cancel() (Jeff Layton) [525963]
- [fs] NFS: Ensure inode is always marked I_DIRTY_DATASYNC, if it has unstable pages (Jeff Layton) [525963]
- [fs] NFS: Run COMMIT as an asynchronous RPC call when wbc->for_background is set (Jeff Layton) [525963]
- [fs] NFS: Reduce the number of unnecessary COMMIT calls (Jeff Layton) [525963]
- [fs] NFS: Add a count of the number of unstable writes carried by an inode (Jeff Layton) [525963]
- [fs] NFS: Cleanup - move nfs_write_inode() into fs/nfs/write.c (Jeff Layton) [525963]
- [fs] writeback: pass writeback_control to ->write_inode (Jeff Layton) [525963]
- [fs] writeback: make sure data is on disk before calling ->write_inode (Jeff Layton) [525963]
- [fs] writeback: introduce wbc.for_background (Jeff Layton) [525963]
- [netdrv] macvlan: fix support for multiple driver backends (Anthony Liguori) [553337 566731]
- [netdrv] net/macvtap: add vhost support (Anthony Liguori) [553337 566731]
- [netdrv] macvtap: add GSO/csum offload support (Anthony Liguori) [553337 566731]
- [netdrv] macvtap: rework object lifetime rules (Anthony Liguori) [553337 566731]
- [netdrv] macvtap: fix reference counting (Anthony Liguori) [553337 566731]
- [netdrv] net: macvtap driver (Anthony Liguori) [553337 566731]
- [netdrv] macvlan: export macvlan mode through netlink (Anthony Liguori) [553337 566731]
- [netdrv] macvlan: implement bridge, VEPA and private mode (Anthony Liguori) [553337 566731]
- [netdrv] macvlan: cleanup rx statistics (Anthony Liguori) [553337 566731]
- [netdrv] macvlan: Precise RX stats accounting (Anthony Liguori) [553337 566731]
- [netdrv] macvlan: add private dev_txq_stats_fold function (Anthony Liguori) [553337 566731]
- [netdrv] veth: move loopback logic to common location (Anthony Liguori) [553337 566731]
- [s390x] zfcp: Remove lock dependency on unit remove (Hendrik Brueckner) [576860]
- [s390x] zfcp: Remove lock dependency on unit add (Hendrik Brueckner) [576860]
- [s390x] zfcp: Remove lock dependency on CCW remove (Hendrik Brueckner) [576860]
- [s390x] dasd: fix alignment of transport mode recovery TCW (Hendrik Brueckner) [575824]
- [s390x] cio: fix drvdata usage for the console subchannel (Hendrik Brueckner) [575826]
- [s390x] zcore: CPU registers are not saved under LPAR (Hendrik Brueckner) [575221]
- [s390x] zfcpdump: Use direct IO in order to increase dump speed (Hendrik Brueckner) [575189]
- [s390x] qeth: change checksumming default for HiperSockets (Hendrik Brueckner) [572227]
- [s390x] qeth: l3 send dhcp in non pass thru mode (Hendrik Brueckner) [572225]
- [s390x] zfcp: Remove attached ports and units correctly (Hendrik Brueckner) [571938]
- [drm] Bring in nouveau updates from upstream (Ben Skeggs) [558468]
- [vfs] pass struct file to do_truncate on O_TRUNC opens (Jeff Layton) [573995]
- [vfs] O_TRUNC open shouldn't fail after file truncation (Jeff Layton) [573995]
- [net] netfilter: ctnetlink: compute message size properly (Jiri Pirko) [578476]
- [block] cfq-iosched: Do not merge queues of BE and IDLE classes (Jeff Moyer) [577393]
- [block] remove 16 bytes of padding from struct request on 64bits (Jeff Moyer) [577393]
- [block] cfq: remove 8 bytes of padding from cfq_rb_root on 64 bit builds (Jeff Moyer) [577393]
- [block] cfq-iosched: quantum check tweak (Jeff Moyer) [577393]
- [block] remove padding from io_context on 64bit builds (Jeff Moyer) [577393]
- [block] cfq: reorder cfq_queue removing padding on 64bit (Jeff Moyer) [577393]
- [block] cfq-iosched: split seeky coop queues after one slice (Jeff Moyer) [577393]
- [x86] edac, mce: Filter out invalid values (Bhavna Sarathy) [574487]
- [x86] edac, mce, amd: silence GART TLB errors (Bhavna Sarathy) [574487]
- [x86] edac, mce: correct corenum reporting (Bhavna Sarathy) [574487]
- [x86] edac, mce: update AMD F10h revD check (Bhavna Sarathy) [574487]
- [x86] amd64_edac: Simplify ECC override handling (Bhavna Sarathy) [574487]
- [x86] amd64_edac: Do not falsely trigger kerneloops (Bhavna Sarathy) [574487]
- [x86] amd64_edac: Ensure index stays within bounds in amd64_get_scrub_rate (Bhavna Sarathy) [574487]
- [x86] amd64_edac: restrict PCI config space access (Bhavna Sarathy) [574487]
- [x86] amd64_edac: fix K8 chip select reporting (Bhavna Sarathy) [574487]
- [x86] amd64_edac: bump driver version (Bhavna Sarathy) [574487]
- [x86] amd64_edac: fix use-uninitialised bug (Bhavna Sarathy) [574487]
- [x86] amd64_edac: correct sys address to chip select mapping (Bhavna Sarathy) [574487]
- [x86] amd64_edac: add a leaner syndrome decoding algorithm (Bhavna Sarathy) [574487]
- [x86] amd64_edac: remove early hw support check (Bhavna Sarathy) [574487]
- [x86] amd64_edac: detect DDR3 memory type (Bhavna Sarathy) [574487]
- [x86] edac: add memory types strings for debugging (Bhavna Sarathy) [574487]
- [x86] amd64_edac: remove unneeded extract_error_address wrapper (Bhavna Sarathy) [574487]
- [x86] amd64_edac: rename StinkyIdentifier (Bhavna Sarathy) [574487]
- [x86] amd64_edac: remove superfluous dbg printk (Bhavna Sarathy) [574487]
- [x86] amd64_edac: enhance address to DRAM bank mapping (Bhavna Sarathy) [574487]
- [x86] amd64_edac: cleanup f10_early_channel_count (Bhavna Sarathy) [574487]
- [x86] amd64_edac: dump DIMM sizes on K8 too (Bhavna Sarathy) [574487]
- [x86] amd64_edac: cleanup rest of amd64_dump_misc_regs (Bhavna Sarathy) [574487]
- [x86] amd64_edac: cleanup DRAM cfg low debug output (Bhavna Sarathy) [574487]
- [x86] amd64_edac: wrap-up pci config read error handling (Bhavna Sarathy) [574487]
- [x86] amd64_edac: make DRAM regions output more human-readable (Bhavna Sarathy) [574487]
- [x86] amd64_edac: clarify DRAM CTL debug reporting (Bhavna Sarathy) [574487]

* Tue Apr 06 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-20.el6]
- [netdrv] iwlwifi: fix kdump hang (Stanislaw Gruszka) [575122]
- [kernel] clockevent: Don't remove broadcast device when cpu is dead (Danny Feng) [572438]
- [block] Export max number of segments and max segment size in sysfs (Jeff Moyer) [574132]
- [block] Finalize conversion of block limits functions (Jeff Moyer) [574132]
- [block] Fix overrun in lcm() and move it to lib (Jeff Moyer) [574132]
- [block] jiffies fixes (Jeff Moyer) [574132]
- [block] Consolidate phys_segment and hw_segment limits (Jeff Moyer) [574132]
- [block] Rename blk_queue_max_sectors to blk_queue_max_hw_sectors (Jeff Moyer) [574132]
- [block] Add BLK_ prefix to definitions (Jeff Moyer) [574132]
- [block] Remove unused accessor function (Jeff Moyer) [574132]
- [block] Update blk_queue_max_sectors and documentation (Jeff Moyer) [574132]
- [ata] ahci: Turn off DMA engines when there's no device attached (Matthew Garrett) [577967]
- [scsi] qla2xxx: minor updates and fixes from upstream (Rob Evers) [574526]
- [scsi] Additional BSG corrections from upstream (Rob Evers) [574590]
- [netdrv] be2net: Update be2net 10GB NIC driver to version 2.102.147u (Ivan Vecera) [576172]
- [scsi] update fibre channel layer (Mike Christie) [571824]
- [scsi] lpfc Update from 8.3.5.6 to 8.3.5.7 FC/FCoE (Rob Evers) [576174]
- [netdrv] e100: fix the 'size' argument passed to pci_pool_create() (Dean Nelson) [576887]
- [kernel] futex: remove rw parameter from get_futex_key() (Amerigo Wang) [555700]
- [drm] Add drm_gem_object_handle_unreference_unlocked and drm_gem_object_unreference_unlocked (Adam Jackson) [575910]
- [drm] i915: Update to 2.6.34-rc1 (pre-vga-switcheroo) (Adam Jackson) [575910]
- [scsi] libfcoe: Send port LKA every FIP_VN_KA_PERIOD secs (Rob Evers) [570693]
- [scsi] fnic: updating driver to 1.4.0.98 syncs w/ upstream (Rob Evers) [570693]
- [sound] snd-hda-intel: avoid divide by zero (Jaroslav Kysela) [567173] {CVE-2010-1085}
- [netdrv] bnx2x: use new firmware (Stanislaw Gruszka) [560993]
- [netdrv] bnx2: remove old firmware (Stanislaw Gruszka) [560993]
- [netdrv] bnx2x: 1.52.1-6 firmware (Stanislaw Gruszka) [560993]
- [netdrv] bnx2x: 1.52.1-6 bug fixes (Stanislaw Gruszka) [560993]
- [ata] ahci: support FIS-based switching (David Milburn) [463152]
- [drm] radeon: better GPU reset for lockup (Jerome Glisse) [576511]
- [block] cciss: add 30 second initial timeout wait on controller reset (Tomas Henzl) [574094]
- [serial] fix hang in serial console open (Neil Horman) [568418]
- [virt] vmw_pvscsi: adding vmware paravirtualized driver (Rob Evers) [553062]
- [scsi] 3w-9xxx: update 3w-9xxx to v2.26.02.014RH (Tomas Henzl) [572779]
- [netdrv] ixgbevf: initial support for 82599VF driver (Andy Gospodarek) [462790]
- [netdrv] ixgbe: update to version 2.0.62-k2 (Andy Gospodarek) [462790]
- [netdrv] netxen: More critical bug fixes and AER support (Tony Camuso) [516840]
- [netdrv] netxen: Sync with upstream kernel bug fixes (Tony Camuso) [516840]
- [fs] dlm: use bastmode in debugfs output (David Teigland) [568102]
- [fs] dlm: send reply before bast (David Teigland) [568102]
- [fs] dlm: fix ordering of bast and cast (David Teigland) [568102]
- [virt] virtio-net: remove send queue (Anthony Liguori) [555698]
- [virt] virtio-net: Defer skb allocation and remove recv queue (Anthony Liguori) [555698]
- [net] bridge: Allow enable/disable UFO on bridge device via ethtool (Anthony Liguori) [555537]
- [net] Make UFO on master device independent of attached devices (Anthony Liguori) [555537]
- [fs] xfs: fix locking for inode cache radix tree tag updates (Christoph Hellwig) [573836]
- [uv] fix microcode.ctl slow down in boot-time on large systems (George Beshers) [573018]
- [scsi] lpfc Update from 8.3.5.5 to 8.3.5.6 FC/FCoE (Rob Evers) [568889]
- [mm] transparent hugepage support update (Andrea Arcangeli) [556572]
- [netdrv] e1000e: fix data corruptor in NFS packet split filtering hw (Neil Horman) [572350]
- [security] selinux: dynamic class/perm discovery (Eric Paris) [570812]
- [security] selinux/ss: correct size computation (Eric Paris) [573000]
- [security] SELinux: reduce size of access vector hash table (Eric Paris) [570433]
- [security] SELinux: reset the security_ops before flushing the avc cache (Eric Paris) [572998]
- [sched] Fix sched_mc_power_savings for !SMT (Danny Feng) [571879]
- [security] selinux: Only audit permissions specified in policy (Eric Paris) [573002]
- [security] selinux: fix memory leak in sel_make_bools (Eric Paris) [573008]
- [security] SELinux: Make selinux_kernel_create_files_as() shouldn't just always return 0 (Eric Paris) [573011]
- [security] selinux: convert range transition list to a hashtab (Eric Paris) [572702]
- [virt] x86: remove kmap_atomic_pte paravirt op (Paolo Bonzini) [567203]
- [virt] vmi: disable highmem PTE allocation even when CONFIG_HIGHPTE=y (Paolo Bonzini) [567203]
- [virt] xen: disable highmem PTE allocation even when CONFIG_HIGHPTE=y (Paolo Bonzini) [567203]
- [virt] x86: allow allocation of highmem user page tables to be disabled when CONFIG_HIGHPTE=y (Paolo Bonzini) [567203]
- [netdrv] qlge: update to latest upstream (Andy Gospodarek) [562311]
- [netdrv] add netif_printk helpers (Andy Gospodarek) [562311]
- [net] bridge: Fix build error when IGMP_SNOOPING is not enabled (Herbert Xu) [574321]
- [net] bridge: Add multicast count/interval sysfs entries (Herbert Xu) [574321]
- [net] bridge: Add hash elasticity/max sysfs entries (Herbert Xu) [574321]
- [net] bridge: Add multicast_snooping sysfs toggle (Herbert Xu) [574321]
- [net] bridge: Add multicast_router sysfs entries (Herbert Xu) [574321]
- [net] bridge: Add multicast data-path hooks (Herbert Xu) [574321]
- [net] bridge: Add multicast start/stop hooks (Herbert Xu) [574321]
- [net] bridge: Add multicast forwarding functions (Herbert Xu) [574321]
- [net] bridge: Move NULL mdb check into br_mdb_ip_get (Herbert Xu) [574321]
- [net] bridge: ensure to unlock in error path in br_multicast_query() (Herbert Xu) [574321]
- [net] bridge: Fix RCU race in br_multicast_stop (Herbert Xu) [574321]
- [net] bridge: Use RCU list primitive in __br_mdb_ip_get (Herbert Xu) [574321]
- [net] bridge: cleanup: remove unneed check (Herbert Xu) [574321]
- [net] bridge: depends on INET (Herbert Xu) [574321]
- [net] bridge: Make IGMP snooping depend upon BRIDGE. (Herbert Xu) [574321]
- [net] bridge: Add core IGMP snooping support (Herbert Xu) [574321]
- [net] bridge: Fix br_forward crash in promiscuous mode (Herbert Xu) [574321]
- [net] bridge: Split may_deliver/deliver_clone out of br_flood (Herbert Xu) [574321]
- [net] bridge: Use BR_INPUT_SKB_CB on xmit path (Herbert Xu) [574321]
- [net] bridge: Avoid unnecessary clone on forward path (Herbert Xu) [574321]
- [net] bridge: Allow tail-call on br_pass_frame_up (Herbert Xu) [574321]
- [net] bridge: Do br_pass_frame_up after other ports (Herbert Xu) [574321]
- [net] Add netdev_alloc_skb_ip_align() helper (Herbert Xu) [574321]
- [kernel] futex_lock_pi() key refcnt fix (Danny Feng) [566347] {CVE-2010-0623}
- [pci] AER: fix aer inject result in kernel oops (Prarit Bhargava) [568515]
- [scsi] fix 32bit compatibility in BSG interface (Rob Evers) [554538]
- [x86] ACPI: don't cond_resched if irq is disabled (Danny Feng) [572441]
- [x86] Ensure dell-laptop buffers are below 4GB (Matthew Garrett) [570036]
- [hwmon] add hex '0x' indication to coretemp module output (Dean Nelson) [571865]
- [cifs] update cifs client code to latest upstream code (Jeff Layton) [562788]
- [block] fix merge_bvec_fn return value checks (Mike Snitzer) [571455]
- [fs] ext4: avoid uninit mem references on some mount options (Eric Sandeen) [562008]
- [s390x] dasd: Correct offline processing (Hendrik Brueckner) [568376]
- [s390x] dasd: Fix refcounting (Hendrik Brueckner) [568376]
- [x86] amd_iommu: remove dma-ops warning message (Bhavna Sarathy) [560002]
- [x86] amd_iommu: Fix IO page fault by adding device notifiers (Bhavna Sarathy) [560002]
- [x86] amd_iommu: Fix IOMMU API initialization for iommu=pt (Bhavna Sarathy) [560002]
- [x86] amd_iommu: Fix possible integer overflow (Bhavna Sarathy) [560002]
- [x86] amd_iommu: Fix deassignment of a device from the pt domain (Bhavna Sarathy) [560002]
- [gfs2] Allow the number of committed revokes to temporarily be negative (Benjamin Marzinski) [563907]
- [ppc64] powerpc: export data from new hcall H_EM_GET_PARMS (Steve Best) [570019]
- [x86] ACPI: Be in TS_POLLING state during mwait based C-state entry (Avi Kivity) [571440]
- [net] tcp: fix ICMP-RTO war (Jiri Olsa) [567532]
- [mm] Add padding to mm structures allow future patches during the RHEL6 life (Larry Woodman) [554511]

* Tue Mar 09 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-19.el6]
- [mm] Switch to SLAB (Aristeu Rozanski) [570614]

* Mon Mar 08 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-18.el6]
- [kernel/time] revert cc2f92ad1d0e03fe527e8ccfc1f918c368964dc8 (Aristeu Rozanski) [567551]
- [virt] hvc_console: Fix race between hvc_close and hvc_remove (Amit Shah) [568624]
- [scsi] Add netapp to scsi dh alua dev list (Mike Christie) [559586]
- [scsi] scsi_dh_emc: fix mode select setup (Mike Christie) [570685]
- [drm] Remove loop in IronLake graphics interrupt handler (John Villalovos) [557838]
- [x86] Intel Cougar Point chipset support (John Villalovos) [560077]
- [vhost] vhost-net: restart tx poll on sk_sndbuf full (Michael S. Tsirkin) [562837]
- [vhost] fix get_user_pages_fast error handling (Michael S. Tsirkin) [562837]
- [vhost] initialize log eventfd context pointer (Michael S. Tsirkin) [562837]
- [vhost] logging thinko fix (Michael S. Tsirkin) [562837]
- [vhost] vhost-net: switch to smp barriers (Michael S. Tsirkin) [562837]
- [net] bug fix for vlan + gro issue (Andy Gospodarek) [569922]
- [uv] Fix unmap_vma() bug related to mmu_notifiers (George Beshers) [253033]
- [uv] Have mmu_notifiers use SRCU so they may safely schedule (George Beshers) [253033]
- [drm] radeon/kms: bring all v2.6.33 fixes into EL6 kernel (Dave Airlie) [547422 554323 566618 569704]
- [dvb] Fix endless loop when decoding ULE at dvb-core (Mauro Carvalho Chehab) [569243]
- [kernel] sched: Fix SCHED_MC regression caused by change in sched cpu_power (Danny Feng) [568123]
- [s390x] vdso: glibc does not use vdso functions (Hendrik Brueckner) [567755]
- [drm] bring drm core/ttm/fb layer fixes in from upstream (Dave Airlie) [569701]
- [kernel] Fix SMT scheduler regression in find_busiest_queue() (Danny Feng) [568120]
- [s390x] qeth: avoid recovery during device online setting (Hendrik Brueckner) [568781]
- [mm] Fix potential crash with sys_move_pages (Danny Feng) [562591] {CVE-2010-0415}
- [scsi] pmcraid: bug fixes from upstream (Rob Evers) [567376]
- [scsi] lpfc Update from 8.3.5.4 to 8.3.5.5 FC/FCoE (Rob Evers) [564508]
- [ata] ahci: disable FPDMA auto-activate optimization on NVIDIA AHCI (David Milburn) [568815]
- [selinux] netlabel: fix corruption of SELinux MLS categories > 127 (Eric Paris) [568370]
- [gfs2] print glock numbers in hex (Robert S Peterson) [566755]
- [mm] Fix hugetlb.c clear_huge_page parameter (Andrea Arcangeli) [566604]
- [mm] fix anon_vma locking updates for transparent hugepage code (Andrea Arcangeli) [564515]
- [netdrv] cxgb3: add memory barriers (Steve Best) [568390]
- [dm] raid45 target: constructor error path oops fix (Heinz Mauelshagen) [567605]
- [scsi] mpt2sas: fix missing initialization (Tomas Henzl) [567965]
- [net] netfilter: nf_conntrack: per netns nf_conntrack_cachep (Jiri Pirko) [567181]
- [x86] nmi_watchdog: use __cpuinit for nmi_watchdog_default (Don Zickus) [567601]
- [netdrv] ixgbe: prevent speculative processing of descriptors (Steve Best) [568391]
- [kvm] Fix emulate_sys[call, enter, exit]()'s fault handling (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] Fix segment descriptor loading (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] Fix load_guest_segment_descriptor() to inject page fault (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Forbid modifying CS segment register by mov instruction (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Fix x86_emulate_insn() not to use the variable rc for non-X86EMUL values (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: X86EMUL macro replacements: x86_emulate_insn() and its helpers (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: X86EMUL macro replacements: from do_fetch_insn_byte() to x86_decode_insn() (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] inject #UD in 64bit mode from instruction that are not valid there (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Fix properties of instructions in group 1_82 (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: code style cleanup (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Add LOCK prefix validity checking (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Check CPL level during privilege instruction emulation (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Fix popf emulation (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Check IOPL level during io instruction emulation (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: fix memory access during x86 emulation (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Add Virtual-8086 mode of emulation (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Add group9 instruction decoding (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Add group8 instruction decoding (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Introduce No64 decode option (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [kvm] x86 emulator: Add 'push/pop sreg' instructions (Gleb Natapov) [560903 560904 563466] {CVE-2010-0298 CVE-2010-0306 CVE-2010-0419}
- [x86] AES/PCLMUL Instruction support: Various fixes for AES-NI and PCLMMUL (John Villalovos) [463496]
- [x86] AES/PCLMUL Instruction support: Use gas macro for AES-NI instructions (John Villalovos) [463496]
- [x86] AES/PCLMUL Instruction support: Various small fixes for AES/PCMLMUL and generate .byte code for some new instructions via gas macro (John Villalovos) [463496]
- [x86] AES/PCLMUL Instruction support: Add PCLMULQDQ accelerated implementation (John Villalovos) [463496]
- [scsi] megaraid_sas: fix for 32bit apps (Tomas Henzl) [559941]
- [kvm] fix large packet drops on kvm hosts with ipv6 (Neil Horman) [565525]
- [kvm] Add MAINTAINERS entry for virtio_console (Amit Shah) [566391]
- [kvm] virtio: console: Fill ports' entire in_vq with buffers (Amit Shah) [566391]
- [kvm] virtio: console: Error out if we can't allocate buffers for control queue (Amit Shah) [566391]
- [kvm] virtio: console: Add ability to remove module (Amit Shah) [566391]
- [kvm] virtio: console: Ensure no memleaks in case of unused buffers (Amit Shah) [566391]
- [kvm] virtio: console: update Red Hat copyright for 2010 (Amit Shah) [566391]
- [kvm] virtio: Initialize vq->data entries to NULL (Amit Shah) [566391]
- [kvm] virtio: console: outbufs are no longer needed (Amit Shah) [566391]
- [kvm] virtio: console: return -efault for fill_readbuf if copy_to_user fails (Amit Shah) [566391]
- [kvm] virtio: console: Allow sending variable-sized buffers to host, efault on copy_from_user err (Amit Shah) [566391]

* Thu Feb 18 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-17.el6]
- [s390] hvc_iucv: allocate IUCV send/receive buffers in DMA zone (Hendrik Brueckner) [566188]
- [s390] qdio: continue polling for buffer state ERROR (Hendrik Brueckner) [565528]
- [s390] qdio: prevent kernel bug message in interrupt handler (Hendrik Brueckner) [565542]
- [s390] zfcp: report BSG errors in correct field (Hendrik Brueckner) [564378]
- [s390] zfcp: cancel all pending work for a to be removed zfcp_port (Hendrik Brueckner) [564382]
- [nfs] mount.nfs: Unknown error 526 (Steve Dickson) [561975]
- [x86] x86-64, rwsem: Avoid store forwarding hazard in __downgrade_write (Avi Kivity) [563801]
- [x86] x86-64, rwsem: 64-bit xadd rwsem implementation (Avi Kivity) [563801]
- [x86] x86-64: support native xadd rwsem implementation (Avi Kivity) [563801]
- [x86] clean up rwsem type system (Avi Kivity) [563801]
- [x86] x86-32: clean up rwsem inline asm statements (Avi Kivity) [563801]
- [x86] nmi_watchdog: enable by default on RHEL-6 (Don Zickus) [523857]
- [block] freeze_bdev: don't deactivate successfully frozen MS_RDONLY sb (Mike Snitzer) [565890]
- [block] fix bio_add_page for non trivial merge_bvec_fn case (Mike Snitzer) [565890]
- [watchdog] Add support for iTCO watchdog on Ibex Peak chipset (John Villalovos) [536698]
- [kernel] time: Remove xtime_cache (Prarit Bhargava) [563135]
- [kernel] time: Implement logarithmic time accumalation (Prarit Bhargava) [563135]
- [dm] raid1: fail writes if errors are not handled and log fails (Mike Snitzer) [565890]
- [dm] mpath: fix stall when requeueing io (Mike Snitzer) [565890]
- [dm] log: userspace fix overhead_size calcuations (Mike Snitzer) [565890]
- [dm] stripe: avoid divide by zero with invalid stripe count (Mike Snitzer) [565890]
- [mm] anon_vma locking updates for transparent hugepage code (Rik van Riel) [564515]
- [mm] anon_vma linking changes to improve multi-process scalability (Rik van Riel) [564515]
- [virt] virtio_blk: add block topology support (Christoph Hellwig) [556477]
- [kvm] PIT: control word is write-only (Eduardo Habkost) [560905] {CVE-2010-0309}
- [kernel] Prevent futex user corruption to crash the kernel (Jerome Marchand) [563957]
- [selinux] print the module name when SELinux denies a userspace upcall (Eric Paris) [563731]
- [gfs] GFS2 problems on single node cluster (Steven Whitehouse) [564329]
- [ppc] Add kdump support to Collaborative Memory Manager (Steve Best) [563316]

* Fri Feb 12 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-16.el6]
- [nfs] Remove a redundant check for PageFsCache in nfs_migrate_page() (Steve Dickson) [563938]
- [nfs] Fix a bug in nfs_fscache_release_page() (Steve Dickson) [563938]
- [mm] fix BUG()s caused by the transparent hugepage patch (Larry Woodman) [556572]
- [fs] inotify: fix inotify WARN and compatibility issues (Eric Paris) [563363]
- [net] do not check CAP_NET_RAW for kernel created sockets (Eric Paris) [540560]
- [pci] Enablement of PCI ACS control when IOMMU enabled on system (Don Dutile) [523278]
- [pci] PCI ACS support functions (Don Dutile) [523278]
- [uv] x86: Fix RTC latency bug by reading replicated cachelines (George Beshers) [562189]
- [s390x] ctcm / lcs / claw: remove cu3088 layer (Hendrik Brueckner) [557522]
- [uv] vgaarb: add user selectability of the number of gpus in a system (George Beshers) [555879]
- [gpu] vgaarb: fix vga arbiter to accept PCI domains other than 0 (George Beshers) [555879]
- [uv] x86_64: update uv arch to target legacy VGA I/O correctly (George Beshers) [555879]
- [pci] update pci_set_vga_state to call arch functions (George Beshers) [555879]
- [uv] PCI: update pci_set_vga_state to call arch functions (George Beshers) [555879]
- [mm] remove madvise(MADV_HUGEPAGE) (Andrea Arcangeli) [556572]
- [mm] hugepage redhat customization (Andrea Arcangeli) [556572]
- [mm] introduce khugepaged (Andrea Arcangeli) [556572]
- [mm] transparent hugepage vmstat (Andrea Arcangeli) [556572]
- [mm] memcg huge memory (Andrea Arcangeli) [556572]
- [mm] memcg compound (Andrea Arcangeli) [556572]
- [mm] pmd_trans_huge migrate bugcheck (Andrea Arcangeli) [556572]
- [mm] madvise(MADV_HUGEPAGE) (Andrea Arcangeli) [556572]
- [mm] verify pmd_trans_huge isnt leaking (Andrea Arcangeli) [556572]
- [mm] transparent hugepage core (Andrea Arcangeli) [556572]
- [mm] dont alloc harder for gfp nomemalloc even if nowait (Andrea Arcangeli) [556572]
- [mm] introduce _GFP_NO_KSWAPD (Andrea Arcangeli) [556572]
- [mm] backport page_referenced microoptimization (Andrea Arcangeli) [556572]
- [mm] kvm mmu transparent hugepage support (Andrea Arcangeli) [556572]
- [mm] clear_copy_huge_page (Andrea Arcangeli) [556572]
- [mm] clear_huge_page fix (Andrea Arcangeli) [556572]
- [mm] split_huge_page paging (Andrea Arcangeli) [556572]
- [mm] split_huge_page_mm/vma (Andrea Arcangeli) [556572]
- [mm] add pmd_huge_pte to mm_struct (Andrea Arcangeli) [556572]
- [mm] clear page compound (Andrea Arcangeli) [556572]
- [mm] add pmd mmu_notifier helpers (Andrea Arcangeli) [556572]
- [mm] pte alloc trans splitting (Andrea Arcangeli) [556572]
- [mm] bail out gup_fast on splitting pmd (Andrea Arcangeli) [556572]
- [mm] add pmd mangling functions to x86 (Andrea Arcangeli) [556572]
- [mm] add pmd mangling generic functions (Andrea Arcangeli) [556572]
- [mm] special pmd_trans_* functions (Andrea Arcangeli) [556572]
- [mm] config_transparent_hugepage (Andrea Arcangeli) [556572]
- [mm] comment reminder in destroy_compound_page (Andrea Arcangeli) [556572]
- [mm] export maybe_mkwrite (Andrea Arcangeli) [556572]
- [mm] no paravirt version of pmd ops (Andrea Arcangeli) [556572]
- [mm] add pmd paravirt ops (Andrea Arcangeli) [556572]
- [mm] add native_set_pmd_at (Andrea Arcangeli) [556572]
- [mm] clear compound mapping (Andrea Arcangeli) [556572]
- [mm] update futex compound knowledge (Andrea Arcangeli) [556572]
- [mm] alter compound get_page/put_page (Andrea Arcangeli) [556572]
- [mm] add a compound_lock (Andrea Arcangeli) [556572]
- [mm] define MADV_HUGEPAGE (Andrea Arcangeli) [556572]
- [oprofile] Support Nehalem-EX CPU in Oprofile (John Villalovos) [528998]
- [nfs] nfs: handle NFSv3 -EKEYEXPIRED errors as we would -EJUKEBOX (Jeff Layton) [479359]
- [nfs] handle NFSv2 -EKEYEXPIRED returns from RPC layer appropriately (Jeff Layton) [479359]
- [nfs] sunrpc: parse and return errors reported by gssd (Jeff Layton) [479359]
- [nfs] nfs4: handle -EKEYEXPIRED errors from RPC layer (Jeff Layton) [479359]
- [net] nf_conntrack: fix memory corruption (Jon Masters) [559471]
- [kvm] emulate accessed bit for EPT (Rik van Riel) [555106]
- [vhost] fix TUN=m VHOST_NET=y (Michael S. Tsirkin) [562837]
- [vhost] vhost-net: defer f->private_data until setup succeeds (Chris Wright) [562837]
- [vhost] vhost-net: comment use of invalid fd when setting vhost backend (Chris Wright) [562837]
- [vhost] access check thinko fixes (Michael S. Tsirkin) [562837]
- [vhost] make default mapping empty by default (Michael S. Tsirkin) [562837]
- [vhost] add access_ok checks (Michael S. Tsirkin) [562837]
- [vhost] prevent modification of an active ring (Michael S. Tsirkin) [562837]
- [vhost] fix high 32 bit in FEATURES ioctls (Michael S. Tsirkin) [562837]
- [dm] dm-raid1: fix deadlock at suspending failed device (Takahiro Yasui) [557932]
- [dm] fix kernel panic at releasing bio on recovery failed region (Takahiro Yasui) [557934]
- [scsi] lpfc Update from 8.3.4 to 8.3.5.4 FC/FCoE (Rob Evers) [531028]
- [nfs] sunrpc/cache: fix module refcnt leak in a failure path (Steve Dickson) [562285]
- [nfs] Ensure that we handle NFS4ERR_STALE_STATEID correctly (Steve Dickson) [560784]
- [nfs] NFSv4.1: Don't call nfs4_schedule_state_recovery() unnecessarily (Steve Dickson) [560784]
- [nfs] NFSv4: Don't allow posix locking against servers that don't support it (Steve Dickson) [560784]
- [nfs] Ensure that the NFSv4 locking can recover from stateid errors (Steve Dickson) [560784]
- [nfs] Avoid warnings when CONFIG_NFS_V4=n (Steve Dickson) [560784]
- [nfs] Make nfs_commitdata_release static (Steve Dickson) [560784]
- [nfs] Try to commit unstable writes in nfs_release_page() (Steve Dickson) [560784]
- [nfs] Fix a reference leak in nfs_wb_cancel_page() (Steve Dickson) [560784]
- [nfs] nfs41: cleanup callback code to use __be32 type (Steve Dickson) [560785]
- [nfs] nfs41: clear NFS4CLNT_RECALL_SLOT bit on session reset (Steve Dickson) [560785]
- [nfs] nfs41: fix nfs4_callback_recallslot (Steve Dickson) [560785]
- [nfs] nfs41: resize slot table in reset (Steve Dickson) [560785]
- [nfs] nfs41: implement cb_recall_slot (Steve Dickson) [560785]
- [nfs] nfs41: back channel drc minimal implementation (Steve Dickson) [560785]
- [nfs] nfs41: prepare for back channel drc (Steve Dickson) [560785]
- [nfs] nfs41: remove uneeded checks in callback processing (Steve Dickson) [560785]
- [nfs] nfs41: directly encode back channel error (Steve Dickson) [560785]
- [nfs] nfs41: fix wrong error on callback header xdr overflow (Steve Dickson) [560785]
- [nfs] nfs41: Process callback's referring call list (Steve Dickson) [560785]
- [nfs] nfs41: Check slot table for referring calls (Steve Dickson) [560785]
- [nfs] nfs41: Adjust max cache response size value (Steve Dickson) [560785]
- [nfs] NFSD: Create PF_INET6 listener in write_ports (Steve Dickson) [560785]
- [nfs] SUNRPC: NFS kernel APIs shouldn't return ENOENT for "transport not found" (Steve Dickson) [560785]
- [nfs] SUNRPC: Bury "#ifdef IPV6" in svc_create_xprt() (Steve Dickson) [560785]
- [nfs] NFSD: Support AF_INET6 in svc_addsock() function (Steve Dickson) [560785]
- [nfs] SUNRPC: Use rpc_pton() in ip_map_parse() (Steve Dickson) [560785]
- [nfs] nfsd: 4.1 has an rfc number (Steve Dickson) [560785]
- [nfs] nfsd41: Create the recovery entry for the NFSv4.1 client (Steve Dickson) [560785]
- [nfs] nfsd: use vfs_fsync for non-directories (Steve Dickson) [560785]
- [nfs] nfsd4: Use FIRST_NFS4_OP in nfsd4_decode_compound() (Steve Dickson) [560785]
- [nfs] nfsd41: nfsd4_decode_compound() does not recognize all ops (Steve Dickson) [560785]

* Fri Feb 05 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-15.el6]
- [block] blk-cgroup: Fix lockdep warning of potential deadlock in blk-cgroup (Vivek Goyal) [561903]
- [block] cfq: Do not idle on async queues and drive deeper WRITE depths (Vivek Goyal) [561902]
- [quota] 64-bit quota format fixes (Jerome Marchand) [546311]
- [x86] fix Add AMD Node ID MSR support (Bhavna Sarathy) [557540]
- [fs] ext4: fix type of "offset" in ext4_io_end (Eric Sandeen) [560097]
- [x86] Disable HPET MSI on ATI SB700/SB800 (Prarit Bhargava) [557332]
- [x86] arch specific support for remapping HPET MSIs (Prarit Bhargava) [557332]
- [x86] intr-remap: generic support for remapping HPET MSIs (Prarit Bhargava) [557332]
- [gfs] GFS2: Extend umount wait coverage to full glock lifetime (Steven Whitehouse) [561287]
- [gfs] GFS2: Wait for unlock completion on umount (Steven Whitehouse) [561287]
- [gfs] GFS2: Use MAX_LFS_FILESIZE for meta inode size (Steven Whitehouse) [561307]
- [gfs] GFS2: Use GFP_NOFS for alloc structure (Steven Whitehouse) [561307]
- [gfs] GFS2: Fix refcnt leak on gfs2_follow_link() error path (Steven Whitehouse) [561307]

* Wed Feb 03 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-14.el6]
- [s390x] dasd: fix online/offline race (Hendrik Brueckner) [552840]
- [netdrv] update tg3 to version 3.106 and fix panic (John Feeney) [555101]
- [s390x] dasd: Fix null pointer in s390dbf and discipline checking (Hendrik Brueckner) [559615]
- [s390x] zcrypt: Do not remove coprocessor in case of error 8/72 (Hendrik Brueckner) [559613]
- [s390x] cio: channel path vary operation has no effect (Hendrik Brueckner) [559612]
- [uv] x86: Ensure hub revision set for all ACPI modes (George Beshers) [559752]
- [uv] x86: Add function retrieving node controller revision number (George Beshers) [559752]

* Fri Jan 29 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-13.el6]
- [virtio] console: show error message if hvc_alloc fails for console ports (Amit Shah) [543824]
- [virtio] console: Add debugfs files for each port to expose debug info (Amit Shah) [543824]
- [virtio] console: Add ability to hot-unplug ports (Amit Shah) [543824]
- [virtio] hvc_console: Export (GPL'ed) hvc_remove (Amit Shah) [543824]
- [virtio] Add ability to detach unused buffers from vrings (Amit Shah) [543824]
- [virtio] console: Handle port hot-plug (Amit Shah) [543824]
- [virtio] console: Remove cached data on port close (Amit Shah) [543824]
- [virtio] console: Register with sysfs and create a 'name' attribute for ports (Amit Shah) [543824]
- [virtio] console: Ensure only one process can have a port open at a time (Amit Shah) [543824]
- [virtio] console: Add file operations to ports for open/read/write/poll (Amit Shah) [543824]
- [virtio] console: Associate each port with a char device (Amit Shah) [543824]
- [virtio] console: Prepare for writing to / reading from userspace buffers (Amit Shah) [543824]
- [virtio] console: Add a new MULTIPORT feature, support for generic ports (Amit Shah) [543824]
- [virtio] console: Introduce a send_buf function for a common path for sending data to host (Amit Shah) [543824]
- [virtio] console: Introduce function to hand off data from host to readers (Amit Shah) [543824]
- [virtio] console: Separate out find_vqs operation into a different function (Amit Shah) [543824]
- [virtio] console: Separate out console init into a new function (Amit Shah) [543824]
- [virtio] console: Separate out console-specific data into a separate struct (Amit Shah) [543824]
- [virtio] console: ensure console size is updated on hvc open (Amit Shah) [543824]
- [virtio] console: struct ports for multiple ports per device. (Amit Shah) [543824]
- [virtio] console: remove global var (Amit Shah) [543824]
- [virtio] console: don't assume a single console port. (Amit Shah) [543824]
- [virtio] console: use vdev->priv to avoid accessing global var. (Amit Shah) [543824]
- [virtio] console: introduce a get_inbuf helper to fetch bufs from in_vq (Amit Shah) [543824]
- [virtio] console: ensure add_inbuf can work for multiple ports as well (Amit Shah) [543824]
- [virtio] console: encapsulate buffer information in a struct (Amit Shah) [543824]
- [virtio] console: port encapsulation (Amit Shah) [543824]
- [virtio] console: We support only one device at a time (Amit Shah) [543824]
- [virtio] hvc_console: Remove __devinit annotation from hvc_alloc (Amit Shah) [543824]
- [virtio] hvc_console: make the ops pointer const. (Amit Shah) [543824]
- [virtio] console: statically initialize virtio_cons (Amit Shah) [543824]
- [virtio] console: comment cleanup (Amit Shah) [543824]
- [x86] Fix crash when profiling more than 28 events (Bhavna Sarathy) [557570]
- [x86] Add AMD Node ID MSR support (Bhavna Sarathy) [557540]
- [kvm] fix spurious interrupt with irqfd (Marcelo Tosatti) [559343]
- [kvm] eventfd: allow atomic read and waitqueue remove (Marcelo Tosatti) [559343]
- [kvm] properly check max PIC pin in irq route setup (Marcelo Tosatti) [559343]
- [kvm] only allow one gsi per fd (Marcelo Tosatti) [559343]
- [kvm] x86: Fix leak of free lapic date in kvm_arch_vcpu_init() (Marcelo Tosatti) [559343]
- [kvm] x86: Fix probable memory leak of vcpu->arch.mce_banks (Marcelo Tosatti) [559343]
- [kvm] MMU: bail out pagewalk on kvm_read_guest error (Marcelo Tosatti) [559343]
- [kvm] x86: Fix host_mapping_level() (Marcelo Tosatti) [559343]
- [kvm] Fix race between APIC TMR and IRR (Marcelo Tosatti) [559343]
- [x86] acpi: Export acpi_pci_irq_{add|del}_prt() (James Paradis) [553781]
- [kdump] backport upstream ppc64 kcrctab fixes (Neil Horman) [558803]
- [mm] Memory tracking for Stratus (James Paradis) [512400]

* Thu Jan 28 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-12.el6]
- [drm] radeon possible security issue (Jerome Glisse) [556692]
- [mm] Memory tracking for Stratus (James Paradis) [512400]
- [pci] Always set prefetchable base/limit upper32 registers (Prarit Bhargava) [553471]
- [scsi] Sync be2iscsi with upstream (Mike Christie) [515256]
- [x86] msr/cpuid: Register enough minors for the MSR and CPUID drivers (George Beshers) [557554]
- [x86] Remove unnecessary mdelay() from cpu_disable_common() (Peter Bogdanovic) [463633]
- [x86] ioapic: Document another case when level irq is seen as an edge (Peter Bogdanovic) [463633]
- [x86] ioapic: Fix the EOI register detection mechanism (Peter Bogdanovic) [463633]
- [x86] io-apic: Move the effort of clearing remoteIRR explicitly before migrating the irq (Peter Bogdanovic) [463633]
- [x86] Remove local_irq_enable()/local_irq_disable() in fixup_irqs() (Peter Bogdanovic) [463633]
- [x86] Use EOI register in io-apic on intel platforms (Peter Bogdanovic) [463633]

* Tue Jan 26 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-11.el6]
- [kdump] Remove the 32MB limitation for crashkernel (Steve Best) [529270]
- [dm] dm-raid45: export missing dm_rh_inc (Heinz Mauelshagen) [552329]
- [block] dm-raid45: add raid45 target (Heinz Mauelshagen) [552329]
- [block] dm-replicator: blockdev site link handler (Heinz Mauelshagen) [552364]
- [block] dm-replicator: ringbuffer replication log handler (Heinz Mauelshagen) [552364]
- [block] dm-replicator: replication log and site link handler interfaces and main replicator module (Heinz Mauelshagen) [552364]
- [block] dm-replicator: documentation and module registry (Heinz Mauelshagen) [552364]
- [s390x] qeth: set default BLKT settings dependend on OSA hw level (Hendrik Brueckner) [557474]
- [drm] bring RHEL6 radeon drm up to 2.6.33-rc4/5 level (Jerome Glisse) [557539]
- [netdrv] e1000e: enhance frame fragment detection (Andy Gospodarek) [462780]
- [stable] ipv6: skb_dst() can be NULL in ipv6_hop_jumbo(). (David S. Miller) [555084]
- [stable] module: handle ppc64 relocating kcrctabs when CONFIG_RELOCATABLE=y (Rusty Russell) [555084]
- [stable] fix more leaks in audit_tree.c tag_chunk() (Al Viro) [555084]
- [stable] fix braindamage in audit_tree.c untag_chunk() (Al Viro) [555084]
- [stable] mac80211: fix skb buffering issue (and fixes to that) (Johannes Berg) [555084]
- [stable] kernel/sysctl.c: fix stable merge error in NOMMU mmap_min_addr (Mike Frysinger) [555084]
- [stable] libertas: Remove carrier signaling from the scan code (Samuel Ortiz) [555084]
- [stable] mac80211: add missing sanity checks for action frames (Felix Fietkau) [555084]
- [stable] iwl: off by one bug (Dan Carpenter) [555084]
- [stable] cfg80211: fix syntax error on user regulatory hints (Luis R. Rodriguez) [555084]
- [stable] ath5k: Fix eeprom checksum check for custom sized eeproms (Luis R. Rodriguez) [555084]
- [stable] iwlwifi: fix iwl_queue_used bug when read_ptr == write_ptr (Zhu Yi) [555084]
- [stable] xen: fix hang on suspend. (Ian Campbell) [555084]
- [stable] quota: Fix dquot_transfer for filesystems different from ext4 (Jan Kara) [555084]
- [stable] hwmon: (adt7462) Fix pin 28 monitoring (Roger Blofeld) [555084]
- [stable] hwmon: (coretemp) Fix TjMax for Atom N450/D410/D510 CPUs (Yong Wang) [555084]
- [stable] netfilter: nf_ct_ftp: fix out of bounds read in update_nl_seq() (Patrick McHardy) [555084]
- [stable] netfilter: ebtables: enforce CAP_NET_ADMIN (Florian Westphal) [555084]
- [stable] ASoC: Fix WM8350 DSP mode B configuration (Mark Brown) [555084]
- [stable] ALSA: atiixp: Specify codec for Foxconn RC4107MA-RS2 (Daniel T Chen) [555084]
- [stable] ALSA: ac97: Add Dell Dimension 2400 to Headphone/Line Jack Sense blacklist (Daniel T Chen) [555084]
- [stable] mmc_block: fix queue cleanup (Adrian Hunter) [555084]
- [stable] mmc_block: fix probe error cleanup bug (Jarkko Lavinen) [555084]
- [stable] mmc_block: add dev_t initialization check (Anna Lemehova) [555084]
- [stable] kernel/signal.c: fix kernel information leak with print-fatal-signals=1 (Andi Kleen) [555084]
- [stable] dma-debug: allow DMA_BIDIRECTIONAL mappings to be synced with DMA_FROM_DEVICE and (Krzysztof Halasa) [555084]
- [stable] lib/rational.c needs module.h (Sascha Hauer) [555084]
- [stable] drivers/cpuidle/governors/menu.c: fix undefined reference to `__udivdi3' (Stephen Hemminger) [555084]
- [stable] rtc_cmos: convert shutdown to new pnp_driver->shutdown (OGAWA Hirofumi) [555084]
- [stable] Revert "x86: Side-step lguest problem by only building cmpxchg8b_emu for pre-Pentium" (Rusty Russell) [555084]
- [stable] exofs: simple_write_end does not mark_inode_dirty (Boaz Harrosh) [555084]
- [stable] modules: Skip empty sections when exporting section notes (Ben Hutchings) [555084]
- [stable] ASoC: fix params_rate() macro use in several codecs (Guennadi Liakhovetski) [555084]
- [stable] fasync: split 'fasync_helper()' into separate add/remove functions (Linus Torvalds) [555084]
- [stable] untangle the do_mremap() mess (Al Viro)

* Fri Jan 22 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-10.el6]
- [mm] mmap: don't return ENOMEM when mapcount is temporarily exceeded in munmap() (Danny Feng) [557000]
- [netdrv] vxge: fix issues found in Neterion testing (Michal Schmidt) [493985]
- [x86] Force irq complete move during cpu offline (Prarit Bhargava) [541815]
- [sound] Fix SPDIF-In for AD1988 codecs + add Intel Cougar IDs (Jaroslav Kysela) [557473]
- [scsi] aic79xx: check for non-NULL scb in ahd_handle_nonpkt_busfree (Tomas Henzl) [557753]
- [s390x] fix loading of PER control registers for utrace. (CAI Qian) [556410]
- [s390x] ptrace: dont abuse PT_PTRACED (CAI Qian) [552102]
- [perf] Remove the "event" callback from perf events (Jason Baron) [525517]
- [perf] Use overflow handler instead of the event callback (Jason Baron) [525517]
- [perf] Fix locking for PERF_FORMAT_GROUP (Jason Baron) [525517]
- [perf] Fix event scaling for inherited counters (Jason Baron) [525517]
- [perf] Fix PERF_FORMAT_GROUP scale info (Jason Baron) [525517]
- [perf] Allow for custom overflow handlers (Jason Baron) [525517]
- [perf] Add a callback to perf events (Jason Baron) [525517]
- [perf] improve error reporting (Jason Baron) [525517]
- [perf] add kernel internal interface (Jason Baron) [525517]
- [utrace] fix utrace_maybe_reap() vs find_matching_engine() race (Oleg Nesterov) [557338]
- [x86] Disable Memory hot add on x86 32-bit (Prarit Bhargava) [557131]
- [netdrv] e1000e: update to the latest upstream (Andy Gospodarek) [462780]
- [gfs] Use dquot_send_warning() (Steven Whitehouse) [557057]
- [gfs] Add quota netlink support (Steven Whitehouse) [557057]
- [netdrv] qlge: update to upstream version v1.00.00.23.00.00-01 (Andy Gospodarek) [553357]
- [s390x] zfcp: set HW timeout requested by BSG request (Hendrik Brueckner) [556918]
- [s390x] zfcp: introduce BSG timeout callback (Hendrik Brueckner) [556918]
- [scsi] scsi_transport_fc: Allow LLD to reset FC BSG timeout (Hendrik Brueckner) [556918]

* Wed Jan 20 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-9.el6]
- [kvm] fix cleanup_srcu_struct on vm destruction (Marcelo Tosatti) [554762]
- [x86] core: make LIST_POISON less deadly (Avi Kivity) [554640]
- [x86] dell-wmi: Add support for new Dell systems (Matthew Garrett) [525548]
- [fs] xfs: 2.6.33 updates (Eric Sandeen) [554891]
- [x86] Add kernel pagefault tracepoint for x86 & x86_64. (Larry Woodman) [526032]
- [pci] PCIe AER: honor ACPI HEST FIRMWARE FIRST mode (Matthew Garrett) [537205]
- [block] direct-io: cleanup blockdev_direct_IO locking (Eric Sandeen) [556547]
- [tracing] tracepoint: Add signal tracepoints (Masami Hiramatsu) [526030]
- [cgroups] fix for "kernel BUG at kernel/cgroup.c:790" (Dave Anderson) [547815]
- [irq] Expose the irq_desc node as /proc/irq/*/node (George Beshers) [555866]
- [scsi] qla2xxx - Update support for FC/FCoE HBA/CNA (Rob Evers) [553854]
- [scsi] bfa update from 2.1.2.0 to 2.1.2.1 (Rob Evers) [475704]
- [nfs] sunrpc: fix build-time warning (Steve Dickson) [437715]
- [nfs] sunrpc: on successful gss error pipe write, don't return error (Steve Dickson) [437715]
- [nfs] SUNRPC: Fix the return value in gss_import_sec_context() (Steve Dickson) [437715]
- [nfs] SUNRPC: Fix up an error return value in gss_import_sec_context_kerberos() (Steve Dickson) [437715]
- [nfs] sunrpc: fix peername failed on closed listener (Steve Dickson) [437715]
- [nfs] nfsd: make sure data is on disk before calling ->fsync (Steve Dickson) [437715]
- [uv] React 2.6.32.y: isolcpus broken in 2.6.32.y kernel (George Beshers) [548842]
- [gru] GRU Rollup patch (George Beshers) [546680]
- [uv] XPC: pass nasid instead of nid to gru_create_message_queue (George Beshers) [546695]
- [uv] x86: XPC receive message reuse triggers invalid BUG_ON (George Beshers) [546695]
- [uv] x86: xpc_make_first_contact hang due to not accepting ACTIVE state (George Beshers) [546695]
- [uv] x86: xpc NULL deref when mesq becomes empty (George Beshers) [546695]
- [uv] x86: update XPC to handle updated BIOS interface (George Beshers) [546695]
- [uv] xpc needs to provide an abstraction for uv_gpa (George Beshers) [546695]
- [uv] x86, irq: Check move_in_progress before freeing the vector mapping (George Beshers) [546668]
- [uv] x86: Remove move_cleanup_count from irq_cfg (George Beshers) [546668]
- [uv] x86, irq: Allow 0xff for /proc/irq/[n]/smp_affinity on an 8-cpu system (George Beshers) [546668]
- [uv] x86, apic: Move SGI UV functionality out of generic IO-APIC code (George Beshers) [546668]
- [uv] x86 SGI: Fix irq affinity for hub based interrupts (George Beshers) [546668]
- [uv] x86 RTC: Always enable RTC clocksource (George Beshers) [546668]
- [uv] x86 RTC: Rename generic_interrupt to x86_platform_ipi (George Beshers) [546668]
- [uv] x86, mm: Correct the implementation of is_untracked_pat_range() (George Beshers) [548524]
- [uv] x86: Change is_ISA_range() into an inline function (George Beshers) [548524]
- [uv] x86, platform: Change is_untracked_pat_range() to bool (George Beshers) [548524]
- [uv] x86, mm: is_untracked_pat_range() takes a normal semiclosed range (George Beshers) [548524]
- [uv] x86, mm: Call is_untracked_pat_range() rather than is_ISA_range() (George Beshers) [548524]
- [uv] x86 SGI: Dont track GRU space in PAT (George Beshers) [548524]
- [scsi] megaraid: upgrade to 4.17 (Tomas Henzl) [520729]
- [scsi] mpt2sas: Bump version 03.100.03.00 (Tomas Henzl) [470848]
- [scsi] mpt2sas: don't update links nor unblock device at no link rate change (Tomas Henzl) [470848]
- [scsi] mpt2sas: add support for RAID Action System Shutdown Initiated at OS Shutdown (Tomas Henzl) [470848]
- [scsi] mpt2sas: freeze the sdev IO queue when firmware sends internal device reset (Tomas Henzl) [470848]
- [scsi] mpt2sas: fix PPC endian bug (Tomas Henzl) [470848]
- [scsi] mpt2sas: mpt2sas_base_get_sense_buffer_dma returns little endian (Tomas Henzl) [470848]
- [scsi] mpt2sas: return DID_TRANSPORT_DISRUPTED in nexus loss and SCSI_MLQUEUE_DEVICE_BUSY if device is busy (Tomas Henzl) [470848]
- [scsi] mpt2sas: retrieve the ioc facts prior to putting the controller into READY state (Tomas Henzl) [470848]
- [scsi] mpt2sas: add new info messages for IR and Expander events (Tomas Henzl) [470848]
- [scsi] mpt2sas: limit the max_depth to 32 for SATA devices (Tomas Henzl) [470848]
- [scsi] mpt2sas: add TimeStamp support when sending ioc_init (Tomas Henzl) [470848]
- [scsi] mpt2sas: add extended type for diagnostic buffer support (Tomas Henzl) [470848]
- [scsi] mpt2sas: add command line option diag_buffer_enable (Tomas Henzl) [470848]
- [scsi] mpt2sas: fix some comments (Tomas Henzl) [470848]
- [scsi] mpt2sas: stop driver when firmware encounters faults (Tomas Henzl) [470848]
- [scsi] mpt2sas: adding MPI Headers - revision L (Tomas Henzl) [470848]
- [scsi] mpt2sas: new device SAS2208 support (Tomas Henzl) [470848]
- [scsi] mpt2sas: check for valid response info (Tomas Henzl) [470848]
- [scsi] mpt2sas: fix expander remove fail (Tomas Henzl) [470848]
- [scsi] mpt2sas: use sas address instead of handle as a lookup (Tomas Henzl) [470848]
- [sound] ALSA HDA driver update 2009-12-15 (Jaroslav Kysela) [555812]
- [block] Honor the gfp_mask for alloc_page() in blkdev_issue_discard() (Mike Snitzer) [554719]
- [scsi] sync fcoe with upstream (Mike Christie) [549945]
- [net] dccp: modify how dccp creates slab caches to prevent bug halt in SLUB (Neil Horman) [553698]
- [s390x] tape: Add pr_fmt() macro to all tape source files (Hendrik Brueckner) [554380]
- [s390] qeth: fix packet loss if TSO is switched on (Hendrik Brueckner) [546632]
- [s390x] qeth: Support for HiperSockets Network Traffic Analyzer (Hendrik Brueckner) [463706]
- [serial] 8250: add support for DTR/DSR hardware flow control (Mauro Carvalho Chehab) [523848]

* Tue Jan 19 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-8.el6]
- [build] Revert "[redhat] disabling temporaly DEVTMPFS" (Aristeu Rozanski)

* Tue Jan 19 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-7.el6]
- [drm] minor printk fixes from upstream (Dave Airlie) [554601]
- [offb] add support for framebuffer handoff to offb. (Dave Airlie) [554948]
- [x86] allow fbdev primary video code on 64-bit. (Dave Airlie) [554930]
- [drm] nouveau: update to 2.6.33 level (Dave Airlie) [549930]
- [drm] ttm: validation API changes + ERESTART fixes. (Dave Airlie) [554918]
- [drm] radeon/kms: update to 2.6.33 (without TTM API changes) (Dave Airlie) [554918]
- [drm] i915: bring Intel DRM/KMS driver up to 2.6.33 (Dave Airlie) [554616]
- [drm] radeon/intel: realign displayport helper code with upstream. (Dave Airlie) [554601]
- [drm] kms: rollup KMS core and helper changes to 2.6.33 (Dave Airlie) [554601]
- [drm] remove address mask param for drm_pci_alloc() (Dave Airlie) [554601]
- [drm] add new userspace core drm interfaces from 2.6.33 (Dave Airlie) [554601]
- [drm] unlocked ioctl support for core + macro fixes (Dave Airlie) [554601]
- [drm] ttm: rollup upstream TTM fixes (Dave Airlie) [554601]
- [drm] mm: patch drm core memory range manager up to 2.6.33 (Dave Airlie) [554601]
- [drm] drm/edid: update to 2.6.33 EDID parser code (Dave Airlie) [554601]
- [net] dccp: fix module load dependency btw dccp_probe and dccp (Neil Horman) [554840]
- [powerpc] pseries: Correct pseries/dlpar.c build break without CONFIG_SMP (Steve Best) [539318]
- [powerpc] cpu-allocation/deallocation process (Steve Best) [539318]
- [powerpc] Add code to online/offline CPUs of a DLPAR node (Steve Best) [539318]
- [powerpc] CPU DLPAR handling (Steve Best) [539318]
- [powerpc] sysfs cpu probe/release files (Steve Best) [539318]
- [powerpc] Kernel handling of Dynamic Logical Partitioning (Steve Best) [539318]
- [powerpc] pseries: Add hooks to put the CPU into an appropriate offline state (Steve Best) [539318]
- [powerpc] pseries: Add extended_cede_processor() helper function. (Steve Best) [539318]
- [gfs] GFS2: Fix glock refcount issues (Steven Whitehouse) [546634]
- [gfs] GFS2: Ensure uptodate inode size when using O_APPEND (Steven Whitehouse) [547639]
- [gfs] GFS2: Fix locking bug in rename (Steven Whitehouse) [547640]
- [gfs] GFS2: Fix lock ordering in gfs2_check_blk_state() (Steven Whitehouse) [554673]
- [gfs2] only show nobarrier option on /proc/mounts when the option is active (Steven Whitehouse) [546665]
- [gfs2] add barrier/nobarrier mount options (Steven Whitehouse) [546665]
- [gfs2] remove division from new statfs code (Steven Whitehouse) [298561]
- [gfs2] Improve statfs and quota usability (Steven Whitehouse) [298561]
- [gfs2] Add set_xquota support (Steven Whitehouse) [298561]
- [gfs2] Add get_xquota support (Steven Whitehouse) [298561]
- [gfs2] Clean up gfs2_adjust_quota() and do_glock() (Steven Whitehouse) [298561]
- [gfs2] Remove constant argument from qd_get() (Steven Whitehouse) [298561]
- [gfs2] Remove constant argument from qdsb_get() (Steven Whitehouse) [298561]
- [gfs2] Add proper error reporting to quota sync via sysfs (Steven Whitehouse) [298561]
- [gfs2] Add get_xstate quota function (Steven Whitehouse) [298561]
- [gfs2] Remove obsolete code in quota.c (Steven Whitehouse) [298561]
- [gfs2] Hook gfs2_quota_sync into VFS via gfs2_quotactl_ops (Steven Whitehouse) [298561]
- [gfs2] Alter arguments of gfs2_quota/statfs_sync (Steven Whitehouse) [298561]
- [gfs2] Fix -o meta mounts for subsequent mounts (Steven Whitehouse) [546664]
- [gfs] GFS2: Fix gfs2_xattr_acl_chmod() (Steven Whitehouse) [546294]
- [gfs] VFS: Use GFP_NOFS in posix_acl_from_xattr() (Steven Whitehouse) [546294]
- [gfs] GFS2: Add cached ACLs support (Steven Whitehouse) [546294]
- [gfs] GFS2: Clean up ACLs (Steven Whitehouse) [546294]
- [gfs] GFS2: Use gfs2_set_mode() instead of munge_mode() (Steven Whitehouse) [546294]
- [gfs] GFS2: Use forget_all_cached_acls() (Steven Whitehouse) [546294]
- [gfs] VFS: Add forget_all_cached_acls() (Steven Whitehouse) [546294]
- [gfs] GFS2: Fix up system xattrs (Steven Whitehouse) [546294]
- [netdrv] igb: Update igb driver to support Barton Hills (Stefan Assmann) [462783]
- [dm] add feature flags to reduce future kABI impact (Mike Snitzer) [547756]
- [block] Stop using byte offsets (Mike Snitzer) [554718]
- [dm] Fix device mapper topology stacking (Mike Snitzer) [554718]
- [block] bdev_stack_limits wrapper (Mike Snitzer) [554718]
- [block] Fix discard alignment calculation and printing (Mike Snitzer) [554718]
- [block] Correct handling of bottom device misaligment (Mike Snitzer) [554718]
- [block] Fix incorrect alignment offset reporting and update documentation (Mike Snitzer) [554718]
- [kvm] Fix possible circular locking in kvm_vm_ioctl_assign_device() (Marcelo Tosatti) [554762]
- [kvm] only clear irq_source_id if irqchip is present (Marcelo Tosatti) [554762]
- [kvm] fix lock imbalance in kvm_*_irq_source_id() (Marcelo Tosatti) [554762]
- [kvm] VMX: Report unexpected simultaneous exceptions as internal errors (Marcelo Tosatti) [554762]
- [kvm] Allow internal errors reported to userspace to carry extra data (Marcelo Tosatti) [554762]
- [kvm] x86: disable paravirt mmu reporting (Marcelo Tosatti) [554762]
- [kvm] x86: disallow KVM_{SET, GET}_LAPIC without allocated in-kernel lapic (Marcelo Tosatti) [554762]
- [kvm] x86: disallow multiple KVM_CREATE_IRQCHIP (Marcelo Tosatti) [554762]
- [kvm] VMX: Disable unrestricted guest when EPT disabled (Marcelo Tosatti) [554762]
- [kvm] SVM: remove needless mmap_sem acquision from nested_svm_map (Marcelo Tosatti) [554762]
- [kvm] SVM: Notify nested hypervisor of lost event injections (Marcelo Tosatti) [554762]
- [kvm] SVM: Move INTR vmexit out of atomic code (Marcelo Tosatti) [554762]
- [kvm] remove pre_task_link setting in save_state_to_tss16 (Marcelo Tosatti) [554762]
- [kvm] x86: Extend KVM_SET_VCPU_EVENTS with selective updates (Marcelo Tosatti) [554500]
- [kvm] x86: Add KVM_GET/SET_VCPU_EVENTS (Marcelo Tosatti) [554500]
- [kvm] fix kvmclock-adjust-offset ioctl to match upstream (Marcelo Tosatti) [554524]
- [kvm] SVM: init_vmcb(): remove redundant save->cr0 initialization (Marcelo Tosatti) [554506]
- [kvm] SVM: Reset cr0 properly on vcpu reset (Marcelo Tosatti) [554506]
- [kvm] VMX: Use macros instead of hex value on cr0 initialization (Marcelo Tosatti) [554506]
- [kvm] avoid taking ioapic mutex for non-ioapic EOIs (Marcelo Tosatti) [550809]
- [kvm] Bump maximum vcpu count to 64 (Marcelo Tosatti) [550809]
- [kvm] convert slots_lock to a mutex (Marcelo Tosatti) [550809]
- [kvm] switch vcpu context to use SRCU (Marcelo Tosatti) [550809]
- [kvm] convert io_bus to SRCU (Marcelo Tosatti) [550809]
- [kvm] x86: switch kvm_set_memory_alias to SRCU update (Marcelo Tosatti) [550809]
- [kvm] use SRCU for dirty log (Marcelo Tosatti) [550809]
- [kvm] introduce kvm->srcu and convert kvm_set_memory_region to SRCU update (Marcelo Tosatti) [550809]
- [kvm] use gfn_to_pfn_memslot in kvm_iommu_map_pages (Marcelo Tosatti) [550809]
- [kvm] introduce gfn_to_pfn_memslot (Marcelo Tosatti) [550809]
- [kvm] split kvm_arch_set_memory_region into prepare and commit (Marcelo Tosatti) [550809]
- [kvm] modify alias layout in x86s struct kvm_arch (Marcelo Tosatti) [550809]
- [kvm] modify memslots layout in struct kvm (Marcelo Tosatti) [550809]
- [kvm] rcu: Enable synchronize_sched_expedited() fastpath (Marcelo Tosatti) [550809]
- [kvm] rcu: Add synchronize_srcu_expedited() to the documentation (Marcelo Tosatti) [550809]
- [kvm] rcu: Add synchronize_srcu_expedited() to the rcutorture test suite (Marcelo Tosatti) [550809]
- [kvm] Add synchronize_srcu_expedited() (Marcelo Tosatti) [550809]
- [kvm] Drop kvm->irq_lock lock from irq injection path (Marcelo Tosatti) [550809]
- [kvm] Move IO APIC to its own lock (Marcelo Tosatti) [550809]
- [kvm] Convert irq notifiers lists to RCU locking (Marcelo Tosatti) [550809]
- [kvm] Move irq ack notifier list to arch independent code (Marcelo Tosatti) [550809]
- [kvm] Move irq routing data structure to rcu locking (Marcelo Tosatti) [550809]
- [kvm] Maintain back mapping from irqchip/pin to gsi (Marcelo Tosatti) [550809]
- [kvm] Change irq routing table to use gsi indexed array (Marcelo Tosatti) [550809]
- [kvm] Move irq sharing information to irqchip level (Marcelo Tosatti) [550809]
- [kvm] Call pic_clear_isr() on pic reset to reuse logic there (Marcelo Tosatti) [550809]
- [kvm] Dont pass kvm_run arguments (Marcelo Tosatti) [550809]

* Thu Jan 14 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-6.el6]
- [modsign] Remove Makefile.modpost qualifying message for module sign failure (David Howells) [543529]
- [nfs] fix oops in nfs_rename() (Jeff Layton) [554337]
- [x86] AMD: Fix stale cpuid4_info shared_map data in shared_cpu_map cpumasks (Prarit Bhargava) [546610]
- [s390] kernel: improve code generated by atomic operations (Hendrik Brueckner) [547411]
- [s390x] tape: incomplete device removal (Hendrik Brueckner) [547415]
- [netdrv] be2net: update be2net driver to latest upstream (Ivan Vecera) [515262]
- [x86] mce: fix confusion between bank attributes and mce attributes (hiro muneda) [476606]
- [tpm] autoload tpm_tis driver (John Feeney) [531891]
- [stable] generic_permission: MAY_OPEN is not write access (Serge E. Hallyn) [555084]
- [stable] rt2x00: Disable powersaving for rt61pci and rt2800pci. (Gertjan van Wingerde) [555084]
- [stable] lguest: fix bug in setting guest GDT entry (Rusty Russell) [555084]
- [stable] ext4: Update documentation to correct the inode_readahead_blks option name (Fang Wenqi) [555084]
- [stable] sched: Sched_rt_periodic_timer vs cpu hotplug (Peter Zijlstra) [555084]
- [stable] amd64_edac: fix forcing module load/unload (Borislav Petkov) [555084]
- [stable] amd64_edac: make driver loading more robust (Borislav Petkov) [555084]
- [stable] amd64_edac: fix driver instance freeing (Borislav Petkov) [555084]
- [stable] x86, msr: msrs_alloc/free for CONFIG_SMP=n (Borislav Petkov) [555084]
- [stable] x86, msr: Add support for non-contiguous cpumasks (Borislav Petkov) [555084]
- [stable] amd64_edac: unify MCGCTL ECC switching (Borislav Petkov) [555084]
- [stable] cpumask: use modern cpumask style in drivers/edac/amd64_edac.c (Rusty Russell) [555084]
- [stable] x86, msr: Unify rdmsr_on_cpus/wrmsr_on_cpus (Borislav Petkov) [555084]
- [stable] ext4: fix sleep inside spinlock issue with quota and dealloc (#14739) (Dmitry Monakhov) [555084]
- [stable] ext4: Convert to generic reserved quota's space management. (Dmitry Monakhov) [555084]
- [stable] quota: decouple fs reserved space from quota reservation (Dmitry Monakhov) [555084]
- [stable] Add unlocked version of inode_add_bytes() function (Dmitry Monakhov) [555084]
- [stable] udf: Try harder when looking for VAT inode (Jan Kara) [555084]
- [stable] orinoco: fix GFP_KERNEL in orinoco_set_key with interrupts disabled (Andrey Borzenkov) [555084]
- [stable] drm: disable all the possible outputs/crtcs before entering KMS mode (Zhao Yakui) [555084]
- [stable] drm/radeon/kms: fix crtc vblank update for r600 (Dave Airlie) [555084]
- [stable] sched: Fix balance vs hotplug race (Peter Zijlstra) [555084]
- [stable] Keys: KEYCTL_SESSION_TO_PARENT needs TIF_NOTIFY_RESUME architecture support (Geert Uytterhoeven) [555084]
- [stable] b43: avoid PPC fault during resume (Larry Finger) [555084]
- [stable] hwmon: (sht15) Off-by-one error in array index + incorrect constants (Jonathan Cameron) [555084]
- [stable] netfilter: fix crashes in bridge netfilter caused by fragment jumps (Patrick McHardy) [555084]
- [stable] ipv6: reassembly: use seperate reassembly queues for conntrack and local delivery (Patrick McHardy) [555084]
- [stable] e100: Fix broken cbs accounting due to missing memset. (Roger Oksanen) [555084]
- [stable] memcg: avoid oom-killing innocent task in case of use_hierarchy (Daisuke Nishimura) [555084]
- [stable] x86/ptrace: make genregs[32]_get/set more robust (Linus Torvalds) [555084]
- [stable] V4L/DVB (13596): ov511.c typo: lock => unlock (Dan Carpenter) [555084]
- [stable] kernel/sysctl.c: fix the incomplete part of sysctl_max_map_count-should-be-non-negative.patch (WANG Cong) [555084]
- [stable] 'sysctl_max_map_count' should be non-negative (Amerigo Wang) [555084]
- [stable] NOMMU: Optimise away the {dac_,}mmap_min_addr tests (David Howells) [555084]
- [stable] mac80211: fix race with suspend and dynamic_ps_disable_work (Luis R. Rodriguez) [555084]
- [stable] iwlwifi: fix 40MHz operation setting on cards that do not allow it (Reinette Chatre) [555084]
- [stable] iwlwifi: fix more eeprom endian bugs (Johannes Berg) [555084]
- [stable] iwlwifi: fix EEPROM/OTP reading endian annotations and a bug (Johannes Berg) [555084]
- [stable] iwl3945: fix panic in iwl3945 driver (Zhu Yi) [555084]
- [stable] iwl3945: disable power save (Reinette Chatre) [555084]
- [stable] ath9k_hw: Fix AR_GPIO_INPUT_EN_VAL_BT_PRIORITY_BB and its shift value in 0x4054 (Vasanthakumar Thiagarajan) [555084]
- [stable] ath9k_hw: Fix possible OOB array indexing in gen_timer_index[] on 64-bit (Vasanthakumar Thiagarajan) [555084]
- [stable] ath9k: fix suspend by waking device prior to stop (Sujith) [555084]
- [stable] ath9k: wake hardware during AMPDU TX actions (Luis R. Rodriguez) [555084]
- [stable] ath9k: fix missed error codes in the tx status check (Felix Fietkau) [555084]
- [stable] ath9k: Fix TX queue draining (Sujith) [555084]
- [stable] ath9k: wake hardware for interface IBSS/AP/Mesh removal (Luis R. Rodriguez) [555084]
- [stable] ath5k: fix SWI calibration interrupt storm (Bob Copeland) [555084]
- [stable] cfg80211: fix race between deauth and assoc response (Johannes Berg) [555084]
- [stable] mac80211: Fix IBSS merge (Sujith) [555084]
- [stable] mac80211: fix WMM AP settings application (Johannes Berg) [555084]
- [stable] mac80211: fix propagation of failed hardware reconfigurations (Luis R. Rodriguez) [555084]
- [stable] iwmc3200wifi: fix array out-of-boundary access (Zhu Yi) [555084]
- [stable] Libertas: fix buffer overflow in lbs_get_essid() (Daniel Mack) [555084]
- [stable] KVM: LAPIC: make sure IRR bitmap is scanned after vm load (Marcelo Tosatti) [555084]
- [stable] KVM: MMU: remove prefault from invlpg handler (Marcelo Tosatti) [555084]
- [stable] ioat2,3: put channel hardware in known state at init (Dan Williams) [555084]
- [stable] ioat3: fix p-disabled q-continuation (Dan Williams) [555084]
- [stable] x86/amd-iommu: Fix initialization failure panic (Joerg Roedel) [555084]
- [stable] dma-debug: Fix bug causing build warning (Ingo Molnar) [555084]
- [stable] dma-debug: Do not add notifier when dma debugging is disabled. (Shaun Ruffell) [555084]
- [stable] dma: at_hdmac: correct incompatible type for argument 1 of 'spin_lock_bh' (Nicolas Ferre) [555084]
- [stable] md: Fix unfortunate interaction with evms (NeilBrown) [555084]
- [stable] x86: SGI UV: Fix writes to led registers on remote uv hubs (Mike Travis) [555084]
- [stable] drivers/net/usb: Correct code taking the size of a pointer (Julia Lawall) [555084]
- [stable] USB: fix bugs in usb_(de)authorize_device (Alan Stern) [555084]
- [stable] USB: rename usb_configure_device (Alan Stern) [555084]
- [stable] Bluetooth: Prevent ill-timed autosuspend in USB driver (Oliver Neukum) [555084]
- [stable] USB: musb: gadget_ep0: avoid SetupEnd interrupt (Sergei Shtylyov) [555084]
- [stable] USB: Fix a bug on appledisplay.c regarding signedness (pancho horrillo) [555084]
- [stable] USB: option: support hi speed for modem Haier CE100 (Donny Kurnia) [555084]
- [stable] USB: emi62: fix crash when trying to load EMI 6|2 firmware (Clemens Ladisch) [555084]
- [stable] drm/radeon: fix build on 64-bit with some compilers. (Dave Airlie) [555084]
- [stable] ASoC: Do not write to invalid registers on the wm9712. (Eric Millbrandt) [555084]
- [stable] powerpc: Handle VSX alignment faults correctly in little-endian mode (Neil Campbell) [555084]
- [stable] ACPI: Use the return result of ACPI lid notifier chain correctly (Zhao Yakui) [555084]
- [stable] ACPI: EC: Fix MSI DMI detection (Alexey Starikovskiy) [555084]
- [stable] acerhdf: limit modalias matching to supported (Stefan Bader) [555084]
- [stable] ALSA: hda - Fix missing capsrc_nids for ALC88x (Takashi Iwai) [555084]
- [stable] sound: sgio2audio/pdaudiocf/usb-audio: initialize PCM buffer (Clemens Ladisch) [555084]
- [stable] ASoC: wm8974: fix a wrong bit definition (Guennadi Liakhovetski) [555084]
- [stable] pata_cmd64x: fix overclocking of UDMA0-2 modes (Bartlomiej Zolnierkiewicz) [555084]
- [stable] pata_hpt3x2n: fix clock turnaround (Sergei Shtylyov) [555084]
- [stable] clockevents: Prevent clockevent_devices list corruption on cpu hotplug (Thomas Gleixner) [555084]
- [stable] sched: Select_task_rq_fair() must honour SD_LOAD_BALANCE (Peter Zijlstra) [555084]
- [stable] x86, cpuid: Add "volatile" to asm in native_cpuid() (Suresh Siddha) [555084]
- [stable] sched: Fix task_hot() test order (Peter Zijlstra) [555084]
- [stable] SCSI: fc class: fix fc_transport_init error handling (Mike Christie) [555084]
- [stable] SCSI: st: fix mdata->page_order handling (FUJITA Tomonori) [555084]
- [stable] SCSI: qla2xxx: dpc thread can execute before scsi host has been added (Michael Reed) [555084]
- [stable] SCSI: ipr: fix EEH recovery (Kleber Sacilotto de Souza) [555084]
- [stable] implement early_io{re,un}map for ia64 (Luck, Tony) [555084]
- [stable] perf_event: Fix incorrect range check on cpu number (Paul Mackerras) [555084]
- [stable] netfilter: xtables: document minimal required version (Jan Engelhardt) [555084]
- [stable] intel-iommu: ignore page table validation in pass through mode (Chris Wright) [555084]
- [stable] jffs2: Fix long-standing bug with symlink garbage collection. (David Woodhouse) [555084]
- [stable] ipvs: zero usvc and udest (Simon Horman) [555084]
- [stable] mm: sigbus instead of abusing oom (Hugh Dickins) [555084]
- [stable] drm/i915: Fix LVDS stability issue on Ironlake (Zhenyu Wang) [555084]
- [stable] drm/i915: PineView only has LVDS and CRT ports (Zhenyu Wang) [555084]
- [stable] drm/i915: Avoid NULL dereference with component_only tv_modes (Chris Wilson) [555084]
- [stable] x86: Under BIOS control, restore AP's APIC_LVTTHMR to the BSP value (Yong Wang) [555084]
- [stable] bcm63xx_enet: fix compilation failure after get_stats_count removal (Florian Fainelli) [555084]
- [stable] V4L/DVB (13116): gspca - ov519: Webcam 041e:4067 added. (Rafal Milecki) [555084]
- [stable] ext3: Fix data / filesystem corruption when write fails to copy data (Jan Kara) [555084]
- [stable] net: Fix userspace RTM_NEWLINK notifications. (Eric W. Biederman) [555084]
- [stable] ACPI: Use the ARB_DISABLE for the CPU which model id is less than 0x0f. (Zhao Yakui) [555084]
- [stable] vmalloc: conditionalize build of pcpu_get_vm_areas() (Tejun Heo) [555084]
- [stable] asus-laptop: change light sens default values. (Corentin Chary) [555084]
- [stable] acerhdf: add new BIOS versions (Peter Feuerer) [555084]
- [stable] matroxfb: fix problems with display stability (Alan Cox) [555084]
- [stable] ipw2100: fix rebooting hang with driver loaded (Zhu Yi) [555084]
- [stable] thinkpad-acpi: preserve rfkill state across suspend/resume (Henrique de Moraes Holschuh) [555084]
- [stable] thinkpad-acpi: fix default brightness_mode for R50e/R51 (Henrique de Moraes Holschuh) [555084]
- [stable] memcg: fix memory.memsw.usage_in_bytes for root cgroup (Kirill A. Shutemov) [555084]
- [stable] mac80211: Fix dynamic power save for scanning. (Vivek Natarajan) [555084]
- [stable] ath9k: fix tx status reporting (Felix Fietkau) [555084]
- [stable] tracing: Fix event format export (Johannes Berg) [555084]
- [stable] b43legacy: avoid PPC fault during resume (Larry Finger) [555084]
- [stable] sparc: Set UTS_MACHINE correctly. (David S. Miller) [555084]
- [stable] sparc64: Fix stack debugging IRQ stack regression. (David S. Miller) [555084]
- [stable] sparc64: Fix overly strict range type matching for PCI devices. (David S. Miller) [555084]
- [stable] sparc64: Don't specify IRQF_SHARED for LDC interrupts. (David S. Miller) [555084]
- [stable] b44 WOL setup: one-bit-off stack corruption kernel panic fix (Stanislav Brabec) [555084]
- [stable] ip_fragment: also adjust skb->truesize for packets not owned by a socket (Patrick McHardy) [555084]
- [stable] tcp: Stalling connections: Fix timeout calculation routine (Damian Lukowski) [555084]
- [stable] slc90e66: fix UDMA handling (Bartlomiej Zolnierkiewicz) [555084]
- [stable] xen: try harder to balloon up under memory pressure. (Ian Campbell) [555084]
- [stable] Xen balloon: fix totalram_pages counting. (Gianluca Guida) [555084]
- [stable] xen: explicitly create/destroy stop_machine workqueues outside suspend/resume region. (Ian Campbell) [555084]
- [stable] xen: use iret for return from 64b kernel to 32b usermode (Jeremy Fitzhardinge) [555084]
- [stable] xen: don't leak IRQs over suspend/resume. (Ian Campbell) [555084]
- [stable] xen: improve error handling in do_suspend. (Ian Campbell) [555084]
- [stable] xen: call clock resume notifier on all CPUs (Ian Campbell) [555084]
- [stable] xen: register runstate info for boot CPU early (Jeremy Fitzhardinge) [555084]
- [stable] xen: don't call dpm_resume_noirq() with interrupts disabled. (Jeremy Fitzhardinge) [555084]
- [stable] xen: register runstate on secondary CPUs (Ian Campbell) [555084]
- [stable] xen: register timer interrupt with IRQF_TIMER (Ian Campbell) [555084]
- [stable] xen: correctly restore pfn_to_mfn_list_list after resume (Ian Campbell) [555084]
- [stable] xen: restore runstate_info even if !have_vcpu_info_placement (Jeremy Fitzhardinge) [555084]
- [stable] xen: re-register runstate area earlier on resume. (Ian Campbell) [555084]
- [stable] xen/xenbus: make DEVICE_ATTR()s static (Jeremy Fitzhardinge) [555084]
- [stable] drm/i915: Add the missing clonemask for display port on Ironlake (Zhao Yakui) [555084]
- [stable] drm/i915: Set the error code after failing to insert new offset into mm ht. (Chris Wilson) [555084]
- [stable] drm/ttm: Fix build failure due to missing struct page (Martin Michlmayr) [555084]
- [stable] drm/radeon/kms: rs6xx/rs740: clamp vram to aperture size (Alex Deucher) [555084]
- [stable] drm/radeon/kms: fix vram setup on rs600 (Alex Deucher) [555084]
- [stable] drm/radeon/kms: fix legacy crtc2 dpms (Alex Deucher) [555084]
- [stable] drm/radeon/kms: handle vblanks properly with dpms on (Alex Deucher) [555084]
- [stable] drm/radeon/kms: Add quirk for HIS X1300 board (Alex Deucher) [555084]
- [stable] powerpc: Fix usage of 64-bit instruction in 32-bit altivec code (Benjamin Herrenschmidt) [555084]
- [stable] powerpc/therm_adt746x: Record pwm invert bit at module load time] (Darrick J. Wong) [555084]
- [stable] powerpc/windfarm: Add detection for second cpu pump (Bolko Maass) [555084]
- [stable] mm: hugetlb: fix hugepage memory leak in walk_page_range() (Naoya Horiguchi) [555084]
- [stable] mm: hugetlb: fix hugepage memory leak in mincore() (Naoya Horiguchi) [555084]
- [stable] x86: Fix bogus warning in apic_noop.apic_write() (Thomas Gleixner) [555084]
- [stable] rtl8187: Fix wrong rfkill switch mask for some models (Larry Finger) [555084]
- [stable] wireless: correctly report signal value for IEEE80211_HW_SIGNAL_UNSPEC (John W. Linville) [555084]
- [stable] mac80211: fix scan abort sanity checks (Johannes Berg) [555084]
- [stable] mac80211: Revert 'Use correct sign for mesh active path refresh' (Javier Cardona) [555084]
- [stable] mac80211: Fixed bug in mesh portal paths (Javier Cardona) [555084]
- [stable] mac80211: Fix bug in computing crc over dynamic IEs in beacon (Vasanthakumar Thiagarajan) [555084]
- [stable] Serial: Do not read IIR in serial8250_start_tx when UART_BUG_TXEN (Ian Jackson) [555084]
- [stable] Driver core: fix race in dev_driver_string (Alan Stern) [555084]
- [stable] debugfs: fix create mutex racy fops and private data (Mathieu Desnoyers) [555084]
- [stable] devpts_get_tty() should validate inode (Sukadev Bhattiprolu) [555084]
- [stable] futex: Take mmap_sem for get_user_pages in fault_in_user_writeable (Andi Kleen) [555084]
- [stable] md/bitmap: protect against bitmap removal while being updated. (NeilBrown) [555084]
- [stable] hfs: fix a potential buffer overflow (Amerigo Wang) [555084]
- [stable] pxa/em-x270: fix usb hub power up/reset sequence (Igor Grinberg) [555084]
- [stable] USB: Close usb_find_interface race v3 (Russ Dill) [555084]
- [stable] USB: usb-storage: add BAD_SENSE flag (Alan Stern) [555084]
- [stable] USB: usbtmc: repeat usb_bulk_msg until whole message is transfered (Andre Herms) [555084]
- [stable] USB: option.c: add support for D-Link DWM-162-U5 (Zhang Le) [555084]
- [stable] USB: musb_gadget_ep0: fix unhandled endpoint 0 IRQs, again (Sergei Shtylyov) [555084]
- [stable] USB: xhci: Add correct email and files to MAINTAINERS entry. (Sarah Sharp) [555084]
- [stable] jbd2: don't wipe the journal on a failed journal checksum (Theodore Ts'o) [555084]
- [stable] UBI: flush wl before clearing update marker (Sebastian Andrzej Siewior) [555084]
- [stable] bsdacct: fix uid/gid misreporting (Alexey Dobriyan) [555084]
- [stable] V4L/DVB: Fix test in copy_reg_bits() (Roel Kluin) [555084]
- [stable] pata_hpt{37x|3x2n}: fix timing register masks (take 2) (Sergei Shtylyov) [555084]
- [stable] x86: Fix typo in Intel CPU cache size descriptor (Dave Jones) [555084]
- [stable] x86: Add new Intel CPU cache size descriptors (Dave Jones) [555084]
- [stable] x86: Fix duplicated UV BAU interrupt vector (Cliff Wickman) [555084]
- [stable] x86/mce: Set up timer unconditionally (Jan Beulich) [555084]
- [stable] x86, mce: don't restart timer if disabled (Hidetoshi Seto) [555084]
- [stable] x86: Use -maccumulate-outgoing-args for sane mcount prologues (Thomas Gleixner) [555084]
- [stable] x86: Prevent GCC 4.4.x (pentium-mmx et al) function prologue wreckage (Thomas Gleixner) [555084]
- [stable] KVM: x86: include pvclock MSRs in msrs_to_save (Glauber Costa) [555084]
- [stable] KVM: fix irq_source_id size verification (Marcelo Tosatti) [555084]
- [stable] KVM: s390: Make psw available on all exits, not just a subset (Carsten Otte) [555084]
- [stable] KVM: s390: Fix prefix register checking in arch/s390/kvm/sigp.c (Carsten Otte) [555084]
- [stable] KVM: x86 emulator: limit instructions to 15 bytes (Avi Kivity) [555084]
- [stable] ALSA: hrtimer - Fix lock-up (Takashi Iwai) [555084]
- [stable] hrtimer: Fix /proc/timer_list regression (Feng Tang) [555084]
- [stable] ath5k: enable EEPROM checksum check (Luis R. Rodriguez) [555084]
- [stable] ath5k: allow setting txpower to 0 (Bob Copeland) [555084]
- [stable] ssb: Fix range check in sprom write (Michael Buesch) [555084]
- [stable] x86, apic: Enable lapic nmi watchdog on AMD Family 11h (Mikael Pettersson) [555084]
- [stable] x86: ASUS P4S800 reboot=bios quirk (Leann Ogasawara) [555084]
- [stable] x86: GART: pci-gart_64.c: Use correct length in strncmp (Joe Perches) [555084]
- [stable] x86: Fix iommu=nodac parameter handling (Tejun Heo) [555084]
- [stable] x86, Calgary IOMMU quirk: Find nearest matching Calgary while walking up the PCI tree (Darrick J. Wong) [555084]
- [stable] x86/amd-iommu: un__init iommu_setup_msi (Joerg Roedel) [555084]
- [stable] x86/amd-iommu: attach devices to pre-allocated domains early (Joerg Roedel) [555084]
- [stable] sched: Fix and clean up rate-limit newidle code (Mike Galbraith) [555084]
- [stable] sched: Rate-limit newidle (Mike Galbraith) [555084]
- [stable] sched: Fix affinity logic in select_task_rq_fair() (Mike Galbraith) [555084]
- [stable] sched: Check for an idle shared cache in select_task_rq_fair() (Mike Galbraith) [555084]
- [stable] PM / Runtime: Fix lockdep warning in __pm_runtime_set_status() (Rafael J. Wysocki) [555084]
- [stable] perf_event: Initialize data.period in perf_swevent_hrtimer() (Xiao Guangrong) [555084]
- [stable] perf_event: Fix invalid type in ioctl definition (Arjan van de Ven) [555084]
- [stable] rcu: Remove inline from forward-referenced functions (Paul E. McKenney) [555084]
- [stable] rcu: Fix note_new_gpnum() uses of ->gpnum (Paul E. McKenney) [555084]
- [stable] rcu: Fix synchronization for rcu_process_gp_end() uses of ->completed counter (Paul E. McKenney) [555084]
- [stable] rcu: Prepare for synchronization fixes: clean up for non-NO_HZ handling of ->completed counter (Paul E. McKenney) [555084]
- [stable] firewire: ohci: handle receive packets with a data length of zero (Jay Fenlason) [555084]
- [stable] USB: option: add pid for ZTE (zhao.ming9@zte.com.cn) [555084]
- [stable] USB: usb-storage: fix bug in fill_inquiry (Alan Stern) [555084]
- [stable] ext4: Fix potential fiemap deadlock (mmap_sem vs. i_data_sem) (Theodore Ts'o) [555084]
- [stable] ext4: Wait for proper transaction commit on fsync (Jan Kara) [555084]
- [stable] ext4: fix incorrect block reservation on quota transfer. (Dmitry Monakhov) [555084]
- [stable] ext4: quota macros cleanup (Dmitry Monakhov) [555084]
- [stable] ext4: ext4_get_reserved_space() must return bytes instead of blocks (Dmitry Monakhov) [555084]
- [stable] ext4: remove blocks from inode prealloc list on failure (Curt Wohlgemuth) [555084]
- [stable] ext4: Avoid data / filesystem corruption when write fails to copy data (Jan Kara) [555084]
- [stable] ext4: Return the PTR_ERR of the correct pointer in setup_new_group_blocks() (Roel Kluin) [555084]
- [stable] jbd2: Add ENOMEM checking in and for jbd2_journal_write_metadata_buffer() (Theodore Ts'o) [555084]
- [stable] ext4: move_extent_per_page() cleanup (Akira Fujita) [555084]
- [stable] ext4: initialize moved_len before calling ext4_move_extents() (Kazuya Mio) [555084]
- [stable] ext4: Fix double-free of blocks with EXT4_IOC_MOVE_EXT (Akira Fujita) [555084]
- [stable] ext4: make "norecovery" an alias for "noload" (Eric Sandeen) [555084]
- [stable] ext4: fix error handling in ext4_ind_get_blocks() (Jan Kara) [555084]
- [stable] ext4: avoid issuing unnecessary barriers (Theodore Ts'o) [555084]
- [stable] ext4: fix block validity checks so they work correctly with meta_bg (Theodore Ts'o) [555084]
- [stable] ext4: fix uninit block bitmap initialization when s_meta_first_bg is non-zero (Theodore Ts'o) [555084]
- [stable] ext4: don't update the superblock in ext4_statfs() (Theodore Ts'o) [555084]
- [stable] ext4: journal all modifications in ext4_xattr_set_handle (Eric Sandeen) [555084]
- [stable] ext4: fix i_flags access in ext4_da_writepages_trans_blocks() (Julia Lawall) [555084]
- [stable] ext4: make sure directory and symlink blocks are revoked (Theodore Ts'o) [555084]
- [stable] ext4: plug a buffer_head leak in an error path of ext4_iget() (Theodore Ts'o) [555084]
- [stable] ext4: fix possible recursive locking warning in EXT4_IOC_MOVE_EXT (Akira Fujita) [555084]
- [stable] ext4: fix lock order problem in ext4_move_extents() (Akira Fujita) [555084]
- [stable] ext4: fix the returned block count if EXT4_IOC_MOVE_EXT fails (Akira Fujita) [555084]
- [stable] ext4: avoid divide by zero when trying to mount a corrupted file system (Theodore Ts'o) [555084]
- [stable] ext4: fix potential buffer head leak when add_dirent_to_buf() returns ENOSPC (Theodore Ts'o) [555084]
- [stable] SCSI: megaraid_sas: fix 64 bit sense pointer truncation (Yang, Bo) [555084]
- [stable] SCSI: osd_protocol.h: Add missing #include (Martin Michlmayr) [555084]
- [stable] signal: Fix alternate signal stack check (Sebastian Andrzej Siewior) [555084]

* Sat Jan 09 2010 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-5.el6]
- [scsi] cciss: fix spinlock use (Tomas Henzl) [552910]
- [scsi] cciss,hpsa: reassign controllers (Tomas Henzl) [552192]
- [modsign] Don't attempt to sign a module if there are no key files (David Howells) [543529]
- [x86] Compile mce-inject module (Prarit Bhargava) [553323]
- [nfs] fix insecure export option (Steve Dickson) [437715]
- [nfs] NFS update to 2.6.33 part 3 (Steve Dickson) [437715]
- [nfs] NFS update to 2.6.33 part 2 (Steve Dickson) [437715]
- [nfs] NFS update to 2.6.33 part 1 (Steve Dickson) [437715]
- [s390] cio: deactivated devices can cause use after free panic (Hendrik Brueckner) [548490]
- [s390] cio: memory leaks when checking unusable devices (Hendrik Brueckner) [548490]
- [s390] cio: DASD steal lock task hangs (Hendrik Brueckner) [548490]
- [s390] cio: DASD cannot be set online (Hendrik Brueckner) [548490]
- [s390] cio: erratic DASD I/O behavior (Hendrik Brueckner) [548490]
- [s390] cio: not operational devices cannot be deactivated (Hendrik Brueckner) [548490]
- [s390] cio: initialization of I/O devices fails (Hendrik Brueckner) [548490]
- [s390] cio: kernel panic after unexpected interrupt (Hendrik Brueckner) [548490]
- [s390] cio: incorrect device state after device recognition and recovery (Hendrik Brueckner) [548490]
- [s390] cio: setting a device online or offline fails for unknown reasons (Hendrik Brueckner) [548490]
- [s390] cio: device recovery fails after concurrent hardware changes (Hendrik Brueckner) [548490]
- [s390] cio: device recovery stalls after multiple hardware events (Hendrik Brueckner) [548490]
- [s390] cio: double free under memory pressure (Hendrik Brueckner) [548490]
- [sunrpc] Don't display zero scope IDs (Jeff Layton) [463530]
- [sunrpc] Deprecate support for site-local addresses (Jeff Layton) [463530]
- [input] dell-laptop: Update rfkill state on switch change (Matthew Garrett) [547892]
- [input] Add support for adding i8042 filters (Matthew Garrett) [547892]
- [vfs] force reval of target when following LAST_BIND symlinks (Jeff Layton) [548153]
- [scsi] scsi_dh_rdac: add two IBM devices to rdac_dev_list (Rob Evers) [528576]
- [fs] ext4: flush delalloc blocks when space is low (Eric Sandeen) [526758]
- [fs] fs-writeback: Add helper function to start writeback if idle (Eric Sandeen) [526758]
- [fat] make discard a mount option (Jeff Moyer) [552355]
- [ext4] make trim/discard optional (and off by default) (Jeff Moyer) [552355]
- [fusion] bump version to 3.04.13 (Tomas Henzl) [548408]
- [fusion] fix for incorrect data underrun (Tomas Henzl) [548408]
- [fusion] remove unnecessary printk (Tomas Henzl) [548408]
- [cifs] NULL out tcon, pSesInfo, and srvTcp pointers when chasing DFS referrals (Jeff Layton) [545984]
- [fs] ext4: wait for log to commit when unmounting (Josef Bacik) [524267]
- [mm] hwpoison: backport the latest patches from linux-2.6.33 (Dean Nelson) [547705]
- [netdrv] bnx2i: update to 2.1.0 (Stanislaw Gruszka) [463268]
- [netdrv] cnic: fixes for RHEL6 (Stanislaw Gruszka) [463268]
- [gfs2] Fix potential race in glock code (Steven Whitehouse) [546279]
- [scsi] make driver PCI legacy I/O port free (Tomas Henzl) [549118]
- [scsi] eliminate double free (Tomas Henzl) [549351]
- [dlm] always use GFP_NOFS (David Teigland) [545904]
- [block] Fix topology stacking for data and discard alignment (Mike Snitzer) [549766]
- [scsi] scsi_dh: Make alua hardware handler s activate async (Rob Evers) [537257]
- [scsi] scsi_dh: Make hp hardware handler s activate async (Rob Evers) [537257]
- [scsi] scsi_dh: Make rdac hardware handler s activate async (Rob Evers) [537257]
- [scsi] scsi_dh: Change the scsidh_activate interface to be asynchronous (Rob Evers) [537257]
- [netdrv] update tg3 to version 3.105 (John Feeney) [465194]
- [netdrv] bnx2x: update to 1.52.1-5 (Stanislaw Gruszka) [464427]
- [netdrv] ixgbe: add support for 82599-KR and update to latest upstream (Andy Gospodarek) [462781]
- [block] cfq-iosched: Remove prio_change logic for workload selection (Jeff Moyer) [548796]
- [block] cfq-iosched: Get rid of nr_groups (Jeff Moyer) [548796]
- [block] cfq-iosched: Remove the check for same cfq group from allow_merge (Jeff Moyer) [548796]
- [block] cfq: set workload as expired if it doesn't have any slice left (Jeff Moyer) [548796]
- [block] Fix a CFQ crash in "for-2.6.33" branch of block tree (Jeff Moyer) [548796]
- [block] cfq: Remove wait_request flag when idle time is being deleted (Jeff Moyer) [548796]
- [block] cfq-iosched: commenting non-obvious initialization (Jeff Moyer) [548796]
- [block] cfq-iosched: Take care of corner cases of group losing share due to deletion (Jeff Moyer) [548796]
- [block] cfq-iosched: Get rid of cfqq wait_busy_done flag (Jeff Moyer) [548796]
- [block] cfq: Optimization for close cooperating queue searching (Jeff Moyer) [548796]
- [block] cfq-iosched: reduce write depth only if sync was delayed (Jeff Moyer) [548796]
- [x86] ucode-amd: Load ucode-patches once and not separately of each CPU (George Beshers) [548840]
- [x86] Remove enabling x2apic message for every CPU (George Beshers) [548840]
- [x86] Limit number of per cpu TSC sync messages (George Beshers) [548840]
- [sched] Limit the number of scheduler debug messages (George Beshers) [548840]
- [init] Limit the number of per cpu calibration bootup messages (George Beshers) [548840]
- [x86] Limit the number of processor bootup messages (George Beshers) [548840]
- [x86] cpu: mv display_cacheinfo -> cpu_detect_cache_sizes (George Beshers) [548840]
- [x86] Remove CPU cache size output for non-Intel too (George Beshers) [548840]
- [x86] Remove the CPU cache size printk's (George Beshers) [548840]

* Wed Dec 23 2009 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-4.el6]
- [kvm] VMX: Use shared msr infrastructure (Avi Kivity) [547777]
- [kvm] x86 shared msr infrastructure (Avi Kivity) [547777]
- [kvm] VMX: Move MSR_KERNEL_GS_BASE out of the vmx autoload msr area (Avi Kivity) [547777]
- [kvm] core, x86: Add user return notifiers (Avi Kivity) [547777]
- [quota] ext4: Support for 64-bit quota format (Jerome Marchand) [546311]
- [quota] ext3: Support for vfsv1 quota format (Jerome Marchand) [546311]
- [quota] Implement quota format with 64-bit space and inode limits (Jerome Marchand) [546311]
- [quota] Move definition of QFMT_OCFS2 to linux/quota.h (Jerome Marchand) [546311]
- [scsi] cciss: remove pci-ids (Tomas Henzl) [464649]
- [scsi] hpsa: new driver (Tomas Henzl) [464649]
- [mm] Add file page writeback mm tracepoints. (Larry Woodman) [523093]
- [mm] Add page reclaim mm tracepoints. (Larry Woodman) [523093]
- [mm] Add file page mm tracepoints. (Larry Woodman) [523093]
- [mm] Add anonynmous page mm tracepoints. (Larry Woodman) [523093]
- [mm] Add mm tracepoint definitions to kmem.h (Larry Woodman) [523093]
- [ksm] fix ksm.h breakage of nommu build (Izik Eidus) [548586]
- [ksm] remove unswappable max_kernel_pages (Izik Eidus) [548586]
- [ksm] memory hotremove migration only (Izik Eidus) [548586]
- [ksm] rmap_walk to remove_migation_ptes (Izik Eidus) [548586]
- [ksm] mem cgroup charge swapin copy (Izik Eidus) [548586]
- [ksm] share anon page without allocating (Izik Eidus) [548586]
- [ksm] take keyhole reference to page (Izik Eidus) [548586]
- [ksm] hold anon_vma in rmap_item (Izik Eidus) [548586]
- [ksm] let shared pages be swappable (Izik Eidus) [548586]
- [ksm] fix mlockfreed to munlocked (Izik Eidus) [548586]
- [ksm] stable_node point to page and back (Izik Eidus) [548586]
- [ksm] separate stable_node (Izik Eidus) [548586]
- [ksm] singly-linked rmap_list (Izik Eidus) [548586]
- [ksm] cleanup some function arguments (Izik Eidus) [548586]
- [ksm] remove redundancies when merging page (Izik Eidus) [548586]
- [ksm] three remove_rmap_item_from_tree cleanups (Izik Eidus) [548586]
- [mm] stop ptlock enlarging struct page (Izik Eidus) [548586]
- [mm] vmscan: do not evict inactive pages when skipping an active list scan (Rik van Riel) [548457]
- [mm] vmscan: make consistent of reclaim bale out between do_try_to_free_page and shrink_zone (Rik van Riel) [548457]
- [mm] vmscan: kill sc.swap_cluster_max (Rik van Riel) [548457]
- [mm] vmscan: zone_reclaim() dont use insane swap_cluster_max (Rik van Riel) [548457]
- [mm] vmscan: kill hibernation specific reclaim logic and unify it (Rik van Riel) [548457]
- [mm] vmscan: separate sc.swap_cluster_max and sc.nr_max_reclaim (Rik van Riel) [548457]
- [mm] vmscan: stop kswapd waiting on congestion when the min watermark is not being met (Rik van Riel) [548457]
- [mm] vmscan: have kswapd sleep for a short interval and double check it should be asleep (Rik van Riel) [548457]
- [mm] pass address down to rmap ones (Rik van Riel) [548457]
- [mm] CONFIG_MMU for PG_mlocked (Rik van Riel) [548457]
- [mm] mlocking in try_to_unmap_one (Rik van Riel) [548457]
- [mm] define PAGE_MAPPING_FLAGS (Rik van Riel) [548457]
- [mm] swap_info: note SWAP_MAP_SHMEM (Rik van Riel) [548457]
- [mm] swap_info: swap count continuations (Rik van Riel) [548457]
- [mm] swap_info: swap_map of chars not shorts (Rik van Riel) [548457]
- [mm] swap_info: SWAP_HAS_CACHE cleanups (Rik van Riel) [548457]
- [mm] swap_info: miscellaneous minor cleanups (Rik van Riel) [548457]
- [mm] swap_info: include first_swap_extent (Rik van Riel) [548457]
- [mm] swap_info: change to array of pointers (Rik van Riel) [548457]
- [mm] swap_info: private to swapfile.c (Rik van Riel) [548457]
- [mm] move inc_zone_page_state(NR_ISOLATED) to just isolated place (Rik van Riel) [548457]
- [xen] support MAXSMP (Andrew Jones) [547129]
- [xen] wait up to 5 minutes for device connetion and fix fallout (Paolo Bonzini) [523630]
- [uv] x86 SGI: Map low MMR ranges (George Beshers) [548181]
- [uv] gru: function to generate chipset IPI values (George Beshers) [548181]
- [uv] x86 RTC: Clean up error handling (George Beshers) [548181]
- [uv] x86: RTC: Add clocksource only boot option (George Beshers) [548181]
- [uv] x86: RTC: Fix early expiry handling (George Beshers) [548181]
- [uv] x86: introduce uv_gpa_is_mmr (George Beshers) [548181]
- [uv] x86: function to translate from gpa -> socket_paddr (George Beshers) [548181]
- [uv] x86: SGI UV: Fix BAU initialization (George Beshers) [548181]
- [s390] zfcp: Block SCSI EH thread for rport state BLOCKED (Hendrik Brueckner) [547413]
- [scsi] scsi_transport_fc: Introduce helper function for blocking scsi_eh (Hendrik Brueckner) [547413]
- [s390] zfcp: improve FSF error reporting (Hendrik Brueckner) [547386]
- [s390] zfcp: fix ELS ADISC handling to prevent QDIO errors (Hendrik Brueckner) [547385]
- [s390] zfcp: Assign scheduled work to driver queue (Hendrik Brueckner) [547377]
- [s390] zfcp: Don't fail SCSI commands when transitioning to blocked fc_rport (Hendrik Brueckner) [547379]
- [s390] ctcm: suspend has to wait for outstanding I/O (Hendrik Brueckner) [546633]
- [s390] cmm: free pages on hibernate (Hendrik Brueckner) [546407]
- [s390] iucv: add work_queue cleanup for suspend (Hendrik Brueckner) [546319]
- [s390] dasd: let device initialization wait for LCU setup (Hendrik Brueckner) [547735]
- [s390] dasd: remove strings from s390dbf (Hendrik Brueckner) [547735]
- [s390] dasd: enable prefix independent of pav support (Hendrik Brueckner) [547735]
- [sound] ALSA HDA driver update 2009-12-15 (Jaroslav Kysela) [525391]
- [utrace] utrace core (Roland McGrath) [549491]
- [utrace] implement utrace-ptrace (Roland McGrath) [549491]
- [ptrace] reorder the code in kernel/ptrace.c (Roland McGrath) [549491]
- [ptrace] export __ptrace_detach() and do_notify_parent_cldstop() (Roland McGrath) [549491]
- [ptrace_signal] check PT_PTRACED before reporting a signal (Roland McGrath) [549491]
- [tracehooks] check PT_PTRACED before reporting the single-step (Roland McGrath) [549491]
- [tracehooks] kill some PT_PTRACED checks (Roland McGrath) [549491]
- [signals] check ->group_stop_count after tracehook_get_signal() (Roland McGrath) [549491]
- [ptrace] x86: change syscall_trace_leave() to rely on tracehook when stepping (Roland McGrath) [549491]
- [ptrace] x86: implement user_single_step_siginfo() (Roland McGrath) [549491]
- [ptrace] change tracehook_report_syscall_exit() to handle stepping (Roland McGrath) [549491]
- [ptrace] powerpc: implement user_single_step_siginfo() (Roland McGrath) [549491]
- [ptrace] introduce user_single_step_siginfo() helper (Roland McGrath) [549491]
- [ptrace] copy_process() should disable stepping (Roland McGrath) [549491]
- [ptrace] cleanup ptrace_init_task()->ptrace_link() path (Roland McGrath) [549491]

* Thu Dec 17 2009 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-3.el6]
- [modsign] Don't check e_entry in ELF header (David Howells) [548027]
- [pci] pciehp: Provide an option to disable native PCIe hotplug (Matthew Garrett) [517050]
- [s390] OSA QDIO data connection isolation (Hendrik Brueckner) [537496]
- [s390] zcrypt: adjust speed rating of cex3 adapters (Hendrik Brueckner) [537495]
- [s390] zcrypt: adjust speed rating between cex2 and pcixcc (Hendrik Brueckner) [537495]
- [s390] zcrypt: use definitions for cex3 (Hendrik Brueckner) [537495]
- [s390] zcrypt: add support for cex3 device types (Hendrik Brueckner) [537495]
- [s390] zcrypt: special command support for cex3 exploitation (Hendrik Brueckner) [537495]
- [s390] zcrypt: initialize ap_messages for cex3 exploitation (Hendrik Brueckner) [537495]
- [s390] kernel: performance counter fix and page fault optimization (Hendrik Brueckner) [546396]
- [s390] kernel: fix dump indicator (Hendrik Brueckner) [546285]
- [s390] dasd: support DIAG access for read-only devices (Hendrik Brueckner) [546309]
- [s390] zcrypt: Do not simultaneously schedule hrtimer (Hendrik Brueckner) [546291]
- [s390] kernel: clear high-order bits after switching to 64-bit mode (Hendrik Brueckner) [546314]
- [virt] vhost: add missing architectures (Michael S. Tsirkin) [540389]
- [virt] vhost_net: a kernel-level virtio server (Michael S. Tsirkin) [540389]
- [virt] mm: export use_mm/unuse_mm to modules (Michael S. Tsirkin) [540389]
- [virt] tun: export underlying socket (Michael S. Tsirkin) [540389]
- [dm] snapshot-merge support from 2.6.33 (Mike Snitzer) [547563]
- [dm] snapshot changes from 2.6.33 (Mike Snitzer) [547563]
- [dm] crypt changes from 2.6.33 (Mike Snitzer) [547563]
- [dm] raid1 changes from 2.6.33 (Mike Snitzer) [547563]
- [dm] core and mpath changes from 2.6.33 (Mike Snitzer) [547563]
- [scsi] fix dma handling when using virtual hosts (Mike Christie) [525241]
- [nfs] convert proto= option to use netids rather than a protoname (Jeff Layton) [545973]

* Fri Dec 11 2009 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-2.el6]
- [block] config: enable CONFIG_BLK_DEV_INTEGRITY (Jeff Moyer) [490732]
- [block] config: enable CONFIG_BLK_CGROUP (Jeff Moyer) [425895]
- [libata] Clarify ata_set_lba_range_entries function (Jeff Moyer) [528046]
- [libata] Report zeroed read after Trim and max discard size (Jeff Moyer) [528046]
- [scsi] Correctly handle thin provisioning write error (Jeff Moyer) [528046]
- [scsi] sd: WRITE SAME(16) / UNMAP support (Jeff Moyer) [528046]
- [scsi] scsi_debug: Thin provisioning support (Jeff Moyer) [528046]
- [scsi] Add missing command definitions (Jeff Moyer) [528046]
- [block] Add support for the ATA TRIM command in libata. (Jeff Moyer) [528046]
- [block] dio: fix performance regression (Jeff Moyer) [545507]
- [block] cfq-iosched: Do not access cfqq after freeing it (Jeff Moyer) [425895]
- [block] include linux/err.h to use ERR_PTR (Jeff Moyer) [425895]
- [block] cfq-iosched: use call_rcu() instead of doing grace period stall on queue exit (Jeff Moyer) [425895]
- [block] blkio: Allow CFQ group IO scheduling even when CFQ is a module (Jeff Moyer) [425895]
- [block] blkio: Implement dynamic io controlling policy registration (Jeff Moyer) [425895]
- [block] blkio: Export some symbols from blkio as its user CFQ can be a module (Jeff Moyer) [425895]
- [block] cfq-iosched: make nonrot check logic consistent (Jeff Moyer) [545225]
- [block] io controller: quick fix for blk-cgroup and modular CFQ (Jeff Moyer) [425895]
- [block] cfq-iosched: move IO controller declerations to a header file (Jeff Moyer) [425895]
- [block] cfq-iosched: fix compile problem with !CONFIG_CGROUP (Jeff Moyer) [425895]
- [block] blkio: Documentation (Jeff Moyer) [425895]
- [block] blkio: Wait on sync-noidle queue even if rq_noidle = 1 (Jeff Moyer) [425895]
- [block] blkio: Implement group_isolation tunable (Jeff Moyer) [425895]
- [block] blkio: Determine async workload length based on total number of queues (Jeff Moyer) [425895]
- [block] blkio: Wait for cfq queue to get backlogged if group is empty (Jeff Moyer) [425895]
- [block] blkio: Propagate cgroup weight updation to cfq groups (Jeff Moyer) [425895]
- [block] blkio: Drop the reference to queue once the task changes cgroup (Jeff Moyer) [425895]
- [block] blkio: Provide some isolation between groups (Jeff Moyer) [425895]
- [block] blkio: Export disk time and sectors used by a group to user space (Jeff Moyer) [425895]
- [block] blkio: Some debugging aids for CFQ (Jeff Moyer) [425895]
- [block] blkio: Take care of cgroup deletion and cfq group reference counting (Jeff Moyer) [425895]
- [block] blkio: Dynamic cfq group creation based on cgroup tasks belongs to (Jeff Moyer) [425895]
- [block] blkio: Group time used accounting and workload context save restore (Jeff Moyer) [425895]
- [block] blkio: Implement per cfq group latency target and busy queue avg (Jeff Moyer) [425895]
- [block] blkio: Introduce per cfq group weights and vdisktime calculations (Jeff Moyer) [425895]
- [block] blkio: Introduce blkio controller cgroup interface (Jeff Moyer) [425895]
- [block] blkio: Introduce the root service tree for cfq groups (Jeff Moyer) [425895]
- [block] blkio: Keep queue on service tree until we expire it (Jeff Moyer) [425895]
- [block] blkio: Implement macro to traverse each service tree in group (Jeff Moyer) [425895]
- [block] blkio: Introduce the notion of cfq groups (Jeff Moyer) [425895]
- [block] blkio: Set must_dispatch only if we decided to not dispatch the request (Jeff Moyer) [425895]
- [block] cfq-iosched: no dispatch limit for single queue (Jeff Moyer) [425895]
- [block] Allow devices to indicate whether discarded blocks are zeroed (Jeff Moyer) [545203]
- [block] Revert "cfq: Make use of service count to estimate the rb_key offset" (Jeff Moyer) [425895]
- [block] cfq-iosched: fix corner cases in idling logic (Jeff Moyer) [425895]
- [block] cfq-iosched: idling on deep seeky sync queues (Jeff Moyer) [425895]
- [block] cfq-iosched: fix no-idle preemption logic (Jeff Moyer) [425895]
- [block] cfq-iosched: fix ncq detection code (Jeff Moyer) [425895]
- [block] cfq-iosched: cleanup unreachable code (Jeff Moyer) [425895]
- [block] cfq: Make use of service count to estimate the rb_key offset (Jeff Moyer) [425895]
- [block] partitions: read whole sector with EFI GPT header (Jeff Moyer) [463632]
- [block] partitions: use sector size for EFI GPT (Jeff Moyer) [463632]
- [block] Expose discard granularity (Jeff Moyer) [545203]
- [block] cfq-iosched: fix next_rq computation (Jeff Moyer) [425895]
- [block] cfq-iosched: simplify prio-unboost code (Jeff Moyer) [425895]
- [block] blkdev: flush disk cache on ->fsync (Jeff Moyer) [545199]
- [block] cfq-iosched: fix style issue in cfq_get_avg_queues() (Jeff Moyer) [425895]
- [block] cfq-iosched: fairness for sync no-idle queues (Jeff Moyer) [425895]
- [block] cfq-iosched: enable idling for last queue on priority class (Jeff Moyer) [425895]
- [block] cfq-iosched: reimplement priorities using different service trees (Jeff Moyer) [425895]
- [block] cfq-iosched: preparation to handle multiple service trees (Jeff Moyer) [425895]
- [block] cfq-iosched: adapt slice to number of processes doing I/O (Jeff Moyer) [425895]
- [block] cfq-iosched: improve hw_tag detection (Jeff Moyer) [425895]
- [block] cfq: break apart merged cfqqs if they stop cooperating (Jeff Moyer) [533932]
- [block] cfq: change the meaning of the cfqq_coop flag (Jeff Moyer) [533932]
- [block] cfq: merge cooperating cfq_queues (Jeff Moyer) [533932]
- [block] cfq: calculate the seek_mean per cfq_queue not per cfq_io_context (Jeff Moyer) [533932]
- [block] CFQ is more than a desktop scheduler (Jeff Moyer) [533932]
- [block] revert: cfq-iosched: limit coop preemption (Jeff Moyer) [533932]
- perf: Don't free perf_mmap_data until work has been done (Aristeu Rozanski) [547432]
- ext4: Fix insuficient checks in EXT4_IOC_MOVE_EXT (Aristeu Rozanski) [547432]
- agp: clear GTT on intel (Aristeu Rozanski) [547432]
- drm/i915: Fix sync to vblank when VGA output is turned off (Aristeu Rozanski) [547432]
- drm: nouveau fixes (Aristeu Rozanski) [547432]
- drm: radeon dp support (Aristeu Rozanski) [547432]
- drm: radeon fixes (Aristeu Rozanski) [547432]
- KVM: allow userspace to adjust kvmclock offset (Aristeu Rozanski) [547432]
- ath9k backports (Aristeu Rozanski) [547432]
- intel-iommu backport (Aristeu Rozanski) [547432]
- updating patch linux-2.6-nfsd4-proots.patch (2.6.32-8.fc13 reference) (Aristeu Rozanski) [547432]
- updating linux-2.6-execshield.patch (2.6.32-8.fc13 reference) (Aristeu Rozanski) [547432]

* Tue Dec 08 2009 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-1.el6]
- [rebase] Rebased to 2.6.32

* Mon Dec 07 2009 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-0.54.el6]
- [edac] amd64_edac: disabling temporarily (Aristeu Rozanski)
- [x86] Enable CONFIG_SPARSE_IRQ (Prarit Bhargava) [543174]
- [x86] panic if AMD cpu_khz is wrong (Prarit Bhargava) [523468]
- [infiniband] Rewrite SG handling for RDMA logic (Mike Christie) [540269]

* Wed Nov 25 2009 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-0.53.el6]
- [net] Add acession counts to all datagram protocols (Neil Horman) [445366]
- [modsign] Enable module signing in the RHEL RPM (David Howells) [517341]
- [modsign] Don't include .note.gnu.build-id in the digest (David Howells) [517341]
- [modsign] Apply signature checking to modules on module load (David Howells) [517341]
- [modsign] Module signature checker and key manager (David Howells) [517341]
- [modsign] Module ELF verifier (David Howells) [517341]
- [modsign] Add indications of module ELF types (David Howells) [517341]
- [modsign] Multiprecision maths library (David Howells) [517341]
- [procfs] add ability to modify proc file limits from outside a processes own context (Neil Horman) [461946]
- [s390x] fix build failure with CONFIG_FTRACE_SYSCALLS (Aristeu Rozanski) [538978]

* Wed Nov 25 2009 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-0.52.el6]
- [x86] AMD Northbridge: Verify NB's node is online (Prarit Bhargava) [536769]
- [scsi] devinfo update for Hitachi entries (Takahiro Yasui) [526763]
- [net] export device speed and duplex via sysfs (Andy Gospodarek) [453432]
- [ppc64] Fix kcrctab_ sections to undo undesireable relocations that break kdump (Neil Horman) [509012]
- [mm] Limit 32-bit x86 systems to 16GB and prevent panic on boot when system has more than ~30GB (Larry Woodman) [532039]

* Mon Nov 23 2009 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-0.51.el6]
- [kernel] Set panic_on_oops to 1 (Prarit Bhargava) [529963]
- [kdump] kexec: allow to shrink reserved memory (Amerigo Wang) [523091]
- [kdump] doc: update the kdump document (Amerigo Wang) [523091]
- [kdump] powerpc: implement crashkernel=auto (Amerigo Wang) [523091]
- [kdump] powerpc: add CONFIG_KEXEC_AUTO_RESERVE (Amerigo Wang) [523091]
- [kdump] ia64: implement crashkernel=auto (Amerigo Wang) [523091]
- [kdump] ia64: add CONFIG_KEXEC_AUTO_RESERVE (Amerigo Wang) [523091]
- [kdump] x86: implement crashkernel=auto (Amerigo Wang) [523091]
- [kdump] x86: add CONFIG_KEXEC_AUTO_RESERVE (Amerigo Wang) [523091]
- [block] aio: implement request batching (Jeff Moyer) [533931]
- [block] get rid of the WRITE_ODIRECT flag (Jeff Moyer) [533931]

* Sat Nov 21 2009 Aristeu Rozanski <arozansk@redhat.com> [2.6.32-0.50.el6]
- [crypto] padlock-aes: Use the correct mask when checking whether copying is required (Chuck Ebbert)
- [rfkill] add support to a key to control all radios (Aristeu Rozanski)
- [acpi] be less verbose about old BIOSes (Aristeu Rozanski)
- [drm] intel big hammer (Aristeu Rozanski)
- [e1000] add quirk for ich9 (Aristeu Rozanski)
- [pci] cacheline sizing (Dave Jones)
- [crash] add crash driver (Dave Anderson)
- [fb] disable fbcon logo with parameter (Aristeu Rozanski)
- [pci] silence some PCI resource allocation errors (Aristeu Rozanski)
- [serio] disable error messages when i8042 isn't found (Peter Jones)
- [serial] Enable higher baud rates for 16C95x (Aristeu Rozanski)
- [input] remove pcspkr modalias (Aristeu Rozanski)
- [floppy] remove the floppy pnp modalias (Aristeu Rozanski)
- [input] remove unwanted messages on spurious events (Aristeu Rozanski)
- [sound] hda intel prealloc 4mb dmabuffer (Aristeu Rozanski)
- [sound] disables hda beep by default (Aristeu Rozanski)
- [pci] sets PCIE ASPM default policy to POWERSAVE (Aristeu Rozanski)
- [pci] add config option to control the default state of PCI MSI interrupts (Aristeu Rozanski)
- [debug] always inline kzalloc (Aristeu Rozanski)
- [debug] add would_have_oomkilled procfs ctl (Aristeu Rozanski)
- [debug] add calls to print_tainted() on spinlock functions (Aristeu Rozanski)
- [debug] display tainted information on other places (Aristeu Rozanski)
- [x86] add option to control the NMI watchdog timeout (Aristeu Rozanski)
- [debug] print common struct sizes at boot time (Aristeu Rozanski)
- [acpi] Disable firmware video brightness change by default (Matthew Garrett)
- [acpi] Disable brightness switch by default (Aristeu Rozanski)
- [usb] enable autosuspend on UVC by default (Matthew Garrett)
- [usb] enable autosuspend by default on qcserial (Matthew Garrett)
- [usb] Allow drivers to enable USB autosuspend on a per-device basis (Matthew Garrett)
- [nfs] make nfs4 callback hidden (Steve Dickson)
- [nfsd4] proots (Aristeu Rozanski)
- [execshield] introduce execshield (Aristeu Rozanski)
- [powerpc] add modalias_show operation (Aristeu Rozanski)
- [hwmon] add VIA hwmon temperature sensor support (Aristeu Rozanski)
- [utrace] introduce utrace implementation (Aristeu Rozanski)
- [build] introduce AFTER_LINK variable (Aristeu Rozanski)


###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
